var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
import { Node as Node$1, Extension, getExtensionField, InputRule, wrappingInputRule, mergeAttributes, isNodeActive, markInputRule, markPasteRule, Editor } from "@tiptap/core";
import { PluginKey, Plugin, TextSelection } from "prosemirror-state";
import Suggestion from "@tiptap/suggestion";
import { DecorationSet, Decoration } from "prosemirror-view";
import { Step } from "prosemirror-transform";
import { sendableSteps, getVersion, receiveTransaction, collab } from "prosemirror-collab";
import "prosemirror-markdown";
import CodeBlockLowlight from "@tiptap/extension-code-block-lowlight";
import Text from "@tiptap/extension-text";
import TiptapImage from "@tiptap/extension-image";
import { generateRemoteUrl, generateUrl } from "@nextcloud/router";
import { getCurrentUser } from "@nextcloud/auth";
import { NodeViewWrapper, VueNodeViewRenderer, NodeViewContent, EditorContent } from "@tiptap/vue-2";
import ClickOutside from "vue-click-outside";
import Vue from "vue";
import Vuex, { Store } from "vuex";
import { getBuilder } from "@nextcloud/browser-storage";
import TiptapBulletList from "@tiptap/extension-bullet-list";
import TipTapTaskItem from "@tiptap/extension-task-item";
import { findParentNodeClosestToPos } from "prosemirror-utils";
import TiptapTaskList from "@tiptap/extension-task-list";
import TipTapHeading from "@tiptap/extension-heading";
import container from "markdown-it-container";
import { Table as Table$1 } from "@tiptap/extension-table";
import { TableCell as TableCell$1 } from "@tiptap/extension-table-cell";
import { TableHeader as TableHeader$1 } from "@tiptap/extension-table-header";
import { TableRow as TableRow$1 } from "@tiptap/extension-table-row";
import { isInTable, selectionCell, moveCellForward } from "prosemirror-tables";
import require$$2 from "vue-material-design-icons/DotsHorizontal";
import Document from "@tiptap/extension-document";
import Paragraph from "@tiptap/extension-paragraph";
import Blockquote from "@tiptap/extension-blockquote";
import OrderedList from "@tiptap/extension-ordered-list";
import ListItem from "@tiptap/extension-list-item";
import CodeBlock from "@tiptap/extension-code-block";
import HorizontalRule from "@tiptap/extension-horizontal-rule";
import Dropcursor from "@tiptap/extension-dropcursor";
import TipTapItalic from "@tiptap/extension-italic";
import TipTapLink from "@tiptap/extension-link";
import MarkdownIt from "markdown-it";
import taskLists from "markdown-it-task-lists";
import TipTapStrike from "@tiptap/extension-strike";
import { Bold, starInputRegex, starPasteRegex, underscoreInputRegex, underscorePasteRegex } from "@tiptap/extension-bold";
import TipTapUnderline from "@tiptap/extension-underline";
/*
 * @copyright Copyright (c) 2021 Jonas <jonas@freesources.org>
 *
 * @author Jonas <jonas@freesources.org>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
const EmojiPluginKey = new PluginKey("emoji");
Node$1.create({
  name: "emoji",
  addOptions() {
    return {
      HTMLAttributes: {},
      suggestion: {
        char: ":",
        pluginKey: EmojiPluginKey,
        command: ({ editor, range, props }) => {
          editor.chain().focus().insertContentAt(range, props.native + " ").run();
        }
      }
    };
  },
  content: "text*",
  addCommands() {
    return {
      emoji: (emojiObject) => ({ commands }) => {
        return commands.insertContent(emojiObject.native + " ");
      }
    };
  },
  addProseMirrorPlugins() {
    return [
      Suggestion(__spreadValues({
        editor: this.editor
      }, this.options.suggestion))
    ];
  }
});
/*
 * @copyright Copyright (c) 2019 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
Extension.create({
  name: "customkeymap",
  addKeyboardShortcuts() {
    return this.options;
  },
  addProseMirrorPlugins() {
    return [
      new Plugin({
        props: {
          handleKeyDown(view, event) {
            const key = event.key || event.keyCode;
            if ((event.ctrlKey || event.metaKey) && !event.shiftKey && (key === "f" || key === 70)) {
              event.stopPropagation();
              window.dispatchEvent(event);
              return true;
            }
          }
        }
      })
    ];
  }
});
/*
 * @copyright Copyright (c) 2020 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
class Span {
  constructor(from, to, author) {
    this.from = from;
    this.to = to;
    this.author = author;
  }
}
/*
 * @copyright Copyright (c) 2021 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
function updateBlameMap(map, transform, clientIDs) {
  const result = [];
  const mapping = transform.mapping;
  for (let i = 0; i < map.length; i++) {
    const span = map[i];
    const from = mapping.map(span.from, 1);
    const to = mapping.map(span.to, -1);
    if (from < to)
      result.push(new Span(from, to, span.author));
  }
  for (let i = 0; i < mapping.maps.length; i++) {
    const map2 = mapping.maps[i];
    const after = mapping.slice(i + 1);
    map2.forEach((_s, _e, start, end) => {
      insertIntoBlameMap(result, after.map(start, 1), after.map(end, -1), clientIDs[i]);
    });
  }
  return result;
}
function insertIntoBlameMap(map, from, to, author) {
  if (from >= to) {
    return;
  }
  let pos = 0;
  let next;
  for (; pos < map.length; pos++) {
    next = map[pos];
    if (next.author === author) {
      if (next.to >= from)
        break;
    } else if (next.to > from) {
      if (next.from < from) {
        const left = new Span(next.from, from, next.author);
        if (next.to > to)
          map.splice(pos++, 0, left);
        else
          map[pos++] = left;
      }
      break;
    }
  }
  while (next = map[pos]) {
    if (next.author === author) {
      if (next.from > to)
        break;
      from = Math.min(from, next.from);
      to = Math.max(to, next.to);
      map.splice(pos, 1);
    } else {
      if (next.from >= to)
        break;
      if (next.to > to) {
        map[pos] = new Span(to, next.to, next.author);
        break;
      } else {
        map.splice(pos, 1);
      }
    }
  }
  map.splice(pos, 0, new Span(from, to, author));
}
class TrackState {
  constructor(blameMap) {
    this.blameMap = blameMap;
  }
  applyTransform(transform) {
    var _a;
    const clientID = (_a = transform.getMeta("clientID")) != null ? _a : transform.steps.map((item) => "self");
    const newBlame = updateBlameMap(this.blameMap, transform, clientID);
    return new TrackState(newBlame);
  }
}
/*
 * @copyright Copyright (c) 2020 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
Extension.create({
  name: "users",
  addOptions() {
    return {
      clientID: 0,
      color: (clientID) => {
        return "#" + Math.floor(Math.abs(Math.sin(clientID) * 16777215) % 16777215).toString(16) + "aa";
      },
      name: (clientID) => {
        return "Unknown user " + clientID;
      }
    };
  },
  addProseMirrorPlugins() {
    return [
      new Plugin({
        clientID: this.options.clientID,
        color: this.options.color,
        name: this.options.name,
        state: {
          init(_2, instance) {
            return {
              tracked: new TrackState([new Span(0, instance.doc.content.size, null)], [], [], []),
              deco: DecorationSet.empty
            };
          },
          apply(tr, instance, oldState, state2) {
            let { tracked, decos } = instance;
            let tState = this.getState(oldState).tracked;
            if (tr.docChanged) {
              if (!tr.getMeta("clientID")) {
                tr.setMeta("clientID", tr.steps.map((i) => this.spec.clientID));
              }
              tracked = tracked.applyTransform(tr);
              tState = tracked;
            }
            decos = tState.blameMap.map((span) => {
              const clientID = span.author;
              return Decoration.inline(span.from, span.to, {
                class: "author-annotation",
                style: "background-color: " + this.spec.color(clientID) + "66;",
                title: this.spec.name(clientID)
              });
            }).filter((dec) => dec !== null);
            return { tracked, deco: DecorationSet.create(state2.doc, decos) };
          }
        },
        props: {
          decorations(state2) {
            return this.getState(state2).deco;
          }
        }
      })
    ];
  }
});
let timeout;
const debounce$1 = (fn, delay) => (...args) => {
  if (timeout) {
    clearTimeout(timeout);
  }
  timeout = setTimeout(() => {
    fn(...args);
    timeout = null;
  }, delay);
};
Extension.create({
  name: "collaboration",
  onCreate() {
    this.getSendableSteps = debounce$1((state2) => {
      const sendable = sendableSteps(state2);
      if (sendable && this.editor.options.editable) {
        this.options.onSendable({
          editor: this.editor,
          sendable: {
            version: sendable.version,
            steps: sendable.steps.map((step) => step.toJSON()),
            clientID: sendable.clientID
          }
        });
      }
    }, this.options.debounce);
    this.editor.on("transaction", ({ editor }) => {
      this.getSendableSteps(editor.state);
    });
  },
  addOptions() {
    return {
      version: 0,
      clientID: Math.floor(Math.random() * 4294967295),
      debounce: 250,
      onSendable: () => {
      },
      update: ({ steps, version: version2 }) => {
        const { state: state2, view, schema } = this.editor;
        if (getVersion(state2) > version2) {
          return;
        }
        view.dispatch(receiveTransaction(state2, steps.map((item) => Step.fromJSON(schema, item.step)), steps.map((item) => item.clientID)));
      }
    };
  },
  addProseMirrorPlugins() {
    return [
      collab({
        version: this.options.version,
        clientID: this.options.clientID
      })
    ];
  }
});
/*
 * @copyright Copyright (c) 2022 Max <max@nextcloud.com>
 *
 * @author Max <max@nextcloud.com>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
Extension.create({
  name: "markdown",
  extendMarkSchema(extension) {
    const context = {
      name: extension.name,
      options: extension.options,
      storage: extension.storage
    };
    return {
      toMarkdown: getExtensionField(extension, "toMarkdown", context)
    };
  },
  extendNodeSchema(extension) {
    const context = {
      name: extension.name,
      options: extension.options,
      storage: extension.storage
    };
    return {
      toMarkdown: getExtensionField(extension, "toMarkdown", context)
    };
  }
});
var path = {};
var render$5 = function __render__() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("span", _vm._b({
    staticClass: "material-design-icon trash-can-icon",
    attrs: {
      "aria-hidden": !_vm.title,
      "aria-label": _vm.title,
      "role": "img"
    },
    on: {
      "click": function click($event) {
        return _vm.$emit("click", $event);
      }
    }
  }, "span", _vm.$attrs, false), [_c("svg", {
    staticClass: "material-design-icon__svg",
    attrs: {
      "fill": _vm.fillColor,
      "width": _vm.size,
      "height": _vm.size,
      "viewBox": "0 0 24 24"
    }
  }, [_c("path", {
    attrs: {
      "d": "M9,3V4H4V6H5V19A2,2 0 0,0 7,21H17A2,2 0 0,0 19,19V6H20V4H15V3H9M9,8H11V17H9V8M13,8H15V17H13V8Z"
    }
  }, [_vm.title ? _c("title", [_vm._v(_vm._s(_vm.title))]) : _vm._e()])])]);
};
var staticRenderFns$5 = [];
function normalizeComponent$2(scriptExports, render2, staticRenderFns2, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render2) {
    options.render = render2;
    options.staticRenderFns = staticRenderFns2;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function(context) {
      context = context || this.$vnode && this.$vnode.ssrContext || this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}
const __vue2_script$5 = {
  name: "TrashCanIcon",
  props: {
    title: {
      type: String
    },
    fillColor: {
      type: String,
      default: "currentColor"
    },
    size: {
      type: Number,
      default: 24
    }
  }
};
const __cssModules$5 = {};
var __component__$5 = /* @__PURE__ */ normalizeComponent$2(__vue2_script$5, render$5, staticRenderFns$5, false, __vue2_injectStyles$5, null, null, null);
function __vue2_injectStyles$5(context) {
  for (let o in __cssModules$5) {
    this[o] = __cssModules$5[o];
  }
}
var TrashCanIcon = /* @__PURE__ */ function() {
  return __component__$5.exports;
}();
/*
 * @copyright Copyright (c) 2020 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
const persistentStorage = getBuilder("text").persist().build();
Vue.use(Vuex);
const store$5 = new Store({
  state: {
    showAuthorAnnotations: persistentStorage.getItem("showAuthorAnnotations") === "true",
    currentSession: persistentStorage.getItem("currentSession")
  },
  mutations: {
    SET_SHOW_AUTHOR_ANNOTATIONS(state2, value) {
      state2.showAuthorAnnotations = value;
      persistentStorage.setItem("showAuthorAnnotations", "" + value);
    },
    SET_CURRENT_SESSION(state2, value) {
      state2.currentSession = value;
      persistentStorage.setItem("currentSession", value);
    }
  },
  actions: {
    setShowAuthorAnnotations({ commit }, value) {
      store$5.commit("SET_SHOW_AUTHOR_ANNOTATIONS", value);
    },
    setCurrentSession({ commit }, value) {
      store$5.commit("SET_CURRENT_SESSION", value);
    }
  }
});
/*
 * @copyright Copyright (c) 2021 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
var store$4 = {
  data() {
    return {
      $store: store$5
    };
  },
  beforeMount() {
    if (typeof this.$store === "undefined") {
      this.$store = store$5;
    }
  }
};
var render$4 = function __render__2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("NodeViewWrapper", [_c("div", {
    staticClass: "image",
    class: {
      "icon-loading": !_vm.loaded
    },
    attrs: {
      "data-component": "image-view",
      "data-src": _vm.src
    }
  }, [_vm.imageLoaded && _vm.isSupportedImage ? _c("div", {
    directives: [{
      name: "click-outside",
      rawName: "v-click-outside",
      value: function value() {
        return _vm.showIcons = false;
      },
      expression: "() => showIcons = false"
    }],
    staticClass: "image__view",
    on: {
      "click": function click($event) {
        _vm.showIcons = true;
      },
      "mouseover": function mouseover($event) {
        _vm.showIcons = true;
      },
      "mouseleave": function mouseleave($event) {
        _vm.showIcons = false;
      }
    }
  }, [_c("transition", {
    attrs: {
      "name": "fade"
    }
  }, [_c("img", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.loaded,
      expression: "loaded"
    }],
    staticClass: "image__main",
    attrs: {
      "src": _vm.imageUrl
    },
    on: {
      "load": _vm.onLoaded
    }
  })]), _c("transition", {
    attrs: {
      "name": "fade"
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.loaded,
      expression: "loaded"
    }],
    staticClass: "image__caption"
  }, [_c("input", {
    ref: "altInput",
    attrs: {
      "type": "text"
    },
    domProps: {
      "value": _vm.alt
    },
    on: {
      "keyup": function keyup($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter"))
          return null;
        return _vm.updateAlt();
      }
    }
  }), _vm.editor.isEditable && _vm.showIcons ? _c("div", {
    staticClass: "trash-icon",
    attrs: {
      "title": "Delete this image"
    },
    on: {
      "click": _vm.deleteNode
    }
  }, [_c("TrashCanIcon")], 1) : _vm._e()])])], 1) : _c("div", [_c("transition", {
    attrs: {
      "name": "fade"
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.loaded,
      expression: "loaded"
    }]
  }, [_c("a", {
    attrs: {
      "href": _vm.internalLinkOrImage,
      "target": "_blank"
    }
  }, [!_vm.isSupportedImage ? _c("span", [_vm._v(_vm._s(_vm.alt))]) : _vm._e()])])]), _vm.isSupportedImage ? _c("transition", {
    attrs: {
      "name": "fade"
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.loaded,
      expression: "loaded"
    }],
    staticClass: "image__caption"
  }, [_c("input", {
    ref: "altInput",
    attrs: {
      "type": "text"
    },
    domProps: {
      "value": _vm.alt
    },
    on: {
      "keyup": function keyup($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter"))
          return null;
        return _vm.updateAlt();
      }
    }
  })])]) : _vm._e()], 1)])]);
};
var staticRenderFns$4 = [];
var ImageView_vue_vue_type_style_index_0_scoped_true_lang = "";
const imageMimes = [
  "image/png",
  "image/jpeg",
  "image/jpg",
  "image/gif",
  "image/x-xbitmap",
  "image/x-ms-bmp",
  "image/bmp",
  "image/svg+xml",
  "image/webp"
];
const getQueryVariable = (src, variable) => {
  const query = src.split("?")[1];
  if (typeof query === "undefined") {
    return;
  }
  const vars = query.split(/[&#]/);
  if (typeof vars === "undefined") {
    return;
  }
  for (let i = 0; i < vars.length; i++) {
    const pair = vars[i].split("=");
    if (decodeURIComponent(pair[0]) === variable) {
      return decodeURIComponent(pair[1]);
    }
  }
};
const __vue2_script$4 = {
  name: "ImageView",
  components: {
    TrashCanIcon,
    NodeViewWrapper
  },
  directives: {
    ClickOutside
  },
  mixins: [
    store$4
  ],
  inject: ["fileId"],
  props: ["editor", "node", "extension", "updateAttributes", "deleteNode"],
  data() {
    return {
      imageLoaded: false,
      loaded: false,
      failed: false,
      showIcons: false
    };
  },
  computed: {
    currentSession() {
      return this.$store.state.currentSession;
    },
    davUrl() {
      if (getCurrentUser()) {
        const uid2 = getCurrentUser().uid;
        const encoded = encodeURI(this.imagePath);
        return generateRemoteUrl(`dav/files/${uid2}${encoded}`);
      } else {
        return generateUrl("/s/{token}/download?path={dirname}&files={basename}", {
          token: this.token,
          dirname: this.extension.options.currentDirectory,
          basename: this.basename
        });
      }
    },
    imageUrl() {
      if (this.src.startsWith("text://") && this.currentSession) {
        const documentId = this.currentSession.documentId;
        const sessionId = this.currentSession.id;
        const sessionToken = this.currentSession.token;
        const imageFileName = getQueryVariable(this.src, "imageFileName");
        if (getCurrentUser() || !this.token) {
          return generateUrl("/apps/text/image?documentId={documentId}&sessionId={sessionId}&sessionToken={sessionToken}&imageFileName={imageFileName}", {
            documentId,
            sessionId,
            sessionToken,
            imageFileName
          });
        } else {
          return generateUrl("/apps/text/image?documentId={documentId}&sessionId={sessionId}&sessionToken={sessionToken}&imageFileName={imageFileName}&shareToken={shareToken}", {
            documentId,
            sessionId,
            sessionToken,
            imageFileName,
            shareToken: this.token
          });
        }
      }
      if (this.isRemoteUrl || this.isPreviewUrl || this.isDataUrl) {
        return this.src;
      }
      if (this.hasPreview && this.mime !== "image/gif") {
        return this.previewUrl;
      }
      return this.davUrl;
    },
    isRemoteUrl() {
      return this.src.startsWith("http://") || this.src.startsWith("https://");
    },
    isPreviewUrl() {
      return this.src.match(/^(\/index.php)?\/core\/preview/) || this.src.match(/^(\/index.php)?\/apps\/files_sharing\/publicpreview\//);
    },
    isDataUrl() {
      return this.src.startsWith("data:");
    },
    basename() {
      if (this.src.startsWith("text://")) {
        const imageFileName = getQueryVariable(this.src, "imageFileName");
        return `.attachments.${this.fileId}/${imageFileName}`;
      }
      return decodeURI(this.src.split("?")[0]);
    },
    imageFileId() {
      return getQueryVariable(this.src, "fileId");
    },
    imagePath() {
      const f = [
        this.extension.options.currentDirectory,
        this.basename
      ].join("/");
      return path.normalize(f);
    },
    hasPreview() {
      return getQueryVariable(this.src, "hasPreview") === "true" || this.src.startsWith("text://");
    },
    previewUrl() {
      const fileQuery = `file=${encodeURIComponent(this.imagePath)}`;
      const query = fileQuery + "&x=1024&y=1024&a=true";
      if (getCurrentUser() && this.imageFileId) {
        return generateUrl(`/core/preview?fileId=${this.imageFileId}&${query}`);
      }
      if (getCurrentUser()) {
        return generateUrl(`/core/preview.png?${query}`);
      }
      if (this.token) {
        return generateUrl(`/apps/files_sharing/publicpreview/${this.token}?${query}`);
      }
      console.error("No way to authenticate image retrival - need to be logged in or provide a token");
      return "";
    },
    mime() {
      return getQueryVariable(this.src, "mimetype");
    },
    mimeIcon() {
      if (this.mime) {
        const mimeIconUrl = window.OC.MimeType.getIconUrl(this.mime);
        return { backgroundImage: `url(${mimeIconUrl})` };
      }
      return {};
    },
    isSupportedImage() {
      return typeof this.mime === "undefined" || imageMimes.indexOf(this.mime) !== -1;
    },
    internalLinkOrImage() {
      if (this.imageFileId) {
        return generateUrl("/f/" + this.imageFileId);
      }
      return this.src;
    },
    src: {
      get() {
        return this.node.attrs.src || "";
      },
      set(src) {
        this.updateAttributes({
          src
        });
      }
    },
    alt: {
      get() {
        return this.node.attrs.alt ? this.node.attrs.alt : "";
      },
      set(alt) {
        this.updateAttributes({
          alt
        });
      }
    },
    t() {
      return (a, s) => window.t(a, s);
    },
    token() {
      return document.getElementById("sharingToken") && document.getElementById("sharingToken").value;
    }
  },
  beforeMount() {
    if (!this.isSupportedImage) {
      this.failed = true;
      this.imageLoaded = false;
      this.loaded = true;
      return;
    }
    const img = new Image();
    img.onload = () => {
      this.imageLoaded = true;
    };
    img.onerror = () => {
      this.failed = true;
      this.imageLoaded = false;
      this.loaded = true;
    };
    img.src = this.imageUrl;
  },
  methods: {
    updateAlt() {
      this.alt = this.$refs.altInput.value;
    },
    onLoaded() {
      this.loaded = true;
      this.$nextTick(() => {
        this.editor.commands.scrollIntoView();
      });
    }
  }
};
const __cssModules$4 = {};
var __component__$4 = /* @__PURE__ */ normalizeComponent$2(__vue2_script$4, render$4, staticRenderFns$4, false, __vue2_injectStyles$4, "8286211e", null, null);
function __vue2_injectStyles$4(context) {
  for (let o in __cssModules$4) {
    this[o] = __cssModules$4[o];
  }
}
var ImageView = /* @__PURE__ */ function() {
  return __component__$4.exports;
}();
/*
 * @copyright Copyright (c) 2019 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
const Image$1 = TiptapImage.extend({
  selectable: false,
  addOptions() {
    var _a;
    return __spreadProps(__spreadValues({}, (_a = this.parent) == null ? void 0 : _a.call(this)), {
      currentDirectory: void 0
    });
  },
  addNodeView() {
    return VueNodeViewRenderer(ImageView);
  },
  addProseMirrorPlugins() {
    return [
      new Plugin({
        props: {
          handleDrop: (view, event, slice) => {
            if (event.dataTransfer.files && event.dataTransfer.files.length > 0) {
              const coordinates = view.posAtCoords({ left: event.clientX, top: event.clientY });
              const customEvent = new CustomEvent("image-drop", {
                bubbles: true,
                detail: {
                  files: event.dataTransfer.files,
                  position: coordinates.pos
                }
              });
              event.target.dispatchEvent(customEvent);
              return true;
            }
          },
          handlePaste: (view, event, slice) => {
            if (event.clipboardData.files && event.clipboardData.files.length > 0) {
              const customEvent = new CustomEvent("image-paste", {
                bubbles: true,
                detail: {
                  files: event.clipboardData.files
                }
              });
              event.target.dispatchEvent(customEvent);
              return true;
            }
          }
        }
      })
    ];
  }
});
/*
 * @copyright Copyright (c) 2019 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
var PlainTextDocument = Node$1.create({
  name: "doc",
  content: "block",
  addKeyboardShortcuts() {
    return {
      Tab: () => this.editor.commands.insertContent("	")
    };
  }
});
/*
 * @copyright Copyright (c) 2021 Jonas Meurer <jonas@freesources.org>
 *
 * @author Jonas Meurer <jonas@freesources.org>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
function listInputRule(find2, type, getAttributes) {
  const handler = ({ state: state2, range, match: match2 }) => {
    const wrap = wrappingInputRule({ find: find2, type, getAttributes });
    wrap.handler({ state: state2, range, match: match2 });
    if (match2.length >= 3) {
      state2.tr.insertText(match2[2]);
    }
  };
  return new InputRule({ find: find2, handler });
}
/*
 * @copyright Copyright (c) 2020 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
const BulletList = TiptapBulletList.extend({
  addInputRules() {
    return [
      listInputRule(/^\s*([-+*])\s([^\s[])$/, this.type)
    ];
  }
});
/*
 * @copyright Copyright (c) 2019 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
const TaskItem = TipTapTaskItem.extend({
  addOptions() {
    return {
      nested: true,
      HTMLAttributes: {}
    };
  },
  draggable: false,
  content: "paragraph block*",
  addAttributes() {
    const adjust = __spreadValues({}, this.parent());
    adjust.checked.parseHTML = (el) => {
      var _a;
      return (_a = el.querySelector("input[type=checkbox]")) == null ? void 0 : _a.checked;
    };
    return adjust;
  },
  parseHTML: [
    {
      priority: 101,
      tag: "li",
      getAttrs: (el) => {
        const checkbox = el.querySelector("input[type=checkbox]");
        return checkbox;
      },
      context: "taskList/"
    }
  ],
  renderHTML({ node, HTMLAttributes }) {
    const listAttributes = { class: "checkbox-item" };
    const checkboxAttributes = { type: "checkbox", class: "", contenteditable: false };
    if (node.attrs.checked) {
      checkboxAttributes.checked = true;
      listAttributes.class += " checked";
    }
    return [
      "li",
      mergeAttributes(HTMLAttributes, listAttributes),
      [
        "input",
        checkboxAttributes
      ],
      [
        "label",
        0
      ]
    ];
  },
  addNodeView: false,
  toMarkdown: (state2, node) => {
    state2.write(`[${node.attrs.checked ? "x" : " "}] `);
    state2.renderContent(node);
  },
  addInputRules() {
    return [
      ...this.parent(),
      wrappingInputRule({
        find: /^\s*([-+*])\s(\[(x|X| ?)\])\s$/,
        type: this.type,
        getAttributes: (match2) => ({
          checked: "xX".includes(match2[match2.length - 1])
        })
      })
    ];
  },
  addProseMirrorPlugins() {
    return [
      new Plugin({
        props: {
          handleClick: (view, pos, event) => {
            const state2 = view.state;
            const schema = state2.schema;
            const coordinates = view.posAtCoords({ left: event.clientX, top: event.clientY });
            const position = state2.doc.resolve(coordinates.pos);
            const parentList = findParentNodeClosestToPos(position, function(node) {
              return node.type === schema.nodes.taskItem || node.type === schema.nodes.listItem;
            });
            const isListClicked = event.target.tagName.toLowerCase() === "li";
            if (!isListClicked || !parentList || parentList.node.type !== schema.nodes.taskItem) {
              return;
            }
            const tr = state2.tr;
            tr.setNodeMarkup(parentList.pos, schema.nodes.taskItem, { checked: !parentList.node.attrs.checked });
            view.dispatch(tr);
          }
        }
      })
    ];
  }
});
/*
 * @copyright Copyright (c) 2020 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
const TaskList = TiptapTaskList.extend({
  parseHTML: [
    {
      priority: 100,
      tag: "ul.contains-task-list"
    }
  ],
  toMarkdown: (state2, node) => {
    state2.renderList(node, "  ", () => (node.attrs.bullet || "*") + " ");
  }
});
/*
 * @copyright Copyright (c) 2021, überdosis GbR
 *
 * @license MIT
 *
 */
function nodeEqualsType({ types, node }) {
  return Array.isArray(types) && types.includes(node.type) || node.type === types;
}
Extension.create({
  name: "trailingNode",
  addOptions() {
    return {
      node: "paragraph",
      notAfter: ["paragraph"]
    };
  },
  addProseMirrorPlugins() {
    const plugin2 = new PluginKey(this.name);
    const disabledNodes = Object.entries(this.editor.schema.nodes).map(([, value]) => value).filter((node) => this.options.notAfter.includes(node.name));
    return [
      new Plugin({
        key: plugin2,
        appendTransaction: (_2, __, state2) => {
          const { doc, tr, schema } = state2;
          const shouldInsertNodeAtEnd = plugin2.getState(state2);
          const endPosition = doc.content.size;
          const type = schema.nodes[this.options.node];
          if (!shouldInsertNodeAtEnd) {
            return;
          }
          return tr.insert(endPosition, type.create());
        },
        state: {
          init: (_2, state2) => {
            const lastNode = state2.tr.doc.lastChild;
            return !nodeEqualsType({ node: lastNode, types: disabledNodes });
          },
          apply: (tr, value) => {
            if (!tr.docChanged) {
              return value;
            }
            const lastNode = tr.doc.lastChild;
            return !nodeEqualsType({ node: lastNode, types: disabledNodes });
          }
        }
      })
    ];
  }
});
const Heading = TipTapHeading.extend({
  addKeyboardShortcuts() {
    return this.options.levels.reduce((items, level) => __spreadProps(__spreadValues({}, items), {
      [`Mod-Shift-${level}`]: () => this.editor.commands.toggleHeading({ level })
    }), {});
  }
});
/*
 * @copyright Copyright (c) 2022 Vinicius Reis <vinicius@nextcloud.com>
 *
 * @author Vinicius Reis <vinicius@nextcloud.com>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
const typesAvailable = ["info", "warn", "error", "success"];
const buildRender = (type) => (tokens, idx, options, env, slf) => {
  const tag = tokens[idx];
  if (tag.nesting === 1) {
    tag.attrSet("data-callout", type);
    tag.attrJoin("class", `callout callout-${type}`);
  }
  return slf.renderToken(tokens, idx, options, env, slf);
};
var callouts = (md) => {
  typesAvailable.forEach((type) => {
    md.use(container, type, {
      render: buildRender(type)
    });
  });
  return md;
};
/*
 * @copyright Copyright (c) 2022 Vinicius Reis <vinicius@nextcloud.com>
 *
 * @author Vinicius Reis <vinicius@nextcloud.com>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
var Callout = Node$1.create({
  name: "callout",
  content: "paragraph+",
  group: "block",
  defining: true,
  addOptions() {
    return {
      types: typesAvailable,
      HTMLAttributes: {
        class: "callout"
      }
    };
  },
  addAttributes() {
    return {
      type: {
        default: "info",
        rendered: false,
        parseHTML: (element) => {
          return element.getAttribute("data-callout") || typesAvailable.find((type) => element.classList.contains(type)) || element.classList.contains("warning") && "warn";
        },
        renderHTML: (attributes) => {
          return {
            "data-callout": attributes.type,
            class: `callout-${attributes.type}`
          };
        }
      }
    };
  },
  parseHTML() {
    return [
      {
        tag: "div.callout"
      },
      {
        tag: "p.callout",
        priority: 1001
      }
    ];
  },
  renderHTML({ node, HTMLAttributes }) {
    const { class: classy } = this.options.HTMLAttributes;
    const attributes = __spreadProps(__spreadValues({}, this.options.HTMLAttributes), {
      "data-callout": node.attrs.type,
      class: `${classy} ${classy}-${node.attrs.type}`
    });
    return ["div", mergeAttributes(attributes, HTMLAttributes), 0];
  },
  toMarkdown: (state2, node) => {
    state2.write("::: " + (node.attrs.type || "info") + "\n");
    state2.renderContent(node);
    state2.ensureNewLine();
    state2.write(":::");
    state2.closeBlock(node);
  },
  addCommands() {
    return {
      setCallout: (attributes) => ({ commands }) => {
        return commands.wrapIn(this.name, attributes);
      },
      toggleCallout: (attributes) => ({ commands, state: state2 }) => {
        if (!isNodeActive(state2, this.name)) {
          return commands.setCallout(attributes);
        }
        if (!isNodeActive(state2, this.name, attributes)) {
          return commands.updateAttributes(this.name, attributes);
        }
        return commands.unsetCallout();
      },
      unsetCallout: () => ({ commands }) => {
        return commands.lift(this.name);
      }
    };
  }
});
var TableCaption = Node$1.create({
  name: "tableCaption",
  content: "inline*",
  addAttributes() {
    return {};
  },
  renderHTML() {
    return ["caption"];
  },
  toMarkdown(state2, node) {
  },
  parseHTML() {
    return [
      { tag: "table caption", priority: 90 }
    ];
  }
});
var TableCell = TableCell$1.extend({
  content: "inline*",
  toMarkdown(state2, node) {
    state2.write(" ");
    state2.renderInline(node);
    state2.write(" |");
  },
  parseHTML() {
    return [
      { tag: "td" },
      { tag: "th" },
      { tag: "table thead ~ tbody th", priority: 70 },
      { tag: "table thead ~ tbody td", priority: 70 }
    ];
  }
});
var TableHeader = TableHeader$1.extend({
  content: "inline*",
  toMarkdown(state2, node) {
    state2.write(" ");
    state2.renderInline(node);
    state2.write(" |");
  },
  parseHTML() {
    return [
      { tag: "table thead:empty ~ tbody :first-child th", priority: 80 },
      { tag: "table thead:empty ~ tbody :first-child td", priority: 80 },
      { tag: "table thead :first-child th", priority: 60 },
      { tag: "table thead :first-child td", priority: 60 },
      { tag: "table tbody :first-child th", priority: 60 },
      { tag: "table tbody :first-child td", priority: 60 },
      { tag: "table > :first-child > th", priority: 60 },
      { tag: "table > :first-child > td", priority: 60 }
    ];
  }
});
var TableRow = TableRow$1.extend({
  content: "tableCell*",
  toMarkdown(state2, node) {
    state2.write("|");
    state2.renderInline(node);
    state2.ensureNewLine();
  },
  parseHTML() {
    return [
      { tag: "tr", priority: 80 }
    ];
  }
});
var TableHeadRow = TableRow.extend({
  name: "tableHeadRow",
  content: "tableHeader*",
  toMarkdown(state2, node) {
    state2.write("|");
    state2.renderInline(node);
    state2.ensureNewLine();
    state2.write("|");
    node.forEach((cell) => {
      state2.write(state2.repeat("-", cell.textContent.length + 2));
      state2.write("|");
    });
    state2.ensureNewLine();
  },
  parseHTML() {
    return [
      { tag: "tr", priority: 70 }
    ];
  }
});
function createTable(schema, rowsCount, colsCount, cellContent) {
  const headerCells = [];
  const cells = [];
  for (let index = 0; index < colsCount; index += 1) {
    const cell = schema.nodes.tableCell.createAndFill();
    if (cell) {
      cells.push(cell);
    }
    const headerCell = schema.nodes.tableHeader.createAndFill();
    if (headerCell) {
      headerCells.push(headerCell);
    }
  }
  const headRow = schema.nodes.tableHeadRow.createChecked(null, headerCells);
  const rows = [];
  for (let index = 1; index < rowsCount; index += 1) {
    rows.push(schema.nodes.tableRow.createChecked(null, cells));
  }
  return schema.nodes.table.createChecked(null, [headRow, ...rows]);
}
function findSameCellInNextRow($cell) {
  if ($cell.index(-1) === $cell.node(-1).childCount - 1) {
    return null;
  }
  let cellStart = $cell.after();
  const table = $cell.node(-1);
  for (let row = $cell.indexAfter(-1); row < table.childCount; row++) {
    const rowNode = table.child(row);
    if (rowNode.childCount >= $cell.index()) {
      for (let cell = 0; cell < $cell.index(); cell++) {
        const cellNode = rowNode.child(cell);
        cellStart += cellNode.nodeSize;
      }
      return cellStart + 1;
    }
    cellStart += rowNode.nodeSize;
  }
}
var Table = Table$1.extend({
  content: "tableCaption? tableHeadRow tableRow*",
  addExtensions() {
    return [
      TableCaption,
      TableCell,
      TableHeader,
      TableHeadRow,
      TableRow
    ];
  },
  addCommands() {
    return __spreadProps(__spreadValues({}, this.parent()), {
      insertTable: () => ({ tr, dispatch, editor }) => {
        if (isInTable(tr))
          return false;
        const node = createTable(editor.schema, 3, 3);
        if (dispatch) {
          const offset2 = tr.selection.anchor + 1;
          tr.replaceSelectionWith(node).scrollIntoView().setSelection(TextSelection.near(tr.doc.resolve(offset2)));
        }
        return true;
      },
      leaveTable: () => ({ tr, dispatch, editor }) => {
        if (!isInTable(tr))
          return false;
        const { $head, empty } = tr.selection;
        if (!empty)
          return false;
        const tableDepth = $head.depth < 3 ? 1 : $head.depth - 2;
        if (dispatch) {
          const $next = tr.doc.resolve($head.after(tableDepth) + 1);
          const selection = TextSelection.near($next);
          dispatch(tr.setSelection(selection).scrollIntoView());
        }
        return true;
      },
      goToNextRow: () => ({ tr, dispatch, editor }) => {
        if (!isInTable(tr))
          return false;
        const cell = findSameCellInNextRow(selectionCell(tr));
        if (cell == null)
          return;
        if (dispatch) {
          const $cell = tr.doc.resolve(cell);
          const selection = TextSelection.between($cell, moveCellForward($cell));
          dispatch(tr.setSelection(selection).scrollIntoView());
        }
        return true;
      }
    });
  },
  renderHTML({ HTMLAttributes }) {
    return ["table", mergeAttributes(this.options.HTMLAttributes, HTMLAttributes), 0];
  },
  toMarkdown(state2, node) {
    state2.renderContent(node);
    state2.closeBlock(node);
  },
  addKeyboardShortcuts() {
    return __spreadProps(__spreadValues({}, this.parent()), {
      Tab: () => this.editor.commands.goToNextCell() || this.editor.commands.leaveTable(),
      Enter: () => {
        if (this.editor.commands.goToNextRow()) {
          return true;
        }
        if (!this.editor.can().addRowAfter()) {
          return false;
        }
        return this.editor.chain().addRowAfter().goToNextRow().run();
      }
    });
  }
});
var commonjsGlobal = typeof globalThis !== "undefined" ? globalThis : typeof window !== "undefined" ? window : typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : {};
function getDefaultExportFromCjs(x) {
  return x && x.__esModule && Object.prototype.hasOwnProperty.call(x, "default") ? x["default"] : x;
}
function getAugmentedNamespace(n) {
  if (n.__esModule)
    return n;
  var a = Object.defineProperty({}, "__esModule", { value: true });
  Object.keys(n).forEach(function(k) {
    var d = Object.getOwnPropertyDescriptor(n, k);
    Object.defineProperty(a, k, d.get ? d : {
      enumerable: true,
      get: function() {
        return n[k];
      }
    });
  });
  return a;
}
var Actions$1 = { exports: {} };
var gettext$1 = {};
var check = function(it) {
  return it && it.Math == Math && it;
};
var global$r = check(typeof globalThis == "object" && globalThis) || check(typeof window == "object" && window) || check(typeof self == "object" && self) || check(typeof commonjsGlobal == "object" && commonjsGlobal) || function() {
  return this;
}() || Function("return this")();
var objectGetOwnPropertyDescriptor = {};
var fails$e = function(exec2) {
  try {
    return !!exec2();
  } catch (error) {
    return true;
  }
};
var fails$d = fails$e;
var descriptors = !fails$d(function() {
  return Object.defineProperty({}, 1, { get: function() {
    return 7;
  } })[1] != 7;
});
var fails$c = fails$e;
var functionBindNative = !fails$c(function() {
  var test2 = function() {
  }.bind();
  return typeof test2 != "function" || test2.hasOwnProperty("prototype");
});
var NATIVE_BIND$2 = functionBindNative;
var call$9 = Function.prototype.call;
var functionCall = NATIVE_BIND$2 ? call$9.bind(call$9) : function() {
  return call$9.apply(call$9, arguments);
};
var objectPropertyIsEnumerable = {};
var $propertyIsEnumerable = {}.propertyIsEnumerable;
var getOwnPropertyDescriptor$1 = Object.getOwnPropertyDescriptor;
var NASHORN_BUG = getOwnPropertyDescriptor$1 && !$propertyIsEnumerable.call({ 1: 2 }, 1);
objectPropertyIsEnumerable.f = NASHORN_BUG ? function propertyIsEnumerable(V) {
  var descriptor = getOwnPropertyDescriptor$1(this, V);
  return !!descriptor && descriptor.enumerable;
} : $propertyIsEnumerable;
var createPropertyDescriptor$2 = function(bitmap, value) {
  return {
    enumerable: !(bitmap & 1),
    configurable: !(bitmap & 2),
    writable: !(bitmap & 4),
    value
  };
};
var NATIVE_BIND$1 = functionBindNative;
var FunctionPrototype$2 = Function.prototype;
var bind$1 = FunctionPrototype$2.bind;
var call$8 = FunctionPrototype$2.call;
var uncurryThis$e = NATIVE_BIND$1 && bind$1.bind(call$8, call$8);
var functionUncurryThis = NATIVE_BIND$1 ? function(fn) {
  return fn && uncurryThis$e(fn);
} : function(fn) {
  return fn && function() {
    return call$8.apply(fn, arguments);
  };
};
var uncurryThis$d = functionUncurryThis;
var toString$7 = uncurryThis$d({}.toString);
var stringSlice$4 = uncurryThis$d("".slice);
var classofRaw$1 = function(it) {
  return stringSlice$4(toString$7(it), 8, -1);
};
var global$q = global$r;
var uncurryThis$c = functionUncurryThis;
var fails$b = fails$e;
var classof$4 = classofRaw$1;
var Object$4 = global$q.Object;
var split = uncurryThis$c("".split);
var indexedObject = fails$b(function() {
  return !Object$4("z").propertyIsEnumerable(0);
}) ? function(it) {
  return classof$4(it) == "String" ? split(it, "") : Object$4(it);
} : Object$4;
var global$p = global$r;
var TypeError$8 = global$p.TypeError;
var requireObjectCoercible$4 = function(it) {
  if (it == void 0)
    throw TypeError$8("Can't call method on " + it);
  return it;
};
var IndexedObject = indexedObject;
var requireObjectCoercible$3 = requireObjectCoercible$4;
var toIndexedObject$4 = function(it) {
  return IndexedObject(requireObjectCoercible$3(it));
};
var isCallable$d = function(argument) {
  return typeof argument == "function";
};
var isCallable$c = isCallable$d;
var isObject$e = function(it) {
  return typeof it == "object" ? it !== null : isCallable$c(it);
};
var global$o = global$r;
var isCallable$b = isCallable$d;
var aFunction = function(argument) {
  return isCallable$b(argument) ? argument : void 0;
};
var getBuiltIn$4 = function(namespace, method) {
  return arguments.length < 2 ? aFunction(global$o[namespace]) : global$o[namespace] && global$o[namespace][method];
};
var uncurryThis$b = functionUncurryThis;
var objectIsPrototypeOf = uncurryThis$b({}.isPrototypeOf);
var getBuiltIn$3 = getBuiltIn$4;
var engineUserAgent = getBuiltIn$3("navigator", "userAgent") || "";
var global$n = global$r;
var userAgent = engineUserAgent;
var process = global$n.process;
var Deno = global$n.Deno;
var versions = process && process.versions || Deno && Deno.version;
var v8 = versions && versions.v8;
var match, version;
if (v8) {
  match = v8.split(".");
  version = match[0] > 0 && match[0] < 4 ? 1 : +(match[0] + match[1]);
}
if (!version && userAgent) {
  match = userAgent.match(/Edge\/(\d+)/);
  if (!match || match[1] >= 74) {
    match = userAgent.match(/Chrome\/(\d+)/);
    if (match)
      version = +match[1];
  }
}
var engineV8Version = version;
var V8_VERSION = engineV8Version;
var fails$a = fails$e;
var nativeSymbol = !!Object.getOwnPropertySymbols && !fails$a(function() {
  var symbol = Symbol();
  return !String(symbol) || !(Object(symbol) instanceof Symbol) || !Symbol.sham && V8_VERSION && V8_VERSION < 41;
});
var NATIVE_SYMBOL$1 = nativeSymbol;
var useSymbolAsUid = NATIVE_SYMBOL$1 && !Symbol.sham && typeof Symbol.iterator == "symbol";
var global$m = global$r;
var getBuiltIn$2 = getBuiltIn$4;
var isCallable$a = isCallable$d;
var isPrototypeOf$1 = objectIsPrototypeOf;
var USE_SYMBOL_AS_UID$1 = useSymbolAsUid;
var Object$3 = global$m.Object;
var isSymbol$3 = USE_SYMBOL_AS_UID$1 ? function(it) {
  return typeof it == "symbol";
} : function(it) {
  var $Symbol = getBuiltIn$2("Symbol");
  return isCallable$a($Symbol) && isPrototypeOf$1($Symbol.prototype, Object$3(it));
};
var global$l = global$r;
var String$3 = global$l.String;
var tryToString$1 = function(argument) {
  try {
    return String$3(argument);
  } catch (error) {
    return "Object";
  }
};
var global$k = global$r;
var isCallable$9 = isCallable$d;
var tryToString = tryToString$1;
var TypeError$7 = global$k.TypeError;
var aCallable$1 = function(argument) {
  if (isCallable$9(argument))
    return argument;
  throw TypeError$7(tryToString(argument) + " is not a function");
};
var aCallable = aCallable$1;
var getMethod$2 = function(V, P) {
  var func = V[P];
  return func == null ? void 0 : aCallable(func);
};
var global$j = global$r;
var call$7 = functionCall;
var isCallable$8 = isCallable$d;
var isObject$d = isObject$e;
var TypeError$6 = global$j.TypeError;
var ordinaryToPrimitive$1 = function(input, pref) {
  var fn, val;
  if (pref === "string" && isCallable$8(fn = input.toString) && !isObject$d(val = call$7(fn, input)))
    return val;
  if (isCallable$8(fn = input.valueOf) && !isObject$d(val = call$7(fn, input)))
    return val;
  if (pref !== "string" && isCallable$8(fn = input.toString) && !isObject$d(val = call$7(fn, input)))
    return val;
  throw TypeError$6("Can't convert object to primitive value");
};
var shared$4 = { exports: {} };
var global$i = global$r;
var defineProperty$6 = Object.defineProperty;
var setGlobal$3 = function(key, value) {
  try {
    defineProperty$6(global$i, key, { value, configurable: true, writable: true });
  } catch (error) {
    global$i[key] = value;
  }
  return value;
};
var global$h = global$r;
var setGlobal$2 = setGlobal$3;
var SHARED = "__core-js_shared__";
var store$3 = global$h[SHARED] || setGlobal$2(SHARED, {});
var sharedStore = store$3;
var store$2 = sharedStore;
(shared$4.exports = function(key, value) {
  return store$2[key] || (store$2[key] = value !== void 0 ? value : {});
})("versions", []).push({
  version: "3.22.5",
  mode: "global",
  copyright: "\xA9 2014-2022 Denis Pushkarev (zloirock.ru)",
  license: "https://github.com/zloirock/core-js/blob/v3.22.5/LICENSE",
  source: "https://github.com/zloirock/core-js"
});
var global$g = global$r;
var requireObjectCoercible$2 = requireObjectCoercible$4;
var Object$2 = global$g.Object;
var toObject$2 = function(argument) {
  return Object$2(requireObjectCoercible$2(argument));
};
var uncurryThis$a = functionUncurryThis;
var toObject$1 = toObject$2;
var hasOwnProperty$d = uncurryThis$a({}.hasOwnProperty);
var hasOwnProperty_1 = Object.hasOwn || function hasOwn(it, key) {
  return hasOwnProperty$d(toObject$1(it), key);
};
var uncurryThis$9 = functionUncurryThis;
var id = 0;
var postfix = Math.random();
var toString$6 = uncurryThis$9(1 .toString);
var uid$2 = function(key) {
  return "Symbol(" + (key === void 0 ? "" : key) + ")_" + toString$6(++id + postfix, 36);
};
var global$f = global$r;
var shared$3 = shared$4.exports;
var hasOwn$7 = hasOwnProperty_1;
var uid$1 = uid$2;
var NATIVE_SYMBOL = nativeSymbol;
var USE_SYMBOL_AS_UID = useSymbolAsUid;
var WellKnownSymbolsStore = shared$3("wks");
var Symbol$6 = global$f.Symbol;
var symbolFor = Symbol$6 && Symbol$6["for"];
var createWellKnownSymbol = USE_SYMBOL_AS_UID ? Symbol$6 : Symbol$6 && Symbol$6.withoutSetter || uid$1;
var wellKnownSymbol$5 = function(name) {
  if (!hasOwn$7(WellKnownSymbolsStore, name) || !(NATIVE_SYMBOL || typeof WellKnownSymbolsStore[name] == "string")) {
    var description = "Symbol." + name;
    if (NATIVE_SYMBOL && hasOwn$7(Symbol$6, name)) {
      WellKnownSymbolsStore[name] = Symbol$6[name];
    } else if (USE_SYMBOL_AS_UID && symbolFor) {
      WellKnownSymbolsStore[name] = symbolFor(description);
    } else {
      WellKnownSymbolsStore[name] = createWellKnownSymbol(description);
    }
  }
  return WellKnownSymbolsStore[name];
};
var global$e = global$r;
var call$6 = functionCall;
var isObject$c = isObject$e;
var isSymbol$2 = isSymbol$3;
var getMethod$1 = getMethod$2;
var ordinaryToPrimitive = ordinaryToPrimitive$1;
var wellKnownSymbol$4 = wellKnownSymbol$5;
var TypeError$5 = global$e.TypeError;
var TO_PRIMITIVE = wellKnownSymbol$4("toPrimitive");
var toPrimitive$1 = function(input, pref) {
  if (!isObject$c(input) || isSymbol$2(input))
    return input;
  var exoticToPrim = getMethod$1(input, TO_PRIMITIVE);
  var result;
  if (exoticToPrim) {
    if (pref === void 0)
      pref = "default";
    result = call$6(exoticToPrim, input, pref);
    if (!isObject$c(result) || isSymbol$2(result))
      return result;
    throw TypeError$5("Can't convert object to primitive value");
  }
  if (pref === void 0)
    pref = "number";
  return ordinaryToPrimitive(input, pref);
};
var toPrimitive = toPrimitive$1;
var isSymbol$1 = isSymbol$3;
var toPropertyKey$2 = function(argument) {
  var key = toPrimitive(argument, "string");
  return isSymbol$1(key) ? key : key + "";
};
var global$d = global$r;
var isObject$b = isObject$e;
var document$1 = global$d.document;
var EXISTS$1 = isObject$b(document$1) && isObject$b(document$1.createElement);
var documentCreateElement$1 = function(it) {
  return EXISTS$1 ? document$1.createElement(it) : {};
};
var DESCRIPTORS$8 = descriptors;
var fails$9 = fails$e;
var createElement = documentCreateElement$1;
var ie8DomDefine = !DESCRIPTORS$8 && !fails$9(function() {
  return Object.defineProperty(createElement("div"), "a", {
    get: function() {
      return 7;
    }
  }).a != 7;
});
var DESCRIPTORS$7 = descriptors;
var call$5 = functionCall;
var propertyIsEnumerableModule = objectPropertyIsEnumerable;
var createPropertyDescriptor$1 = createPropertyDescriptor$2;
var toIndexedObject$3 = toIndexedObject$4;
var toPropertyKey$1 = toPropertyKey$2;
var hasOwn$6 = hasOwnProperty_1;
var IE8_DOM_DEFINE$1 = ie8DomDefine;
var $getOwnPropertyDescriptor$1 = Object.getOwnPropertyDescriptor;
objectGetOwnPropertyDescriptor.f = DESCRIPTORS$7 ? $getOwnPropertyDescriptor$1 : function getOwnPropertyDescriptor(O, P) {
  O = toIndexedObject$3(O);
  P = toPropertyKey$1(P);
  if (IE8_DOM_DEFINE$1)
    try {
      return $getOwnPropertyDescriptor$1(O, P);
    } catch (error) {
    }
  if (hasOwn$6(O, P))
    return createPropertyDescriptor$1(!call$5(propertyIsEnumerableModule.f, O, P), O[P]);
};
var objectDefineProperty = {};
var DESCRIPTORS$6 = descriptors;
var fails$8 = fails$e;
var v8PrototypeDefineBug = DESCRIPTORS$6 && fails$8(function() {
  return Object.defineProperty(function() {
  }, "prototype", {
    value: 42,
    writable: false
  }).prototype != 42;
});
var global$c = global$r;
var isObject$a = isObject$e;
var String$2 = global$c.String;
var TypeError$4 = global$c.TypeError;
var anObject$8 = function(argument) {
  if (isObject$a(argument))
    return argument;
  throw TypeError$4(String$2(argument) + " is not an object");
};
var global$b = global$r;
var DESCRIPTORS$5 = descriptors;
var IE8_DOM_DEFINE = ie8DomDefine;
var V8_PROTOTYPE_DEFINE_BUG$1 = v8PrototypeDefineBug;
var anObject$7 = anObject$8;
var toPropertyKey = toPropertyKey$2;
var TypeError$3 = global$b.TypeError;
var $defineProperty = Object.defineProperty;
var $getOwnPropertyDescriptor = Object.getOwnPropertyDescriptor;
var ENUMERABLE = "enumerable";
var CONFIGURABLE$1 = "configurable";
var WRITABLE = "writable";
objectDefineProperty.f = DESCRIPTORS$5 ? V8_PROTOTYPE_DEFINE_BUG$1 ? function defineProperty(O, P, Attributes) {
  anObject$7(O);
  P = toPropertyKey(P);
  anObject$7(Attributes);
  if (typeof O === "function" && P === "prototype" && "value" in Attributes && WRITABLE in Attributes && !Attributes[WRITABLE]) {
    var current = $getOwnPropertyDescriptor(O, P);
    if (current && current[WRITABLE]) {
      O[P] = Attributes.value;
      Attributes = {
        configurable: CONFIGURABLE$1 in Attributes ? Attributes[CONFIGURABLE$1] : current[CONFIGURABLE$1],
        enumerable: ENUMERABLE in Attributes ? Attributes[ENUMERABLE] : current[ENUMERABLE],
        writable: false
      };
    }
  }
  return $defineProperty(O, P, Attributes);
} : $defineProperty : function defineProperty2(O, P, Attributes) {
  anObject$7(O);
  P = toPropertyKey(P);
  anObject$7(Attributes);
  if (IE8_DOM_DEFINE)
    try {
      return $defineProperty(O, P, Attributes);
    } catch (error) {
    }
  if ("get" in Attributes || "set" in Attributes)
    throw TypeError$3("Accessors not supported");
  if ("value" in Attributes)
    O[P] = Attributes.value;
  return O;
};
var DESCRIPTORS$4 = descriptors;
var definePropertyModule$2 = objectDefineProperty;
var createPropertyDescriptor = createPropertyDescriptor$2;
var createNonEnumerableProperty$4 = DESCRIPTORS$4 ? function(object, key, value) {
  return definePropertyModule$2.f(object, key, createPropertyDescriptor(1, value));
} : function(object, key, value) {
  object[key] = value;
  return object;
};
var makeBuiltIn$2 = { exports: {} };
var DESCRIPTORS$3 = descriptors;
var hasOwn$5 = hasOwnProperty_1;
var FunctionPrototype$1 = Function.prototype;
var getDescriptor = DESCRIPTORS$3 && Object.getOwnPropertyDescriptor;
var EXISTS = hasOwn$5(FunctionPrototype$1, "name");
var PROPER = EXISTS && function something() {
}.name === "something";
var CONFIGURABLE = EXISTS && (!DESCRIPTORS$3 || DESCRIPTORS$3 && getDescriptor(FunctionPrototype$1, "name").configurable);
var functionName = {
  EXISTS,
  PROPER,
  CONFIGURABLE
};
var uncurryThis$8 = functionUncurryThis;
var isCallable$7 = isCallable$d;
var store$1 = sharedStore;
var functionToString = uncurryThis$8(Function.toString);
if (!isCallable$7(store$1.inspectSource)) {
  store$1.inspectSource = function(it) {
    return functionToString(it);
  };
}
var inspectSource$2 = store$1.inspectSource;
var global$a = global$r;
var isCallable$6 = isCallable$d;
var inspectSource$1 = inspectSource$2;
var WeakMap$3 = global$a.WeakMap;
var nativeWeakMap = isCallable$6(WeakMap$3) && /native code/.test(inspectSource$1(WeakMap$3));
var shared$2 = shared$4.exports;
var uid = uid$2;
var keys$2 = shared$2("keys");
var sharedKey$2 = function(key) {
  return keys$2[key] || (keys$2[key] = uid(key));
};
var hiddenKeys$4 = {};
var NATIVE_WEAK_MAP = nativeWeakMap;
var global$9 = global$r;
var uncurryThis$7 = functionUncurryThis;
var isObject$9 = isObject$e;
var createNonEnumerableProperty$3 = createNonEnumerableProperty$4;
var hasOwn$4 = hasOwnProperty_1;
var shared$1 = sharedStore;
var sharedKey$1 = sharedKey$2;
var hiddenKeys$3 = hiddenKeys$4;
var OBJECT_ALREADY_INITIALIZED = "Object already initialized";
var TypeError$2 = global$9.TypeError;
var WeakMap$2 = global$9.WeakMap;
var set, get$2, has;
var enforce = function(it) {
  return has(it) ? get$2(it) : set(it, {});
};
var getterFor = function(TYPE) {
  return function(it) {
    var state2;
    if (!isObject$9(it) || (state2 = get$2(it)).type !== TYPE) {
      throw TypeError$2("Incompatible receiver, " + TYPE + " required");
    }
    return state2;
  };
};
if (NATIVE_WEAK_MAP || shared$1.state) {
  var store = shared$1.state || (shared$1.state = new WeakMap$2());
  var wmget = uncurryThis$7(store.get);
  var wmhas = uncurryThis$7(store.has);
  var wmset = uncurryThis$7(store.set);
  set = function(it, metadata) {
    if (wmhas(store, it))
      throw new TypeError$2(OBJECT_ALREADY_INITIALIZED);
    metadata.facade = it;
    wmset(store, it, metadata);
    return metadata;
  };
  get$2 = function(it) {
    return wmget(store, it) || {};
  };
  has = function(it) {
    return wmhas(store, it);
  };
} else {
  var STATE = sharedKey$1("state");
  hiddenKeys$3[STATE] = true;
  set = function(it, metadata) {
    if (hasOwn$4(it, STATE))
      throw new TypeError$2(OBJECT_ALREADY_INITIALIZED);
    metadata.facade = it;
    createNonEnumerableProperty$3(it, STATE, metadata);
    return metadata;
  };
  get$2 = function(it) {
    return hasOwn$4(it, STATE) ? it[STATE] : {};
  };
  has = function(it) {
    return hasOwn$4(it, STATE);
  };
}
var internalState = {
  set,
  get: get$2,
  has,
  enforce,
  getterFor
};
var fails$7 = fails$e;
var isCallable$5 = isCallable$d;
var hasOwn$3 = hasOwnProperty_1;
var DESCRIPTORS$2 = descriptors;
var CONFIGURABLE_FUNCTION_NAME = functionName.CONFIGURABLE;
var inspectSource = inspectSource$2;
var InternalStateModule = internalState;
var enforceInternalState = InternalStateModule.enforce;
var getInternalState$1 = InternalStateModule.get;
var defineProperty$5 = Object.defineProperty;
var CONFIGURABLE_LENGTH = DESCRIPTORS$2 && !fails$7(function() {
  return defineProperty$5(function() {
  }, "length", { value: 8 }).length !== 8;
});
var TEMPLATE = String(String).split("String");
var makeBuiltIn$1 = makeBuiltIn$2.exports = function(value, name, options) {
  if (String(name).slice(0, 7) === "Symbol(") {
    name = "[" + String(name).replace(/^Symbol\(([^)]*)\)/, "$1") + "]";
  }
  if (options && options.getter)
    name = "get " + name;
  if (options && options.setter)
    name = "set " + name;
  if (!hasOwn$3(value, "name") || CONFIGURABLE_FUNCTION_NAME && value.name !== name) {
    defineProperty$5(value, "name", { value: name, configurable: true });
  }
  if (CONFIGURABLE_LENGTH && options && hasOwn$3(options, "arity") && value.length !== options.arity) {
    defineProperty$5(value, "length", { value: options.arity });
  }
  if (options && hasOwn$3(options, "constructor") && options.constructor) {
    if (DESCRIPTORS$2)
      try {
        defineProperty$5(value, "prototype", { writable: false });
      } catch (error) {
      }
  } else
    value.prototype = void 0;
  var state2 = enforceInternalState(value);
  if (!hasOwn$3(state2, "source")) {
    state2.source = TEMPLATE.join(typeof name == "string" ? name : "");
  }
  return value;
};
Function.prototype.toString = makeBuiltIn$1(function toString() {
  return isCallable$5(this) && getInternalState$1(this).source || inspectSource(this);
}, "toString");
var global$8 = global$r;
var isCallable$4 = isCallable$d;
var createNonEnumerableProperty$2 = createNonEnumerableProperty$4;
var makeBuiltIn = makeBuiltIn$2.exports;
var setGlobal$1 = setGlobal$3;
var defineBuiltIn$4 = function(O, key, value, options) {
  var unsafe = options ? !!options.unsafe : false;
  var simple = options ? !!options.enumerable : false;
  var noTargetGet = options ? !!options.noTargetGet : false;
  var name = options && options.name !== void 0 ? options.name : key;
  if (isCallable$4(value))
    makeBuiltIn(value, name, options);
  if (O === global$8) {
    if (simple)
      O[key] = value;
    else
      setGlobal$1(key, value);
    return O;
  } else if (!unsafe) {
    delete O[key];
  } else if (!noTargetGet && O[key]) {
    simple = true;
  }
  if (simple)
    O[key] = value;
  else
    createNonEnumerableProperty$2(O, key, value);
  return O;
};
var objectGetOwnPropertyNames = {};
var ceil = Math.ceil;
var floor$1 = Math.floor;
var toIntegerOrInfinity$4 = function(argument) {
  var number = +argument;
  return number !== number || number === 0 ? 0 : (number > 0 ? floor$1 : ceil)(number);
};
var toIntegerOrInfinity$3 = toIntegerOrInfinity$4;
var max$1 = Math.max;
var min$2 = Math.min;
var toAbsoluteIndex$1 = function(index, length) {
  var integer = toIntegerOrInfinity$3(index);
  return integer < 0 ? max$1(integer + length, 0) : min$2(integer, length);
};
var toIntegerOrInfinity$2 = toIntegerOrInfinity$4;
var min$1 = Math.min;
var toLength$2 = function(argument) {
  return argument > 0 ? min$1(toIntegerOrInfinity$2(argument), 9007199254740991) : 0;
};
var toLength$1 = toLength$2;
var lengthOfArrayLike$1 = function(obj) {
  return toLength$1(obj.length);
};
var toIndexedObject$2 = toIndexedObject$4;
var toAbsoluteIndex = toAbsoluteIndex$1;
var lengthOfArrayLike = lengthOfArrayLike$1;
var createMethod$1 = function(IS_INCLUDES) {
  return function($this, el, fromIndex) {
    var O = toIndexedObject$2($this);
    var length = lengthOfArrayLike(O);
    var index = toAbsoluteIndex(fromIndex, length);
    var value;
    if (IS_INCLUDES && el != el)
      while (length > index) {
        value = O[index++];
        if (value != value)
          return true;
      }
    else
      for (; length > index; index++) {
        if ((IS_INCLUDES || index in O) && O[index] === el)
          return IS_INCLUDES || index || 0;
      }
    return !IS_INCLUDES && -1;
  };
};
var arrayIncludes = {
  includes: createMethod$1(true),
  indexOf: createMethod$1(false)
};
var uncurryThis$6 = functionUncurryThis;
var hasOwn$2 = hasOwnProperty_1;
var toIndexedObject$1 = toIndexedObject$4;
var indexOf$1 = arrayIncludes.indexOf;
var hiddenKeys$2 = hiddenKeys$4;
var push$1 = uncurryThis$6([].push);
var objectKeysInternal = function(object, names) {
  var O = toIndexedObject$1(object);
  var i = 0;
  var result = [];
  var key;
  for (key in O)
    !hasOwn$2(hiddenKeys$2, key) && hasOwn$2(O, key) && push$1(result, key);
  while (names.length > i)
    if (hasOwn$2(O, key = names[i++])) {
      ~indexOf$1(result, key) || push$1(result, key);
    }
  return result;
};
var enumBugKeys$3 = [
  "constructor",
  "hasOwnProperty",
  "isPrototypeOf",
  "propertyIsEnumerable",
  "toLocaleString",
  "toString",
  "valueOf"
];
var internalObjectKeys$1 = objectKeysInternal;
var enumBugKeys$2 = enumBugKeys$3;
var hiddenKeys$1 = enumBugKeys$2.concat("length", "prototype");
objectGetOwnPropertyNames.f = Object.getOwnPropertyNames || function getOwnPropertyNames(O) {
  return internalObjectKeys$1(O, hiddenKeys$1);
};
var objectGetOwnPropertySymbols = {};
objectGetOwnPropertySymbols.f = Object.getOwnPropertySymbols;
var getBuiltIn$1 = getBuiltIn$4;
var uncurryThis$5 = functionUncurryThis;
var getOwnPropertyNamesModule = objectGetOwnPropertyNames;
var getOwnPropertySymbolsModule = objectGetOwnPropertySymbols;
var anObject$6 = anObject$8;
var concat$1 = uncurryThis$5([].concat);
var ownKeys$4 = getBuiltIn$1("Reflect", "ownKeys") || function ownKeys(it) {
  var keys3 = getOwnPropertyNamesModule.f(anObject$6(it));
  var getOwnPropertySymbols = getOwnPropertySymbolsModule.f;
  return getOwnPropertySymbols ? concat$1(keys3, getOwnPropertySymbols(it)) : keys3;
};
var hasOwn$1 = hasOwnProperty_1;
var ownKeys$3 = ownKeys$4;
var getOwnPropertyDescriptorModule = objectGetOwnPropertyDescriptor;
var definePropertyModule$1 = objectDefineProperty;
var copyConstructorProperties$1 = function(target, source, exceptions) {
  var keys3 = ownKeys$3(source);
  var defineProperty4 = definePropertyModule$1.f;
  var getOwnPropertyDescriptor3 = getOwnPropertyDescriptorModule.f;
  for (var i = 0; i < keys3.length; i++) {
    var key = keys3[i];
    if (!hasOwn$1(target, key) && !(exceptions && hasOwn$1(exceptions, key))) {
      defineProperty4(target, key, getOwnPropertyDescriptor3(source, key));
    }
  }
};
var fails$6 = fails$e;
var isCallable$3 = isCallable$d;
var replacement = /#|\.prototype\./;
var isForced$1 = function(feature, detection) {
  var value = data[normalize(feature)];
  return value == POLYFILL ? true : value == NATIVE ? false : isCallable$3(detection) ? fails$6(detection) : !!detection;
};
var normalize = isForced$1.normalize = function(string) {
  return String(string).replace(replacement, ".").toLowerCase();
};
var data = isForced$1.data = {};
var NATIVE = isForced$1.NATIVE = "N";
var POLYFILL = isForced$1.POLYFILL = "P";
var isForced_1 = isForced$1;
var global$7 = global$r;
var getOwnPropertyDescriptor2 = objectGetOwnPropertyDescriptor.f;
var createNonEnumerableProperty$1 = createNonEnumerableProperty$4;
var defineBuiltIn$3 = defineBuiltIn$4;
var setGlobal = setGlobal$3;
var copyConstructorProperties = copyConstructorProperties$1;
var isForced = isForced_1;
var _export = function(options, source) {
  var TARGET = options.target;
  var GLOBAL = options.global;
  var STATIC = options.stat;
  var FORCED, target, key, targetProperty, sourceProperty, descriptor;
  if (GLOBAL) {
    target = global$7;
  } else if (STATIC) {
    target = global$7[TARGET] || setGlobal(TARGET, {});
  } else {
    target = (global$7[TARGET] || {}).prototype;
  }
  if (target)
    for (key in source) {
      sourceProperty = source[key];
      if (options.noTargetGet) {
        descriptor = getOwnPropertyDescriptor2(target, key);
        targetProperty = descriptor && descriptor.value;
      } else
        targetProperty = target[key];
      FORCED = isForced(GLOBAL ? key : TARGET + (STATIC ? "." : "#") + key, options.forced);
      if (!FORCED && targetProperty !== void 0) {
        if (typeof sourceProperty == typeof targetProperty)
          continue;
        copyConstructorProperties(sourceProperty, targetProperty);
      }
      if (options.sham || targetProperty && targetProperty.sham) {
        createNonEnumerableProperty$1(sourceProperty, "sham", true);
      }
      defineBuiltIn$3(target, key, sourceProperty, options);
    }
};
var wellKnownSymbol$3 = wellKnownSymbol$5;
var TO_STRING_TAG$1 = wellKnownSymbol$3("toStringTag");
var test = {};
test[TO_STRING_TAG$1] = "z";
var toStringTagSupport = String(test) === "[object z]";
var global$6 = global$r;
var TO_STRING_TAG_SUPPORT$2 = toStringTagSupport;
var isCallable$2 = isCallable$d;
var classofRaw = classofRaw$1;
var wellKnownSymbol$2 = wellKnownSymbol$5;
var TO_STRING_TAG = wellKnownSymbol$2("toStringTag");
var Object$1 = global$6.Object;
var CORRECT_ARGUMENTS = classofRaw(function() {
  return arguments;
}()) == "Arguments";
var tryGet = function(it, key) {
  try {
    return it[key];
  } catch (error) {
  }
};
var classof$3 = TO_STRING_TAG_SUPPORT$2 ? classofRaw : function(it) {
  var O, tag, result;
  return it === void 0 ? "Undefined" : it === null ? "Null" : typeof (tag = tryGet(O = Object$1(it), TO_STRING_TAG)) == "string" ? tag : CORRECT_ARGUMENTS ? classofRaw(O) : (result = classofRaw(O)) == "Object" && isCallable$2(O.callee) ? "Arguments" : result;
};
var global$5 = global$r;
var classof$2 = classof$3;
var String$1 = global$5.String;
var toString$5 = function(argument) {
  if (classof$2(argument) === "Symbol")
    throw TypeError("Cannot convert a Symbol value to a string");
  return String$1(argument);
};
var anObject$5 = anObject$8;
var regexpFlags$1 = function() {
  var that = anObject$5(this);
  var result = "";
  if (that.hasIndices)
    result += "d";
  if (that.global)
    result += "g";
  if (that.ignoreCase)
    result += "i";
  if (that.multiline)
    result += "m";
  if (that.dotAll)
    result += "s";
  if (that.unicode)
    result += "u";
  if (that.sticky)
    result += "y";
  return result;
};
var fails$5 = fails$e;
var global$4 = global$r;
var $RegExp$2 = global$4.RegExp;
var UNSUPPORTED_Y$1 = fails$5(function() {
  var re = $RegExp$2("a", "y");
  re.lastIndex = 2;
  return re.exec("abcd") != null;
});
var MISSED_STICKY = UNSUPPORTED_Y$1 || fails$5(function() {
  return !$RegExp$2("a", "y").sticky;
});
var BROKEN_CARET = UNSUPPORTED_Y$1 || fails$5(function() {
  var re = $RegExp$2("^r", "gy");
  re.lastIndex = 2;
  return re.exec("str") != null;
});
var regexpStickyHelpers = {
  BROKEN_CARET,
  MISSED_STICKY,
  UNSUPPORTED_Y: UNSUPPORTED_Y$1
};
var objectDefineProperties = {};
var internalObjectKeys = objectKeysInternal;
var enumBugKeys$1 = enumBugKeys$3;
var objectKeys$1 = Object.keys || function keys(O) {
  return internalObjectKeys(O, enumBugKeys$1);
};
var DESCRIPTORS$1 = descriptors;
var V8_PROTOTYPE_DEFINE_BUG = v8PrototypeDefineBug;
var definePropertyModule = objectDefineProperty;
var anObject$4 = anObject$8;
var toIndexedObject = toIndexedObject$4;
var objectKeys = objectKeys$1;
objectDefineProperties.f = DESCRIPTORS$1 && !V8_PROTOTYPE_DEFINE_BUG ? Object.defineProperties : function defineProperties(O, Properties) {
  anObject$4(O);
  var props = toIndexedObject(Properties);
  var keys3 = objectKeys(Properties);
  var length = keys3.length;
  var index = 0;
  var key;
  while (length > index)
    definePropertyModule.f(O, key = keys3[index++], props[key]);
  return O;
};
var getBuiltIn = getBuiltIn$4;
var html$1 = getBuiltIn("document", "documentElement");
var anObject$3 = anObject$8;
var definePropertiesModule = objectDefineProperties;
var enumBugKeys = enumBugKeys$3;
var hiddenKeys = hiddenKeys$4;
var html = html$1;
var documentCreateElement = documentCreateElement$1;
var sharedKey = sharedKey$2;
var GT = ">";
var LT = "<";
var PROTOTYPE = "prototype";
var SCRIPT = "script";
var IE_PROTO = sharedKey("IE_PROTO");
var EmptyConstructor = function() {
};
var scriptTag = function(content) {
  return LT + SCRIPT + GT + content + LT + "/" + SCRIPT + GT;
};
var NullProtoObjectViaActiveX = function(activeXDocument2) {
  activeXDocument2.write(scriptTag(""));
  activeXDocument2.close();
  var temp = activeXDocument2.parentWindow.Object;
  activeXDocument2 = null;
  return temp;
};
var NullProtoObjectViaIFrame = function() {
  var iframe = documentCreateElement("iframe");
  var JS = "java" + SCRIPT + ":";
  var iframeDocument;
  iframe.style.display = "none";
  html.appendChild(iframe);
  iframe.src = String(JS);
  iframeDocument = iframe.contentWindow.document;
  iframeDocument.open();
  iframeDocument.write(scriptTag("document.F=Object"));
  iframeDocument.close();
  return iframeDocument.F;
};
var activeXDocument;
var NullProtoObject = function() {
  try {
    activeXDocument = new ActiveXObject("htmlfile");
  } catch (error) {
  }
  NullProtoObject = typeof document != "undefined" ? document.domain && activeXDocument ? NullProtoObjectViaActiveX(activeXDocument) : NullProtoObjectViaIFrame() : NullProtoObjectViaActiveX(activeXDocument);
  var length = enumBugKeys.length;
  while (length--)
    delete NullProtoObject[PROTOTYPE][enumBugKeys[length]];
  return NullProtoObject();
};
hiddenKeys[IE_PROTO] = true;
var objectCreate$1 = Object.create || function create(O, Properties) {
  var result;
  if (O !== null) {
    EmptyConstructor[PROTOTYPE] = anObject$3(O);
    result = new EmptyConstructor();
    EmptyConstructor[PROTOTYPE] = null;
    result[IE_PROTO] = O;
  } else
    result = NullProtoObject();
  return Properties === void 0 ? result : definePropertiesModule.f(result, Properties);
};
var fails$4 = fails$e;
var global$3 = global$r;
var $RegExp$1 = global$3.RegExp;
var regexpUnsupportedDotAll = fails$4(function() {
  var re = $RegExp$1(".", "s");
  return !(re.dotAll && re.exec("\n") && re.flags === "s");
});
var fails$3 = fails$e;
var global$2 = global$r;
var $RegExp = global$2.RegExp;
var regexpUnsupportedNcg = fails$3(function() {
  var re = $RegExp("(?<a>b)", "g");
  return re.exec("b").groups.a !== "b" || "b".replace(re, "$<a>c") !== "bc";
});
var call$4 = functionCall;
var uncurryThis$4 = functionUncurryThis;
var toString$4 = toString$5;
var regexpFlags = regexpFlags$1;
var stickyHelpers = regexpStickyHelpers;
var shared = shared$4.exports;
var create2 = objectCreate$1;
var getInternalState = internalState.get;
var UNSUPPORTED_DOT_ALL = regexpUnsupportedDotAll;
var UNSUPPORTED_NCG = regexpUnsupportedNcg;
var nativeReplace = shared("native-string-replace", String.prototype.replace);
var nativeExec = RegExp.prototype.exec;
var patchedExec = nativeExec;
var charAt$3 = uncurryThis$4("".charAt);
var indexOf = uncurryThis$4("".indexOf);
var replace$1 = uncurryThis$4("".replace);
var stringSlice$3 = uncurryThis$4("".slice);
var UPDATES_LAST_INDEX_WRONG = function() {
  var re1 = /a/;
  var re2 = /b*/g;
  call$4(nativeExec, re1, "a");
  call$4(nativeExec, re2, "a");
  return re1.lastIndex !== 0 || re2.lastIndex !== 0;
}();
var UNSUPPORTED_Y = stickyHelpers.BROKEN_CARET;
var NPCG_INCLUDED = /()??/.exec("")[1] !== void 0;
var PATCH = UPDATES_LAST_INDEX_WRONG || NPCG_INCLUDED || UNSUPPORTED_Y || UNSUPPORTED_DOT_ALL || UNSUPPORTED_NCG;
if (PATCH) {
  patchedExec = function exec2(string) {
    var re = this;
    var state2 = getInternalState(re);
    var str = toString$4(string);
    var raw = state2.raw;
    var result, reCopy, lastIndex, match2, i, object, group;
    if (raw) {
      raw.lastIndex = re.lastIndex;
      result = call$4(patchedExec, raw, str);
      re.lastIndex = raw.lastIndex;
      return result;
    }
    var groups = state2.groups;
    var sticky = UNSUPPORTED_Y && re.sticky;
    var flags = call$4(regexpFlags, re);
    var source = re.source;
    var charsAdded = 0;
    var strCopy = str;
    if (sticky) {
      flags = replace$1(flags, "y", "");
      if (indexOf(flags, "g") === -1) {
        flags += "g";
      }
      strCopy = stringSlice$3(str, re.lastIndex);
      if (re.lastIndex > 0 && (!re.multiline || re.multiline && charAt$3(str, re.lastIndex - 1) !== "\n")) {
        source = "(?: " + source + ")";
        strCopy = " " + strCopy;
        charsAdded++;
      }
      reCopy = new RegExp("^(?:" + source + ")", flags);
    }
    if (NPCG_INCLUDED) {
      reCopy = new RegExp("^" + source + "$(?!\\s)", flags);
    }
    if (UPDATES_LAST_INDEX_WRONG)
      lastIndex = re.lastIndex;
    match2 = call$4(nativeExec, sticky ? reCopy : re, strCopy);
    if (sticky) {
      if (match2) {
        match2.input = stringSlice$3(match2.input, charsAdded);
        match2[0] = stringSlice$3(match2[0], charsAdded);
        match2.index = re.lastIndex;
        re.lastIndex += match2[0].length;
      } else
        re.lastIndex = 0;
    } else if (UPDATES_LAST_INDEX_WRONG && match2) {
      re.lastIndex = re.global ? match2.index + match2[0].length : lastIndex;
    }
    if (NPCG_INCLUDED && match2 && match2.length > 1) {
      call$4(nativeReplace, match2[0], reCopy, function() {
        for (i = 1; i < arguments.length - 2; i++) {
          if (arguments[i] === void 0)
            match2[i] = void 0;
        }
      });
    }
    if (match2 && groups) {
      match2.groups = object = create2(null);
      for (i = 0; i < groups.length; i++) {
        group = groups[i];
        object[group[0]] = match2[group[1]];
      }
    }
    return match2;
  };
}
var regexpExec$2 = patchedExec;
var $$1 = _export;
var exec = regexpExec$2;
$$1({ target: "RegExp", proto: true, forced: /./.exec !== exec }, {
  exec
});
var NATIVE_BIND = functionBindNative;
var FunctionPrototype = Function.prototype;
var apply$3 = FunctionPrototype.apply;
var call$3 = FunctionPrototype.call;
var functionApply = typeof Reflect == "object" && Reflect.apply || (NATIVE_BIND ? call$3.bind(apply$3) : function() {
  return call$3.apply(apply$3, arguments);
});
var uncurryThis$3 = functionUncurryThis;
var defineBuiltIn$2 = defineBuiltIn$4;
var regexpExec$1 = regexpExec$2;
var fails$2 = fails$e;
var wellKnownSymbol$1 = wellKnownSymbol$5;
var createNonEnumerableProperty = createNonEnumerableProperty$4;
var SPECIES = wellKnownSymbol$1("species");
var RegExpPrototype$2 = RegExp.prototype;
var fixRegexpWellKnownSymbolLogic = function(KEY, exec2, FORCED, SHAM) {
  var SYMBOL = wellKnownSymbol$1(KEY);
  var DELEGATES_TO_SYMBOL = !fails$2(function() {
    var O = {};
    O[SYMBOL] = function() {
      return 7;
    };
    return ""[KEY](O) != 7;
  });
  var DELEGATES_TO_EXEC = DELEGATES_TO_SYMBOL && !fails$2(function() {
    var execCalled = false;
    var re = /a/;
    if (KEY === "split") {
      re = {};
      re.constructor = {};
      re.constructor[SPECIES] = function() {
        return re;
      };
      re.flags = "";
      re[SYMBOL] = /./[SYMBOL];
    }
    re.exec = function() {
      execCalled = true;
      return null;
    };
    re[SYMBOL]("");
    return !execCalled;
  });
  if (!DELEGATES_TO_SYMBOL || !DELEGATES_TO_EXEC || FORCED) {
    var uncurriedNativeRegExpMethod = uncurryThis$3(/./[SYMBOL]);
    var methods = exec2(SYMBOL, ""[KEY], function(nativeMethod, regexp, str, arg2, forceStringMethod) {
      var uncurriedNativeMethod = uncurryThis$3(nativeMethod);
      var $exec = regexp.exec;
      if ($exec === regexpExec$1 || $exec === RegExpPrototype$2.exec) {
        if (DELEGATES_TO_SYMBOL && !forceStringMethod) {
          return { done: true, value: uncurriedNativeRegExpMethod(regexp, str, arg2) };
        }
        return { done: true, value: uncurriedNativeMethod(str, regexp, arg2) };
      }
      return { done: false };
    });
    defineBuiltIn$2(String.prototype, KEY, methods[0]);
    defineBuiltIn$2(RegExpPrototype$2, SYMBOL, methods[1]);
  }
  if (SHAM)
    createNonEnumerableProperty(RegExpPrototype$2[SYMBOL], "sham", true);
};
var uncurryThis$2 = functionUncurryThis;
var toIntegerOrInfinity$1 = toIntegerOrInfinity$4;
var toString$3 = toString$5;
var requireObjectCoercible$1 = requireObjectCoercible$4;
var charAt$2 = uncurryThis$2("".charAt);
var charCodeAt = uncurryThis$2("".charCodeAt);
var stringSlice$2 = uncurryThis$2("".slice);
var createMethod = function(CONVERT_TO_STRING) {
  return function($this, pos) {
    var S = toString$3(requireObjectCoercible$1($this));
    var position = toIntegerOrInfinity$1(pos);
    var size = S.length;
    var first, second;
    if (position < 0 || position >= size)
      return CONVERT_TO_STRING ? "" : void 0;
    first = charCodeAt(S, position);
    return first < 55296 || first > 56319 || position + 1 === size || (second = charCodeAt(S, position + 1)) < 56320 || second > 57343 ? CONVERT_TO_STRING ? charAt$2(S, position) : first : CONVERT_TO_STRING ? stringSlice$2(S, position, position + 2) : (first - 55296 << 10) + (second - 56320) + 65536;
  };
};
var stringMultibyte = {
  codeAt: createMethod(false),
  charAt: createMethod(true)
};
var charAt$1 = stringMultibyte.charAt;
var advanceStringIndex$1 = function(S, index, unicode) {
  return index + (unicode ? charAt$1(S, index).length : 1);
};
var uncurryThis$1 = functionUncurryThis;
var toObject = toObject$2;
var floor = Math.floor;
var charAt = uncurryThis$1("".charAt);
var replace = uncurryThis$1("".replace);
var stringSlice$1 = uncurryThis$1("".slice);
var SUBSTITUTION_SYMBOLS = /\$([$&'`]|\d{1,2}|<[^>]*>)/g;
var SUBSTITUTION_SYMBOLS_NO_NAMED = /\$([$&'`]|\d{1,2})/g;
var getSubstitution$1 = function(matched, str, position, captures, namedCaptures, replacement2) {
  var tailPos = position + matched.length;
  var m = captures.length;
  var symbols = SUBSTITUTION_SYMBOLS_NO_NAMED;
  if (namedCaptures !== void 0) {
    namedCaptures = toObject(namedCaptures);
    symbols = SUBSTITUTION_SYMBOLS;
  }
  return replace(replacement2, symbols, function(match2, ch) {
    var capture;
    switch (charAt(ch, 0)) {
      case "$":
        return "$";
      case "&":
        return matched;
      case "`":
        return stringSlice$1(str, 0, position);
      case "'":
        return stringSlice$1(str, tailPos);
      case "<":
        capture = namedCaptures[stringSlice$1(ch, 1, -1)];
        break;
      default:
        var n = +ch;
        if (n === 0)
          return match2;
        if (n > m) {
          var f = floor(n / 10);
          if (f === 0)
            return match2;
          if (f <= m)
            return captures[f - 1] === void 0 ? charAt(ch, 1) : captures[f - 1] + charAt(ch, 1);
          return match2;
        }
        capture = captures[n - 1];
    }
    return capture === void 0 ? "" : capture;
  });
};
var global$1 = global$r;
var call$2 = functionCall;
var anObject$2 = anObject$8;
var isCallable$1 = isCallable$d;
var classof$1 = classofRaw$1;
var regexpExec = regexpExec$2;
var TypeError$1 = global$1.TypeError;
var regexpExecAbstract = function(R, S) {
  var exec2 = R.exec;
  if (isCallable$1(exec2)) {
    var result = call$2(exec2, R, S);
    if (result !== null)
      anObject$2(result);
    return result;
  }
  if (classof$1(R) === "RegExp")
    return call$2(regexpExec, R, S);
  throw TypeError$1("RegExp#exec called on incompatible receiver");
};
var apply$2 = functionApply;
var call$1 = functionCall;
var uncurryThis = functionUncurryThis;
var fixRegExpWellKnownSymbolLogic = fixRegexpWellKnownSymbolLogic;
var fails$1 = fails$e;
var anObject$1 = anObject$8;
var isCallable = isCallable$d;
var toIntegerOrInfinity = toIntegerOrInfinity$4;
var toLength = toLength$2;
var toString$2 = toString$5;
var requireObjectCoercible = requireObjectCoercible$4;
var advanceStringIndex = advanceStringIndex$1;
var getMethod = getMethod$2;
var getSubstitution = getSubstitution$1;
var regExpExec = regexpExecAbstract;
var wellKnownSymbol = wellKnownSymbol$5;
var REPLACE = wellKnownSymbol("replace");
var max = Math.max;
var min = Math.min;
var concat = uncurryThis([].concat);
var push = uncurryThis([].push);
var stringIndexOf = uncurryThis("".indexOf);
var stringSlice = uncurryThis("".slice);
var maybeToString = function(it) {
  return it === void 0 ? it : String(it);
};
var REPLACE_KEEPS_$0 = function() {
  return "a".replace(/./, "$0") === "$0";
}();
var REGEXP_REPLACE_SUBSTITUTES_UNDEFINED_CAPTURE = function() {
  if (/./[REPLACE]) {
    return /./[REPLACE]("a", "$0") === "";
  }
  return false;
}();
var REPLACE_SUPPORTS_NAMED_GROUPS = !fails$1(function() {
  var re = /./;
  re.exec = function() {
    var result = [];
    result.groups = { a: "7" };
    return result;
  };
  return "".replace(re, "$<a>") !== "7";
});
fixRegExpWellKnownSymbolLogic("replace", function(_2, nativeReplace2, maybeCallNative) {
  var UNSAFE_SUBSTITUTE = REGEXP_REPLACE_SUBSTITUTES_UNDEFINED_CAPTURE ? "$" : "$0";
  return [
    function replace2(searchValue, replaceValue) {
      var O = requireObjectCoercible(this);
      var replacer = searchValue == void 0 ? void 0 : getMethod(searchValue, REPLACE);
      return replacer ? call$1(replacer, searchValue, O, replaceValue) : call$1(nativeReplace2, toString$2(O), searchValue, replaceValue);
    },
    function(string, replaceValue) {
      var rx = anObject$1(this);
      var S = toString$2(string);
      if (typeof replaceValue == "string" && stringIndexOf(replaceValue, UNSAFE_SUBSTITUTE) === -1 && stringIndexOf(replaceValue, "$<") === -1) {
        var res = maybeCallNative(nativeReplace2, rx, S, replaceValue);
        if (res.done)
          return res.value;
      }
      var functionalReplace = isCallable(replaceValue);
      if (!functionalReplace)
        replaceValue = toString$2(replaceValue);
      var global2 = rx.global;
      if (global2) {
        var fullUnicode = rx.unicode;
        rx.lastIndex = 0;
      }
      var results = [];
      while (true) {
        var result = regExpExec(rx, S);
        if (result === null)
          break;
        push(results, result);
        if (!global2)
          break;
        var matchStr = toString$2(result[0]);
        if (matchStr === "")
          rx.lastIndex = advanceStringIndex(S, toLength(rx.lastIndex), fullUnicode);
      }
      var accumulatedResult = "";
      var nextSourcePosition = 0;
      for (var i = 0; i < results.length; i++) {
        result = results[i];
        var matched = toString$2(result[0]);
        var position = max(min(toIntegerOrInfinity(result.index), S.length), 0);
        var captures = [];
        for (var j = 1; j < result.length; j++)
          push(captures, maybeToString(result[j]));
        var namedCaptures = result.groups;
        if (functionalReplace) {
          var replacerArgs = concat([matched], captures, position, S);
          if (namedCaptures !== void 0)
            push(replacerArgs, namedCaptures);
          var replacement2 = toString$2(apply$2(replaceValue, void 0, replacerArgs));
        } else {
          replacement2 = getSubstitution(matched, S, position, captures, namedCaptures, replaceValue);
        }
        if (position >= nextSourcePosition) {
          accumulatedResult += stringSlice(S, nextSourcePosition, position) + replacement2;
          nextSourcePosition = position + matched.length;
        }
      }
      return accumulatedResult + stringSlice(S, nextSourcePosition);
    }
  ];
}, !REPLACE_SUPPORTS_NAMED_GROUPS || !REPLACE_KEEPS_$0 || REGEXP_REPLACE_SUBSTITUTES_UNDEFINED_CAPTURE);
var $ = _export;
var DESCRIPTORS = descriptors;
var defineProperty$4 = objectDefineProperty.f;
$({ target: "Object", stat: true, forced: Object.defineProperty !== defineProperty$4, sham: !DESCRIPTORS }, {
  defineProperty: defineProperty$4
});
var TO_STRING_TAG_SUPPORT$1 = toStringTagSupport;
var classof = classof$3;
var objectToString$3 = TO_STRING_TAG_SUPPORT$1 ? {}.toString : function toString2() {
  return "[object " + classof(this) + "]";
};
var TO_STRING_TAG_SUPPORT = toStringTagSupport;
var defineBuiltIn$1 = defineBuiltIn$4;
var toString$1 = objectToString$3;
if (!TO_STRING_TAG_SUPPORT) {
  defineBuiltIn$1(Object.prototype, "toString", toString$1, { unsafe: true });
}
var call = functionCall;
var hasOwn2 = hasOwnProperty_1;
var isPrototypeOf = objectIsPrototypeOf;
var regExpFlags = regexpFlags$1;
var RegExpPrototype$1 = RegExp.prototype;
var regexpGetFlags = function(R) {
  var flags = R.flags;
  return flags === void 0 && !("flags" in RegExpPrototype$1) && !hasOwn2(R, "flags") && isPrototypeOf(RegExpPrototype$1, R) ? call(regExpFlags, R) : flags;
};
var PROPER_FUNCTION_NAME = functionName.PROPER;
var defineBuiltIn = defineBuiltIn$4;
var anObject = anObject$8;
var $toString = toString$5;
var fails = fails$e;
var getRegExpFlags = regexpGetFlags;
var TO_STRING = "toString";
var RegExpPrototype = RegExp.prototype;
var n$ToString = RegExpPrototype[TO_STRING];
var NOT_GENERIC = fails(function() {
  return n$ToString.call({ source: "a", flags: "b" }) != "/a/b";
});
var INCORRECT_NAME = PROPER_FUNCTION_NAME && n$ToString.name != TO_STRING;
if (NOT_GENERIC || INCORRECT_NAME) {
  defineBuiltIn(RegExp.prototype, TO_STRING, function toString4() {
    var R = anObject(this);
    var pattern = $toString(R.source);
    var flags = $toString(getRegExpFlags(R));
    return "/" + pattern + "/" + flags;
  }, { unsafe: true });
}
var FUNC_ERROR_TEXT = "Expected a function";
var HASH_UNDEFINED$3 = "__lodash_hash_undefined__";
var INFINITY = 1 / 0;
var funcTag$2 = "[object Function]", genTag$1 = "[object GeneratorFunction]", symbolTag$1 = "[object Symbol]";
var reIsDeepProp = /\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/, reIsPlainProp = /^\w*$/, reLeadingDot = /^\./, rePropName = /[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|$))/g;
var reRegExpChar$1 = /[\\^$.*+?()[\]{}|]/g;
var reEscapeChar = /\\(\\)?/g;
var reIsHostCtor$1 = /^\[object .+?Constructor\]$/;
var freeGlobal$2 = typeof commonjsGlobal == "object" && commonjsGlobal && commonjsGlobal.Object === Object && commonjsGlobal;
var freeSelf$1 = typeof self == "object" && self && self.Object === Object && self;
var root$9 = freeGlobal$2 || freeSelf$1 || Function("return this")();
function getValue$2(object, key) {
  return object == null ? void 0 : object[key];
}
function isHostObject(value) {
  var result = false;
  if (value != null && typeof value.toString != "function") {
    try {
      result = !!(value + "");
    } catch (e) {
    }
  }
  return result;
}
var arrayProto$1 = Array.prototype, funcProto$3 = Function.prototype, objectProto$f = Object.prototype;
var coreJsData$2 = root$9["__core-js_shared__"];
var maskSrcKey$1 = function() {
  var uid2 = /[^.]+$/.exec(coreJsData$2 && coreJsData$2.keys && coreJsData$2.keys.IE_PROTO || "");
  return uid2 ? "Symbol(src)_1." + uid2 : "";
}();
var funcToString$3 = funcProto$3.toString;
var hasOwnProperty$c = objectProto$f.hasOwnProperty;
var objectToString$2 = objectProto$f.toString;
var reIsNative$1 = RegExp("^" + funcToString$3.call(hasOwnProperty$c).replace(reRegExpChar$1, "\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, "$1.*?") + "$");
var Symbol$5 = root$9.Symbol, splice$1 = arrayProto$1.splice;
var Map$4 = getNative$8(root$9, "Map"), nativeCreate$5 = getNative$8(Object, "create");
var symbolProto$1 = Symbol$5 ? Symbol$5.prototype : void 0, symbolToString = symbolProto$1 ? symbolProto$1.toString : void 0;
function Hash$2(entries) {
  var index = -1, length = entries ? entries.length : 0;
  this.clear();
  while (++index < length) {
    var entry = entries[index];
    this.set(entry[0], entry[1]);
  }
}
function hashClear$2() {
  this.__data__ = nativeCreate$5 ? nativeCreate$5(null) : {};
}
function hashDelete$2(key) {
  return this.has(key) && delete this.__data__[key];
}
function hashGet$2(key) {
  var data3 = this.__data__;
  if (nativeCreate$5) {
    var result = data3[key];
    return result === HASH_UNDEFINED$3 ? void 0 : result;
  }
  return hasOwnProperty$c.call(data3, key) ? data3[key] : void 0;
}
function hashHas$2(key) {
  var data3 = this.__data__;
  return nativeCreate$5 ? data3[key] !== void 0 : hasOwnProperty$c.call(data3, key);
}
function hashSet$2(key, value) {
  var data3 = this.__data__;
  data3[key] = nativeCreate$5 && value === void 0 ? HASH_UNDEFINED$3 : value;
  return this;
}
Hash$2.prototype.clear = hashClear$2;
Hash$2.prototype["delete"] = hashDelete$2;
Hash$2.prototype.get = hashGet$2;
Hash$2.prototype.has = hashHas$2;
Hash$2.prototype.set = hashSet$2;
function ListCache$5(entries) {
  var index = -1, length = entries ? entries.length : 0;
  this.clear();
  while (++index < length) {
    var entry = entries[index];
    this.set(entry[0], entry[1]);
  }
}
function listCacheClear$2() {
  this.__data__ = [];
}
function listCacheDelete$2(key) {
  var data3 = this.__data__, index = assocIndexOf$5(data3, key);
  if (index < 0) {
    return false;
  }
  var lastIndex = data3.length - 1;
  if (index == lastIndex) {
    data3.pop();
  } else {
    splice$1.call(data3, index, 1);
  }
  return true;
}
function listCacheGet$2(key) {
  var data3 = this.__data__, index = assocIndexOf$5(data3, key);
  return index < 0 ? void 0 : data3[index][1];
}
function listCacheHas$2(key) {
  return assocIndexOf$5(this.__data__, key) > -1;
}
function listCacheSet$2(key, value) {
  var data3 = this.__data__, index = assocIndexOf$5(data3, key);
  if (index < 0) {
    data3.push([key, value]);
  } else {
    data3[index][1] = value;
  }
  return this;
}
ListCache$5.prototype.clear = listCacheClear$2;
ListCache$5.prototype["delete"] = listCacheDelete$2;
ListCache$5.prototype.get = listCacheGet$2;
ListCache$5.prototype.has = listCacheHas$2;
ListCache$5.prototype.set = listCacheSet$2;
function MapCache$3(entries) {
  var index = -1, length = entries ? entries.length : 0;
  this.clear();
  while (++index < length) {
    var entry = entries[index];
    this.set(entry[0], entry[1]);
  }
}
function mapCacheClear$2() {
  this.__data__ = {
    "hash": new Hash$2(),
    "map": new (Map$4 || ListCache$5)(),
    "string": new Hash$2()
  };
}
function mapCacheDelete$2(key) {
  return getMapData$5(this, key)["delete"](key);
}
function mapCacheGet$2(key) {
  return getMapData$5(this, key).get(key);
}
function mapCacheHas$2(key) {
  return getMapData$5(this, key).has(key);
}
function mapCacheSet$2(key, value) {
  getMapData$5(this, key).set(key, value);
  return this;
}
MapCache$3.prototype.clear = mapCacheClear$2;
MapCache$3.prototype["delete"] = mapCacheDelete$2;
MapCache$3.prototype.get = mapCacheGet$2;
MapCache$3.prototype.has = mapCacheHas$2;
MapCache$3.prototype.set = mapCacheSet$2;
function assocIndexOf$5(array, key) {
  var length = array.length;
  while (length--) {
    if (eq$6(array[length][0], key)) {
      return length;
    }
  }
  return -1;
}
function baseGet(object, path2) {
  path2 = isKey(path2, object) ? [path2] : castPath(path2);
  var index = 0, length = path2.length;
  while (object != null && index < length) {
    object = object[toKey(path2[index++])];
  }
  return index && index == length ? object : void 0;
}
function baseIsNative$2(value) {
  if (!isObject$8(value) || isMasked$2(value)) {
    return false;
  }
  var pattern = isFunction$5(value) || isHostObject(value) ? reIsNative$1 : reIsHostCtor$1;
  return pattern.test(toSource$3(value));
}
function baseToString(value) {
  if (typeof value == "string") {
    return value;
  }
  if (isSymbol(value)) {
    return symbolToString ? symbolToString.call(value) : "";
  }
  var result = value + "";
  return result == "0" && 1 / value == -INFINITY ? "-0" : result;
}
function castPath(value) {
  return isArray$5(value) ? value : stringToPath(value);
}
function getMapData$5(map, key) {
  var data3 = map.__data__;
  return isKeyable$2(key) ? data3[typeof key == "string" ? "string" : "hash"] : data3.map;
}
function getNative$8(object, key) {
  var value = getValue$2(object, key);
  return baseIsNative$2(value) ? value : void 0;
}
function isKey(value, object) {
  if (isArray$5(value)) {
    return false;
  }
  var type = typeof value;
  if (type == "number" || type == "symbol" || type == "boolean" || value == null || isSymbol(value)) {
    return true;
  }
  return reIsPlainProp.test(value) || !reIsDeepProp.test(value) || object != null && value in Object(object);
}
function isKeyable$2(value) {
  var type = typeof value;
  return type == "string" || type == "number" || type == "symbol" || type == "boolean" ? value !== "__proto__" : value === null;
}
function isMasked$2(func) {
  return !!maskSrcKey$1 && maskSrcKey$1 in func;
}
var stringToPath = memoize(function(string) {
  string = toString3(string);
  var result = [];
  if (reLeadingDot.test(string)) {
    result.push("");
  }
  string.replace(rePropName, function(match2, number, quote, string2) {
    result.push(quote ? string2.replace(reEscapeChar, "$1") : number || match2);
  });
  return result;
});
function toKey(value) {
  if (typeof value == "string" || isSymbol(value)) {
    return value;
  }
  var result = value + "";
  return result == "0" && 1 / value == -INFINITY ? "-0" : result;
}
function toSource$3(func) {
  if (func != null) {
    try {
      return funcToString$3.call(func);
    } catch (e) {
    }
    try {
      return func + "";
    } catch (e) {
    }
  }
  return "";
}
function memoize(func, resolver) {
  if (typeof func != "function" || resolver && typeof resolver != "function") {
    throw new TypeError(FUNC_ERROR_TEXT);
  }
  var memoized = function() {
    var args = arguments, key = resolver ? resolver.apply(this, args) : args[0], cache = memoized.cache;
    if (cache.has(key)) {
      return cache.get(key);
    }
    var result = func.apply(this, args);
    memoized.cache = cache.set(key, result);
    return result;
  };
  memoized.cache = new (memoize.Cache || MapCache$3)();
  return memoized;
}
memoize.Cache = MapCache$3;
function eq$6(value, other) {
  return value === other || value !== value && other !== other;
}
var isArray$5 = Array.isArray;
function isFunction$5(value) {
  var tag = isObject$8(value) ? objectToString$2.call(value) : "";
  return tag == funcTag$2 || tag == genTag$1;
}
function isObject$8(value) {
  var type = typeof value;
  return !!value && (type == "object" || type == "function");
}
function isObjectLike$7(value) {
  return !!value && typeof value == "object";
}
function isSymbol(value) {
  return typeof value == "symbol" || isObjectLike$7(value) && objectToString$2.call(value) == symbolTag$1;
}
function toString3(value) {
  return value == null ? "" : baseToString(value);
}
function get$1(object, path2, defaultValue) {
  var result = object == null ? void 0 : baseGet(object, path2);
  return result === void 0 ? defaultValue : result;
}
var lodash_get = get$1;
var plurals$1 = {
  ach: {
    name: "Acholi",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n > 1)",
    pluralsFunc: function(n) {
      return n > 1;
    }
  },
  af: {
    name: "Afrikaans",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  ak: {
    name: "Akan",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n > 1)",
    pluralsFunc: function(n) {
      return n > 1;
    }
  },
  am: {
    name: "Amharic",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n > 1)",
    pluralsFunc: function(n) {
      return n > 1;
    }
  },
  an: {
    name: "Aragonese",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  ar: {
    name: "Arabic",
    examples: [{
      plural: 0,
      sample: 0
    }, {
      plural: 1,
      sample: 1
    }, {
      plural: 2,
      sample: 2
    }, {
      plural: 3,
      sample: 3
    }, {
      plural: 4,
      sample: 11
    }, {
      plural: 5,
      sample: 100
    }],
    nplurals: 6,
    pluralsText: "nplurals = 6; plural = (n === 0 ? 0 : n === 1 ? 1 : n === 2 ? 2 : n % 100 >= 3 && n % 100 <= 10 ? 3 : n % 100 >= 11 ? 4 : 5)",
    pluralsFunc: function(n) {
      return n === 0 ? 0 : n === 1 ? 1 : n === 2 ? 2 : n % 100 >= 3 && n % 100 <= 10 ? 3 : n % 100 >= 11 ? 4 : 5;
    }
  },
  arn: {
    name: "Mapudungun",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n > 1)",
    pluralsFunc: function(n) {
      return n > 1;
    }
  },
  ast: {
    name: "Asturian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  ay: {
    name: "Aymar\xE1",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  az: {
    name: "Azerbaijani",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  be: {
    name: "Belarusian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }, {
      plural: 2,
      sample: 5
    }],
    nplurals: 3,
    pluralsText: "nplurals = 3; plural = (n % 10 === 1 && n % 100 !== 11 ? 0 : n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2)",
    pluralsFunc: function(n) {
      return n % 10 === 1 && n % 100 !== 11 ? 0 : n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2;
    }
  },
  bg: {
    name: "Bulgarian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  bn: {
    name: "Bengali",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  bo: {
    name: "Tibetan",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  br: {
    name: "Breton",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n > 1)",
    pluralsFunc: function(n) {
      return n > 1;
    }
  },
  brx: {
    name: "Bodo",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  bs: {
    name: "Bosnian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }, {
      plural: 2,
      sample: 5
    }],
    nplurals: 3,
    pluralsText: "nplurals = 3; plural = (n % 10 === 1 && n % 100 !== 11 ? 0 : n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2)",
    pluralsFunc: function(n) {
      return n % 10 === 1 && n % 100 !== 11 ? 0 : n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2;
    }
  },
  ca: {
    name: "Catalan",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  cgg: {
    name: "Chiga",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  cs: {
    name: "Czech",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }, {
      plural: 2,
      sample: 5
    }],
    nplurals: 3,
    pluralsText: "nplurals = 3; plural = (n === 1 ? 0 : (n >= 2 && n <= 4) ? 1 : 2)",
    pluralsFunc: function(n) {
      return n === 1 ? 0 : n >= 2 && n <= 4 ? 1 : 2;
    }
  },
  csb: {
    name: "Kashubian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }, {
      plural: 2,
      sample: 5
    }],
    nplurals: 3,
    pluralsText: "nplurals = 3; plural = (n === 1 ? 0 : n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2)",
    pluralsFunc: function(n) {
      return n === 1 ? 0 : n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2;
    }
  },
  cy: {
    name: "Welsh",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }, {
      plural: 2,
      sample: 3
    }, {
      plural: 3,
      sample: 8
    }],
    nplurals: 4,
    pluralsText: "nplurals = 4; plural = (n === 1 ? 0 : n === 2 ? 1 : (n !== 8 && n !== 11) ? 2 : 3)",
    pluralsFunc: function(n) {
      return n === 1 ? 0 : n === 2 ? 1 : n !== 8 && n !== 11 ? 2 : 3;
    }
  },
  da: {
    name: "Danish",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  de: {
    name: "German",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  doi: {
    name: "Dogri",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  dz: {
    name: "Dzongkha",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  el: {
    name: "Greek",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  en: {
    name: "English",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  eo: {
    name: "Esperanto",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  es: {
    name: "Spanish",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  et: {
    name: "Estonian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  eu: {
    name: "Basque",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  fa: {
    name: "Persian",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  ff: {
    name: "Fulah",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  fi: {
    name: "Finnish",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  fil: {
    name: "Filipino",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n > 1)",
    pluralsFunc: function(n) {
      return n > 1;
    }
  },
  fo: {
    name: "Faroese",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  fr: {
    name: "French",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n > 1)",
    pluralsFunc: function(n) {
      return n > 1;
    }
  },
  fur: {
    name: "Friulian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  fy: {
    name: "Frisian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  ga: {
    name: "Irish",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }, {
      plural: 2,
      sample: 3
    }, {
      plural: 3,
      sample: 7
    }, {
      plural: 4,
      sample: 11
    }],
    nplurals: 5,
    pluralsText: "nplurals = 5; plural = (n === 1 ? 0 : n === 2 ? 1 : n < 7 ? 2 : n < 11 ? 3 : 4)",
    pluralsFunc: function(n) {
      return n === 1 ? 0 : n === 2 ? 1 : n < 7 ? 2 : n < 11 ? 3 : 4;
    }
  },
  gd: {
    name: "Scottish Gaelic",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }, {
      plural: 2,
      sample: 3
    }, {
      plural: 3,
      sample: 20
    }],
    nplurals: 4,
    pluralsText: "nplurals = 4; plural = ((n === 1 || n === 11) ? 0 : (n === 2 || n === 12) ? 1 : (n > 2 && n < 20) ? 2 : 3)",
    pluralsFunc: function(n) {
      return n === 1 || n === 11 ? 0 : n === 2 || n === 12 ? 1 : n > 2 && n < 20 ? 2 : 3;
    }
  },
  gl: {
    name: "Galician",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  gu: {
    name: "Gujarati",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  gun: {
    name: "Gun",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n > 1)",
    pluralsFunc: function(n) {
      return n > 1;
    }
  },
  ha: {
    name: "Hausa",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  he: {
    name: "Hebrew",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  hi: {
    name: "Hindi",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  hne: {
    name: "Chhattisgarhi",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  hr: {
    name: "Croatian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }, {
      plural: 2,
      sample: 5
    }],
    nplurals: 3,
    pluralsText: "nplurals = 3; plural = (n % 10 === 1 && n % 100 !== 11 ? 0 : n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2)",
    pluralsFunc: function(n) {
      return n % 10 === 1 && n % 100 !== 11 ? 0 : n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2;
    }
  },
  hu: {
    name: "Hungarian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  hy: {
    name: "Armenian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  id: {
    name: "Indonesian",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  is: {
    name: "Icelandic",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n % 10 !== 1 || n % 100 === 11)",
    pluralsFunc: function(n) {
      return n % 10 !== 1 || n % 100 === 11;
    }
  },
  it: {
    name: "Italian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  ja: {
    name: "Japanese",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  jbo: {
    name: "Lojban",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  jv: {
    name: "Javanese",
    examples: [{
      plural: 0,
      sample: 0
    }, {
      plural: 1,
      sample: 1
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 0)",
    pluralsFunc: function(n) {
      return n !== 0;
    }
  },
  ka: {
    name: "Georgian",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  kk: {
    name: "Kazakh",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  km: {
    name: "Khmer",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  kn: {
    name: "Kannada",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  ko: {
    name: "Korean",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  ku: {
    name: "Kurdish",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  kw: {
    name: "Cornish",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }, {
      plural: 2,
      sample: 3
    }, {
      plural: 3,
      sample: 4
    }],
    nplurals: 4,
    pluralsText: "nplurals = 4; plural = (n === 1 ? 0 : n === 2 ? 1 : n === 3 ? 2 : 3)",
    pluralsFunc: function(n) {
      return n === 1 ? 0 : n === 2 ? 1 : n === 3 ? 2 : 3;
    }
  },
  ky: {
    name: "Kyrgyz",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  lb: {
    name: "Letzeburgesch",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  ln: {
    name: "Lingala",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n > 1)",
    pluralsFunc: function(n) {
      return n > 1;
    }
  },
  lo: {
    name: "Lao",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  lt: {
    name: "Lithuanian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }, {
      plural: 2,
      sample: 10
    }],
    nplurals: 3,
    pluralsText: "nplurals = 3; plural = (n % 10 === 1 && n % 100 !== 11 ? 0 : n % 10 >= 2 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2)",
    pluralsFunc: function(n) {
      return n % 10 === 1 && n % 100 !== 11 ? 0 : n % 10 >= 2 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2;
    }
  },
  lv: {
    name: "Latvian",
    examples: [{
      plural: 2,
      sample: 0
    }, {
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 3,
    pluralsText: "nplurals = 3; plural = (n % 10 === 1 && n % 100 !== 11 ? 0 : n !== 0 ? 1 : 2)",
    pluralsFunc: function(n) {
      return n % 10 === 1 && n % 100 !== 11 ? 0 : n !== 0 ? 1 : 2;
    }
  },
  mai: {
    name: "Maithili",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  mfe: {
    name: "Mauritian Creole",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n > 1)",
    pluralsFunc: function(n) {
      return n > 1;
    }
  },
  mg: {
    name: "Malagasy",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n > 1)",
    pluralsFunc: function(n) {
      return n > 1;
    }
  },
  mi: {
    name: "Maori",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n > 1)",
    pluralsFunc: function(n) {
      return n > 1;
    }
  },
  mk: {
    name: "Macedonian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n === 1 || n % 10 === 1 ? 0 : 1)",
    pluralsFunc: function(n) {
      return n === 1 || n % 10 === 1 ? 0 : 1;
    }
  },
  ml: {
    name: "Malayalam",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  mn: {
    name: "Mongolian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  mni: {
    name: "Manipuri",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  mnk: {
    name: "Mandinka",
    examples: [{
      plural: 0,
      sample: 0
    }, {
      plural: 1,
      sample: 1
    }, {
      plural: 2,
      sample: 2
    }],
    nplurals: 3,
    pluralsText: "nplurals = 3; plural = (n === 0 ? 0 : n === 1 ? 1 : 2)",
    pluralsFunc: function(n) {
      return n === 0 ? 0 : n === 1 ? 1 : 2;
    }
  },
  mr: {
    name: "Marathi",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  ms: {
    name: "Malay",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  mt: {
    name: "Maltese",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }, {
      plural: 2,
      sample: 11
    }, {
      plural: 3,
      sample: 20
    }],
    nplurals: 4,
    pluralsText: "nplurals = 4; plural = (n === 1 ? 0 : n === 0 || ( n % 100 > 1 && n % 100 < 11) ? 1 : (n % 100 > 10 && n % 100 < 20 ) ? 2 : 3)",
    pluralsFunc: function(n) {
      return n === 1 ? 0 : n === 0 || n % 100 > 1 && n % 100 < 11 ? 1 : n % 100 > 10 && n % 100 < 20 ? 2 : 3;
    }
  },
  my: {
    name: "Burmese",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  nah: {
    name: "Nahuatl",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  nap: {
    name: "Neapolitan",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  nb: {
    name: "Norwegian Bokmal",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  ne: {
    name: "Nepali",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  nl: {
    name: "Dutch",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  nn: {
    name: "Norwegian Nynorsk",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  no: {
    name: "Norwegian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  nso: {
    name: "Northern Sotho",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  oc: {
    name: "Occitan",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n > 1)",
    pluralsFunc: function(n) {
      return n > 1;
    }
  },
  or: {
    name: "Oriya",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  pa: {
    name: "Punjabi",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  pap: {
    name: "Papiamento",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  pl: {
    name: "Polish",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }, {
      plural: 2,
      sample: 5
    }],
    nplurals: 3,
    pluralsText: "nplurals = 3; plural = (n === 1 ? 0 : n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2)",
    pluralsFunc: function(n) {
      return n === 1 ? 0 : n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2;
    }
  },
  pms: {
    name: "Piemontese",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  ps: {
    name: "Pashto",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  pt: {
    name: "Portuguese",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  rm: {
    name: "Romansh",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  ro: {
    name: "Romanian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }, {
      plural: 2,
      sample: 20
    }],
    nplurals: 3,
    pluralsText: "nplurals = 3; plural = (n === 1 ? 0 : (n === 0 || (n % 100 > 0 && n % 100 < 20)) ? 1 : 2)",
    pluralsFunc: function(n) {
      return n === 1 ? 0 : n === 0 || n % 100 > 0 && n % 100 < 20 ? 1 : 2;
    }
  },
  ru: {
    name: "Russian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }, {
      plural: 2,
      sample: 5
    }],
    nplurals: 3,
    pluralsText: "nplurals = 3; plural = (n % 10 === 1 && n % 100 !== 11 ? 0 : n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2)",
    pluralsFunc: function(n) {
      return n % 10 === 1 && n % 100 !== 11 ? 0 : n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2;
    }
  },
  rw: {
    name: "Kinyarwanda",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  sah: {
    name: "Yakut",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  sat: {
    name: "Santali",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  sco: {
    name: "Scots",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  sd: {
    name: "Sindhi",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  se: {
    name: "Northern Sami",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  si: {
    name: "Sinhala",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  sk: {
    name: "Slovak",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }, {
      plural: 2,
      sample: 5
    }],
    nplurals: 3,
    pluralsText: "nplurals = 3; plural = (n === 1 ? 0 : (n >= 2 && n <= 4) ? 1 : 2)",
    pluralsFunc: function(n) {
      return n === 1 ? 0 : n >= 2 && n <= 4 ? 1 : 2;
    }
  },
  sl: {
    name: "Slovenian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }, {
      plural: 2,
      sample: 3
    }, {
      plural: 3,
      sample: 5
    }],
    nplurals: 4,
    pluralsText: "nplurals = 4; plural = (n % 100 === 1 ? 0 : n % 100 === 2 ? 1 : n % 100 === 3 || n % 100 === 4 ? 2 : 3)",
    pluralsFunc: function(n) {
      return n % 100 === 1 ? 0 : n % 100 === 2 ? 1 : n % 100 === 3 || n % 100 === 4 ? 2 : 3;
    }
  },
  so: {
    name: "Somali",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  son: {
    name: "Songhay",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  sq: {
    name: "Albanian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  sr: {
    name: "Serbian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }, {
      plural: 2,
      sample: 5
    }],
    nplurals: 3,
    pluralsText: "nplurals = 3; plural = (n % 10 === 1 && n % 100 !== 11 ? 0 : n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2)",
    pluralsFunc: function(n) {
      return n % 10 === 1 && n % 100 !== 11 ? 0 : n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2;
    }
  },
  su: {
    name: "Sundanese",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  sv: {
    name: "Swedish",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  sw: {
    name: "Swahili",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  ta: {
    name: "Tamil",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  te: {
    name: "Telugu",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  tg: {
    name: "Tajik",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n > 1)",
    pluralsFunc: function(n) {
      return n > 1;
    }
  },
  th: {
    name: "Thai",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  ti: {
    name: "Tigrinya",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n > 1)",
    pluralsFunc: function(n) {
      return n > 1;
    }
  },
  tk: {
    name: "Turkmen",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  tr: {
    name: "Turkish",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n > 1)",
    pluralsFunc: function(n) {
      return n > 1;
    }
  },
  tt: {
    name: "Tatar",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  ug: {
    name: "Uyghur",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  uk: {
    name: "Ukrainian",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }, {
      plural: 2,
      sample: 5
    }],
    nplurals: 3,
    pluralsText: "nplurals = 3; plural = (n % 10 === 1 && n % 100 !== 11 ? 0 : n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2)",
    pluralsFunc: function(n) {
      return n % 10 === 1 && n % 100 !== 11 ? 0 : n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2;
    }
  },
  ur: {
    name: "Urdu",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  uz: {
    name: "Uzbek",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n > 1)",
    pluralsFunc: function(n) {
      return n > 1;
    }
  },
  vi: {
    name: "Vietnamese",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  wa: {
    name: "Walloon",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n > 1)",
    pluralsFunc: function(n) {
      return n > 1;
    }
  },
  wo: {
    name: "Wolof",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  },
  yo: {
    name: "Yoruba",
    examples: [{
      plural: 0,
      sample: 1
    }, {
      plural: 1,
      sample: 2
    }],
    nplurals: 2,
    pluralsText: "nplurals = 2; plural = (n !== 1)",
    pluralsFunc: function(n) {
      return n !== 1;
    }
  },
  zh: {
    name: "Chinese",
    examples: [{
      plural: 0,
      sample: 1
    }],
    nplurals: 1,
    pluralsText: "nplurals = 1; plural = 0",
    pluralsFunc: function() {
      return 0;
    }
  }
};
var get = lodash_get;
var plurals = plurals$1;
var gettext = Gettext;
function Gettext(options) {
  options = options || {};
  this.catalogs = {};
  this.locale = "";
  this.domain = "messages";
  this.listeners = [];
  this.sourceLocale = "";
  if (options.sourceLocale) {
    if (typeof options.sourceLocale === "string") {
      this.sourceLocale = options.sourceLocale;
    } else {
      this.warn("The `sourceLocale` option should be a string");
    }
  }
  this.debug = "debug" in options && options.debug === true;
}
Gettext.prototype.on = function(eventName, callback) {
  this.listeners.push({
    eventName,
    callback
  });
};
Gettext.prototype.off = function(eventName, callback) {
  this.listeners = this.listeners.filter(function(listener) {
    return (listener.eventName === eventName && listener.callback === callback) === false;
  });
};
Gettext.prototype.emit = function(eventName, eventData) {
  for (var i = 0; i < this.listeners.length; i++) {
    var listener = this.listeners[i];
    if (listener.eventName === eventName) {
      listener.callback(eventData);
    }
  }
};
Gettext.prototype.warn = function(message) {
  if (this.debug) {
    console.warn(message);
  }
  this.emit("error", new Error(message));
};
Gettext.prototype.addTranslations = function(locale, domain, translations) {
  if (!this.catalogs[locale]) {
    this.catalogs[locale] = {};
  }
  this.catalogs[locale][domain] = translations;
};
Gettext.prototype.setLocale = function(locale) {
  if (typeof locale !== "string") {
    this.warn("You called setLocale() with an argument of type " + typeof locale + ". The locale must be a string.");
    return;
  }
  if (locale.trim() === "") {
    this.warn("You called setLocale() with an empty value, which makes little sense.");
  }
  if (locale !== this.sourceLocale && !this.catalogs[locale]) {
    this.warn('You called setLocale() with "' + locale + '", but no translations for that locale has been added.');
  }
  this.locale = locale;
};
Gettext.prototype.setTextDomain = function(domain) {
  if (typeof domain !== "string") {
    this.warn("You called setTextDomain() with an argument of type " + typeof domain + ". The domain must be a string.");
    return;
  }
  if (domain.trim() === "") {
    this.warn("You called setTextDomain() with an empty `domain` value.");
  }
  this.domain = domain;
};
Gettext.prototype.gettext = function(msgid) {
  return this.dnpgettext(this.domain, "", msgid);
};
Gettext.prototype.dgettext = function(domain, msgid) {
  return this.dnpgettext(domain, "", msgid);
};
Gettext.prototype.ngettext = function(msgid, msgidPlural, count) {
  return this.dnpgettext(this.domain, "", msgid, msgidPlural, count);
};
Gettext.prototype.dngettext = function(domain, msgid, msgidPlural, count) {
  return this.dnpgettext(domain, "", msgid, msgidPlural, count);
};
Gettext.prototype.pgettext = function(msgctxt, msgid) {
  return this.dnpgettext(this.domain, msgctxt, msgid);
};
Gettext.prototype.dpgettext = function(domain, msgctxt, msgid) {
  return this.dnpgettext(domain, msgctxt, msgid);
};
Gettext.prototype.npgettext = function(msgctxt, msgid, msgidPlural, count) {
  return this.dnpgettext(this.domain, msgctxt, msgid, msgidPlural, count);
};
Gettext.prototype.dnpgettext = function(domain, msgctxt, msgid, msgidPlural, count) {
  var defaultTranslation = msgid;
  var translation;
  var index;
  msgctxt = msgctxt || "";
  if (!isNaN(count) && count !== 1) {
    defaultTranslation = msgidPlural || msgid;
  }
  translation = this._getTranslation(domain, msgctxt, msgid);
  if (translation) {
    if (typeof count === "number") {
      var pluralsFunc = plurals[Gettext.getLanguageCode(this.locale)].pluralsFunc;
      index = pluralsFunc(count);
      if (typeof index === "boolean") {
        index = index ? 1 : 0;
      }
    } else {
      index = 0;
    }
    return translation.msgstr[index] || defaultTranslation;
  } else if (!this.sourceLocale || this.locale !== this.sourceLocale) {
    this.warn('No translation was found for msgid "' + msgid + '" in msgctxt "' + msgctxt + '" and domain "' + domain + '"');
  }
  return defaultTranslation;
};
Gettext.prototype.getComment = function(domain, msgctxt, msgid) {
  var translation;
  translation = this._getTranslation(domain, msgctxt, msgid);
  if (translation) {
    return translation.comments || {};
  }
  return {};
};
Gettext.prototype._getTranslation = function(domain, msgctxt, msgid) {
  msgctxt = msgctxt || "";
  return get(this.catalogs, [this.locale, domain, "translations", msgctxt, msgid]);
};
Gettext.getLanguageCode = function(locale) {
  return locale.split(/[\-_]/)[0].toLowerCase();
};
Gettext.prototype.textdomain = function(domain) {
  if (this.debug) {
    console.warn("textdomain(domain) was used to set locales in node-gettext v1. Make sure you are using it for domains, and switch to setLocale(locale) if you are not.\n\n To read more about the migration from node-gettext v1 to v2, see https://github.com/alexanderwallin/node-gettext/#migrating-from-1x-to-2x\n\nThis warning will be removed in the final 2.0.0");
  }
  this.setTextDomain(domain);
};
Gettext.prototype.setlocale = function(locale) {
  this.setLocale(locale);
};
Gettext.prototype.addTextdomain = function() {
  console.error("addTextdomain() is deprecated.\n\n* To add translations, use addTranslations()\n* To set the default domain, use setTextDomain() (or its alias textdomain())\n\nTo read more about the migration from node-gettext v1 to v2, see https://github.com/alexanderwallin/node-gettext/#migrating-from-1x-to-2x");
};
var dist = {};
Object.defineProperty(dist, "__esModule", {
  value: true
});
dist.getCanonicalLocale = getCanonicalLocale;
dist.getDayNames = getDayNames;
dist.getDayNamesMin = getDayNamesMin;
dist.getDayNamesShort = getDayNamesShort;
dist.getFirstDay = getFirstDay;
dist.getLanguage = getLanguage;
dist.getLocale = getLocale;
dist.getMonthNames = getMonthNames;
dist.getMonthNamesShort = getMonthNamesShort;
dist.translate = translate;
dist.translatePlural = translatePlural;
function getLocale() {
  return document.documentElement.dataset.locale || "en";
}
function getCanonicalLocale() {
  return getLocale().replace(/_/g, "-");
}
function getLanguage() {
  return document.documentElement.lang || "en";
}
function translate(app, text, vars, count, options) {
  if (typeof OC === "undefined") {
    console.warn("No OC found");
    return text;
  }
  return OC.L10N.translate(app, text, vars, count, options);
}
function translatePlural(app, textSingular, textPlural, count, vars, options) {
  if (typeof OC === "undefined") {
    console.warn("No OC found");
    return textSingular;
  }
  return OC.L10N.translatePlural(app, textSingular, textPlural, count, vars, options);
}
function getFirstDay() {
  if (typeof window.firstDay === "undefined") {
    console.warn("No firstDay found");
    return 1;
  }
  return window.firstDay;
}
function getDayNames() {
  if (typeof window.dayNames === "undefined") {
    console.warn("No dayNames found");
    return ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"];
  }
  return window.dayNames;
}
function getDayNamesShort() {
  if (typeof window.dayNamesShort === "undefined") {
    console.warn("No dayNamesShort found");
    return ["Sun.", "Mon.", "Tue.", "Wed.", "Thu.", "Fri.", "Sat."];
  }
  return window.dayNamesShort;
}
function getDayNamesMin() {
  if (typeof window.dayNamesMin === "undefined") {
    console.warn("No dayNamesMin found");
    return ["Su", "Mo", "Tu", "We", "Th", "Fr", "Sa"];
  }
  return window.dayNamesMin;
}
function getMonthNames() {
  if (typeof window.monthNames === "undefined") {
    console.warn("No monthNames found");
    return ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"];
  }
  return window.monthNames;
}
function getMonthNamesShort() {
  if (typeof window.monthNamesShort === "undefined") {
    console.warn("No monthNamesShort found");
    return ["Jan.", "Feb.", "Mar.", "Apr.", "May.", "Jun.", "Jul.", "Aug.", "Sep.", "Oct.", "Nov.", "Dec."];
  }
  return window.monthNamesShort;
}
Object.defineProperty(gettext$1, "__esModule", {
  value: true
});
gettext$1.getGettextBuilder = getGettextBuilder;
var _nodeGettext = _interopRequireDefault(gettext);
var _ = dist;
function _interopRequireDefault(obj) {
  return obj && obj.__esModule ? obj : { default: obj };
}
function _classCallCheck$1(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}
function _defineProperties$1(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor)
      descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}
function _createClass$1(Constructor, protoProps, staticProps) {
  if (protoProps)
    _defineProperties$1(Constructor.prototype, protoProps);
  if (staticProps)
    _defineProperties$1(Constructor, staticProps);
  Object.defineProperty(Constructor, "prototype", { writable: false });
  return Constructor;
}
var GettextBuilder = /* @__PURE__ */ function() {
  function GettextBuilder2() {
    _classCallCheck$1(this, GettextBuilder2);
    this.translations = {};
    this.debug = false;
  }
  _createClass$1(GettextBuilder2, [{
    key: "setLanguage",
    value: function setLanguage(language) {
      this.locale = language;
      return this;
    }
  }, {
    key: "detectLocale",
    value: function detectLocale() {
      return this.setLanguage((0, _.getLanguage)().replace("-", "_"));
    }
  }, {
    key: "addTranslation",
    value: function addTranslation(language, data3) {
      this.translations[language] = data3;
      return this;
    }
  }, {
    key: "enableDebugMode",
    value: function enableDebugMode() {
      this.debug = true;
      return this;
    }
  }, {
    key: "build",
    value: function build() {
      return new GettextWrapper(this.locale || "en", this.translations, this.debug);
    }
  }]);
  return GettextBuilder2;
}();
var GettextWrapper = /* @__PURE__ */ function() {
  function GettextWrapper2(locale, data3, debug) {
    _classCallCheck$1(this, GettextWrapper2);
    this.gt = new _nodeGettext.default({
      debug,
      sourceLocale: "en"
    });
    for (var key in data3) {
      this.gt.addTranslations(key, "messages", data3[key]);
    }
    this.gt.setLocale(locale);
  }
  _createClass$1(GettextWrapper2, [{
    key: "subtitudePlaceholders",
    value: function subtitudePlaceholders(translated, vars) {
      return translated.replace(/{([^{}]*)}/g, function(a, b) {
        var r = vars[b];
        if (typeof r === "string" || typeof r === "number") {
          return r.toString();
        } else {
          return a;
        }
      });
    }
  }, {
    key: "gettext",
    value: function gettext2(original) {
      var placeholders = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
      return this.subtitudePlaceholders(this.gt.gettext(original), placeholders);
    }
  }, {
    key: "ngettext",
    value: function ngettext(singular, plural, count) {
      var placeholders = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : {};
      return this.subtitudePlaceholders(this.gt.ngettext(singular, plural, count).replace(/%n/g, count.toString()), placeholders);
    }
  }]);
  return GettextWrapper2;
}();
function getGettextBuilder() {
  return new GettextBuilder();
}
function _typeof(obj) {
  "@babel/helpers - typeof";
  return _typeof = typeof Symbol == "function" && typeof Symbol.iterator == "symbol" ? function(obj2) {
    return typeof obj2;
  } : function(obj2) {
    return obj2 && typeof Symbol == "function" && obj2.constructor === Symbol && obj2 !== Symbol.prototype ? "symbol" : typeof obj2;
  }, _typeof(obj);
}
function _defineProperty$1(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }
  return obj;
}
function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}
function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor)
      descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}
function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps)
    _defineProperties(Constructor.prototype, protoProps);
  if (staticProps)
    _defineProperties(Constructor, staticProps);
  Object.defineProperty(Constructor, "prototype", {
    writable: false
  });
  return Constructor;
}
/**!
 * @fileOverview Kickass library to create and place poppers near their reference elements.
 * @version 1.16.1
 * @license
 * Copyright (c) 2016 Federico Zivolo and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
var isBrowser = typeof window !== "undefined" && typeof document !== "undefined" && typeof navigator !== "undefined";
var timeoutDuration = function() {
  var longerTimeoutBrowsers = ["Edge", "Trident", "Firefox"];
  for (var i = 0; i < longerTimeoutBrowsers.length; i += 1) {
    if (isBrowser && navigator.userAgent.indexOf(longerTimeoutBrowsers[i]) >= 0) {
      return 1;
    }
  }
  return 0;
}();
function microtaskDebounce(fn) {
  var called = false;
  return function() {
    if (called) {
      return;
    }
    called = true;
    window.Promise.resolve().then(function() {
      called = false;
      fn();
    });
  };
}
function taskDebounce(fn) {
  var scheduled = false;
  return function() {
    if (!scheduled) {
      scheduled = true;
      setTimeout(function() {
        scheduled = false;
        fn();
      }, timeoutDuration);
    }
  };
}
var supportsMicroTasks = isBrowser && window.Promise;
var debounce = supportsMicroTasks ? microtaskDebounce : taskDebounce;
function isFunction$4(functionToCheck) {
  var getType = {};
  return functionToCheck && getType.toString.call(functionToCheck) === "[object Function]";
}
function getStyleComputedProperty(element, property) {
  if (element.nodeType !== 1) {
    return [];
  }
  var window2 = element.ownerDocument.defaultView;
  var css = window2.getComputedStyle(element, null);
  return property ? css[property] : css;
}
function getParentNode(element) {
  if (element.nodeName === "HTML") {
    return element;
  }
  return element.parentNode || element.host;
}
function getScrollParent(element) {
  if (!element) {
    return document.body;
  }
  switch (element.nodeName) {
    case "HTML":
    case "BODY":
      return element.ownerDocument.body;
    case "#document":
      return element.body;
  }
  var _getStyleComputedProp = getStyleComputedProperty(element), overflow = _getStyleComputedProp.overflow, overflowX = _getStyleComputedProp.overflowX, overflowY = _getStyleComputedProp.overflowY;
  if (/(auto|scroll|overlay)/.test(overflow + overflowY + overflowX)) {
    return element;
  }
  return getScrollParent(getParentNode(element));
}
function getReferenceNode(reference) {
  return reference && reference.referenceNode ? reference.referenceNode : reference;
}
var isIE11 = isBrowser && !!(window.MSInputMethodContext && document.documentMode);
var isIE10 = isBrowser && /MSIE 10/.test(navigator.userAgent);
function isIE$1(version2) {
  if (version2 === 11) {
    return isIE11;
  }
  if (version2 === 10) {
    return isIE10;
  }
  return isIE11 || isIE10;
}
function getOffsetParent(element) {
  if (!element) {
    return document.documentElement;
  }
  var noOffsetParent = isIE$1(10) ? document.body : null;
  var offsetParent = element.offsetParent || null;
  while (offsetParent === noOffsetParent && element.nextElementSibling) {
    offsetParent = (element = element.nextElementSibling).offsetParent;
  }
  var nodeName = offsetParent && offsetParent.nodeName;
  if (!nodeName || nodeName === "BODY" || nodeName === "HTML") {
    return element ? element.ownerDocument.documentElement : document.documentElement;
  }
  if (["TH", "TD", "TABLE"].indexOf(offsetParent.nodeName) !== -1 && getStyleComputedProperty(offsetParent, "position") === "static") {
    return getOffsetParent(offsetParent);
  }
  return offsetParent;
}
function isOffsetContainer(element) {
  var nodeName = element.nodeName;
  if (nodeName === "BODY") {
    return false;
  }
  return nodeName === "HTML" || getOffsetParent(element.firstElementChild) === element;
}
function getRoot(node) {
  if (node.parentNode !== null) {
    return getRoot(node.parentNode);
  }
  return node;
}
function findCommonOffsetParent(element1, element2) {
  if (!element1 || !element1.nodeType || !element2 || !element2.nodeType) {
    return document.documentElement;
  }
  var order = element1.compareDocumentPosition(element2) & Node.DOCUMENT_POSITION_FOLLOWING;
  var start = order ? element1 : element2;
  var end = order ? element2 : element1;
  var range = document.createRange();
  range.setStart(start, 0);
  range.setEnd(end, 0);
  var commonAncestorContainer = range.commonAncestorContainer;
  if (element1 !== commonAncestorContainer && element2 !== commonAncestorContainer || start.contains(end)) {
    if (isOffsetContainer(commonAncestorContainer)) {
      return commonAncestorContainer;
    }
    return getOffsetParent(commonAncestorContainer);
  }
  var element1root = getRoot(element1);
  if (element1root.host) {
    return findCommonOffsetParent(element1root.host, element2);
  } else {
    return findCommonOffsetParent(element1, getRoot(element2).host);
  }
}
function getScroll(element) {
  var side = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "top";
  var upperSide = side === "top" ? "scrollTop" : "scrollLeft";
  var nodeName = element.nodeName;
  if (nodeName === "BODY" || nodeName === "HTML") {
    var html2 = element.ownerDocument.documentElement;
    var scrollingElement = element.ownerDocument.scrollingElement || html2;
    return scrollingElement[upperSide];
  }
  return element[upperSide];
}
function includeScroll(rect, element) {
  var subtract = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : false;
  var scrollTop = getScroll(element, "top");
  var scrollLeft = getScroll(element, "left");
  var modifier = subtract ? -1 : 1;
  rect.top += scrollTop * modifier;
  rect.bottom += scrollTop * modifier;
  rect.left += scrollLeft * modifier;
  rect.right += scrollLeft * modifier;
  return rect;
}
function getBordersSize(styles, axis) {
  var sideA = axis === "x" ? "Left" : "Top";
  var sideB = sideA === "Left" ? "Right" : "Bottom";
  return parseFloat(styles["border" + sideA + "Width"]) + parseFloat(styles["border" + sideB + "Width"]);
}
function getSize(axis, body, html2, computedStyle) {
  return Math.max(body["offset" + axis], body["scroll" + axis], html2["client" + axis], html2["offset" + axis], html2["scroll" + axis], isIE$1(10) ? parseInt(html2["offset" + axis]) + parseInt(computedStyle["margin" + (axis === "Height" ? "Top" : "Left")]) + parseInt(computedStyle["margin" + (axis === "Height" ? "Bottom" : "Right")]) : 0);
}
function getWindowSizes(document2) {
  var body = document2.body;
  var html2 = document2.documentElement;
  var computedStyle = isIE$1(10) && getComputedStyle(html2);
  return {
    height: getSize("Height", body, html2, computedStyle),
    width: getSize("Width", body, html2, computedStyle)
  };
}
var classCallCheck = function(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
};
var createClass = function() {
  function defineProperties2(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor)
        descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }
  return function(Constructor, protoProps, staticProps) {
    if (protoProps)
      defineProperties2(Constructor.prototype, protoProps);
    if (staticProps)
      defineProperties2(Constructor, staticProps);
    return Constructor;
  };
}();
var defineProperty$3 = function(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }
  return obj;
};
var _extends = Object.assign || function(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];
    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }
  return target;
};
function getClientRect(offsets) {
  return _extends({}, offsets, {
    right: offsets.left + offsets.width,
    bottom: offsets.top + offsets.height
  });
}
function getBoundingClientRect(element) {
  var rect = {};
  try {
    if (isIE$1(10)) {
      rect = element.getBoundingClientRect();
      var scrollTop = getScroll(element, "top");
      var scrollLeft = getScroll(element, "left");
      rect.top += scrollTop;
      rect.left += scrollLeft;
      rect.bottom += scrollTop;
      rect.right += scrollLeft;
    } else {
      rect = element.getBoundingClientRect();
    }
  } catch (e) {
  }
  var result = {
    left: rect.left,
    top: rect.top,
    width: rect.right - rect.left,
    height: rect.bottom - rect.top
  };
  var sizes = element.nodeName === "HTML" ? getWindowSizes(element.ownerDocument) : {};
  var width = sizes.width || element.clientWidth || result.width;
  var height = sizes.height || element.clientHeight || result.height;
  var horizScrollbar = element.offsetWidth - width;
  var vertScrollbar = element.offsetHeight - height;
  if (horizScrollbar || vertScrollbar) {
    var styles = getStyleComputedProperty(element);
    horizScrollbar -= getBordersSize(styles, "x");
    vertScrollbar -= getBordersSize(styles, "y");
    result.width -= horizScrollbar;
    result.height -= vertScrollbar;
  }
  return getClientRect(result);
}
function getOffsetRectRelativeToArbitraryNode(children, parent) {
  var fixedPosition = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : false;
  var isIE102 = isIE$1(10);
  var isHTML = parent.nodeName === "HTML";
  var childrenRect = getBoundingClientRect(children);
  var parentRect = getBoundingClientRect(parent);
  var scrollParent = getScrollParent(children);
  var styles = getStyleComputedProperty(parent);
  var borderTopWidth = parseFloat(styles.borderTopWidth);
  var borderLeftWidth = parseFloat(styles.borderLeftWidth);
  if (fixedPosition && isHTML) {
    parentRect.top = Math.max(parentRect.top, 0);
    parentRect.left = Math.max(parentRect.left, 0);
  }
  var offsets = getClientRect({
    top: childrenRect.top - parentRect.top - borderTopWidth,
    left: childrenRect.left - parentRect.left - borderLeftWidth,
    width: childrenRect.width,
    height: childrenRect.height
  });
  offsets.marginTop = 0;
  offsets.marginLeft = 0;
  if (!isIE102 && isHTML) {
    var marginTop = parseFloat(styles.marginTop);
    var marginLeft = parseFloat(styles.marginLeft);
    offsets.top -= borderTopWidth - marginTop;
    offsets.bottom -= borderTopWidth - marginTop;
    offsets.left -= borderLeftWidth - marginLeft;
    offsets.right -= borderLeftWidth - marginLeft;
    offsets.marginTop = marginTop;
    offsets.marginLeft = marginLeft;
  }
  if (isIE102 && !fixedPosition ? parent.contains(scrollParent) : parent === scrollParent && scrollParent.nodeName !== "BODY") {
    offsets = includeScroll(offsets, parent);
  }
  return offsets;
}
function getViewportOffsetRectRelativeToArtbitraryNode(element) {
  var excludeScroll = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
  var html2 = element.ownerDocument.documentElement;
  var relativeOffset = getOffsetRectRelativeToArbitraryNode(element, html2);
  var width = Math.max(html2.clientWidth, window.innerWidth || 0);
  var height = Math.max(html2.clientHeight, window.innerHeight || 0);
  var scrollTop = !excludeScroll ? getScroll(html2) : 0;
  var scrollLeft = !excludeScroll ? getScroll(html2, "left") : 0;
  var offset2 = {
    top: scrollTop - relativeOffset.top + relativeOffset.marginTop,
    left: scrollLeft - relativeOffset.left + relativeOffset.marginLeft,
    width,
    height
  };
  return getClientRect(offset2);
}
function isFixed(element) {
  var nodeName = element.nodeName;
  if (nodeName === "BODY" || nodeName === "HTML") {
    return false;
  }
  if (getStyleComputedProperty(element, "position") === "fixed") {
    return true;
  }
  var parentNode = getParentNode(element);
  if (!parentNode) {
    return false;
  }
  return isFixed(parentNode);
}
function getFixedPositionOffsetParent(element) {
  if (!element || !element.parentElement || isIE$1()) {
    return document.documentElement;
  }
  var el = element.parentElement;
  while (el && getStyleComputedProperty(el, "transform") === "none") {
    el = el.parentElement;
  }
  return el || document.documentElement;
}
function getBoundaries(popper, reference, padding, boundariesElement) {
  var fixedPosition = arguments.length > 4 && arguments[4] !== void 0 ? arguments[4] : false;
  var boundaries = { top: 0, left: 0 };
  var offsetParent = fixedPosition ? getFixedPositionOffsetParent(popper) : findCommonOffsetParent(popper, getReferenceNode(reference));
  if (boundariesElement === "viewport") {
    boundaries = getViewportOffsetRectRelativeToArtbitraryNode(offsetParent, fixedPosition);
  } else {
    var boundariesNode = void 0;
    if (boundariesElement === "scrollParent") {
      boundariesNode = getScrollParent(getParentNode(reference));
      if (boundariesNode.nodeName === "BODY") {
        boundariesNode = popper.ownerDocument.documentElement;
      }
    } else if (boundariesElement === "window") {
      boundariesNode = popper.ownerDocument.documentElement;
    } else {
      boundariesNode = boundariesElement;
    }
    var offsets = getOffsetRectRelativeToArbitraryNode(boundariesNode, offsetParent, fixedPosition);
    if (boundariesNode.nodeName === "HTML" && !isFixed(offsetParent)) {
      var _getWindowSizes = getWindowSizes(popper.ownerDocument), height = _getWindowSizes.height, width = _getWindowSizes.width;
      boundaries.top += offsets.top - offsets.marginTop;
      boundaries.bottom = height + offsets.top;
      boundaries.left += offsets.left - offsets.marginLeft;
      boundaries.right = width + offsets.left;
    } else {
      boundaries = offsets;
    }
  }
  padding = padding || 0;
  var isPaddingNumber = typeof padding === "number";
  boundaries.left += isPaddingNumber ? padding : padding.left || 0;
  boundaries.top += isPaddingNumber ? padding : padding.top || 0;
  boundaries.right -= isPaddingNumber ? padding : padding.right || 0;
  boundaries.bottom -= isPaddingNumber ? padding : padding.bottom || 0;
  return boundaries;
}
function getArea(_ref) {
  var width = _ref.width, height = _ref.height;
  return width * height;
}
function computeAutoPlacement(placement2, refRect, popper, reference, boundariesElement) {
  var padding = arguments.length > 5 && arguments[5] !== void 0 ? arguments[5] : 0;
  if (placement2.indexOf("auto") === -1) {
    return placement2;
  }
  var boundaries = getBoundaries(popper, reference, padding, boundariesElement);
  var rects = {
    top: {
      width: boundaries.width,
      height: refRect.top - boundaries.top
    },
    right: {
      width: boundaries.right - refRect.right,
      height: boundaries.height
    },
    bottom: {
      width: boundaries.width,
      height: boundaries.bottom - refRect.bottom
    },
    left: {
      width: refRect.left - boundaries.left,
      height: boundaries.height
    }
  };
  var sortedAreas = Object.keys(rects).map(function(key) {
    return _extends({
      key
    }, rects[key], {
      area: getArea(rects[key])
    });
  }).sort(function(a, b) {
    return b.area - a.area;
  });
  var filteredAreas = sortedAreas.filter(function(_ref2) {
    var width = _ref2.width, height = _ref2.height;
    return width >= popper.clientWidth && height >= popper.clientHeight;
  });
  var computedPlacement = filteredAreas.length > 0 ? filteredAreas[0].key : sortedAreas[0].key;
  var variation = placement2.split("-")[1];
  return computedPlacement + (variation ? "-" + variation : "");
}
function getReferenceOffsets(state2, popper, reference) {
  var fixedPosition = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : null;
  var commonOffsetParent = fixedPosition ? getFixedPositionOffsetParent(popper) : findCommonOffsetParent(popper, getReferenceNode(reference));
  return getOffsetRectRelativeToArbitraryNode(reference, commonOffsetParent, fixedPosition);
}
function getOuterSizes(element) {
  var window2 = element.ownerDocument.defaultView;
  var styles = window2.getComputedStyle(element);
  var x = parseFloat(styles.marginTop || 0) + parseFloat(styles.marginBottom || 0);
  var y = parseFloat(styles.marginLeft || 0) + parseFloat(styles.marginRight || 0);
  var result = {
    width: element.offsetWidth + y,
    height: element.offsetHeight + x
  };
  return result;
}
function getOppositePlacement(placement2) {
  var hash = { left: "right", right: "left", bottom: "top", top: "bottom" };
  return placement2.replace(/left|right|bottom|top/g, function(matched) {
    return hash[matched];
  });
}
function getPopperOffsets(popper, referenceOffsets, placement2) {
  placement2 = placement2.split("-")[0];
  var popperRect = getOuterSizes(popper);
  var popperOffsets = {
    width: popperRect.width,
    height: popperRect.height
  };
  var isHoriz = ["right", "left"].indexOf(placement2) !== -1;
  var mainSide = isHoriz ? "top" : "left";
  var secondarySide = isHoriz ? "left" : "top";
  var measurement = isHoriz ? "height" : "width";
  var secondaryMeasurement = !isHoriz ? "height" : "width";
  popperOffsets[mainSide] = referenceOffsets[mainSide] + referenceOffsets[measurement] / 2 - popperRect[measurement] / 2;
  if (placement2 === secondarySide) {
    popperOffsets[secondarySide] = referenceOffsets[secondarySide] - popperRect[secondaryMeasurement];
  } else {
    popperOffsets[secondarySide] = referenceOffsets[getOppositePlacement(secondarySide)];
  }
  return popperOffsets;
}
function find(arr, check2) {
  if (Array.prototype.find) {
    return arr.find(check2);
  }
  return arr.filter(check2)[0];
}
function findIndex(arr, prop, value) {
  if (Array.prototype.findIndex) {
    return arr.findIndex(function(cur) {
      return cur[prop] === value;
    });
  }
  var match2 = find(arr, function(obj) {
    return obj[prop] === value;
  });
  return arr.indexOf(match2);
}
function runModifiers(modifiers2, data3, ends) {
  var modifiersToRun = ends === void 0 ? modifiers2 : modifiers2.slice(0, findIndex(modifiers2, "name", ends));
  modifiersToRun.forEach(function(modifier) {
    if (modifier["function"]) {
      console.warn("`modifier.function` is deprecated, use `modifier.fn`!");
    }
    var fn = modifier["function"] || modifier.fn;
    if (modifier.enabled && isFunction$4(fn)) {
      data3.offsets.popper = getClientRect(data3.offsets.popper);
      data3.offsets.reference = getClientRect(data3.offsets.reference);
      data3 = fn(data3, modifier);
    }
  });
  return data3;
}
function update() {
  if (this.state.isDestroyed) {
    return;
  }
  var data3 = {
    instance: this,
    styles: {},
    arrowStyles: {},
    attributes: {},
    flipped: false,
    offsets: {}
  };
  data3.offsets.reference = getReferenceOffsets(this.state, this.popper, this.reference, this.options.positionFixed);
  data3.placement = computeAutoPlacement(this.options.placement, data3.offsets.reference, this.popper, this.reference, this.options.modifiers.flip.boundariesElement, this.options.modifiers.flip.padding);
  data3.originalPlacement = data3.placement;
  data3.positionFixed = this.options.positionFixed;
  data3.offsets.popper = getPopperOffsets(this.popper, data3.offsets.reference, data3.placement);
  data3.offsets.popper.position = this.options.positionFixed ? "fixed" : "absolute";
  data3 = runModifiers(this.modifiers, data3);
  if (!this.state.isCreated) {
    this.state.isCreated = true;
    this.options.onCreate(data3);
  } else {
    this.options.onUpdate(data3);
  }
}
function isModifierEnabled(modifiers2, modifierName) {
  return modifiers2.some(function(_ref) {
    var name = _ref.name, enabled = _ref.enabled;
    return enabled && name === modifierName;
  });
}
function getSupportedPropertyName(property) {
  var prefixes = [false, "ms", "Webkit", "Moz", "O"];
  var upperProp = property.charAt(0).toUpperCase() + property.slice(1);
  for (var i = 0; i < prefixes.length; i++) {
    var prefix = prefixes[i];
    var toCheck = prefix ? "" + prefix + upperProp : property;
    if (typeof document.body.style[toCheck] !== "undefined") {
      return toCheck;
    }
  }
  return null;
}
function destroy() {
  this.state.isDestroyed = true;
  if (isModifierEnabled(this.modifiers, "applyStyle")) {
    this.popper.removeAttribute("x-placement");
    this.popper.style.position = "";
    this.popper.style.top = "";
    this.popper.style.left = "";
    this.popper.style.right = "";
    this.popper.style.bottom = "";
    this.popper.style.willChange = "";
    this.popper.style[getSupportedPropertyName("transform")] = "";
  }
  this.disableEventListeners();
  if (this.options.removeOnDestroy) {
    this.popper.parentNode.removeChild(this.popper);
  }
  return this;
}
function getWindow(element) {
  var ownerDocument = element.ownerDocument;
  return ownerDocument ? ownerDocument.defaultView : window;
}
function attachToScrollParents(scrollParent, event, callback, scrollParents) {
  var isBody = scrollParent.nodeName === "BODY";
  var target = isBody ? scrollParent.ownerDocument.defaultView : scrollParent;
  target.addEventListener(event, callback, { passive: true });
  if (!isBody) {
    attachToScrollParents(getScrollParent(target.parentNode), event, callback, scrollParents);
  }
  scrollParents.push(target);
}
function setupEventListeners(reference, options, state2, updateBound) {
  state2.updateBound = updateBound;
  getWindow(reference).addEventListener("resize", state2.updateBound, { passive: true });
  var scrollElement = getScrollParent(reference);
  attachToScrollParents(scrollElement, "scroll", state2.updateBound, state2.scrollParents);
  state2.scrollElement = scrollElement;
  state2.eventsEnabled = true;
  return state2;
}
function enableEventListeners() {
  if (!this.state.eventsEnabled) {
    this.state = setupEventListeners(this.reference, this.options, this.state, this.scheduleUpdate);
  }
}
function removeEventListeners(reference, state2) {
  getWindow(reference).removeEventListener("resize", state2.updateBound);
  state2.scrollParents.forEach(function(target) {
    target.removeEventListener("scroll", state2.updateBound);
  });
  state2.updateBound = null;
  state2.scrollParents = [];
  state2.scrollElement = null;
  state2.eventsEnabled = false;
  return state2;
}
function disableEventListeners() {
  if (this.state.eventsEnabled) {
    cancelAnimationFrame(this.scheduleUpdate);
    this.state = removeEventListeners(this.reference, this.state);
  }
}
function isNumeric(n) {
  return n !== "" && !isNaN(parseFloat(n)) && isFinite(n);
}
function setStyles(element, styles) {
  Object.keys(styles).forEach(function(prop) {
    var unit = "";
    if (["width", "height", "top", "right", "bottom", "left"].indexOf(prop) !== -1 && isNumeric(styles[prop])) {
      unit = "px";
    }
    element.style[prop] = styles[prop] + unit;
  });
}
function setAttributes(element, attributes) {
  Object.keys(attributes).forEach(function(prop) {
    var value = attributes[prop];
    if (value !== false) {
      element.setAttribute(prop, attributes[prop]);
    } else {
      element.removeAttribute(prop);
    }
  });
}
function applyStyle(data3) {
  setStyles(data3.instance.popper, data3.styles);
  setAttributes(data3.instance.popper, data3.attributes);
  if (data3.arrowElement && Object.keys(data3.arrowStyles).length) {
    setStyles(data3.arrowElement, data3.arrowStyles);
  }
  return data3;
}
function applyStyleOnLoad(reference, popper, options, modifierOptions, state2) {
  var referenceOffsets = getReferenceOffsets(state2, popper, reference, options.positionFixed);
  var placement2 = computeAutoPlacement(options.placement, referenceOffsets, popper, reference, options.modifiers.flip.boundariesElement, options.modifiers.flip.padding);
  popper.setAttribute("x-placement", placement2);
  setStyles(popper, { position: options.positionFixed ? "fixed" : "absolute" });
  return options;
}
function getRoundedOffsets(data3, shouldRound) {
  var _data$offsets = data3.offsets, popper = _data$offsets.popper, reference = _data$offsets.reference;
  var round = Math.round, floor2 = Math.floor;
  var noRound = function noRound2(v) {
    return v;
  };
  var referenceWidth = round(reference.width);
  var popperWidth = round(popper.width);
  var isVertical = ["left", "right"].indexOf(data3.placement) !== -1;
  var isVariation = data3.placement.indexOf("-") !== -1;
  var sameWidthParity = referenceWidth % 2 === popperWidth % 2;
  var bothOddWidth = referenceWidth % 2 === 1 && popperWidth % 2 === 1;
  var horizontalToInteger = !shouldRound ? noRound : isVertical || isVariation || sameWidthParity ? round : floor2;
  var verticalToInteger = !shouldRound ? noRound : round;
  return {
    left: horizontalToInteger(bothOddWidth && !isVariation && shouldRound ? popper.left - 1 : popper.left),
    top: verticalToInteger(popper.top),
    bottom: verticalToInteger(popper.bottom),
    right: horizontalToInteger(popper.right)
  };
}
var isFirefox = isBrowser && /Firefox/i.test(navigator.userAgent);
function computeStyle(data3, options) {
  var x = options.x, y = options.y;
  var popper = data3.offsets.popper;
  var legacyGpuAccelerationOption = find(data3.instance.modifiers, function(modifier) {
    return modifier.name === "applyStyle";
  }).gpuAcceleration;
  if (legacyGpuAccelerationOption !== void 0) {
    console.warn("WARNING: `gpuAcceleration` option moved to `computeStyle` modifier and will not be supported in future versions of Popper.js!");
  }
  var gpuAcceleration = legacyGpuAccelerationOption !== void 0 ? legacyGpuAccelerationOption : options.gpuAcceleration;
  var offsetParent = getOffsetParent(data3.instance.popper);
  var offsetParentRect = getBoundingClientRect(offsetParent);
  var styles = {
    position: popper.position
  };
  var offsets = getRoundedOffsets(data3, window.devicePixelRatio < 2 || !isFirefox);
  var sideA = x === "bottom" ? "top" : "bottom";
  var sideB = y === "right" ? "left" : "right";
  var prefixedProperty = getSupportedPropertyName("transform");
  var left = void 0, top = void 0;
  if (sideA === "bottom") {
    if (offsetParent.nodeName === "HTML") {
      top = -offsetParent.clientHeight + offsets.bottom;
    } else {
      top = -offsetParentRect.height + offsets.bottom;
    }
  } else {
    top = offsets.top;
  }
  if (sideB === "right") {
    if (offsetParent.nodeName === "HTML") {
      left = -offsetParent.clientWidth + offsets.right;
    } else {
      left = -offsetParentRect.width + offsets.right;
    }
  } else {
    left = offsets.left;
  }
  if (gpuAcceleration && prefixedProperty) {
    styles[prefixedProperty] = "translate3d(" + left + "px, " + top + "px, 0)";
    styles[sideA] = 0;
    styles[sideB] = 0;
    styles.willChange = "transform";
  } else {
    var invertTop = sideA === "bottom" ? -1 : 1;
    var invertLeft = sideB === "right" ? -1 : 1;
    styles[sideA] = top * invertTop;
    styles[sideB] = left * invertLeft;
    styles.willChange = sideA + ", " + sideB;
  }
  var attributes = {
    "x-placement": data3.placement
  };
  data3.attributes = _extends({}, attributes, data3.attributes);
  data3.styles = _extends({}, styles, data3.styles);
  data3.arrowStyles = _extends({}, data3.offsets.arrow, data3.arrowStyles);
  return data3;
}
function isModifierRequired(modifiers2, requestingName, requestedName) {
  var requesting = find(modifiers2, function(_ref) {
    var name = _ref.name;
    return name === requestingName;
  });
  var isRequired = !!requesting && modifiers2.some(function(modifier) {
    return modifier.name === requestedName && modifier.enabled && modifier.order < requesting.order;
  });
  if (!isRequired) {
    var _requesting = "`" + requestingName + "`";
    var requested = "`" + requestedName + "`";
    console.warn(requested + " modifier is required by " + _requesting + " modifier in order to work, be sure to include it before " + _requesting + "!");
  }
  return isRequired;
}
function arrow(data3, options) {
  var _data$offsets$arrow;
  if (!isModifierRequired(data3.instance.modifiers, "arrow", "keepTogether")) {
    return data3;
  }
  var arrowElement = options.element;
  if (typeof arrowElement === "string") {
    arrowElement = data3.instance.popper.querySelector(arrowElement);
    if (!arrowElement) {
      return data3;
    }
  } else {
    if (!data3.instance.popper.contains(arrowElement)) {
      console.warn("WARNING: `arrow.element` must be child of its popper element!");
      return data3;
    }
  }
  var placement2 = data3.placement.split("-")[0];
  var _data$offsets = data3.offsets, popper = _data$offsets.popper, reference = _data$offsets.reference;
  var isVertical = ["left", "right"].indexOf(placement2) !== -1;
  var len = isVertical ? "height" : "width";
  var sideCapitalized = isVertical ? "Top" : "Left";
  var side = sideCapitalized.toLowerCase();
  var altSide = isVertical ? "left" : "top";
  var opSide = isVertical ? "bottom" : "right";
  var arrowElementSize = getOuterSizes(arrowElement)[len];
  if (reference[opSide] - arrowElementSize < popper[side]) {
    data3.offsets.popper[side] -= popper[side] - (reference[opSide] - arrowElementSize);
  }
  if (reference[side] + arrowElementSize > popper[opSide]) {
    data3.offsets.popper[side] += reference[side] + arrowElementSize - popper[opSide];
  }
  data3.offsets.popper = getClientRect(data3.offsets.popper);
  var center = reference[side] + reference[len] / 2 - arrowElementSize / 2;
  var css = getStyleComputedProperty(data3.instance.popper);
  var popperMarginSide = parseFloat(css["margin" + sideCapitalized]);
  var popperBorderSide = parseFloat(css["border" + sideCapitalized + "Width"]);
  var sideValue = center - data3.offsets.popper[side] - popperMarginSide - popperBorderSide;
  sideValue = Math.max(Math.min(popper[len] - arrowElementSize, sideValue), 0);
  data3.arrowElement = arrowElement;
  data3.offsets.arrow = (_data$offsets$arrow = {}, defineProperty$3(_data$offsets$arrow, side, Math.round(sideValue)), defineProperty$3(_data$offsets$arrow, altSide, ""), _data$offsets$arrow);
  return data3;
}
function getOppositeVariation(variation) {
  if (variation === "end") {
    return "start";
  } else if (variation === "start") {
    return "end";
  }
  return variation;
}
var placements = ["auto-start", "auto", "auto-end", "top-start", "top", "top-end", "right-start", "right", "right-end", "bottom-end", "bottom", "bottom-start", "left-end", "left", "left-start"];
var validPlacements = placements.slice(3);
function clockwise(placement2) {
  var counter = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
  var index = validPlacements.indexOf(placement2);
  var arr = validPlacements.slice(index + 1).concat(validPlacements.slice(0, index));
  return counter ? arr.reverse() : arr;
}
var BEHAVIORS = {
  FLIP: "flip",
  CLOCKWISE: "clockwise",
  COUNTERCLOCKWISE: "counterclockwise"
};
function flip(data3, options) {
  if (isModifierEnabled(data3.instance.modifiers, "inner")) {
    return data3;
  }
  if (data3.flipped && data3.placement === data3.originalPlacement) {
    return data3;
  }
  var boundaries = getBoundaries(data3.instance.popper, data3.instance.reference, options.padding, options.boundariesElement, data3.positionFixed);
  var placement2 = data3.placement.split("-")[0];
  var placementOpposite = getOppositePlacement(placement2);
  var variation = data3.placement.split("-")[1] || "";
  var flipOrder = [];
  switch (options.behavior) {
    case BEHAVIORS.FLIP:
      flipOrder = [placement2, placementOpposite];
      break;
    case BEHAVIORS.CLOCKWISE:
      flipOrder = clockwise(placement2);
      break;
    case BEHAVIORS.COUNTERCLOCKWISE:
      flipOrder = clockwise(placement2, true);
      break;
    default:
      flipOrder = options.behavior;
  }
  flipOrder.forEach(function(step, index) {
    if (placement2 !== step || flipOrder.length === index + 1) {
      return data3;
    }
    placement2 = data3.placement.split("-")[0];
    placementOpposite = getOppositePlacement(placement2);
    var popperOffsets = data3.offsets.popper;
    var refOffsets = data3.offsets.reference;
    var floor2 = Math.floor;
    var overlapsRef = placement2 === "left" && floor2(popperOffsets.right) > floor2(refOffsets.left) || placement2 === "right" && floor2(popperOffsets.left) < floor2(refOffsets.right) || placement2 === "top" && floor2(popperOffsets.bottom) > floor2(refOffsets.top) || placement2 === "bottom" && floor2(popperOffsets.top) < floor2(refOffsets.bottom);
    var overflowsLeft = floor2(popperOffsets.left) < floor2(boundaries.left);
    var overflowsRight = floor2(popperOffsets.right) > floor2(boundaries.right);
    var overflowsTop = floor2(popperOffsets.top) < floor2(boundaries.top);
    var overflowsBottom = floor2(popperOffsets.bottom) > floor2(boundaries.bottom);
    var overflowsBoundaries = placement2 === "left" && overflowsLeft || placement2 === "right" && overflowsRight || placement2 === "top" && overflowsTop || placement2 === "bottom" && overflowsBottom;
    var isVertical = ["top", "bottom"].indexOf(placement2) !== -1;
    var flippedVariationByRef = !!options.flipVariations && (isVertical && variation === "start" && overflowsLeft || isVertical && variation === "end" && overflowsRight || !isVertical && variation === "start" && overflowsTop || !isVertical && variation === "end" && overflowsBottom);
    var flippedVariationByContent = !!options.flipVariationsByContent && (isVertical && variation === "start" && overflowsRight || isVertical && variation === "end" && overflowsLeft || !isVertical && variation === "start" && overflowsBottom || !isVertical && variation === "end" && overflowsTop);
    var flippedVariation = flippedVariationByRef || flippedVariationByContent;
    if (overlapsRef || overflowsBoundaries || flippedVariation) {
      data3.flipped = true;
      if (overlapsRef || overflowsBoundaries) {
        placement2 = flipOrder[index + 1];
      }
      if (flippedVariation) {
        variation = getOppositeVariation(variation);
      }
      data3.placement = placement2 + (variation ? "-" + variation : "");
      data3.offsets.popper = _extends({}, data3.offsets.popper, getPopperOffsets(data3.instance.popper, data3.offsets.reference, data3.placement));
      data3 = runModifiers(data3.instance.modifiers, data3, "flip");
    }
  });
  return data3;
}
function keepTogether(data3) {
  var _data$offsets = data3.offsets, popper = _data$offsets.popper, reference = _data$offsets.reference;
  var placement2 = data3.placement.split("-")[0];
  var floor2 = Math.floor;
  var isVertical = ["top", "bottom"].indexOf(placement2) !== -1;
  var side = isVertical ? "right" : "bottom";
  var opSide = isVertical ? "left" : "top";
  var measurement = isVertical ? "width" : "height";
  if (popper[side] < floor2(reference[opSide])) {
    data3.offsets.popper[opSide] = floor2(reference[opSide]) - popper[measurement];
  }
  if (popper[opSide] > floor2(reference[side])) {
    data3.offsets.popper[opSide] = floor2(reference[side]);
  }
  return data3;
}
function toValue(str, measurement, popperOffsets, referenceOffsets) {
  var split2 = str.match(/((?:\-|\+)?\d*\.?\d*)(.*)/);
  var value = +split2[1];
  var unit = split2[2];
  if (!value) {
    return str;
  }
  if (unit.indexOf("%") === 0) {
    var element = void 0;
    switch (unit) {
      case "%p":
        element = popperOffsets;
        break;
      case "%":
      case "%r":
      default:
        element = referenceOffsets;
    }
    var rect = getClientRect(element);
    return rect[measurement] / 100 * value;
  } else if (unit === "vh" || unit === "vw") {
    var size = void 0;
    if (unit === "vh") {
      size = Math.max(document.documentElement.clientHeight, window.innerHeight || 0);
    } else {
      size = Math.max(document.documentElement.clientWidth, window.innerWidth || 0);
    }
    return size / 100 * value;
  } else {
    return value;
  }
}
function parseOffset(offset2, popperOffsets, referenceOffsets, basePlacement) {
  var offsets = [0, 0];
  var useHeight = ["right", "left"].indexOf(basePlacement) !== -1;
  var fragments = offset2.split(/(\+|\-)/).map(function(frag) {
    return frag.trim();
  });
  var divider = fragments.indexOf(find(fragments, function(frag) {
    return frag.search(/,|\s/) !== -1;
  }));
  if (fragments[divider] && fragments[divider].indexOf(",") === -1) {
    console.warn("Offsets separated by white space(s) are deprecated, use a comma (,) instead.");
  }
  var splitRegex = /\s*,\s*|\s+/;
  var ops = divider !== -1 ? [fragments.slice(0, divider).concat([fragments[divider].split(splitRegex)[0]]), [fragments[divider].split(splitRegex)[1]].concat(fragments.slice(divider + 1))] : [fragments];
  ops = ops.map(function(op, index) {
    var measurement = (index === 1 ? !useHeight : useHeight) ? "height" : "width";
    var mergeWithPrevious = false;
    return op.reduce(function(a, b) {
      if (a[a.length - 1] === "" && ["+", "-"].indexOf(b) !== -1) {
        a[a.length - 1] = b;
        mergeWithPrevious = true;
        return a;
      } else if (mergeWithPrevious) {
        a[a.length - 1] += b;
        mergeWithPrevious = false;
        return a;
      } else {
        return a.concat(b);
      }
    }, []).map(function(str) {
      return toValue(str, measurement, popperOffsets, referenceOffsets);
    });
  });
  ops.forEach(function(op, index) {
    op.forEach(function(frag, index2) {
      if (isNumeric(frag)) {
        offsets[index] += frag * (op[index2 - 1] === "-" ? -1 : 1);
      }
    });
  });
  return offsets;
}
function offset(data3, _ref) {
  var offset2 = _ref.offset;
  var placement2 = data3.placement, _data$offsets = data3.offsets, popper = _data$offsets.popper, reference = _data$offsets.reference;
  var basePlacement = placement2.split("-")[0];
  var offsets = void 0;
  if (isNumeric(+offset2)) {
    offsets = [+offset2, 0];
  } else {
    offsets = parseOffset(offset2, popper, reference, basePlacement);
  }
  if (basePlacement === "left") {
    popper.top += offsets[0];
    popper.left -= offsets[1];
  } else if (basePlacement === "right") {
    popper.top += offsets[0];
    popper.left += offsets[1];
  } else if (basePlacement === "top") {
    popper.left += offsets[0];
    popper.top -= offsets[1];
  } else if (basePlacement === "bottom") {
    popper.left += offsets[0];
    popper.top += offsets[1];
  }
  data3.popper = popper;
  return data3;
}
function preventOverflow(data3, options) {
  var boundariesElement = options.boundariesElement || getOffsetParent(data3.instance.popper);
  if (data3.instance.reference === boundariesElement) {
    boundariesElement = getOffsetParent(boundariesElement);
  }
  var transformProp = getSupportedPropertyName("transform");
  var popperStyles = data3.instance.popper.style;
  var top = popperStyles.top, left = popperStyles.left, transform = popperStyles[transformProp];
  popperStyles.top = "";
  popperStyles.left = "";
  popperStyles[transformProp] = "";
  var boundaries = getBoundaries(data3.instance.popper, data3.instance.reference, options.padding, boundariesElement, data3.positionFixed);
  popperStyles.top = top;
  popperStyles.left = left;
  popperStyles[transformProp] = transform;
  options.boundaries = boundaries;
  var order = options.priority;
  var popper = data3.offsets.popper;
  var check2 = {
    primary: function primary(placement2) {
      var value = popper[placement2];
      if (popper[placement2] < boundaries[placement2] && !options.escapeWithReference) {
        value = Math.max(popper[placement2], boundaries[placement2]);
      }
      return defineProperty$3({}, placement2, value);
    },
    secondary: function secondary(placement2) {
      var mainSide = placement2 === "right" ? "left" : "top";
      var value = popper[mainSide];
      if (popper[placement2] > boundaries[placement2] && !options.escapeWithReference) {
        value = Math.min(popper[mainSide], boundaries[placement2] - (placement2 === "right" ? popper.width : popper.height));
      }
      return defineProperty$3({}, mainSide, value);
    }
  };
  order.forEach(function(placement2) {
    var side = ["left", "top"].indexOf(placement2) !== -1 ? "primary" : "secondary";
    popper = _extends({}, popper, check2[side](placement2));
  });
  data3.offsets.popper = popper;
  return data3;
}
function shift(data3) {
  var placement2 = data3.placement;
  var basePlacement = placement2.split("-")[0];
  var shiftvariation = placement2.split("-")[1];
  if (shiftvariation) {
    var _data$offsets = data3.offsets, reference = _data$offsets.reference, popper = _data$offsets.popper;
    var isVertical = ["bottom", "top"].indexOf(basePlacement) !== -1;
    var side = isVertical ? "left" : "top";
    var measurement = isVertical ? "width" : "height";
    var shiftOffsets = {
      start: defineProperty$3({}, side, reference[side]),
      end: defineProperty$3({}, side, reference[side] + reference[measurement] - popper[measurement])
    };
    data3.offsets.popper = _extends({}, popper, shiftOffsets[shiftvariation]);
  }
  return data3;
}
function hide(data3) {
  if (!isModifierRequired(data3.instance.modifiers, "hide", "preventOverflow")) {
    return data3;
  }
  var refRect = data3.offsets.reference;
  var bound = find(data3.instance.modifiers, function(modifier) {
    return modifier.name === "preventOverflow";
  }).boundaries;
  if (refRect.bottom < bound.top || refRect.left > bound.right || refRect.top > bound.bottom || refRect.right < bound.left) {
    if (data3.hide === true) {
      return data3;
    }
    data3.hide = true;
    data3.attributes["x-out-of-boundaries"] = "";
  } else {
    if (data3.hide === false) {
      return data3;
    }
    data3.hide = false;
    data3.attributes["x-out-of-boundaries"] = false;
  }
  return data3;
}
function inner(data3) {
  var placement2 = data3.placement;
  var basePlacement = placement2.split("-")[0];
  var _data$offsets = data3.offsets, popper = _data$offsets.popper, reference = _data$offsets.reference;
  var isHoriz = ["left", "right"].indexOf(basePlacement) !== -1;
  var subtractLength = ["top", "left"].indexOf(basePlacement) === -1;
  popper[isHoriz ? "left" : "top"] = reference[basePlacement] - (subtractLength ? popper[isHoriz ? "width" : "height"] : 0);
  data3.placement = getOppositePlacement(placement2);
  data3.offsets.popper = getClientRect(popper);
  return data3;
}
var modifiers = {
  shift: {
    order: 100,
    enabled: true,
    fn: shift
  },
  offset: {
    order: 200,
    enabled: true,
    fn: offset,
    offset: 0
  },
  preventOverflow: {
    order: 300,
    enabled: true,
    fn: preventOverflow,
    priority: ["left", "right", "top", "bottom"],
    padding: 5,
    boundariesElement: "scrollParent"
  },
  keepTogether: {
    order: 400,
    enabled: true,
    fn: keepTogether
  },
  arrow: {
    order: 500,
    enabled: true,
    fn: arrow,
    element: "[x-arrow]"
  },
  flip: {
    order: 600,
    enabled: true,
    fn: flip,
    behavior: "flip",
    padding: 5,
    boundariesElement: "viewport",
    flipVariations: false,
    flipVariationsByContent: false
  },
  inner: {
    order: 700,
    enabled: false,
    fn: inner
  },
  hide: {
    order: 800,
    enabled: true,
    fn: hide
  },
  computeStyle: {
    order: 850,
    enabled: true,
    fn: computeStyle,
    gpuAcceleration: true,
    x: "bottom",
    y: "right"
  },
  applyStyle: {
    order: 900,
    enabled: true,
    fn: applyStyle,
    onLoad: applyStyleOnLoad,
    gpuAcceleration: void 0
  }
};
var Defaults = {
  placement: "bottom",
  positionFixed: false,
  eventsEnabled: true,
  removeOnDestroy: false,
  onCreate: function onCreate() {
  },
  onUpdate: function onUpdate() {
  },
  modifiers
};
var Popper = function() {
  function Popper2(reference, popper) {
    var _this = this;
    var options = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
    classCallCheck(this, Popper2);
    this.scheduleUpdate = function() {
      return requestAnimationFrame(_this.update);
    };
    this.update = debounce(this.update.bind(this));
    this.options = _extends({}, Popper2.Defaults, options);
    this.state = {
      isDestroyed: false,
      isCreated: false,
      scrollParents: []
    };
    this.reference = reference && reference.jquery ? reference[0] : reference;
    this.popper = popper && popper.jquery ? popper[0] : popper;
    this.options.modifiers = {};
    Object.keys(_extends({}, Popper2.Defaults.modifiers, options.modifiers)).forEach(function(name) {
      _this.options.modifiers[name] = _extends({}, Popper2.Defaults.modifiers[name] || {}, options.modifiers ? options.modifiers[name] : {});
    });
    this.modifiers = Object.keys(this.options.modifiers).map(function(name) {
      return _extends({
        name
      }, _this.options.modifiers[name]);
    }).sort(function(a, b) {
      return a.order - b.order;
    });
    this.modifiers.forEach(function(modifierOptions) {
      if (modifierOptions.enabled && isFunction$4(modifierOptions.onLoad)) {
        modifierOptions.onLoad(_this.reference, _this.popper, _this.options, modifierOptions, _this.state);
      }
    });
    this.update();
    var eventsEnabled = this.options.eventsEnabled;
    if (eventsEnabled) {
      this.enableEventListeners();
    }
    this.state.eventsEnabled = eventsEnabled;
  }
  createClass(Popper2, [{
    key: "update",
    value: function update$$1() {
      return update.call(this);
    }
  }, {
    key: "destroy",
    value: function destroy$$1() {
      return destroy.call(this);
    }
  }, {
    key: "enableEventListeners",
    value: function enableEventListeners$$1() {
      return enableEventListeners.call(this);
    }
  }, {
    key: "disableEventListeners",
    value: function disableEventListeners$$1() {
      return disableEventListeners.call(this);
    }
  }]);
  return Popper2;
}();
Popper.Utils = (typeof window !== "undefined" ? window : global).PopperUtils;
Popper.placements = placements;
Popper.Defaults = Defaults;
var Popper$1 = Popper;
function listCacheClear$1() {
  this.__data__ = [];
  this.size = 0;
}
var _listCacheClear = listCacheClear$1;
function eq$5(value, other) {
  return value === other || value !== value && other !== other;
}
var eq_1 = eq$5;
var eq$4 = eq_1;
function assocIndexOf$4(array, key) {
  var length = array.length;
  while (length--) {
    if (eq$4(array[length][0], key)) {
      return length;
    }
  }
  return -1;
}
var _assocIndexOf = assocIndexOf$4;
var assocIndexOf$3 = _assocIndexOf;
var arrayProto = Array.prototype;
var splice = arrayProto.splice;
function listCacheDelete$1(key) {
  var data3 = this.__data__, index = assocIndexOf$3(data3, key);
  if (index < 0) {
    return false;
  }
  var lastIndex = data3.length - 1;
  if (index == lastIndex) {
    data3.pop();
  } else {
    splice.call(data3, index, 1);
  }
  --this.size;
  return true;
}
var _listCacheDelete = listCacheDelete$1;
var assocIndexOf$2 = _assocIndexOf;
function listCacheGet$1(key) {
  var data3 = this.__data__, index = assocIndexOf$2(data3, key);
  return index < 0 ? void 0 : data3[index][1];
}
var _listCacheGet = listCacheGet$1;
var assocIndexOf$1 = _assocIndexOf;
function listCacheHas$1(key) {
  return assocIndexOf$1(this.__data__, key) > -1;
}
var _listCacheHas = listCacheHas$1;
var assocIndexOf = _assocIndexOf;
function listCacheSet$1(key, value) {
  var data3 = this.__data__, index = assocIndexOf(data3, key);
  if (index < 0) {
    ++this.size;
    data3.push([key, value]);
  } else {
    data3[index][1] = value;
  }
  return this;
}
var _listCacheSet = listCacheSet$1;
var listCacheClear = _listCacheClear, listCacheDelete = _listCacheDelete, listCacheGet = _listCacheGet, listCacheHas = _listCacheHas, listCacheSet = _listCacheSet;
function ListCache$4(entries) {
  var index = -1, length = entries == null ? 0 : entries.length;
  this.clear();
  while (++index < length) {
    var entry = entries[index];
    this.set(entry[0], entry[1]);
  }
}
ListCache$4.prototype.clear = listCacheClear;
ListCache$4.prototype["delete"] = listCacheDelete;
ListCache$4.prototype.get = listCacheGet;
ListCache$4.prototype.has = listCacheHas;
ListCache$4.prototype.set = listCacheSet;
var _ListCache = ListCache$4;
var ListCache$3 = _ListCache;
function stackClear$1() {
  this.__data__ = new ListCache$3();
  this.size = 0;
}
var _stackClear = stackClear$1;
function stackDelete$1(key) {
  var data3 = this.__data__, result = data3["delete"](key);
  this.size = data3.size;
  return result;
}
var _stackDelete = stackDelete$1;
function stackGet$1(key) {
  return this.__data__.get(key);
}
var _stackGet = stackGet$1;
function stackHas$1(key) {
  return this.__data__.has(key);
}
var _stackHas = stackHas$1;
var freeGlobal$1 = typeof commonjsGlobal == "object" && commonjsGlobal && commonjsGlobal.Object === Object && commonjsGlobal;
var _freeGlobal = freeGlobal$1;
var freeGlobal = _freeGlobal;
var freeSelf = typeof self == "object" && self && self.Object === Object && self;
var root$8 = freeGlobal || freeSelf || Function("return this")();
var _root = root$8;
var root$7 = _root;
var Symbol$4 = root$7.Symbol;
var _Symbol = Symbol$4;
var Symbol$3 = _Symbol;
var objectProto$e = Object.prototype;
var hasOwnProperty$b = objectProto$e.hasOwnProperty;
var nativeObjectToString$1 = objectProto$e.toString;
var symToStringTag$1 = Symbol$3 ? Symbol$3.toStringTag : void 0;
function getRawTag$1(value) {
  var isOwn = hasOwnProperty$b.call(value, symToStringTag$1), tag = value[symToStringTag$1];
  try {
    value[symToStringTag$1] = void 0;
    var unmasked = true;
  } catch (e) {
  }
  var result = nativeObjectToString$1.call(value);
  if (unmasked) {
    if (isOwn) {
      value[symToStringTag$1] = tag;
    } else {
      delete value[symToStringTag$1];
    }
  }
  return result;
}
var _getRawTag = getRawTag$1;
var objectProto$d = Object.prototype;
var nativeObjectToString = objectProto$d.toString;
function objectToString$1(value) {
  return nativeObjectToString.call(value);
}
var _objectToString = objectToString$1;
var Symbol$2 = _Symbol, getRawTag = _getRawTag, objectToString = _objectToString;
var nullTag = "[object Null]", undefinedTag = "[object Undefined]";
var symToStringTag = Symbol$2 ? Symbol$2.toStringTag : void 0;
function baseGetTag$5(value) {
  if (value == null) {
    return value === void 0 ? undefinedTag : nullTag;
  }
  return symToStringTag && symToStringTag in Object(value) ? getRawTag(value) : objectToString(value);
}
var _baseGetTag = baseGetTag$5;
function isObject$7(value) {
  var type = typeof value;
  return value != null && (type == "object" || type == "function");
}
var isObject_1 = isObject$7;
var baseGetTag$4 = _baseGetTag, isObject$6 = isObject_1;
var asyncTag = "[object AsyncFunction]", funcTag$1 = "[object Function]", genTag = "[object GeneratorFunction]", proxyTag = "[object Proxy]";
function isFunction$3(value) {
  if (!isObject$6(value)) {
    return false;
  }
  var tag = baseGetTag$4(value);
  return tag == funcTag$1 || tag == genTag || tag == asyncTag || tag == proxyTag;
}
var isFunction_1 = isFunction$3;
var root$6 = _root;
var coreJsData$1 = root$6["__core-js_shared__"];
var _coreJsData = coreJsData$1;
var coreJsData = _coreJsData;
var maskSrcKey = function() {
  var uid2 = /[^.]+$/.exec(coreJsData && coreJsData.keys && coreJsData.keys.IE_PROTO || "");
  return uid2 ? "Symbol(src)_1." + uid2 : "";
}();
function isMasked$1(func) {
  return !!maskSrcKey && maskSrcKey in func;
}
var _isMasked = isMasked$1;
var funcProto$2 = Function.prototype;
var funcToString$2 = funcProto$2.toString;
function toSource$2(func) {
  if (func != null) {
    try {
      return funcToString$2.call(func);
    } catch (e) {
    }
    try {
      return func + "";
    } catch (e) {
    }
  }
  return "";
}
var _toSource = toSource$2;
var isFunction$2 = isFunction_1, isMasked = _isMasked, isObject$5 = isObject_1, toSource$1 = _toSource;
var reRegExpChar = /[\\^$.*+?()[\]{}|]/g;
var reIsHostCtor = /^\[object .+?Constructor\]$/;
var funcProto$1 = Function.prototype, objectProto$c = Object.prototype;
var funcToString$1 = funcProto$1.toString;
var hasOwnProperty$a = objectProto$c.hasOwnProperty;
var reIsNative = RegExp("^" + funcToString$1.call(hasOwnProperty$a).replace(reRegExpChar, "\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, "$1.*?") + "$");
function baseIsNative$1(value) {
  if (!isObject$5(value) || isMasked(value)) {
    return false;
  }
  var pattern = isFunction$2(value) ? reIsNative : reIsHostCtor;
  return pattern.test(toSource$1(value));
}
var _baseIsNative = baseIsNative$1;
function getValue$1(object, key) {
  return object == null ? void 0 : object[key];
}
var _getValue = getValue$1;
var baseIsNative = _baseIsNative, getValue = _getValue;
function getNative$7(object, key) {
  var value = getValue(object, key);
  return baseIsNative(value) ? value : void 0;
}
var _getNative = getNative$7;
var getNative$6 = _getNative, root$5 = _root;
var Map$3 = getNative$6(root$5, "Map");
var _Map = Map$3;
var getNative$5 = _getNative;
var nativeCreate$4 = getNative$5(Object, "create");
var _nativeCreate = nativeCreate$4;
var nativeCreate$3 = _nativeCreate;
function hashClear$1() {
  this.__data__ = nativeCreate$3 ? nativeCreate$3(null) : {};
  this.size = 0;
}
var _hashClear = hashClear$1;
function hashDelete$1(key) {
  var result = this.has(key) && delete this.__data__[key];
  this.size -= result ? 1 : 0;
  return result;
}
var _hashDelete = hashDelete$1;
var nativeCreate$2 = _nativeCreate;
var HASH_UNDEFINED$2 = "__lodash_hash_undefined__";
var objectProto$b = Object.prototype;
var hasOwnProperty$9 = objectProto$b.hasOwnProperty;
function hashGet$1(key) {
  var data3 = this.__data__;
  if (nativeCreate$2) {
    var result = data3[key];
    return result === HASH_UNDEFINED$2 ? void 0 : result;
  }
  return hasOwnProperty$9.call(data3, key) ? data3[key] : void 0;
}
var _hashGet = hashGet$1;
var nativeCreate$1 = _nativeCreate;
var objectProto$a = Object.prototype;
var hasOwnProperty$8 = objectProto$a.hasOwnProperty;
function hashHas$1(key) {
  var data3 = this.__data__;
  return nativeCreate$1 ? data3[key] !== void 0 : hasOwnProperty$8.call(data3, key);
}
var _hashHas = hashHas$1;
var nativeCreate = _nativeCreate;
var HASH_UNDEFINED$1 = "__lodash_hash_undefined__";
function hashSet$1(key, value) {
  var data3 = this.__data__;
  this.size += this.has(key) ? 0 : 1;
  data3[key] = nativeCreate && value === void 0 ? HASH_UNDEFINED$1 : value;
  return this;
}
var _hashSet = hashSet$1;
var hashClear = _hashClear, hashDelete = _hashDelete, hashGet = _hashGet, hashHas = _hashHas, hashSet = _hashSet;
function Hash$1(entries) {
  var index = -1, length = entries == null ? 0 : entries.length;
  this.clear();
  while (++index < length) {
    var entry = entries[index];
    this.set(entry[0], entry[1]);
  }
}
Hash$1.prototype.clear = hashClear;
Hash$1.prototype["delete"] = hashDelete;
Hash$1.prototype.get = hashGet;
Hash$1.prototype.has = hashHas;
Hash$1.prototype.set = hashSet;
var _Hash = Hash$1;
var Hash = _Hash, ListCache$2 = _ListCache, Map$2 = _Map;
function mapCacheClear$1() {
  this.size = 0;
  this.__data__ = {
    "hash": new Hash(),
    "map": new (Map$2 || ListCache$2)(),
    "string": new Hash()
  };
}
var _mapCacheClear = mapCacheClear$1;
function isKeyable$1(value) {
  var type = typeof value;
  return type == "string" || type == "number" || type == "symbol" || type == "boolean" ? value !== "__proto__" : value === null;
}
var _isKeyable = isKeyable$1;
var isKeyable = _isKeyable;
function getMapData$4(map, key) {
  var data3 = map.__data__;
  return isKeyable(key) ? data3[typeof key == "string" ? "string" : "hash"] : data3.map;
}
var _getMapData = getMapData$4;
var getMapData$3 = _getMapData;
function mapCacheDelete$1(key) {
  var result = getMapData$3(this, key)["delete"](key);
  this.size -= result ? 1 : 0;
  return result;
}
var _mapCacheDelete = mapCacheDelete$1;
var getMapData$2 = _getMapData;
function mapCacheGet$1(key) {
  return getMapData$2(this, key).get(key);
}
var _mapCacheGet = mapCacheGet$1;
var getMapData$1 = _getMapData;
function mapCacheHas$1(key) {
  return getMapData$1(this, key).has(key);
}
var _mapCacheHas = mapCacheHas$1;
var getMapData = _getMapData;
function mapCacheSet$1(key, value) {
  var data3 = getMapData(this, key), size = data3.size;
  data3.set(key, value);
  this.size += data3.size == size ? 0 : 1;
  return this;
}
var _mapCacheSet = mapCacheSet$1;
var mapCacheClear = _mapCacheClear, mapCacheDelete = _mapCacheDelete, mapCacheGet = _mapCacheGet, mapCacheHas = _mapCacheHas, mapCacheSet = _mapCacheSet;
function MapCache$2(entries) {
  var index = -1, length = entries == null ? 0 : entries.length;
  this.clear();
  while (++index < length) {
    var entry = entries[index];
    this.set(entry[0], entry[1]);
  }
}
MapCache$2.prototype.clear = mapCacheClear;
MapCache$2.prototype["delete"] = mapCacheDelete;
MapCache$2.prototype.get = mapCacheGet;
MapCache$2.prototype.has = mapCacheHas;
MapCache$2.prototype.set = mapCacheSet;
var _MapCache = MapCache$2;
var ListCache$1 = _ListCache, Map$1 = _Map, MapCache$1 = _MapCache;
var LARGE_ARRAY_SIZE = 200;
function stackSet$1(key, value) {
  var data3 = this.__data__;
  if (data3 instanceof ListCache$1) {
    var pairs = data3.__data__;
    if (!Map$1 || pairs.length < LARGE_ARRAY_SIZE - 1) {
      pairs.push([key, value]);
      this.size = ++data3.size;
      return this;
    }
    data3 = this.__data__ = new MapCache$1(pairs);
  }
  data3.set(key, value);
  this.size = data3.size;
  return this;
}
var _stackSet = stackSet$1;
var ListCache = _ListCache, stackClear = _stackClear, stackDelete = _stackDelete, stackGet = _stackGet, stackHas = _stackHas, stackSet = _stackSet;
function Stack$2(entries) {
  var data3 = this.__data__ = new ListCache(entries);
  this.size = data3.size;
}
Stack$2.prototype.clear = stackClear;
Stack$2.prototype["delete"] = stackDelete;
Stack$2.prototype.get = stackGet;
Stack$2.prototype.has = stackHas;
Stack$2.prototype.set = stackSet;
var _Stack = Stack$2;
var HASH_UNDEFINED = "__lodash_hash_undefined__";
function setCacheAdd$1(value) {
  this.__data__.set(value, HASH_UNDEFINED);
  return this;
}
var _setCacheAdd = setCacheAdd$1;
function setCacheHas$1(value) {
  return this.__data__.has(value);
}
var _setCacheHas = setCacheHas$1;
var MapCache = _MapCache, setCacheAdd = _setCacheAdd, setCacheHas = _setCacheHas;
function SetCache$1(values) {
  var index = -1, length = values == null ? 0 : values.length;
  this.__data__ = new MapCache();
  while (++index < length) {
    this.add(values[index]);
  }
}
SetCache$1.prototype.add = SetCache$1.prototype.push = setCacheAdd;
SetCache$1.prototype.has = setCacheHas;
var _SetCache = SetCache$1;
function arraySome$1(array, predicate) {
  var index = -1, length = array == null ? 0 : array.length;
  while (++index < length) {
    if (predicate(array[index], index, array)) {
      return true;
    }
  }
  return false;
}
var _arraySome = arraySome$1;
function cacheHas$1(cache, key) {
  return cache.has(key);
}
var _cacheHas = cacheHas$1;
var SetCache = _SetCache, arraySome = _arraySome, cacheHas = _cacheHas;
var COMPARE_PARTIAL_FLAG$3 = 1, COMPARE_UNORDERED_FLAG$1 = 2;
function equalArrays$2(array, other, bitmask, customizer, equalFunc, stack) {
  var isPartial = bitmask & COMPARE_PARTIAL_FLAG$3, arrLength = array.length, othLength = other.length;
  if (arrLength != othLength && !(isPartial && othLength > arrLength)) {
    return false;
  }
  var arrStacked = stack.get(array);
  var othStacked = stack.get(other);
  if (arrStacked && othStacked) {
    return arrStacked == other && othStacked == array;
  }
  var index = -1, result = true, seen = bitmask & COMPARE_UNORDERED_FLAG$1 ? new SetCache() : void 0;
  stack.set(array, other);
  stack.set(other, array);
  while (++index < arrLength) {
    var arrValue = array[index], othValue = other[index];
    if (customizer) {
      var compared = isPartial ? customizer(othValue, arrValue, index, other, array, stack) : customizer(arrValue, othValue, index, array, other, stack);
    }
    if (compared !== void 0) {
      if (compared) {
        continue;
      }
      result = false;
      break;
    }
    if (seen) {
      if (!arraySome(other, function(othValue2, othIndex) {
        if (!cacheHas(seen, othIndex) && (arrValue === othValue2 || equalFunc(arrValue, othValue2, bitmask, customizer, stack))) {
          return seen.push(othIndex);
        }
      })) {
        result = false;
        break;
      }
    } else if (!(arrValue === othValue || equalFunc(arrValue, othValue, bitmask, customizer, stack))) {
      result = false;
      break;
    }
  }
  stack["delete"](array);
  stack["delete"](other);
  return result;
}
var _equalArrays = equalArrays$2;
var root$4 = _root;
var Uint8Array$2 = root$4.Uint8Array;
var _Uint8Array = Uint8Array$2;
function mapToArray$1(map) {
  var index = -1, result = Array(map.size);
  map.forEach(function(value, key) {
    result[++index] = [key, value];
  });
  return result;
}
var _mapToArray = mapToArray$1;
function setToArray$1(set2) {
  var index = -1, result = Array(set2.size);
  set2.forEach(function(value) {
    result[++index] = value;
  });
  return result;
}
var _setToArray = setToArray$1;
var Symbol$1 = _Symbol, Uint8Array$1 = _Uint8Array, eq$3 = eq_1, equalArrays$1 = _equalArrays, mapToArray = _mapToArray, setToArray = _setToArray;
var COMPARE_PARTIAL_FLAG$2 = 1, COMPARE_UNORDERED_FLAG = 2;
var boolTag$1 = "[object Boolean]", dateTag$1 = "[object Date]", errorTag$1 = "[object Error]", mapTag$2 = "[object Map]", numberTag$1 = "[object Number]", regexpTag$1 = "[object RegExp]", setTag$2 = "[object Set]", stringTag$1 = "[object String]", symbolTag = "[object Symbol]";
var arrayBufferTag$1 = "[object ArrayBuffer]", dataViewTag$2 = "[object DataView]";
var symbolProto = Symbol$1 ? Symbol$1.prototype : void 0, symbolValueOf = symbolProto ? symbolProto.valueOf : void 0;
function equalByTag$1(object, other, tag, bitmask, customizer, equalFunc, stack) {
  switch (tag) {
    case dataViewTag$2:
      if (object.byteLength != other.byteLength || object.byteOffset != other.byteOffset) {
        return false;
      }
      object = object.buffer;
      other = other.buffer;
    case arrayBufferTag$1:
      if (object.byteLength != other.byteLength || !equalFunc(new Uint8Array$1(object), new Uint8Array$1(other))) {
        return false;
      }
      return true;
    case boolTag$1:
    case dateTag$1:
    case numberTag$1:
      return eq$3(+object, +other);
    case errorTag$1:
      return object.name == other.name && object.message == other.message;
    case regexpTag$1:
    case stringTag$1:
      return object == other + "";
    case mapTag$2:
      var convert = mapToArray;
    case setTag$2:
      var isPartial = bitmask & COMPARE_PARTIAL_FLAG$2;
      convert || (convert = setToArray);
      if (object.size != other.size && !isPartial) {
        return false;
      }
      var stacked = stack.get(object);
      if (stacked) {
        return stacked == other;
      }
      bitmask |= COMPARE_UNORDERED_FLAG;
      stack.set(object, other);
      var result = equalArrays$1(convert(object), convert(other), bitmask, customizer, equalFunc, stack);
      stack["delete"](object);
      return result;
    case symbolTag:
      if (symbolValueOf) {
        return symbolValueOf.call(object) == symbolValueOf.call(other);
      }
  }
  return false;
}
var _equalByTag = equalByTag$1;
function arrayPush$1(array, values) {
  var index = -1, length = values.length, offset2 = array.length;
  while (++index < length) {
    array[offset2 + index] = values[index];
  }
  return array;
}
var _arrayPush = arrayPush$1;
var isArray$4 = Array.isArray;
var isArray_1 = isArray$4;
var arrayPush = _arrayPush, isArray$3 = isArray_1;
function baseGetAllKeys$1(object, keysFunc, symbolsFunc) {
  var result = keysFunc(object);
  return isArray$3(object) ? result : arrayPush(result, symbolsFunc(object));
}
var _baseGetAllKeys = baseGetAllKeys$1;
function arrayFilter$1(array, predicate) {
  var index = -1, length = array == null ? 0 : array.length, resIndex = 0, result = [];
  while (++index < length) {
    var value = array[index];
    if (predicate(value, index, array)) {
      result[resIndex++] = value;
    }
  }
  return result;
}
var _arrayFilter = arrayFilter$1;
function stubArray$1() {
  return [];
}
var stubArray_1 = stubArray$1;
var arrayFilter = _arrayFilter, stubArray = stubArray_1;
var objectProto$9 = Object.prototype;
var propertyIsEnumerable$1 = objectProto$9.propertyIsEnumerable;
var nativeGetSymbols = Object.getOwnPropertySymbols;
var getSymbols$1 = !nativeGetSymbols ? stubArray : function(object) {
  if (object == null) {
    return [];
  }
  object = Object(object);
  return arrayFilter(nativeGetSymbols(object), function(symbol) {
    return propertyIsEnumerable$1.call(object, symbol);
  });
};
var _getSymbols = getSymbols$1;
function baseTimes$1(n, iteratee) {
  var index = -1, result = Array(n);
  while (++index < n) {
    result[index] = iteratee(index);
  }
  return result;
}
var _baseTimes = baseTimes$1;
function isObjectLike$6(value) {
  return value != null && typeof value == "object";
}
var isObjectLike_1 = isObjectLike$6;
var baseGetTag$3 = _baseGetTag, isObjectLike$5 = isObjectLike_1;
var argsTag$2 = "[object Arguments]";
function baseIsArguments$1(value) {
  return isObjectLike$5(value) && baseGetTag$3(value) == argsTag$2;
}
var _baseIsArguments = baseIsArguments$1;
var baseIsArguments = _baseIsArguments, isObjectLike$4 = isObjectLike_1;
var objectProto$8 = Object.prototype;
var hasOwnProperty$7 = objectProto$8.hasOwnProperty;
var propertyIsEnumerable2 = objectProto$8.propertyIsEnumerable;
var isArguments$2 = baseIsArguments(function() {
  return arguments;
}()) ? baseIsArguments : function(value) {
  return isObjectLike$4(value) && hasOwnProperty$7.call(value, "callee") && !propertyIsEnumerable2.call(value, "callee");
};
var isArguments_1 = isArguments$2;
var isBuffer$3 = { exports: {} };
function stubFalse() {
  return false;
}
var stubFalse_1 = stubFalse;
(function(module, exports) {
  var root2 = _root, stubFalse2 = stubFalse_1;
  var freeExports = exports && !exports.nodeType && exports;
  var freeModule = freeExports && true && module && !module.nodeType && module;
  var moduleExports = freeModule && freeModule.exports === freeExports;
  var Buffer2 = moduleExports ? root2.Buffer : void 0;
  var nativeIsBuffer = Buffer2 ? Buffer2.isBuffer : void 0;
  var isBuffer2 = nativeIsBuffer || stubFalse2;
  module.exports = isBuffer2;
})(isBuffer$3, isBuffer$3.exports);
var MAX_SAFE_INTEGER$1 = 9007199254740991;
var reIsUint = /^(?:0|[1-9]\d*)$/;
function isIndex$2(value, length) {
  var type = typeof value;
  length = length == null ? MAX_SAFE_INTEGER$1 : length;
  return !!length && (type == "number" || type != "symbol" && reIsUint.test(value)) && (value > -1 && value % 1 == 0 && value < length);
}
var _isIndex = isIndex$2;
var MAX_SAFE_INTEGER = 9007199254740991;
function isLength$2(value) {
  return typeof value == "number" && value > -1 && value % 1 == 0 && value <= MAX_SAFE_INTEGER;
}
var isLength_1 = isLength$2;
var baseGetTag$2 = _baseGetTag, isLength$1 = isLength_1, isObjectLike$3 = isObjectLike_1;
var argsTag$1 = "[object Arguments]", arrayTag$1 = "[object Array]", boolTag = "[object Boolean]", dateTag = "[object Date]", errorTag = "[object Error]", funcTag = "[object Function]", mapTag$1 = "[object Map]", numberTag = "[object Number]", objectTag$3 = "[object Object]", regexpTag = "[object RegExp]", setTag$1 = "[object Set]", stringTag = "[object String]", weakMapTag$1 = "[object WeakMap]";
var arrayBufferTag = "[object ArrayBuffer]", dataViewTag$1 = "[object DataView]", float32Tag = "[object Float32Array]", float64Tag = "[object Float64Array]", int8Tag = "[object Int8Array]", int16Tag = "[object Int16Array]", int32Tag = "[object Int32Array]", uint8Tag = "[object Uint8Array]", uint8ClampedTag = "[object Uint8ClampedArray]", uint16Tag = "[object Uint16Array]", uint32Tag = "[object Uint32Array]";
var typedArrayTags = {};
typedArrayTags[float32Tag] = typedArrayTags[float64Tag] = typedArrayTags[int8Tag] = typedArrayTags[int16Tag] = typedArrayTags[int32Tag] = typedArrayTags[uint8Tag] = typedArrayTags[uint8ClampedTag] = typedArrayTags[uint16Tag] = typedArrayTags[uint32Tag] = true;
typedArrayTags[argsTag$1] = typedArrayTags[arrayTag$1] = typedArrayTags[arrayBufferTag] = typedArrayTags[boolTag] = typedArrayTags[dataViewTag$1] = typedArrayTags[dateTag] = typedArrayTags[errorTag] = typedArrayTags[funcTag] = typedArrayTags[mapTag$1] = typedArrayTags[numberTag] = typedArrayTags[objectTag$3] = typedArrayTags[regexpTag] = typedArrayTags[setTag$1] = typedArrayTags[stringTag] = typedArrayTags[weakMapTag$1] = false;
function baseIsTypedArray$1(value) {
  return isObjectLike$3(value) && isLength$1(value.length) && !!typedArrayTags[baseGetTag$2(value)];
}
var _baseIsTypedArray = baseIsTypedArray$1;
function baseUnary$1(func) {
  return function(value) {
    return func(value);
  };
}
var _baseUnary = baseUnary$1;
var _nodeUtil = { exports: {} };
(function(module, exports) {
  var freeGlobal2 = _freeGlobal;
  var freeExports = exports && !exports.nodeType && exports;
  var freeModule = freeExports && true && module && !module.nodeType && module;
  var moduleExports = freeModule && freeModule.exports === freeExports;
  var freeProcess = moduleExports && freeGlobal2.process;
  var nodeUtil2 = function() {
    try {
      var types = freeModule && freeModule.require && freeModule.require("util").types;
      if (types) {
        return types;
      }
      return freeProcess && freeProcess.binding && freeProcess.binding("util");
    } catch (e) {
    }
  }();
  module.exports = nodeUtil2;
})(_nodeUtil, _nodeUtil.exports);
var baseIsTypedArray = _baseIsTypedArray, baseUnary = _baseUnary, nodeUtil = _nodeUtil.exports;
var nodeIsTypedArray = nodeUtil && nodeUtil.isTypedArray;
var isTypedArray$3 = nodeIsTypedArray ? baseUnary(nodeIsTypedArray) : baseIsTypedArray;
var isTypedArray_1 = isTypedArray$3;
var baseTimes = _baseTimes, isArguments$1 = isArguments_1, isArray$2 = isArray_1, isBuffer$2 = isBuffer$3.exports, isIndex$1 = _isIndex, isTypedArray$2 = isTypedArray_1;
var objectProto$7 = Object.prototype;
var hasOwnProperty$6 = objectProto$7.hasOwnProperty;
function arrayLikeKeys$2(value, inherited) {
  var isArr = isArray$2(value), isArg = !isArr && isArguments$1(value), isBuff = !isArr && !isArg && isBuffer$2(value), isType = !isArr && !isArg && !isBuff && isTypedArray$2(value), skipIndexes = isArr || isArg || isBuff || isType, result = skipIndexes ? baseTimes(value.length, String) : [], length = result.length;
  for (var key in value) {
    if ((inherited || hasOwnProperty$6.call(value, key)) && !(skipIndexes && (key == "length" || isBuff && (key == "offset" || key == "parent") || isType && (key == "buffer" || key == "byteLength" || key == "byteOffset") || isIndex$1(key, length)))) {
      result.push(key);
    }
  }
  return result;
}
var _arrayLikeKeys = arrayLikeKeys$2;
var objectProto$6 = Object.prototype;
function isPrototype$3(value) {
  var Ctor = value && value.constructor, proto = typeof Ctor == "function" && Ctor.prototype || objectProto$6;
  return value === proto;
}
var _isPrototype = isPrototype$3;
function overArg$2(func, transform) {
  return function(arg) {
    return func(transform(arg));
  };
}
var _overArg = overArg$2;
var overArg$1 = _overArg;
var nativeKeys$1 = overArg$1(Object.keys, Object);
var _nativeKeys = nativeKeys$1;
var isPrototype$2 = _isPrototype, nativeKeys = _nativeKeys;
var objectProto$5 = Object.prototype;
var hasOwnProperty$5 = objectProto$5.hasOwnProperty;
function baseKeys$1(object) {
  if (!isPrototype$2(object)) {
    return nativeKeys(object);
  }
  var result = [];
  for (var key in Object(object)) {
    if (hasOwnProperty$5.call(object, key) && key != "constructor") {
      result.push(key);
    }
  }
  return result;
}
var _baseKeys = baseKeys$1;
var isFunction$1 = isFunction_1, isLength = isLength_1;
function isArrayLike$4(value) {
  return value != null && isLength(value.length) && !isFunction$1(value);
}
var isArrayLike_1 = isArrayLike$4;
var arrayLikeKeys$1 = _arrayLikeKeys, baseKeys = _baseKeys, isArrayLike$3 = isArrayLike_1;
function keys$1(object) {
  return isArrayLike$3(object) ? arrayLikeKeys$1(object) : baseKeys(object);
}
var keys_1 = keys$1;
var baseGetAllKeys = _baseGetAllKeys, getSymbols = _getSymbols, keys2 = keys_1;
function getAllKeys$1(object) {
  return baseGetAllKeys(object, keys2, getSymbols);
}
var _getAllKeys = getAllKeys$1;
var getAllKeys = _getAllKeys;
var COMPARE_PARTIAL_FLAG$1 = 1;
var objectProto$4 = Object.prototype;
var hasOwnProperty$4 = objectProto$4.hasOwnProperty;
function equalObjects$1(object, other, bitmask, customizer, equalFunc, stack) {
  var isPartial = bitmask & COMPARE_PARTIAL_FLAG$1, objProps = getAllKeys(object), objLength = objProps.length, othProps = getAllKeys(other), othLength = othProps.length;
  if (objLength != othLength && !isPartial) {
    return false;
  }
  var index = objLength;
  while (index--) {
    var key = objProps[index];
    if (!(isPartial ? key in other : hasOwnProperty$4.call(other, key))) {
      return false;
    }
  }
  var objStacked = stack.get(object);
  var othStacked = stack.get(other);
  if (objStacked && othStacked) {
    return objStacked == other && othStacked == object;
  }
  var result = true;
  stack.set(object, other);
  stack.set(other, object);
  var skipCtor = isPartial;
  while (++index < objLength) {
    key = objProps[index];
    var objValue = object[key], othValue = other[key];
    if (customizer) {
      var compared = isPartial ? customizer(othValue, objValue, key, other, object, stack) : customizer(objValue, othValue, key, object, other, stack);
    }
    if (!(compared === void 0 ? objValue === othValue || equalFunc(objValue, othValue, bitmask, customizer, stack) : compared)) {
      result = false;
      break;
    }
    skipCtor || (skipCtor = key == "constructor");
  }
  if (result && !skipCtor) {
    var objCtor = object.constructor, othCtor = other.constructor;
    if (objCtor != othCtor && ("constructor" in object && "constructor" in other) && !(typeof objCtor == "function" && objCtor instanceof objCtor && typeof othCtor == "function" && othCtor instanceof othCtor)) {
      result = false;
    }
  }
  stack["delete"](object);
  stack["delete"](other);
  return result;
}
var _equalObjects = equalObjects$1;
var getNative$4 = _getNative, root$3 = _root;
var DataView$1 = getNative$4(root$3, "DataView");
var _DataView = DataView$1;
var getNative$3 = _getNative, root$2 = _root;
var Promise$2 = getNative$3(root$2, "Promise");
var _Promise = Promise$2;
var getNative$2 = _getNative, root$1 = _root;
var Set$1 = getNative$2(root$1, "Set");
var _Set = Set$1;
var getNative$1 = _getNative, root = _root;
var WeakMap$1 = getNative$1(root, "WeakMap");
var _WeakMap = WeakMap$1;
var DataView = _DataView, Map = _Map, Promise$1 = _Promise, Set = _Set, WeakMap = _WeakMap, baseGetTag$1 = _baseGetTag, toSource = _toSource;
var mapTag = "[object Map]", objectTag$2 = "[object Object]", promiseTag = "[object Promise]", setTag = "[object Set]", weakMapTag = "[object WeakMap]";
var dataViewTag = "[object DataView]";
var dataViewCtorString = toSource(DataView), mapCtorString = toSource(Map), promiseCtorString = toSource(Promise$1), setCtorString = toSource(Set), weakMapCtorString = toSource(WeakMap);
var getTag$1 = baseGetTag$1;
if (DataView && getTag$1(new DataView(new ArrayBuffer(1))) != dataViewTag || Map && getTag$1(new Map()) != mapTag || Promise$1 && getTag$1(Promise$1.resolve()) != promiseTag || Set && getTag$1(new Set()) != setTag || WeakMap && getTag$1(new WeakMap()) != weakMapTag) {
  getTag$1 = function(value) {
    var result = baseGetTag$1(value), Ctor = result == objectTag$2 ? value.constructor : void 0, ctorString = Ctor ? toSource(Ctor) : "";
    if (ctorString) {
      switch (ctorString) {
        case dataViewCtorString:
          return dataViewTag;
        case mapCtorString:
          return mapTag;
        case promiseCtorString:
          return promiseTag;
        case setCtorString:
          return setTag;
        case weakMapCtorString:
          return weakMapTag;
      }
    }
    return result;
  };
}
var _getTag = getTag$1;
var Stack$1 = _Stack, equalArrays = _equalArrays, equalByTag = _equalByTag, equalObjects = _equalObjects, getTag = _getTag, isArray$1 = isArray_1, isBuffer$1 = isBuffer$3.exports, isTypedArray$1 = isTypedArray_1;
var COMPARE_PARTIAL_FLAG = 1;
var argsTag = "[object Arguments]", arrayTag = "[object Array]", objectTag$1 = "[object Object]";
var objectProto$3 = Object.prototype;
var hasOwnProperty$3 = objectProto$3.hasOwnProperty;
function baseIsEqualDeep$1(object, other, bitmask, customizer, equalFunc, stack) {
  var objIsArr = isArray$1(object), othIsArr = isArray$1(other), objTag = objIsArr ? arrayTag : getTag(object), othTag = othIsArr ? arrayTag : getTag(other);
  objTag = objTag == argsTag ? objectTag$1 : objTag;
  othTag = othTag == argsTag ? objectTag$1 : othTag;
  var objIsObj = objTag == objectTag$1, othIsObj = othTag == objectTag$1, isSameTag = objTag == othTag;
  if (isSameTag && isBuffer$1(object)) {
    if (!isBuffer$1(other)) {
      return false;
    }
    objIsArr = true;
    objIsObj = false;
  }
  if (isSameTag && !objIsObj) {
    stack || (stack = new Stack$1());
    return objIsArr || isTypedArray$1(object) ? equalArrays(object, other, bitmask, customizer, equalFunc, stack) : equalByTag(object, other, objTag, bitmask, customizer, equalFunc, stack);
  }
  if (!(bitmask & COMPARE_PARTIAL_FLAG)) {
    var objIsWrapped = objIsObj && hasOwnProperty$3.call(object, "__wrapped__"), othIsWrapped = othIsObj && hasOwnProperty$3.call(other, "__wrapped__");
    if (objIsWrapped || othIsWrapped) {
      var objUnwrapped = objIsWrapped ? object.value() : object, othUnwrapped = othIsWrapped ? other.value() : other;
      stack || (stack = new Stack$1());
      return equalFunc(objUnwrapped, othUnwrapped, bitmask, customizer, stack);
    }
  }
  if (!isSameTag) {
    return false;
  }
  stack || (stack = new Stack$1());
  return equalObjects(object, other, bitmask, customizer, equalFunc, stack);
}
var _baseIsEqualDeep = baseIsEqualDeep$1;
var baseIsEqualDeep = _baseIsEqualDeep, isObjectLike$2 = isObjectLike_1;
function baseIsEqual$1(value, other, bitmask, customizer, stack) {
  if (value === other) {
    return true;
  }
  if (value == null || other == null || !isObjectLike$2(value) && !isObjectLike$2(other)) {
    return value !== value && other !== other;
  }
  return baseIsEqualDeep(value, other, bitmask, customizer, baseIsEqual$1, stack);
}
var _baseIsEqual = baseIsEqual$1;
var baseIsEqual = _baseIsEqual;
function isEqual(value, other) {
  return baseIsEqual(value, other);
}
var isEqual_1 = isEqual;
function getInternetExplorerVersion() {
  var ua = window.navigator.userAgent;
  var msie = ua.indexOf("MSIE ");
  if (msie > 0) {
    return parseInt(ua.substring(msie + 5, ua.indexOf(".", msie)), 10);
  }
  var trident = ua.indexOf("Trident/");
  if (trident > 0) {
    var rv = ua.indexOf("rv:");
    return parseInt(ua.substring(rv + 3, ua.indexOf(".", rv)), 10);
  }
  var edge = ua.indexOf("Edge/");
  if (edge > 0) {
    return parseInt(ua.substring(edge + 5, ua.indexOf(".", edge)), 10);
  }
  return -1;
}
var isIE;
function initCompat() {
  if (!initCompat.init) {
    initCompat.init = true;
    isIE = getInternetExplorerVersion() !== -1;
  }
}
var script$1 = {
  name: "ResizeObserver",
  props: {
    emitOnMount: {
      type: Boolean,
      default: false
    },
    ignoreWidth: {
      type: Boolean,
      default: false
    },
    ignoreHeight: {
      type: Boolean,
      default: false
    }
  },
  mounted: function mounted() {
    var _this = this;
    initCompat();
    this.$nextTick(function() {
      _this._w = _this.$el.offsetWidth;
      _this._h = _this.$el.offsetHeight;
      if (_this.emitOnMount) {
        _this.emitSize();
      }
    });
    var object = document.createElement("object");
    this._resizeObject = object;
    object.setAttribute("aria-hidden", "true");
    object.setAttribute("tabindex", -1);
    object.onload = this.addResizeHandlers;
    object.type = "text/html";
    if (isIE) {
      this.$el.appendChild(object);
    }
    object.data = "about:blank";
    if (!isIE) {
      this.$el.appendChild(object);
    }
  },
  beforeDestroy: function beforeDestroy() {
    this.removeResizeHandlers();
  },
  methods: {
    compareAndNotify: function compareAndNotify() {
      if (!this.ignoreWidth && this._w !== this.$el.offsetWidth || !this.ignoreHeight && this._h !== this.$el.offsetHeight) {
        this._w = this.$el.offsetWidth;
        this._h = this.$el.offsetHeight;
        this.emitSize();
      }
    },
    emitSize: function emitSize() {
      this.$emit("notify", {
        width: this._w,
        height: this._h
      });
    },
    addResizeHandlers: function addResizeHandlers() {
      this._resizeObject.contentDocument.defaultView.addEventListener("resize", this.compareAndNotify);
      this.compareAndNotify();
    },
    removeResizeHandlers: function removeResizeHandlers() {
      if (this._resizeObject && this._resizeObject.onload) {
        if (!isIE && this._resizeObject.contentDocument) {
          this._resizeObject.contentDocument.defaultView.removeEventListener("resize", this.compareAndNotify);
        }
        this.$el.removeChild(this._resizeObject);
        this._resizeObject.onload = null;
        this._resizeObject = null;
      }
    }
  }
};
function normalizeComponent$1(template, style, script2, scopeId, isFunctionalTemplate, moduleIdentifier, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
  if (typeof shadowMode !== "boolean") {
    createInjectorSSR = createInjector;
    createInjector = shadowMode;
    shadowMode = false;
  }
  var options = typeof script2 === "function" ? script2.options : script2;
  if (template && template.render) {
    options.render = template.render;
    options.staticRenderFns = template.staticRenderFns;
    options._compiled = true;
    if (isFunctionalTemplate) {
      options.functional = true;
    }
  }
  if (scopeId) {
    options._scopeId = scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || this.$vnode && this.$vnode.ssrContext || this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (style) {
        style.call(this, createInjectorSSR(context));
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (style) {
    hook = shadowMode ? function(context) {
      style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
    } : function(context) {
      style.call(this, createInjector(context));
    };
  }
  if (hook) {
    if (options.functional) {
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return script2;
}
var __vue_script__$1 = script$1;
var __vue_render__$1 = function __vue_render__() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "resize-observer",
    attrs: {
      tabindex: "-1"
    }
  });
};
var __vue_staticRenderFns__$1 = [];
__vue_render__$1._withStripped = true;
var __vue_inject_styles__$1 = void 0;
var __vue_scope_id__$1 = "data-v-8859cc6c";
var __vue_module_identifier__$1 = void 0;
var __vue_is_functional_template__$1 = false;
var __vue_component__$1 = /* @__PURE__ */ normalizeComponent$1({
  render: __vue_render__$1,
  staticRenderFns: __vue_staticRenderFns__$1
}, __vue_inject_styles__$1, __vue_script__$1, __vue_scope_id__$1, __vue_is_functional_template__$1, __vue_module_identifier__$1, false, void 0, void 0, void 0);
function install$1(Vue2) {
  Vue2.component("resize-observer", __vue_component__$1);
  Vue2.component("ResizeObserver", __vue_component__$1);
}
var plugin$1 = {
  version: "1.0.1",
  install: install$1
};
var GlobalVue$1 = null;
if (typeof window !== "undefined") {
  GlobalVue$1 = window.Vue;
} else if (typeof global !== "undefined") {
  GlobalVue$1 = global.Vue;
}
if (GlobalVue$1) {
  GlobalVue$1.use(plugin$1);
}
var getNative = _getNative;
var defineProperty$2 = function() {
  try {
    var func = getNative(Object, "defineProperty");
    func({}, "", {});
    return func;
  } catch (e) {
  }
}();
var _defineProperty = defineProperty$2;
var defineProperty$1 = _defineProperty;
function baseAssignValue$3(object, key, value) {
  if (key == "__proto__" && defineProperty$1) {
    defineProperty$1(object, key, {
      "configurable": true,
      "enumerable": true,
      "value": value,
      "writable": true
    });
  } else {
    object[key] = value;
  }
}
var _baseAssignValue = baseAssignValue$3;
var baseAssignValue$2 = _baseAssignValue, eq$2 = eq_1;
function assignMergeValue$2(object, key, value) {
  if (value !== void 0 && !eq$2(object[key], value) || value === void 0 && !(key in object)) {
    baseAssignValue$2(object, key, value);
  }
}
var _assignMergeValue = assignMergeValue$2;
function createBaseFor$1(fromRight) {
  return function(object, iteratee, keysFunc) {
    var index = -1, iterable = Object(object), props = keysFunc(object), length = props.length;
    while (length--) {
      var key = props[fromRight ? length : ++index];
      if (iteratee(iterable[key], key, iterable) === false) {
        break;
      }
    }
    return object;
  };
}
var _createBaseFor = createBaseFor$1;
var createBaseFor = _createBaseFor;
var baseFor$1 = createBaseFor();
var _baseFor = baseFor$1;
var _cloneBuffer = { exports: {} };
(function(module, exports) {
  var root2 = _root;
  var freeExports = exports && !exports.nodeType && exports;
  var freeModule = freeExports && true && module && !module.nodeType && module;
  var moduleExports = freeModule && freeModule.exports === freeExports;
  var Buffer2 = moduleExports ? root2.Buffer : void 0, allocUnsafe = Buffer2 ? Buffer2.allocUnsafe : void 0;
  function cloneBuffer2(buffer, isDeep) {
    if (isDeep) {
      return buffer.slice();
    }
    var length = buffer.length, result = allocUnsafe ? allocUnsafe(length) : new buffer.constructor(length);
    buffer.copy(result);
    return result;
  }
  module.exports = cloneBuffer2;
})(_cloneBuffer, _cloneBuffer.exports);
var Uint8Array2 = _Uint8Array;
function cloneArrayBuffer$1(arrayBuffer) {
  var result = new arrayBuffer.constructor(arrayBuffer.byteLength);
  new Uint8Array2(result).set(new Uint8Array2(arrayBuffer));
  return result;
}
var _cloneArrayBuffer = cloneArrayBuffer$1;
var cloneArrayBuffer = _cloneArrayBuffer;
function cloneTypedArray$1(typedArray, isDeep) {
  var buffer = isDeep ? cloneArrayBuffer(typedArray.buffer) : typedArray.buffer;
  return new typedArray.constructor(buffer, typedArray.byteOffset, typedArray.length);
}
var _cloneTypedArray = cloneTypedArray$1;
function copyArray$1(source, array) {
  var index = -1, length = source.length;
  array || (array = Array(length));
  while (++index < length) {
    array[index] = source[index];
  }
  return array;
}
var _copyArray = copyArray$1;
var isObject$4 = isObject_1;
var objectCreate = Object.create;
var baseCreate$1 = function() {
  function object() {
  }
  return function(proto) {
    if (!isObject$4(proto)) {
      return {};
    }
    if (objectCreate) {
      return objectCreate(proto);
    }
    object.prototype = proto;
    var result = new object();
    object.prototype = void 0;
    return result;
  };
}();
var _baseCreate = baseCreate$1;
var overArg = _overArg;
var getPrototype$2 = overArg(Object.getPrototypeOf, Object);
var _getPrototype = getPrototype$2;
var baseCreate = _baseCreate, getPrototype$1 = _getPrototype, isPrototype$1 = _isPrototype;
function initCloneObject$1(object) {
  return typeof object.constructor == "function" && !isPrototype$1(object) ? baseCreate(getPrototype$1(object)) : {};
}
var _initCloneObject = initCloneObject$1;
var isArrayLike$2 = isArrayLike_1, isObjectLike$1 = isObjectLike_1;
function isArrayLikeObject$1(value) {
  return isObjectLike$1(value) && isArrayLike$2(value);
}
var isArrayLikeObject_1 = isArrayLikeObject$1;
var baseGetTag = _baseGetTag, getPrototype = _getPrototype, isObjectLike = isObjectLike_1;
var objectTag = "[object Object]";
var funcProto = Function.prototype, objectProto$2 = Object.prototype;
var funcToString = funcProto.toString;
var hasOwnProperty$2 = objectProto$2.hasOwnProperty;
var objectCtorString = funcToString.call(Object);
function isPlainObject$1(value) {
  if (!isObjectLike(value) || baseGetTag(value) != objectTag) {
    return false;
  }
  var proto = getPrototype(value);
  if (proto === null) {
    return true;
  }
  var Ctor = hasOwnProperty$2.call(proto, "constructor") && proto.constructor;
  return typeof Ctor == "function" && Ctor instanceof Ctor && funcToString.call(Ctor) == objectCtorString;
}
var isPlainObject_1 = isPlainObject$1;
function safeGet$2(object, key) {
  if (key === "constructor" && typeof object[key] === "function") {
    return;
  }
  if (key == "__proto__") {
    return;
  }
  return object[key];
}
var _safeGet = safeGet$2;
var baseAssignValue$1 = _baseAssignValue, eq$1 = eq_1;
var objectProto$1 = Object.prototype;
var hasOwnProperty$1 = objectProto$1.hasOwnProperty;
function assignValue$1(object, key, value) {
  var objValue = object[key];
  if (!(hasOwnProperty$1.call(object, key) && eq$1(objValue, value)) || value === void 0 && !(key in object)) {
    baseAssignValue$1(object, key, value);
  }
}
var _assignValue = assignValue$1;
var assignValue = _assignValue, baseAssignValue = _baseAssignValue;
function copyObject$1(source, props, object, customizer) {
  var isNew = !object;
  object || (object = {});
  var index = -1, length = props.length;
  while (++index < length) {
    var key = props[index];
    var newValue = customizer ? customizer(object[key], source[key], key, object, source) : void 0;
    if (newValue === void 0) {
      newValue = source[key];
    }
    if (isNew) {
      baseAssignValue(object, key, newValue);
    } else {
      assignValue(object, key, newValue);
    }
  }
  return object;
}
var _copyObject = copyObject$1;
function nativeKeysIn$1(object) {
  var result = [];
  if (object != null) {
    for (var key in Object(object)) {
      result.push(key);
    }
  }
  return result;
}
var _nativeKeysIn = nativeKeysIn$1;
var isObject$3 = isObject_1, isPrototype = _isPrototype, nativeKeysIn = _nativeKeysIn;
var objectProto = Object.prototype;
var hasOwnProperty = objectProto.hasOwnProperty;
function baseKeysIn$1(object) {
  if (!isObject$3(object)) {
    return nativeKeysIn(object);
  }
  var isProto = isPrototype(object), result = [];
  for (var key in object) {
    if (!(key == "constructor" && (isProto || !hasOwnProperty.call(object, key)))) {
      result.push(key);
    }
  }
  return result;
}
var _baseKeysIn = baseKeysIn$1;
var arrayLikeKeys = _arrayLikeKeys, baseKeysIn = _baseKeysIn, isArrayLike$1 = isArrayLike_1;
function keysIn$2(object) {
  return isArrayLike$1(object) ? arrayLikeKeys(object, true) : baseKeysIn(object);
}
var keysIn_1 = keysIn$2;
var copyObject = _copyObject, keysIn$1 = keysIn_1;
function toPlainObject$1(value) {
  return copyObject(value, keysIn$1(value));
}
var toPlainObject_1 = toPlainObject$1;
var assignMergeValue$1 = _assignMergeValue, cloneBuffer = _cloneBuffer.exports, cloneTypedArray = _cloneTypedArray, copyArray = _copyArray, initCloneObject = _initCloneObject, isArguments = isArguments_1, isArray = isArray_1, isArrayLikeObject = isArrayLikeObject_1, isBuffer = isBuffer$3.exports, isFunction = isFunction_1, isObject$2 = isObject_1, isPlainObject = isPlainObject_1, isTypedArray = isTypedArray_1, safeGet$1 = _safeGet, toPlainObject = toPlainObject_1;
function baseMergeDeep$1(object, source, key, srcIndex, mergeFunc, customizer, stack) {
  var objValue = safeGet$1(object, key), srcValue = safeGet$1(source, key), stacked = stack.get(srcValue);
  if (stacked) {
    assignMergeValue$1(object, key, stacked);
    return;
  }
  var newValue = customizer ? customizer(objValue, srcValue, key + "", object, source, stack) : void 0;
  var isCommon = newValue === void 0;
  if (isCommon) {
    var isArr = isArray(srcValue), isBuff = !isArr && isBuffer(srcValue), isTyped = !isArr && !isBuff && isTypedArray(srcValue);
    newValue = srcValue;
    if (isArr || isBuff || isTyped) {
      if (isArray(objValue)) {
        newValue = objValue;
      } else if (isArrayLikeObject(objValue)) {
        newValue = copyArray(objValue);
      } else if (isBuff) {
        isCommon = false;
        newValue = cloneBuffer(srcValue, true);
      } else if (isTyped) {
        isCommon = false;
        newValue = cloneTypedArray(srcValue, true);
      } else {
        newValue = [];
      }
    } else if (isPlainObject(srcValue) || isArguments(srcValue)) {
      newValue = objValue;
      if (isArguments(objValue)) {
        newValue = toPlainObject(objValue);
      } else if (!isObject$2(objValue) || isFunction(objValue)) {
        newValue = initCloneObject(srcValue);
      }
    } else {
      isCommon = false;
    }
  }
  if (isCommon) {
    stack.set(srcValue, newValue);
    mergeFunc(newValue, srcValue, srcIndex, customizer, stack);
    stack["delete"](srcValue);
  }
  assignMergeValue$1(object, key, newValue);
}
var _baseMergeDeep = baseMergeDeep$1;
var Stack = _Stack, assignMergeValue = _assignMergeValue, baseFor = _baseFor, baseMergeDeep = _baseMergeDeep, isObject$1 = isObject_1, keysIn = keysIn_1, safeGet = _safeGet;
function baseMerge$1(object, source, srcIndex, customizer, stack) {
  if (object === source) {
    return;
  }
  baseFor(source, function(srcValue, key) {
    stack || (stack = new Stack());
    if (isObject$1(srcValue)) {
      baseMergeDeep(object, source, key, srcIndex, baseMerge$1, customizer, stack);
    } else {
      var newValue = customizer ? customizer(safeGet(object, key), srcValue, key + "", object, source, stack) : void 0;
      if (newValue === void 0) {
        newValue = srcValue;
      }
      assignMergeValue(object, key, newValue);
    }
  }, keysIn);
}
var _baseMerge = baseMerge$1;
function identity$2(value) {
  return value;
}
var identity_1 = identity$2;
function apply$1(func, thisArg, args) {
  switch (args.length) {
    case 0:
      return func.call(thisArg);
    case 1:
      return func.call(thisArg, args[0]);
    case 2:
      return func.call(thisArg, args[0], args[1]);
    case 3:
      return func.call(thisArg, args[0], args[1], args[2]);
  }
  return func.apply(thisArg, args);
}
var _apply = apply$1;
var apply = _apply;
var nativeMax = Math.max;
function overRest$1(func, start, transform) {
  start = nativeMax(start === void 0 ? func.length - 1 : start, 0);
  return function() {
    var args = arguments, index = -1, length = nativeMax(args.length - start, 0), array = Array(length);
    while (++index < length) {
      array[index] = args[start + index];
    }
    index = -1;
    var otherArgs = Array(start + 1);
    while (++index < start) {
      otherArgs[index] = args[index];
    }
    otherArgs[start] = transform(array);
    return apply(func, this, otherArgs);
  };
}
var _overRest = overRest$1;
function constant$1(value) {
  return function() {
    return value;
  };
}
var constant_1 = constant$1;
var constant = constant_1, defineProperty3 = _defineProperty, identity$1 = identity_1;
var baseSetToString$1 = !defineProperty3 ? identity$1 : function(func, string) {
  return defineProperty3(func, "toString", {
    "configurable": true,
    "enumerable": false,
    "value": constant(string),
    "writable": true
  });
};
var _baseSetToString = baseSetToString$1;
var HOT_COUNT = 800, HOT_SPAN = 16;
var nativeNow = Date.now;
function shortOut$1(func) {
  var count = 0, lastCalled = 0;
  return function() {
    var stamp = nativeNow(), remaining = HOT_SPAN - (stamp - lastCalled);
    lastCalled = stamp;
    if (remaining > 0) {
      if (++count >= HOT_COUNT) {
        return arguments[0];
      }
    } else {
      count = 0;
    }
    return func.apply(void 0, arguments);
  };
}
var _shortOut = shortOut$1;
var baseSetToString = _baseSetToString, shortOut = _shortOut;
var setToString$1 = shortOut(baseSetToString);
var _setToString = setToString$1;
var identity = identity_1, overRest = _overRest, setToString = _setToString;
function baseRest$1(func, start) {
  return setToString(overRest(func, start, identity), func + "");
}
var _baseRest = baseRest$1;
var eq = eq_1, isArrayLike = isArrayLike_1, isIndex = _isIndex, isObject = isObject_1;
function isIterateeCall$1(value, index, object) {
  if (!isObject(object)) {
    return false;
  }
  var type = typeof index;
  if (type == "number" ? isArrayLike(object) && isIndex(index, object.length) : type == "string" && index in object) {
    return eq(object[index], value);
  }
  return false;
}
var _isIterateeCall = isIterateeCall$1;
var baseRest = _baseRest, isIterateeCall = _isIterateeCall;
function createAssigner$1(assigner) {
  return baseRest(function(object, sources) {
    var index = -1, length = sources.length, customizer = length > 1 ? sources[length - 1] : void 0, guard = length > 2 ? sources[2] : void 0;
    customizer = assigner.length > 3 && typeof customizer == "function" ? (length--, customizer) : void 0;
    if (guard && isIterateeCall(sources[0], sources[1], guard)) {
      customizer = length < 3 ? void 0 : customizer;
      length = 1;
    }
    object = Object(object);
    while (++index < length) {
      var source = sources[index];
      if (source) {
        assigner(object, source, index, customizer);
      }
    }
    return object;
  });
}
var _createAssigner = createAssigner$1;
var baseMerge = _baseMerge, createAssigner = _createAssigner;
var merge = createAssigner(function(object, source, srcIndex) {
  baseMerge(object, source, srcIndex);
});
var merge_1 = merge;
var SVGAnimatedString = function SVGAnimatedString2() {
};
if (typeof window !== "undefined") {
  SVGAnimatedString = window.SVGAnimatedString;
}
function convertToArray(value) {
  if (typeof value === "string") {
    value = value.split(" ");
  }
  return value;
}
function addClasses(el, classes) {
  var newClasses = convertToArray(classes);
  var classList;
  if (el.className instanceof SVGAnimatedString) {
    classList = convertToArray(el.className.baseVal);
  } else {
    classList = convertToArray(el.className);
  }
  newClasses.forEach(function(newClass) {
    if (classList.indexOf(newClass) === -1) {
      classList.push(newClass);
    }
  });
  if (el instanceof SVGElement) {
    el.setAttribute("class", classList.join(" "));
  } else {
    el.className = classList.join(" ");
  }
}
function removeClasses(el, classes) {
  var newClasses = convertToArray(classes);
  var classList;
  if (el.className instanceof SVGAnimatedString) {
    classList = convertToArray(el.className.baseVal);
  } else {
    classList = convertToArray(el.className);
  }
  newClasses.forEach(function(newClass) {
    var index = classList.indexOf(newClass);
    if (index !== -1) {
      classList.splice(index, 1);
    }
  });
  if (el instanceof SVGElement) {
    el.setAttribute("class", classList.join(" "));
  } else {
    el.className = classList.join(" ");
  }
}
var supportsPassive = false;
if (typeof window !== "undefined") {
  supportsPassive = false;
  try {
    var opts = Object.defineProperty({}, "passive", {
      get: function get2() {
        supportsPassive = true;
      }
    });
    window.addEventListener("test", null, opts);
  } catch (e) {
  }
}
function ownKeys$2(object, enumerableOnly) {
  var keys3 = Object.keys(object);
  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly)
      symbols = symbols.filter(function(sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });
    keys3.push.apply(keys3, symbols);
  }
  return keys3;
}
function _objectSpread$2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};
    if (i % 2) {
      ownKeys$2(Object(source), true).forEach(function(key) {
        _defineProperty$1(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys$2(Object(source)).forEach(function(key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }
  return target;
}
var DEFAULT_OPTIONS = {
  container: false,
  delay: 0,
  html: false,
  placement: "top",
  title: "",
  template: '<div class="tooltip" role="tooltip"><div class="tooltip-arrow"></div><div class="tooltip-inner"></div></div>',
  trigger: "hover focus",
  offset: 0
};
var openTooltips = [];
var Tooltip = /* @__PURE__ */ function() {
  function Tooltip2(_reference, _options) {
    var _this = this;
    _classCallCheck(this, Tooltip2);
    _defineProperty$1(this, "_events", []);
    _defineProperty$1(this, "_setTooltipNodeEvent", function(evt, reference, delay, options) {
      var relatedreference = evt.relatedreference || evt.toElement || evt.relatedTarget;
      var callback = function callback2(evt2) {
        var relatedreference2 = evt2.relatedreference || evt2.toElement || evt2.relatedTarget;
        _this._tooltipNode.removeEventListener(evt.type, callback2);
        if (!reference.contains(relatedreference2)) {
          _this._scheduleHide(reference, options.delay, options, evt2);
        }
      };
      if (_this._tooltipNode.contains(relatedreference)) {
        _this._tooltipNode.addEventListener(evt.type, callback);
        return true;
      }
      return false;
    });
    _options = _objectSpread$2(_objectSpread$2({}, DEFAULT_OPTIONS), _options);
    _reference.jquery && (_reference = _reference[0]);
    this.show = this.show.bind(this);
    this.hide = this.hide.bind(this);
    this.reference = _reference;
    this.options = _options;
    this._isOpen = false;
    this._init();
  }
  _createClass(Tooltip2, [{
    key: "show",
    value: function show2() {
      this._show(this.reference, this.options);
    }
  }, {
    key: "hide",
    value: function hide3() {
      this._hide();
    }
  }, {
    key: "dispose",
    value: function dispose2() {
      this._dispose();
    }
  }, {
    key: "toggle",
    value: function toggle() {
      if (this._isOpen) {
        return this.hide();
      } else {
        return this.show();
      }
    }
  }, {
    key: "setClasses",
    value: function setClasses(classes) {
      this._classes = classes;
    }
  }, {
    key: "setContent",
    value: function setContent(content) {
      this.options.title = content;
      if (this._tooltipNode) {
        this._setContent(content, this.options);
      }
    }
  }, {
    key: "setOptions",
    value: function setOptions(options) {
      var classesUpdated = false;
      var classes = options && options.classes || directive.options.defaultClass;
      if (!isEqual_1(this._classes, classes)) {
        this.setClasses(classes);
        classesUpdated = true;
      }
      options = getOptions(options);
      var needPopperUpdate = false;
      var needRestart = false;
      if (this.options.offset !== options.offset || this.options.placement !== options.placement) {
        needPopperUpdate = true;
      }
      if (this.options.template !== options.template || this.options.trigger !== options.trigger || this.options.container !== options.container || classesUpdated) {
        needRestart = true;
      }
      for (var key in options) {
        this.options[key] = options[key];
      }
      if (this._tooltipNode) {
        if (needRestart) {
          var isOpen = this._isOpen;
          this.dispose();
          this._init();
          if (isOpen) {
            this.show();
          }
        } else if (needPopperUpdate) {
          this.popperInstance.update();
        }
      }
    }
  }, {
    key: "_init",
    value: function _init() {
      var events = typeof this.options.trigger === "string" ? this.options.trigger.split(" ") : [];
      this._isDisposed = false;
      this._enableDocumentTouch = events.indexOf("manual") === -1;
      events = events.filter(function(trigger2) {
        return ["click", "hover", "focus"].indexOf(trigger2) !== -1;
      });
      this._setEventListeners(this.reference, events, this.options);
      this.$_originalTitle = this.reference.getAttribute("title");
      this.reference.removeAttribute("title");
      this.reference.setAttribute("data-original-title", this.$_originalTitle);
    }
  }, {
    key: "_create",
    value: function _create(reference, template) {
      var _this2 = this;
      var tooltipGenerator = window.document.createElement("div");
      tooltipGenerator.innerHTML = template.trim();
      var tooltipNode = tooltipGenerator.childNodes[0];
      tooltipNode.id = this.options.ariaId || "tooltip_".concat(Math.random().toString(36).substr(2, 10));
      tooltipNode.setAttribute("aria-hidden", "true");
      if (this.options.autoHide && this.options.trigger.indexOf("hover") !== -1) {
        tooltipNode.addEventListener("mouseenter", function(evt) {
          return _this2._scheduleHide(reference, _this2.options.delay, _this2.options, evt);
        });
        tooltipNode.addEventListener("click", function(evt) {
          return _this2._scheduleHide(reference, _this2.options.delay, _this2.options, evt);
        });
      }
      return tooltipNode;
    }
  }, {
    key: "_setContent",
    value: function _setContent(content, options) {
      var _this3 = this;
      this.asyncContent = false;
      this._applyContent(content, options).then(function() {
        if (!_this3.popperInstance)
          return;
        _this3.popperInstance.update();
      });
    }
  }, {
    key: "_applyContent",
    value: function _applyContent(title, options) {
      var _this4 = this;
      return new Promise(function(resolve, reject) {
        var allowHtml = options.html;
        var rootNode = _this4._tooltipNode;
        if (!rootNode)
          return;
        var titleNode = rootNode.querySelector(_this4.options.innerSelector);
        if (title.nodeType === 1) {
          if (allowHtml) {
            while (titleNode.firstChild) {
              titleNode.removeChild(titleNode.firstChild);
            }
            titleNode.appendChild(title);
          }
        } else if (typeof title === "function") {
          var result = title();
          if (result && typeof result.then === "function") {
            _this4.asyncContent = true;
            options.loadingClass && addClasses(rootNode, options.loadingClass);
            if (options.loadingContent) {
              _this4._applyContent(options.loadingContent, options);
            }
            result.then(function(asyncResult) {
              options.loadingClass && removeClasses(rootNode, options.loadingClass);
              return _this4._applyContent(asyncResult, options);
            }).then(resolve).catch(reject);
          } else {
            _this4._applyContent(result, options).then(resolve).catch(reject);
          }
          return;
        } else {
          allowHtml ? titleNode.innerHTML = title : titleNode.innerText = title;
        }
        resolve();
      });
    }
  }, {
    key: "_show",
    value: function _show(reference, options) {
      if (options && typeof options.container === "string") {
        var container3 = document.querySelector(options.container);
        if (!container3)
          return;
      }
      clearTimeout(this._disposeTimer);
      options = Object.assign({}, options);
      delete options.offset;
      var updateClasses = true;
      if (this._tooltipNode) {
        addClasses(this._tooltipNode, this._classes);
        updateClasses = false;
      }
      var result = this._ensureShown(reference, options);
      if (updateClasses && this._tooltipNode) {
        addClasses(this._tooltipNode, this._classes);
      }
      addClasses(reference, ["v-tooltip-open"]);
      return result;
    }
  }, {
    key: "_ensureShown",
    value: function _ensureShown(reference, options) {
      var _this5 = this;
      if (this._isOpen) {
        return this;
      }
      this._isOpen = true;
      openTooltips.push(this);
      if (this._tooltipNode) {
        this._tooltipNode.style.display = "";
        this._tooltipNode.setAttribute("aria-hidden", "false");
        this.popperInstance.enableEventListeners();
        this.popperInstance.update();
        if (this.asyncContent) {
          this._setContent(options.title, options);
        }
        return this;
      }
      var title = reference.getAttribute("title") || options.title;
      if (!title) {
        return this;
      }
      var tooltipNode = this._create(reference, options.template);
      this._tooltipNode = tooltipNode;
      reference.setAttribute("aria-describedby", tooltipNode.id);
      var container3 = this._findContainer(options.container, reference);
      this._append(tooltipNode, container3);
      var popperOptions = _objectSpread$2(_objectSpread$2({}, options.popperOptions), {}, {
        placement: options.placement
      });
      popperOptions.modifiers = _objectSpread$2(_objectSpread$2({}, popperOptions.modifiers), {}, {
        arrow: {
          element: this.options.arrowSelector
        }
      });
      if (options.boundariesElement) {
        popperOptions.modifiers.preventOverflow = {
          boundariesElement: options.boundariesElement
        };
      }
      this.popperInstance = new Popper$1(reference, tooltipNode, popperOptions);
      this._setContent(title, options);
      requestAnimationFrame(function() {
        if (!_this5._isDisposed && _this5.popperInstance) {
          _this5.popperInstance.update();
          requestAnimationFrame(function() {
            if (!_this5._isDisposed) {
              _this5._isOpen && tooltipNode.setAttribute("aria-hidden", "false");
            } else {
              _this5.dispose();
            }
          });
        } else {
          _this5.dispose();
        }
      });
      return this;
    }
  }, {
    key: "_noLongerOpen",
    value: function _noLongerOpen() {
      var index = openTooltips.indexOf(this);
      if (index !== -1) {
        openTooltips.splice(index, 1);
      }
    }
  }, {
    key: "_hide",
    value: function _hide() {
      var _this6 = this;
      if (!this._isOpen) {
        return this;
      }
      this._isOpen = false;
      this._noLongerOpen();
      this._tooltipNode.style.display = "none";
      this._tooltipNode.setAttribute("aria-hidden", "true");
      if (this.popperInstance) {
        this.popperInstance.disableEventListeners();
      }
      clearTimeout(this._disposeTimer);
      var disposeTime = directive.options.disposeTimeout;
      if (disposeTime !== null) {
        this._disposeTimer = setTimeout(function() {
          if (_this6._tooltipNode) {
            _this6._tooltipNode.removeEventListener("mouseenter", _this6.hide);
            _this6._tooltipNode.removeEventListener("click", _this6.hide);
            _this6._removeTooltipNode();
          }
        }, disposeTime);
      }
      removeClasses(this.reference, ["v-tooltip-open"]);
      return this;
    }
  }, {
    key: "_removeTooltipNode",
    value: function _removeTooltipNode() {
      if (!this._tooltipNode)
        return;
      var parentNode = this._tooltipNode.parentNode;
      if (parentNode) {
        parentNode.removeChild(this._tooltipNode);
        this.reference.removeAttribute("aria-describedby");
      }
      this._tooltipNode = null;
    }
  }, {
    key: "_dispose",
    value: function _dispose() {
      var _this7 = this;
      this._isDisposed = true;
      this.reference.removeAttribute("data-original-title");
      if (this.$_originalTitle) {
        this.reference.setAttribute("title", this.$_originalTitle);
      }
      this._events.forEach(function(_ref) {
        var func = _ref.func, event = _ref.event;
        _this7.reference.removeEventListener(event, func);
      });
      this._events = [];
      if (this._tooltipNode) {
        this._hide();
        this._tooltipNode.removeEventListener("mouseenter", this.hide);
        this._tooltipNode.removeEventListener("click", this.hide);
        this.popperInstance.destroy();
        if (!this.popperInstance.options.removeOnDestroy) {
          this._removeTooltipNode();
        }
      } else {
        this._noLongerOpen();
      }
      return this;
    }
  }, {
    key: "_findContainer",
    value: function _findContainer(container3, reference) {
      if (typeof container3 === "string") {
        container3 = window.document.querySelector(container3);
      } else if (container3 === false) {
        container3 = reference.parentNode;
      }
      return container3;
    }
  }, {
    key: "_append",
    value: function _append(tooltipNode, container3) {
      container3.appendChild(tooltipNode);
    }
  }, {
    key: "_setEventListeners",
    value: function _setEventListeners(reference, events, options) {
      var _this8 = this;
      var directEvents = [];
      var oppositeEvents = [];
      events.forEach(function(event) {
        switch (event) {
          case "hover":
            directEvents.push("mouseenter");
            oppositeEvents.push("mouseleave");
            if (_this8.options.hideOnTargetClick)
              oppositeEvents.push("click");
            break;
          case "focus":
            directEvents.push("focus");
            oppositeEvents.push("blur");
            if (_this8.options.hideOnTargetClick)
              oppositeEvents.push("click");
            break;
          case "click":
            directEvents.push("click");
            oppositeEvents.push("click");
            break;
        }
      });
      directEvents.forEach(function(event) {
        var func = function func2(evt) {
          if (_this8._isOpen === true) {
            return;
          }
          evt.usedByTooltip = true;
          _this8._scheduleShow(reference, options.delay, options, evt);
        };
        _this8._events.push({
          event,
          func
        });
        reference.addEventListener(event, func);
      });
      oppositeEvents.forEach(function(event) {
        var func = function func2(evt) {
          if (evt.usedByTooltip === true) {
            return;
          }
          _this8._scheduleHide(reference, options.delay, options, evt);
        };
        _this8._events.push({
          event,
          func
        });
        reference.addEventListener(event, func);
      });
    }
  }, {
    key: "_onDocumentTouch",
    value: function _onDocumentTouch(event) {
      if (this._enableDocumentTouch) {
        this._scheduleHide(this.reference, this.options.delay, this.options, event);
      }
    }
  }, {
    key: "_scheduleShow",
    value: function _scheduleShow(reference, delay, options) {
      var _this9 = this;
      var computedDelay = delay && delay.show || delay || 0;
      clearTimeout(this._scheduleTimer);
      this._scheduleTimer = window.setTimeout(function() {
        return _this9._show(reference, options);
      }, computedDelay);
    }
  }, {
    key: "_scheduleHide",
    value: function _scheduleHide(reference, delay, options, evt) {
      var _this10 = this;
      var computedDelay = delay && delay.hide || delay || 0;
      clearTimeout(this._scheduleTimer);
      this._scheduleTimer = window.setTimeout(function() {
        if (_this10._isOpen === false) {
          return;
        }
        if (!_this10._tooltipNode.ownerDocument.body.contains(_this10._tooltipNode)) {
          return;
        }
        if (evt.type === "mouseleave") {
          var isSet = _this10._setTooltipNodeEvent(evt, reference, delay, options);
          if (isSet) {
            return;
          }
        }
        _this10._hide(reference, options);
      }, computedDelay);
    }
  }]);
  return Tooltip2;
}();
if (typeof document !== "undefined") {
  document.addEventListener("touchstart", function(event) {
    for (var i = 0; i < openTooltips.length; i++) {
      openTooltips[i]._onDocumentTouch(event);
    }
  }, supportsPassive ? {
    passive: true,
    capture: true
  } : true);
}
function ownKeys$1(object, enumerableOnly) {
  var keys3 = Object.keys(object);
  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly)
      symbols = symbols.filter(function(sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });
    keys3.push.apply(keys3, symbols);
  }
  return keys3;
}
function _objectSpread$1(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};
    if (i % 2) {
      ownKeys$1(Object(source), true).forEach(function(key) {
        _defineProperty$1(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys$1(Object(source)).forEach(function(key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }
  return target;
}
var state = {
  enabled: true
};
var positions = ["top", "top-start", "top-end", "right", "right-start", "right-end", "bottom", "bottom-start", "bottom-end", "left", "left-start", "left-end"];
var defaultOptions = {
  defaultPlacement: "top",
  defaultClass: "vue-tooltip-theme",
  defaultTargetClass: "has-tooltip",
  defaultHtml: true,
  defaultTemplate: '<div class="tooltip" role="tooltip"><div class="tooltip-arrow"></div><div class="tooltip-inner"></div></div>',
  defaultArrowSelector: ".tooltip-arrow, .tooltip__arrow",
  defaultInnerSelector: ".tooltip-inner, .tooltip__inner",
  defaultDelay: 0,
  defaultTrigger: "hover focus",
  defaultOffset: 0,
  defaultContainer: "body",
  defaultBoundariesElement: void 0,
  defaultPopperOptions: {},
  defaultLoadingClass: "tooltip-loading",
  defaultLoadingContent: "...",
  autoHide: true,
  defaultHideOnTargetClick: true,
  disposeTimeout: 5e3,
  popover: {
    defaultPlacement: "bottom",
    defaultClass: "vue-popover-theme",
    defaultBaseClass: "tooltip popover",
    defaultWrapperClass: "wrapper",
    defaultInnerClass: "tooltip-inner popover-inner",
    defaultArrowClass: "tooltip-arrow popover-arrow",
    defaultOpenClass: "open",
    defaultDelay: 0,
    defaultTrigger: "click",
    defaultOffset: 0,
    defaultContainer: "body",
    defaultBoundariesElement: void 0,
    defaultPopperOptions: {},
    defaultAutoHide: true,
    defaultHandleResize: true
  }
};
function getOptions(options) {
  var result = {
    placement: typeof options.placement !== "undefined" ? options.placement : directive.options.defaultPlacement,
    delay: typeof options.delay !== "undefined" ? options.delay : directive.options.defaultDelay,
    html: typeof options.html !== "undefined" ? options.html : directive.options.defaultHtml,
    template: typeof options.template !== "undefined" ? options.template : directive.options.defaultTemplate,
    arrowSelector: typeof options.arrowSelector !== "undefined" ? options.arrowSelector : directive.options.defaultArrowSelector,
    innerSelector: typeof options.innerSelector !== "undefined" ? options.innerSelector : directive.options.defaultInnerSelector,
    trigger: typeof options.trigger !== "undefined" ? options.trigger : directive.options.defaultTrigger,
    offset: typeof options.offset !== "undefined" ? options.offset : directive.options.defaultOffset,
    container: typeof options.container !== "undefined" ? options.container : directive.options.defaultContainer,
    boundariesElement: typeof options.boundariesElement !== "undefined" ? options.boundariesElement : directive.options.defaultBoundariesElement,
    autoHide: typeof options.autoHide !== "undefined" ? options.autoHide : directive.options.autoHide,
    hideOnTargetClick: typeof options.hideOnTargetClick !== "undefined" ? options.hideOnTargetClick : directive.options.defaultHideOnTargetClick,
    loadingClass: typeof options.loadingClass !== "undefined" ? options.loadingClass : directive.options.defaultLoadingClass,
    loadingContent: typeof options.loadingContent !== "undefined" ? options.loadingContent : directive.options.defaultLoadingContent,
    popperOptions: _objectSpread$1({}, typeof options.popperOptions !== "undefined" ? options.popperOptions : directive.options.defaultPopperOptions)
  };
  if (result.offset) {
    var typeofOffset = _typeof(result.offset);
    var offset2 = result.offset;
    if (typeofOffset === "number" || typeofOffset === "string" && offset2.indexOf(",") === -1) {
      offset2 = "0, ".concat(offset2);
    }
    if (!result.popperOptions.modifiers) {
      result.popperOptions.modifiers = {};
    }
    result.popperOptions.modifiers.offset = {
      offset: offset2
    };
  }
  if (result.trigger && result.trigger.indexOf("click") !== -1) {
    result.hideOnTargetClick = false;
  }
  return result;
}
function getPlacement(value, modifiers2) {
  var placement2 = value.placement;
  for (var i = 0; i < positions.length; i++) {
    var pos = positions[i];
    if (modifiers2[pos]) {
      placement2 = pos;
    }
  }
  return placement2;
}
function getContent(value) {
  var type = _typeof(value);
  if (type === "string") {
    return value;
  } else if (value && type === "object") {
    return value.content;
  } else {
    return false;
  }
}
function createTooltip(el, value) {
  var modifiers2 = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
  var content = getContent(value);
  var classes = typeof value.classes !== "undefined" ? value.classes : directive.options.defaultClass;
  var opts = _objectSpread$1({
    title: content
  }, getOptions(_objectSpread$1(_objectSpread$1({}, _typeof(value) === "object" ? value : {}), {}, {
    placement: getPlacement(value, modifiers2)
  })));
  var tooltip = el._tooltip = new Tooltip(el, opts);
  tooltip.setClasses(classes);
  tooltip._vueEl = el;
  var targetClasses = typeof value.targetClasses !== "undefined" ? value.targetClasses : directive.options.defaultTargetClass;
  el._tooltipTargetClasses = targetClasses;
  addClasses(el, targetClasses);
  return tooltip;
}
function destroyTooltip(el) {
  if (el._tooltip) {
    el._tooltip.dispose();
    delete el._tooltip;
    delete el._tooltipOldShow;
  }
  if (el._tooltipTargetClasses) {
    removeClasses(el, el._tooltipTargetClasses);
    delete el._tooltipTargetClasses;
  }
}
function bind(el, _ref) {
  var value = _ref.value;
  _ref.oldValue;
  var modifiers2 = _ref.modifiers;
  var content = getContent(value);
  if (!content || !state.enabled) {
    destroyTooltip(el);
  } else {
    var tooltip;
    if (el._tooltip) {
      tooltip = el._tooltip;
      tooltip.setContent(content);
      tooltip.setOptions(_objectSpread$1(_objectSpread$1({}, value), {}, {
        placement: getPlacement(value, modifiers2)
      }));
    } else {
      tooltip = createTooltip(el, value, modifiers2);
    }
    if (typeof value.show !== "undefined" && value.show !== el._tooltipOldShow) {
      el._tooltipOldShow = value.show;
      value.show ? tooltip.show() : tooltip.hide();
    }
  }
}
var directive = {
  options: defaultOptions,
  bind,
  update: bind,
  unbind: function unbind(el) {
    destroyTooltip(el);
  }
};
function addListeners(el) {
  el.addEventListener("click", onClick);
  el.addEventListener("touchstart", onTouchStart, supportsPassive ? {
    passive: true
  } : false);
}
function removeListeners(el) {
  el.removeEventListener("click", onClick);
  el.removeEventListener("touchstart", onTouchStart);
  el.removeEventListener("touchend", onTouchEnd);
  el.removeEventListener("touchcancel", onTouchCancel);
}
function onClick(event) {
  var el = event.currentTarget;
  event.closePopover = !el.$_vclosepopover_touch;
  event.closeAllPopover = el.$_closePopoverModifiers && !!el.$_closePopoverModifiers.all;
}
function onTouchStart(event) {
  if (event.changedTouches.length === 1) {
    var el = event.currentTarget;
    el.$_vclosepopover_touch = true;
    var touch = event.changedTouches[0];
    el.$_vclosepopover_touchPoint = touch;
    el.addEventListener("touchend", onTouchEnd);
    el.addEventListener("touchcancel", onTouchCancel);
  }
}
function onTouchEnd(event) {
  var el = event.currentTarget;
  el.$_vclosepopover_touch = false;
  if (event.changedTouches.length === 1) {
    var touch = event.changedTouches[0];
    var firstTouch = el.$_vclosepopover_touchPoint;
    event.closePopover = Math.abs(touch.screenY - firstTouch.screenY) < 20 && Math.abs(touch.screenX - firstTouch.screenX) < 20;
    event.closeAllPopover = el.$_closePopoverModifiers && !!el.$_closePopoverModifiers.all;
  }
}
function onTouchCancel(event) {
  var el = event.currentTarget;
  el.$_vclosepopover_touch = false;
}
var vclosepopover = {
  bind: function bind2(el, _ref) {
    var value = _ref.value, modifiers2 = _ref.modifiers;
    el.$_closePopoverModifiers = modifiers2;
    if (typeof value === "undefined" || value) {
      addListeners(el);
    }
  },
  update: function update2(el, _ref2) {
    var value = _ref2.value, oldValue = _ref2.oldValue, modifiers2 = _ref2.modifiers;
    el.$_closePopoverModifiers = modifiers2;
    if (value !== oldValue) {
      if (typeof value === "undefined" || value) {
        addListeners(el);
      } else {
        removeListeners(el);
      }
    }
  },
  unbind: function unbind2(el) {
    removeListeners(el);
  }
};
function ownKeys2(object, enumerableOnly) {
  var keys3 = Object.keys(object);
  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly)
      symbols = symbols.filter(function(sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });
    keys3.push.apply(keys3, symbols);
  }
  return keys3;
}
function _objectSpread(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};
    if (i % 2) {
      ownKeys2(Object(source), true).forEach(function(key) {
        _defineProperty$1(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys2(Object(source)).forEach(function(key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }
  return target;
}
function getDefault(key) {
  var value = directive.options.popover[key];
  if (typeof value === "undefined") {
    return directive.options[key];
  }
  return value;
}
var isIOS = false;
if (typeof window !== "undefined" && typeof navigator !== "undefined") {
  isIOS = /iPad|iPhone|iPod/.test(navigator.userAgent) && !window.MSStream;
}
var openPopovers = [];
var Element$1 = function Element2() {
};
if (typeof window !== "undefined") {
  Element$1 = window.Element;
}
var script = {
  name: "VPopover",
  components: {
    ResizeObserver: __vue_component__$1
  },
  props: {
    open: {
      type: Boolean,
      default: false
    },
    disabled: {
      type: Boolean,
      default: false
    },
    placement: {
      type: String,
      default: function _default() {
        return getDefault("defaultPlacement");
      }
    },
    delay: {
      type: [String, Number, Object],
      default: function _default2() {
        return getDefault("defaultDelay");
      }
    },
    offset: {
      type: [String, Number],
      default: function _default3() {
        return getDefault("defaultOffset");
      }
    },
    trigger: {
      type: String,
      default: function _default4() {
        return getDefault("defaultTrigger");
      }
    },
    container: {
      type: [String, Object, Element$1, Boolean],
      default: function _default5() {
        return getDefault("defaultContainer");
      }
    },
    boundariesElement: {
      type: [String, Element$1],
      default: function _default6() {
        return getDefault("defaultBoundariesElement");
      }
    },
    popperOptions: {
      type: Object,
      default: function _default7() {
        return getDefault("defaultPopperOptions");
      }
    },
    popoverClass: {
      type: [String, Array],
      default: function _default8() {
        return getDefault("defaultClass");
      }
    },
    popoverBaseClass: {
      type: [String, Array],
      default: function _default9() {
        return directive.options.popover.defaultBaseClass;
      }
    },
    popoverInnerClass: {
      type: [String, Array],
      default: function _default10() {
        return directive.options.popover.defaultInnerClass;
      }
    },
    popoverWrapperClass: {
      type: [String, Array],
      default: function _default11() {
        return directive.options.popover.defaultWrapperClass;
      }
    },
    popoverArrowClass: {
      type: [String, Array],
      default: function _default12() {
        return directive.options.popover.defaultArrowClass;
      }
    },
    autoHide: {
      type: Boolean,
      default: function _default13() {
        return directive.options.popover.defaultAutoHide;
      }
    },
    handleResize: {
      type: Boolean,
      default: function _default14() {
        return directive.options.popover.defaultHandleResize;
      }
    },
    openGroup: {
      type: String,
      default: null
    },
    openClass: {
      type: [String, Array],
      default: function _default15() {
        return directive.options.popover.defaultOpenClass;
      }
    },
    ariaId: {
      default: null
    }
  },
  data: function data2() {
    return {
      isOpen: false,
      id: Math.random().toString(36).substr(2, 10)
    };
  },
  computed: {
    cssClass: function cssClass() {
      return _defineProperty$1({}, this.openClass, this.isOpen);
    },
    popoverId: function popoverId() {
      return "popover_".concat(this.ariaId != null ? this.ariaId : this.id);
    }
  },
  watch: {
    open: function open(val) {
      if (val) {
        this.show();
      } else {
        this.hide();
      }
    },
    disabled: function disabled(val, oldVal) {
      if (val !== oldVal) {
        if (val) {
          this.hide();
        } else if (this.open) {
          this.show();
        }
      }
    },
    container: function container2(val) {
      if (this.isOpen && this.popperInstance) {
        var popoverNode = this.$refs.popover;
        var reference = this.$refs.trigger;
        var container3 = this.$_findContainer(this.container, reference);
        if (!container3) {
          console.warn("No container for popover", this);
          return;
        }
        container3.appendChild(popoverNode);
        this.popperInstance.scheduleUpdate();
      }
    },
    trigger: function trigger(val) {
      this.$_removeEventListeners();
      this.$_addEventListeners();
    },
    placement: function placement(val) {
      var _this = this;
      this.$_updatePopper(function() {
        _this.popperInstance.options.placement = val;
      });
    },
    offset: "$_restartPopper",
    boundariesElement: "$_restartPopper",
    popperOptions: {
      handler: "$_restartPopper",
      deep: true
    }
  },
  created: function created() {
    this.$_isDisposed = false;
    this.$_mounted = false;
    this.$_events = [];
    this.$_preventOpen = false;
  },
  mounted: function mounted2() {
    var popoverNode = this.$refs.popover;
    popoverNode.parentNode && popoverNode.parentNode.removeChild(popoverNode);
    this.$_init();
    if (this.open) {
      this.show();
    }
  },
  deactivated: function deactivated() {
    this.hide();
  },
  beforeDestroy: function beforeDestroy2() {
    this.dispose();
  },
  methods: {
    show: function show() {
      var _this2 = this;
      var _ref2 = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {}, event = _ref2.event;
      _ref2.skipDelay;
      var _ref2$force = _ref2.force, force = _ref2$force === void 0 ? false : _ref2$force;
      if (force || !this.disabled) {
        this.$_scheduleShow(event);
        this.$emit("show");
      }
      this.$emit("update:open", true);
      this.$_beingShowed = true;
      requestAnimationFrame(function() {
        _this2.$_beingShowed = false;
      });
    },
    hide: function hide2() {
      var _ref3 = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {}, event = _ref3.event;
      _ref3.skipDelay;
      this.$_scheduleHide(event);
      this.$emit("hide");
      this.$emit("update:open", false);
    },
    dispose: function dispose() {
      this.$_isDisposed = true;
      this.$_removeEventListeners();
      this.hide({
        skipDelay: true
      });
      if (this.popperInstance) {
        this.popperInstance.destroy();
        if (!this.popperInstance.options.removeOnDestroy) {
          var popoverNode = this.$refs.popover;
          popoverNode.parentNode && popoverNode.parentNode.removeChild(popoverNode);
        }
      }
      this.$_mounted = false;
      this.popperInstance = null;
      this.isOpen = false;
      this.$emit("dispose");
    },
    $_init: function $_init() {
      if (this.trigger.indexOf("manual") === -1) {
        this.$_addEventListeners();
      }
    },
    $_show: function $_show() {
      var _this3 = this;
      var reference = this.$refs.trigger;
      var popoverNode = this.$refs.popover;
      clearTimeout(this.$_disposeTimer);
      if (this.isOpen) {
        return;
      }
      if (this.popperInstance) {
        this.isOpen = true;
        this.popperInstance.enableEventListeners();
        this.popperInstance.scheduleUpdate();
      }
      if (!this.$_mounted) {
        var container3 = this.$_findContainer(this.container, reference);
        if (!container3) {
          console.warn("No container for popover", this);
          return;
        }
        container3.appendChild(popoverNode);
        this.$_mounted = true;
        this.isOpen = false;
        if (this.popperInstance) {
          requestAnimationFrame(function() {
            if (!_this3.hidden) {
              _this3.isOpen = true;
            }
          });
        }
      }
      if (!this.popperInstance) {
        var popperOptions = _objectSpread(_objectSpread({}, this.popperOptions), {}, {
          placement: this.placement
        });
        popperOptions.modifiers = _objectSpread(_objectSpread({}, popperOptions.modifiers), {}, {
          arrow: _objectSpread(_objectSpread({}, popperOptions.modifiers && popperOptions.modifiers.arrow), {}, {
            element: this.$refs.arrow
          })
        });
        if (this.offset) {
          var offset2 = this.$_getOffset();
          popperOptions.modifiers.offset = _objectSpread(_objectSpread({}, popperOptions.modifiers && popperOptions.modifiers.offset), {}, {
            offset: offset2
          });
        }
        if (this.boundariesElement) {
          popperOptions.modifiers.preventOverflow = _objectSpread(_objectSpread({}, popperOptions.modifiers && popperOptions.modifiers.preventOverflow), {}, {
            boundariesElement: this.boundariesElement
          });
        }
        this.popperInstance = new Popper$1(reference, popoverNode, popperOptions);
        requestAnimationFrame(function() {
          if (_this3.hidden) {
            _this3.hidden = false;
            _this3.$_hide();
            return;
          }
          if (!_this3.$_isDisposed && _this3.popperInstance) {
            _this3.popperInstance.scheduleUpdate();
            requestAnimationFrame(function() {
              if (_this3.hidden) {
                _this3.hidden = false;
                _this3.$_hide();
                return;
              }
              if (!_this3.$_isDisposed) {
                _this3.isOpen = true;
              } else {
                _this3.dispose();
              }
            });
          } else {
            _this3.dispose();
          }
        });
      }
      var openGroup = this.openGroup;
      if (openGroup) {
        var popover;
        for (var i = 0; i < openPopovers.length; i++) {
          popover = openPopovers[i];
          if (popover.openGroup !== openGroup) {
            popover.hide();
            popover.$emit("close-group");
          }
        }
      }
      openPopovers.push(this);
      this.$emit("apply-show");
    },
    $_hide: function $_hide() {
      var _this4 = this;
      if (!this.isOpen) {
        return;
      }
      var index = openPopovers.indexOf(this);
      if (index !== -1) {
        openPopovers.splice(index, 1);
      }
      this.isOpen = false;
      if (this.popperInstance) {
        this.popperInstance.disableEventListeners();
      }
      clearTimeout(this.$_disposeTimer);
      var disposeTime = directive.options.popover.disposeTimeout || directive.options.disposeTimeout;
      if (disposeTime !== null) {
        this.$_disposeTimer = setTimeout(function() {
          var popoverNode = _this4.$refs.popover;
          if (popoverNode) {
            popoverNode.parentNode && popoverNode.parentNode.removeChild(popoverNode);
            _this4.$_mounted = false;
          }
        }, disposeTime);
      }
      this.$emit("apply-hide");
    },
    $_findContainer: function $_findContainer(container3, reference) {
      if (typeof container3 === "string") {
        container3 = window.document.querySelector(container3);
      } else if (container3 === false) {
        container3 = reference.parentNode;
      }
      return container3;
    },
    $_getOffset: function $_getOffset() {
      var typeofOffset = _typeof(this.offset);
      var offset2 = this.offset;
      if (typeofOffset === "number" || typeofOffset === "string" && offset2.indexOf(",") === -1) {
        offset2 = "0, ".concat(offset2);
      }
      return offset2;
    },
    $_addEventListeners: function $_addEventListeners() {
      var _this5 = this;
      var reference = this.$refs.trigger;
      var directEvents = [];
      var oppositeEvents = [];
      var events = typeof this.trigger === "string" ? this.trigger.split(" ").filter(function(trigger2) {
        return ["click", "hover", "focus"].indexOf(trigger2) !== -1;
      }) : [];
      events.forEach(function(event) {
        switch (event) {
          case "hover":
            directEvents.push("mouseenter");
            oppositeEvents.push("mouseleave");
            break;
          case "focus":
            directEvents.push("focus");
            oppositeEvents.push("blur");
            break;
          case "click":
            directEvents.push("click");
            oppositeEvents.push("click");
            break;
        }
      });
      directEvents.forEach(function(event) {
        var func = function func2(event2) {
          if (_this5.isOpen) {
            return;
          }
          event2.usedByTooltip = true;
          !_this5.$_preventOpen && _this5.show({
            event: event2
          });
          _this5.hidden = false;
        };
        _this5.$_events.push({
          event,
          func
        });
        reference.addEventListener(event, func);
      });
      oppositeEvents.forEach(function(event) {
        var func = function func2(event2) {
          if (event2.usedByTooltip) {
            return;
          }
          _this5.hide({
            event: event2
          });
          _this5.hidden = true;
        };
        _this5.$_events.push({
          event,
          func
        });
        reference.addEventListener(event, func);
      });
    },
    $_scheduleShow: function $_scheduleShow() {
      var skipDelay = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      clearTimeout(this.$_scheduleTimer);
      if (skipDelay) {
        this.$_show();
      } else {
        var computedDelay = parseInt(this.delay && this.delay.show || this.delay || 0);
        this.$_scheduleTimer = setTimeout(this.$_show.bind(this), computedDelay);
      }
    },
    $_scheduleHide: function $_scheduleHide() {
      var _this6 = this;
      var event = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : null;
      var skipDelay = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      clearTimeout(this.$_scheduleTimer);
      if (skipDelay) {
        this.$_hide();
      } else {
        var computedDelay = parseInt(this.delay && this.delay.hide || this.delay || 0);
        this.$_scheduleTimer = setTimeout(function() {
          if (!_this6.isOpen) {
            return;
          }
          if (event && event.type === "mouseleave") {
            var isSet = _this6.$_setTooltipNodeEvent(event);
            if (isSet) {
              return;
            }
          }
          _this6.$_hide();
        }, computedDelay);
      }
    },
    $_setTooltipNodeEvent: function $_setTooltipNodeEvent(event) {
      var _this7 = this;
      var reference = this.$refs.trigger;
      var popoverNode = this.$refs.popover;
      var relatedreference = event.relatedreference || event.toElement || event.relatedTarget;
      var callback = function callback2(event2) {
        var relatedreference2 = event2.relatedreference || event2.toElement || event2.relatedTarget;
        popoverNode.removeEventListener(event.type, callback2);
        if (!reference.contains(relatedreference2)) {
          _this7.hide({
            event: event2
          });
        }
      };
      if (popoverNode.contains(relatedreference)) {
        popoverNode.addEventListener(event.type, callback);
        return true;
      }
      return false;
    },
    $_removeEventListeners: function $_removeEventListeners() {
      var reference = this.$refs.trigger;
      this.$_events.forEach(function(_ref4) {
        var func = _ref4.func, event = _ref4.event;
        reference.removeEventListener(event, func);
      });
      this.$_events = [];
    },
    $_updatePopper: function $_updatePopper(cb) {
      if (this.popperInstance) {
        cb();
        if (this.isOpen)
          this.popperInstance.scheduleUpdate();
      }
    },
    $_restartPopper: function $_restartPopper() {
      if (this.popperInstance) {
        var isOpen = this.isOpen;
        this.dispose();
        this.$_isDisposed = false;
        this.$_init();
        if (isOpen) {
          this.show({
            skipDelay: true,
            force: true
          });
        }
      }
    },
    $_handleGlobalClose: function $_handleGlobalClose(event) {
      var _this8 = this;
      var touch = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      if (this.$_beingShowed)
        return;
      this.hide({
        event
      });
      if (event.closePopover) {
        this.$emit("close-directive");
      } else {
        this.$emit("auto-hide");
      }
      if (touch) {
        this.$_preventOpen = true;
        setTimeout(function() {
          _this8.$_preventOpen = false;
        }, 300);
      }
    },
    $_handleResize: function $_handleResize() {
      if (this.isOpen && this.popperInstance) {
        this.popperInstance.scheduleUpdate();
        this.$emit("resize");
      }
    }
  }
};
if (typeof document !== "undefined" && typeof window !== "undefined") {
  if (isIOS) {
    document.addEventListener("touchend", handleGlobalTouchend, supportsPassive ? {
      passive: true,
      capture: true
    } : true);
  } else {
    window.addEventListener("click", handleGlobalClick, true);
  }
}
function handleGlobalClick(event) {
  handleGlobalClose(event);
}
function handleGlobalTouchend(event) {
  handleGlobalClose(event, true);
}
function handleGlobalClose(event) {
  var touch = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
  var _loop = function _loop2(i2) {
    var popover = openPopovers[i2];
    if (popover.$refs.popover) {
      var contains = popover.$refs.popover.contains(event.target);
      requestAnimationFrame(function() {
        if (event.closeAllPopover || event.closePopover && contains || popover.autoHide && !contains) {
          popover.$_handleGlobalClose(event, touch);
        }
      });
    }
  };
  for (var i = 0; i < openPopovers.length; i++) {
    _loop(i);
  }
}
function normalizeComponent(template, style, script2, scopeId, isFunctionalTemplate, moduleIdentifier, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
  if (typeof shadowMode !== "boolean") {
    createInjectorSSR = createInjector;
    createInjector = shadowMode;
    shadowMode = false;
  }
  const options = typeof script2 === "function" ? script2.options : script2;
  if (template && template.render) {
    options.render = template.render;
    options.staticRenderFns = template.staticRenderFns;
    options._compiled = true;
    if (isFunctionalTemplate) {
      options.functional = true;
    }
  }
  if (scopeId) {
    options._scopeId = scopeId;
  }
  let hook;
  if (moduleIdentifier) {
    hook = function(context) {
      context = context || this.$vnode && this.$vnode.ssrContext || this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (style) {
        style.call(this, createInjectorSSR(context));
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (style) {
    hook = shadowMode ? function(context) {
      style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
    } : function(context) {
      style.call(this, createInjector(context));
    };
  }
  if (hook) {
    if (options.functional) {
      const originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      const existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return script2;
}
var __vue_script__ = script;
var __vue_render__2 = function __vue_render__3() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "v-popover",
    class: _vm.cssClass
  }, [_c("div", {
    ref: "trigger",
    staticClass: "trigger",
    staticStyle: {
      display: "inline-block"
    },
    attrs: {
      "aria-describedby": _vm.isOpen ? _vm.popoverId : void 0,
      tabindex: _vm.trigger.indexOf("focus") !== -1 ? 0 : void 0
    }
  }, [_vm._t("default")], 2), _vm._v(" "), _c("div", {
    ref: "popover",
    class: [_vm.popoverBaseClass, _vm.popoverClass, _vm.cssClass],
    style: {
      visibility: _vm.isOpen ? "visible" : "hidden"
    },
    attrs: {
      id: _vm.popoverId,
      "aria-hidden": _vm.isOpen ? "false" : "true",
      tabindex: _vm.autoHide ? 0 : void 0
    },
    on: {
      keyup: function keyup($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "esc", 27, $event.key, ["Esc", "Escape"])) {
          return null;
        }
        _vm.autoHide && _vm.hide();
      }
    }
  }, [_c("div", {
    class: _vm.popoverWrapperClass
  }, [_c("div", {
    ref: "inner",
    class: _vm.popoverInnerClass,
    staticStyle: {
      position: "relative"
    }
  }, [_c("div", [_vm._t("popover", null, {
    isOpen: _vm.isOpen
  })], 2), _vm._v(" "), _vm.handleResize ? _c("ResizeObserver", {
    on: {
      notify: _vm.$_handleResize
    }
  }) : _vm._e()], 1), _vm._v(" "), _c("div", {
    ref: "arrow",
    class: _vm.popoverArrowClass
  })])])]);
};
var __vue_staticRenderFns__ = [];
__vue_render__2._withStripped = true;
var __vue_inject_styles__ = void 0;
var __vue_scope_id__ = void 0;
var __vue_module_identifier__ = void 0;
var __vue_is_functional_template__ = false;
var __vue_component__ = /* @__PURE__ */ normalizeComponent({
  render: __vue_render__2,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__, __vue_module_identifier__, false, void 0, void 0, void 0);
function styleInject(css, ref) {
  if (ref === void 0)
    ref = {};
  var insertAt = ref.insertAt;
  if (!css || typeof document === "undefined") {
    return;
  }
  var head = document.head || document.getElementsByTagName("head")[0];
  var style = document.createElement("style");
  style.type = "text/css";
  if (insertAt === "top") {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }
  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}
var css_248z = ".resize-observer[data-v-8859cc6c]{position:absolute;top:0;left:0;z-index:-1;width:100%;height:100%;border:none;background-color:transparent;pointer-events:none;display:block;overflow:hidden;opacity:0}.resize-observer[data-v-8859cc6c] object{display:block;position:absolute;top:0;left:0;height:100%;width:100%;overflow:hidden;pointer-events:none;z-index:-1}";
styleInject(css_248z);
function install(Vue2) {
  var options = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
  if (install.installed)
    return;
  install.installed = true;
  var finalOptions = {};
  merge_1(finalOptions, defaultOptions, options);
  plugin.options = finalOptions;
  directive.options = finalOptions;
  Vue2.directive("tooltip", directive);
  Vue2.directive("close-popover", vclosepopover);
  Vue2.component("VPopover", __vue_component__);
}
var VTooltip = directive;
var VClosePopover = vclosepopover;
var VPopover = __vue_component__;
var plugin = {
  install,
  get enabled() {
    return state.enabled;
  },
  set enabled(value) {
    state.enabled = value;
  }
};
var GlobalVue = null;
if (typeof window !== "undefined") {
  GlobalVue = window.Vue;
} else if (typeof global !== "undefined") {
  GlobalVue = global.Vue;
}
if (GlobalVue) {
  GlobalVue.use(plugin);
}
var vTooltip_esm = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  "default": plugin,
  VClosePopover,
  VPopover,
  VTooltip,
  createTooltip,
  destroyTooltip,
  install
}, Symbol.toStringTag, { value: "Module" }));
var require$$1 = /* @__PURE__ */ getAugmentedNamespace(vTooltip_esm);
/*! For license information please see Actions.js.LICENSE.txt */
(function(module, exports) {
  !function(e, t) {
    module.exports = t();
  }(self, function() {
    return function() {
      var e = { 858: function(e2, t2, n2) {
        var a2 = n2(3251), i = n2.n(a2), o = n2(8104), r = n2(9040), s = n2(1205), l = n2(932), c = n2(8099);
        function u(e3, t3) {
          (t3 == null || t3 > e3.length) && (t3 = e3.length);
          for (var n3 = 0, a3 = new Array(t3); n3 < t3; n3++)
            a3[n3] = e3[n3];
          return a3;
        }
        function d(e3, t3) {
          var n3 = Object.keys(e3);
          if (Object.getOwnPropertySymbols) {
            var a3 = Object.getOwnPropertySymbols(e3);
            t3 && (a3 = a3.filter(function(t4) {
              return Object.getOwnPropertyDescriptor(e3, t4).enumerable;
            })), n3.push.apply(n3, a3);
          }
          return n3;
        }
        function m(e3) {
          for (var t3 = 1; t3 < arguments.length; t3++) {
            var n3 = arguments[t3] != null ? arguments[t3] : {};
            t3 % 2 ? d(Object(n3), true).forEach(function(t4) {
              g(e3, t4, n3[t4]);
            }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e3, Object.getOwnPropertyDescriptors(n3)) : d(Object(n3)).forEach(function(t4) {
              Object.defineProperty(e3, t4, Object.getOwnPropertyDescriptor(n3, t4));
            });
          }
          return e3;
        }
        function g(e3, t3, n3) {
          return t3 in e3 ? Object.defineProperty(e3, t3, { value: n3, enumerable: true, configurable: true, writable: true }) : e3[t3] = n3, e3;
        }
        var p = ".focusable";
        t2.Z = { name: "Actions", directives: { tooltip: r.default }, components: { DotsHorizontal: i(), Popover: c.default, VNodes: o.Z }, props: { open: { type: Boolean, default: false }, forceMenu: { type: Boolean, default: false }, forceTitle: { type: Boolean, default: false }, menuTitle: { type: String, default: null }, primary: { type: Boolean, default: false }, defaultIcon: { type: String, default: "" }, ariaLabel: { type: String, default: (0, l.t)("Actions") }, placement: { type: String, default: "bottom" }, boundariesElement: { type: Element, default: function() {
          return document.querySelector("body");
        } }, container: { type: String, default: "body" }, disabled: { type: Boolean, default: false } }, data: function() {
          return { actions: [], opened: this.open, focusIndex: 0, randomId: "menu-" + (0, s.Z)(), children: this.$children, firstAction: {} };
        }, computed: { hasMultipleActions: function() {
          return this.actions.length > 1;
        }, isValidSingleAction: function() {
          return this.actions.length === 1 && this.firstActionElement !== null;
        }, singleActionTitle: function() {
          return this.forceTitle ? this.menuTitle : "";
        }, isDisabled: function() {
          var e3, t3;
          return this.disabled || this.actions.length === 1 && ((e3 = this.firstAction) === null || e3 === void 0 || (t3 = e3.$props) === null || t3 === void 0 ? void 0 : t3.disabled);
        }, firstActionVNode: function() {
          return this.actions[0];
        }, firstActionBinding: function() {
          if (this.firstActionVNode && this.firstActionVNode.componentOptions) {
            var e3 = this.firstActionVNode.componentOptions.tag;
            if (e3 === "ActionLink")
              return m(m({ is: "a", href: this.firstAction.href, target: this.firstAction.target, "aria-label": this.firstAction.ariaLabel }, this.firstAction.$attrs), this.firstAction.$props);
            if (e3 === "ActionRouter")
              return m(m({ is: "router-link", to: this.firstAction.to, exact: this.firstAction.exact, "aria-label": this.firstAction.ariaLabel }, this.firstAction.$attrs), this.firstAction.$props);
            if (e3 === "ActionButton")
              return m(m({ is: "button", "aria-label": this.firstAction.ariaLabel }, this.firstAction.$attrs), this.firstAction.$props);
          }
          return null;
        }, firstActionEvent: function() {
          var e3, t3, n3;
          return (e3 = this.firstActionVNode) === null || e3 === void 0 || (t3 = e3.componentOptions) === null || t3 === void 0 || (n3 = t3.listeners) === null || n3 === void 0 ? void 0 : n3.click;
        }, firstActionEventBinding: function() {
          return this.firstActionEvent ? "click" : null;
        }, firstActionIconSlot: function() {
          var e3, t3;
          return (e3 = this.firstAction) === null || e3 === void 0 || (t3 = e3.$slots) === null || t3 === void 0 ? void 0 : t3.icon;
        }, firstActionClass: function() {
          return ((this.firstActionVNode && this.firstActionVNode.data.staticClass) + " " + (this.firstActionVNode && this.firstActionVNode.data.class)).trim();
        }, iconSlotIsPopulated: function() {
          return !!this.$slots.icon;
        } }, watch: { open: function(e3) {
          e3 !== this.opened && (this.opened = e3);
        }, children: function() {
          this.firstAction = this.children[0] ? this.children[0] : {};
        } }, beforeMount: function() {
          this.initActions();
        }, beforeUpdate: function() {
          this.initActions();
        }, methods: { openMenu: function(e3) {
          this.opened || (this.opened = true, this.$emit("update:open", true), this.$emit("open"));
        }, closeMenu: function(e3) {
          this.opened && (this.opened = false, this.$emit("update:open", false), this.$emit("close"), this.opened = false, this.focusIndex = 0, this.$refs.menuButton.focus());
        }, onOpen: function(e3) {
          var t3 = this;
          this.$nextTick(function() {
            t3.focusFirstAction(e3);
          });
        }, onMouseFocusAction: function(e3) {
          if (document.activeElement !== e3.target) {
            var t3 = e3.target.closest("li");
            if (t3) {
              var n3 = t3.querySelector(p);
              if (n3) {
                var a3 = (i2 = this.$refs.menu.querySelectorAll(p), function(e4) {
                  if (Array.isArray(e4))
                    return u(e4);
                }(i2) || function(e4) {
                  if (typeof Symbol != "undefined" && e4[Symbol.iterator] != null || e4["@@iterator"] != null)
                    return Array.from(e4);
                }(i2) || function(e4, t4) {
                  if (e4) {
                    if (typeof e4 == "string")
                      return u(e4, t4);
                    var n4 = Object.prototype.toString.call(e4).slice(8, -1);
                    return n4 === "Object" && e4.constructor && (n4 = e4.constructor.name), n4 === "Map" || n4 === "Set" ? Array.from(e4) : n4 === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n4) ? u(e4, t4) : void 0;
                  }
                }(i2) || function() {
                  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
                }()).indexOf(n3);
                a3 > -1 && (this.focusIndex = a3, this.focusAction());
              }
            }
          }
          var i2;
        }, removeCurrentActive: function() {
          var e3 = this.$refs.menu.querySelector("li.active");
          e3 && e3.classList.remove("active");
        }, focusAction: function() {
          var e3 = this.$refs.menu.querySelectorAll(p)[this.focusIndex];
          if (e3) {
            this.removeCurrentActive();
            var t3 = e3.closest("li.action");
            e3.focus(), t3 && t3.classList.add("active");
          }
        }, focusPreviousAction: function(e3) {
          this.opened && (this.focusIndex === 0 ? this.closeMenu() : (this.preventIfEvent(e3), this.focusIndex = this.focusIndex - 1), this.focusAction());
        }, focusNextAction: function(e3) {
          if (this.opened) {
            var t3 = this.$refs.menu.querySelectorAll(p).length - 1;
            this.focusIndex === t3 ? this.closeMenu() : (this.preventIfEvent(e3), this.focusIndex = this.focusIndex + 1), this.focusAction();
          }
        }, focusFirstAction: function(e3) {
          this.opened && (this.preventIfEvent(e3), this.focusIndex = 0, this.focusAction());
        }, focusLastAction: function(e3) {
          this.opened && (this.preventIfEvent(e3), this.focusIndex = this.$el.querySelectorAll(p).length - 1, this.focusAction());
        }, preventIfEvent: function(e3) {
          e3 && (e3.preventDefault(), e3.stopPropagation());
        }, execFirstAction: function(e3) {
          this.firstActionEvent && this.firstActionEvent(e3);
        }, initActions: function() {
          this.actions = (this.$slots.default || []).filter(function(e3) {
            return !!e3 && !!e3.componentOptions;
          });
        }, onFocus: function(e3) {
          this.$emit("focus", e3);
        }, onBlur: function(e3) {
          this.$emit("blur", e3);
        } } };
      }, 5041: function(e2, t2) {
        t2.Z = { name: "VNodes", functional: true, render: function(e3, t3) {
          return t3.props.vnodes;
        } };
      }, 8099: function(e2, t2, n2) {
        var a2 = n2(7020);
        t2.default = a2.Z;
      }, 9040: function(e2, t2, n2) {
        n2.d(t2, { default: function() {
          return b;
        } });
        var a2 = n2(2965), i = n2(3379), o = n2.n(i), r = n2(7795), s = n2.n(r), l = n2(569), c = n2.n(l), u = n2(3565), d = n2.n(u), m = n2(9216), g = n2.n(m), p = n2(4589), h = n2.n(p), v = n2(6051), A = {};
        A.styleTagTransform = h(), A.setAttributes = d(), A.insert = c().bind(null, "head"), A.domAPI = s(), A.insertStyleElement = g(), o()(v.Z, A), v.Z && v.Z.locals && v.Z.locals, a2.VTooltip.options.defaultTemplate = '<div class="vue-tooltip" role="tooltip" data-v-'.concat("17fd6e1", '><div class="tooltip-arrow"></div><div class="tooltip-inner"></div></div>'), a2.VTooltip.options.defaultHtml = false, a2.VTooltip.options.defaultDelay = { show: 500, hide: 200 };
        var b = a2.VTooltip;
      }, 932: function(e2, t2, n2) {
        n2.d(t2, { t: function() {
          return o;
        } });
        var a2 = (0, n2(6036).getGettextBuilder)().detectLocale();
        [{ locale: "ar", translations: { "{tag} (invisible)": "{tag} (\u063A\u064A\u0631 \u0645\u0631\u0626\u064A)", "{tag} (restricted)": "{tag} (\u0645\u0642\u064A\u062F)", Actions: "\u0627\u0644\u0625\u062C\u0631\u0627\u0621\u0627\u062A", Activities: "\u0627\u0644\u0646\u0634\u0627\u0637\u0627\u062A", "Animals & Nature": "\u0627\u0644\u062D\u064A\u0648\u0627\u0646\u0627\u062A \u0648\u0627\u0644\u0637\u0628\u064A\u0639\u0629", "Avatar of {displayName}": "\u0635\u0648\u0631\u0629 {displayName} \u0627\u0644\u0631\u0645\u0632\u064A\u0629", "Avatar of {displayName}, {status}": "\u0635\u0648\u0631\u0629 {displayName} \u0627\u0644\u0631\u0645\u0632\u064A\u0629\u060C {status}", "Cancel changes": "\u0625\u0644\u063A\u0627\u0621 \u0627\u0644\u062A\u063A\u064A\u064A\u0631\u0627\u062A", Choose: "\u0625\u062E\u062A\u064A\u0627\u0631", Close: "\u0623\u063A\u0644\u0642", "Close navigation": "\u0625\u063A\u0644\u0627\u0642 \u0627\u0644\u0645\u062A\u0635\u0641\u062D", "Confirm changes": "\u062A\u0623\u0643\u064A\u062F \u0627\u0644\u062A\u063A\u064A\u064A\u0631\u0627\u062A", Custom: "\u0645\u062E\u0635\u0635", "Edit item": "\u062A\u0639\u062F\u064A\u0644 \u0639\u0646\u0635\u0631", "External documentation for {title}": "\u0627\u0644\u0648\u062B\u0627\u0626\u0642 \u0627\u0644\u062E\u0627\u0631\u062C\u064A\u0629 \u0644\u0640{title}", Flags: "\u0627\u0644\u0623\u0639\u0644\u0627\u0645", "Food & Drink": "\u0627\u0644\u0637\u0639\u0627\u0645 \u0648\u0627\u0644\u0634\u0631\u0627\u0628", "Frequently used": "\u0643\u062B\u064A\u0631\u0627 \u0645\u0627 \u062A\u0633\u062A\u062E\u062F\u0645", Global: "\u0639\u0627\u0644\u0645\u064A", "Go back to the list": "\u0627\u0644\u0639\u0648\u062F\u0629 \u0625\u0644\u0649 \u0627\u0644\u0642\u0627\u0626\u0645\u0629", "Message limit of {count} characters reached": "\u062A\u0645 \u0627\u0644\u0648\u0635\u0648\u0644 \u0625\u0644\u0649 \u0627\u0644\u062D\u062F \u0627\u0644\u0623\u0642\u0635\u0649 \u0644\u0639\u062F\u062F \u0627\u0644\u0623\u062D\u0631\u0641 \u0641\u064A \u0627\u0644\u0631\u0633\u0627\u0644\u0629: {count} \u062D\u0631\u0641", Next: "\u0627\u0644\u062A\u0627\u0644\u064A", "No emoji found": "\u0644\u0645 \u064A\u062A\u0645 \u0627\u0644\u0639\u062B\u0648\u0631 \u0639\u0644\u0649 \u0623\u064A \u0631\u0645\u0632 \u062A\u0639\u0628\u064A\u0631\u064A", "No results": "\u0644\u064A\u0633 \u0647\u0646\u0627\u0643 \u0623\u064A\u0629 \u0646\u062A\u064A\u062C\u0629", Objects: "\u0627\u0644\u0623\u0634\u064A\u0627\u0621", "Open navigation": "\u0641\u062A\u062D \u0627\u0644\u0645\u062A\u0635\u0641\u062D", "Pause slideshow": "\u0625\u064A\u0642\u0627\u0641 \u0627\u0644\u0639\u0631\u0636 \u0645\u0624\u0642\u062A\u064B\u0627", "People & Body": "\u0627\u0644\u0646\u0627\u0633 \u0648\u0627\u0644\u062C\u0633\u0645", "Pick an emoji": "\u0627\u062E\u062A\u0631 \u0631\u0645\u0632\u064B\u0627 \u062A\u0639\u0628\u064A\u0631\u064A\u064B\u0627", "Please select a time zone:": "\u0627\u0644\u0631\u062C\u0627\u0621 \u062A\u062D\u062F\u064A\u062F \u0627\u0644\u0645\u0646\u0637\u0642\u0629 \u0627\u0644\u0632\u0645\u0646\u064A\u0629:", Previous: "\u0627\u0644\u0633\u0627\u0628\u0642", Search: "\u0628\u062D\u062B", "Search results": "\u0646\u062A\u0627\u0626\u062C \u0627\u0644\u0628\u062D\u062B", "Select a tag": "\u0627\u062E\u062A\u0631 \u0639\u0644\u0627\u0645\u0629", Settings: "\u0627\u0644\u0625\u0639\u062F\u0627\u062F\u0627\u062A", "Settings navigation": "\u0625\u0639\u062F\u0627\u062F\u0627\u062A \u0627\u0644\u0645\u062A\u0635\u0641\u062D", "Smileys & Emotion": "\u0627\u0644\u0648\u062C\u0648\u0647 \u0648 \u0627\u0644\u0631\u0645\u0648\u0632 \u0627\u0644\u062A\u0639\u0628\u064A\u0631\u064A\u0629", "Start slideshow": "\u0628\u062F\u0621 \u0627\u0644\u0639\u0631\u0636", Submit: "\u0625\u0631\u0633\u0627\u0644", Symbols: "\u0627\u0644\u0631\u0645\u0648\u0632", "Travel & Places": "\u0627\u0644\u0633\u0641\u0631 \u0648\u0627\u0644\u0623\u0645\u0627\u0643\u0646", "Type to search time zone": "\u0627\u0643\u062A\u0628 \u0644\u0644\u0628\u062D\u062B \u0639\u0646 \u0645\u0646\u0637\u0642\u0629 \u0632\u0645\u0646\u064A\u0629", "Unable to search the group": "\u062A\u0639\u0630\u0631 \u0627\u0644\u0628\u062D\u062B \u0641\u064A \u0627\u0644\u0645\u062C\u0645\u0648\u0639\u0629", "Undo changes": "\u0627\u0644\u062A\u0631\u0627\u062C\u0639 \u0639\u0646 \u0627\u0644\u062A\u063A\u064A\u064A\u0631\u0627\u062A", "Write message, @ to mention someone, : for emoji autocompletion \u2026": "\u0627\u0643\u062A\u0628 \u0631\u0633\u0627\u0644\u0629\u060C @ \u0644\u0644\u0625\u0634\u0627\u0631\u0629 \u0625\u0644\u0649 \u0634\u062E\u0635 \u0645\u0627\u060C : \u0644\u0644\u0625\u0643\u0645\u0627\u0644 \u0627\u0644\u062A\u0644\u0642\u0627\u0626\u064A \u0644\u0644\u0631\u0645\u0648\u0632 \u0627\u0644\u062A\u0639\u0628\u064A\u0631\u064A\u0629 ..." } }, { locale: "br", translations: { "{tag} (invisible)": "{tag} (diwelus)", "{tag} (restricted)": "{tag} (bevennet)", Actions: "Oberio\xF9", Activities: "Oberiantizo\xF9", "Animals & Nature": "Loened & Natur", Choose: "Dibab", Close: "Serri\xF1", Custom: "Personela\xF1", Flags: "Bannielo\xF9", "Food & Drink": "Boued & Evajo\xF9", "Frequently used": "Implijet alies", Next: "Da heul", "No emoji found": "Emoji ebet kavet", "No results": "Disoc'h ebet", Objects: "Trao\xF9", "Pause slideshow": "Arsav an diaporama", "People & Body": "Tud & Korf", "Pick an emoji": "Choaz un emoji", Previous: "A-raok", Search: "Klask", "Search results": "Disoc'ho\xF9 an enklask", "Select a tag": "Choaz ur c'hlav", Settings: "Arventenno\xF9", "Smileys & Emotion": "Smileyio\xF9 & Fromo\xF9", "Start slideshow": "Kregi\xF1 an diaporama", Symbols: "Arouezio\xF9", "Travel & Places": "Beaj & Lec'hio\xF9", "Unable to search the group": "Dibosupl eo klask ar strollad" } }, { locale: "ca", translations: { "{tag} (invisible)": "{tag} (invisible)", "{tag} (restricted)": "{tag} (restringit)", Actions: "Accions", Activities: "Activitats", "Animals & Nature": "Animals i natura", "Avatar of {displayName}": "Avatar de {displayName}", "Avatar of {displayName}, {status}": "Avatar de {displayName}, {status}", "Cancel changes": "Cancel\xB7la els canvis", Choose: "Tria", Close: "Tanca", "Close navigation": "Tancar la navegaci\xF3", "Confirm changes": "Confirmeu els canvis", Custom: "Personalitzat", "Edit item": "Edita l'element", "External documentation for {title}": "Documentaci\xF3 externa per a {title}", Flags: "Marques", "Food & Drink": "Menjar i begudes", "Frequently used": "Utilitzats recentment", Global: "Global", "Go back to the list": "Torna a la llista", "Message limit of {count} characters reached": "S'ha arribat al l\xEDmit de {count} car\xE0cters per missatge", Next: "Seg\xFCent", "No emoji found": "No s'ha trobat cap emoji", "No results": "Sense resultats", Objects: "Objectes", "Open navigation": "Obrir la navegaci\xF3", "Pause slideshow": "Atura la presentaci\xF3", "People & Body": "Persones i cos", "Pick an emoji": "Trieu un emoji", "Please select a time zone:": "Seleccioneu una zona hor\xE0ria:", Previous: "Anterior", Search: "Cerca", "Search results": "Resultats de cerca", "Select a tag": "Selecciona una etiqueta", Settings: "Par\xE0metres", "Settings navigation": "Navegaci\xF3 d'opcions", "Smileys & Emotion": "Cares i emocions", "Start slideshow": "Inicia la presentaci\xF3", Submit: "Envia", Symbols: "S\xEDmbols", "Travel & Places": "Viatges i llocs", "Type to search time zone": "Escriviu per cercar la zona hor\xE0ria", "Unable to search the group": "No es pot cercar el grup", "Undo changes": "Desfer canvis", "Write message, @ to mention someone, : for emoji autocompletion \u2026": "Escriu un missatge, @ per esmentar alg\xFA, : per a la compleci\xF3 autom\xE0tica d'emojis..." } }, { locale: "cs_CZ", translations: { "{tag} (invisible)": "{tag} (neviditeln\xE9)", "{tag} (restricted)": "{tag} (omezen\xE9)", Actions: "Akce", Activities: "Aktivity", "Animals & Nature": "Zv\xED\u0159ata a p\u0159\xEDroda", "Avatar of {displayName}": "Z\xE1stupn\xFD obr\xE1zek u\u017Eivatele {displayName}", "Avatar of {displayName}, {status}": "Z\xE1stupn\xFD obr\xE1zek u\u017Eivatele {displayName}, {status}", "Cancel changes": "Zru\u0161it zm\u011Bny", Choose: "Zvolit", Close: "Zav\u0159\xEDt", "Close navigation": "Zav\u0159\xEDt navigaci", "Confirm changes": "Potvrdit zm\u011Bny", Custom: "U\u017Eivatelsky ur\u010Den\xE9", "Edit item": "Upravit polo\u017Eku", "External documentation for {title}": "Extern\xED dokumentace k {title}", Flags: "P\u0159\xEDznaky", "Food & Drink": "J\xEDdlo a pit\xED", "Frequently used": "\u010Casto pou\u017E\xEDvan\xE9", Global: "Glob\xE1ln\xED", "Go back to the list": "J\xEDt zp\u011Bt na seznam", "Message limit of {count} characters reached": "Dosa\u017Eeno limitu po\u010Dtu ({count}) znak\u016F zpr\xE1vy", Next: "N\xE1sleduj\xEDc\xED", "No emoji found": "Nenalezeno \u017E\xE1dn\xE9 emoji", "No results": "Nic nenalezeno", Objects: "Objekty", "Open navigation": "Otev\u0159\xEDt navigaci", "Pause slideshow": "Pozastavit prezentaci", "People & Body": "Lid\xE9 a t\u011Blo", "Pick an emoji": "Vybrat emoji", "Please select a time zone:": "Vyberte \u010Dasovou z\xF3nu:", Previous: "P\u0159edchoz\xED", Search: "Hledat", "Search results": "V\xFDsledky hled\xE1n\xED", "Select a tag": "Vybrat \u0161t\xEDtek", Settings: "Nastaven\xED", "Settings navigation": "Pohyb po nastaven\xED", "Smileys & Emotion": "\xDAsm\u011Bvy a emoce", "Start slideshow": "Spustit prezentaci", Submit: "Odeslat", Symbols: "Symboly", "Travel & Places": "Cestov\xE1n\xED a m\xEDsta", "Type to search time zone": "Psan\xEDm vyhledejte \u010Dasovou z\xF3nu", "Unable to search the group": "Neda\u0159\xED se hledat skupinu", "Undo changes": "Vz\xEDt zm\u011Bny zp\u011Bt", "Write message, @ to mention someone, : for emoji autocompletion \u2026": "Napi\u0161te zpr\xE1vu \u2013 pokud chcete n\u011Bkoho zm\xEDnit, napi\u0161te p\u0159ed jeho u\u017Eivatelsk\xFDm jm\xE9nem @ (zavin\xE1\u010D); automatick\xE9 dopl\u0148ov\xE1n\xED emotikon\u016F zah\xE1j\xEDte naps\xE1n\xEDm : (dvojte\u010Dky)\u2026" } }, { locale: "da", translations: { "{tag} (invisible)": "{tag} (usynlig)", "{tag} (restricted)": "{tag} (begr\xE6nset)", Actions: "Handlinger", Activities: "Aktiviteter", "Animals & Nature": "Dyr & Natur", Choose: "V\xE6lg", Close: "Luk", Custom: "Brugerdefineret", Flags: "Flag", "Food & Drink": "Mad & Drikke", "Frequently used": "Ofte brugt", "Message limit of {count} characters reached": "Begr\xE6nsning p\xE5 {count} tegn er n\xE5et", Next: "Videre", "No emoji found": "Ingen emoji fundet", "No results": "Ingen resultater", Objects: "Objekter", "Pause slideshow": "Suspender fremvisning", "People & Body": "Mennesker & Menneskekroppen", "Pick an emoji": "V\xE6lg en emoji", Previous: "Forrige", Search: "S\xF8g", "Search results": "S\xF8geresultater", "Select a tag": "V\xE6lg et m\xE6rke", Settings: "Indstillinger", "Settings navigation": "Naviger i indstillinger", "Smileys & Emotion": "Smileys & Emotion", "Start slideshow": "Start fremvisning", Symbols: "Symboler", "Travel & Places": "Rejser & Rejsem\xE5l", "Unable to search the group": "Kan ikke s\xF8ge p\xE5 denne gruppe", "Write message, @ to mention someone \u2026": "Skriv i meddelelse, @ for at n\xE6vne nogen  \u2026" } }, { locale: "de", translations: { "{tag} (invisible)": "{tag} (unsichtbar)", "{tag} (restricted)": "{tag} (eingeschr\xE4nkt)", Actions: "Aktionen", Activities: "Aktivit\xE4ten", "Animals & Nature": "Tiere & Natur", "Avatar of {displayName}": "Avatar von {displayName}", "Avatar of {displayName}, {status}": "Avatar von {displayName}, {status}", "Cancel changes": "\xC4nderungen verwerfen", Choose: "Ausw\xE4hlen", Close: "Schlie\xDFen", "Close navigation": "Navigation schlie\xDFen", "Confirm changes": "\xC4nderungen best\xE4tigen", Custom: "Benutzerdefiniert", "Edit item": "Objekt bearbeiten", "External documentation for {title}": "Externe Dokumentation f\xFCr {title}", Flags: "Flaggen", "Food & Drink": "Essen & Trinken", "Frequently used": "H\xE4ufig verwendet", Global: "Global", "Go back to the list": "Zur\xFCck zur Liste", "Message limit of {count} characters reached": "Nachrichtenlimit von {count} Zeichen erreicht", Next: "Weiter", "No emoji found": "Kein Emoji gefunden", "No results": "Keine Ergebnisse", Objects: "Gegenst\xE4nde", "Open navigation": "Navigation \xF6ffnen", "Pause slideshow": "Diashow pausieren", "People & Body": "Menschen & K\xF6rper", "Pick an emoji": "Ein Emoji ausw\xE4hlen", "Please select a time zone:": "Bitte w\xE4hlen Sie eine Zeitzone:", Previous: "Vorherige", Search: "Suche", "Search results": "Suchergebnisse", "Select a tag": "Schlagwort ausw\xE4hlen", Settings: "Einstellungen", "Settings navigation": "Einstellungen f\xFCr die Navigation", "Smileys & Emotion": "Smileys & Emotionen", "Start slideshow": "Diashow starten", Submit: "Einreichen", Symbols: "Symbole", "Travel & Places": "Reisen & Orte", "Type to search time zone": "Tippen, um Zeitzone zu suchen", "Unable to search the group": "Die Gruppe konnte nicht durchsucht werden", "Undo changes": "\xC4nderungen r\xFCckg\xE4ngig machen", "Write message, @ to mention someone, : for emoji autocompletion \u2026": "Nachricht schreiben, @, um jemanden zu erw\xE4hnen, : f\xFCr die automatische Vervollst\xE4ndigung von Emojis \u2026 " } }, { locale: "de_DE", translations: { "{tag} (invisible)": "{tag} (unsichtbar)", "{tag} (restricted)": "{tag} (eingeschr\xE4nkt)", Actions: "Aktionen", Activities: "Aktivit\xE4ten", "Animals & Nature": "Tiere & Natur", "Avatar of {displayName}": "Avatar von {displayName}", "Avatar of {displayName}, {status}": "Avatar von {displayName}, {status}", "Cancel changes": "\xC4nderungen verwerfen", Choose: "Ausw\xE4hlen", Close: "Schlie\xDFen", "Close navigation": "Navigation schlie\xDFen", "Confirm changes": "\xC4nderungen best\xE4tigen", Custom: "Benutzerdefiniert", "Edit item": "Objekt bearbeiten", "External documentation for {title}": "Externe Dokumentation f\xFCr {title}", Flags: "Flaggen", "Food & Drink": "Essen & Trinken", "Frequently used": "H\xE4ufig verwendet", Global: "Global", "Go back to the list": "Zur\xFCck zur Liste", "Message limit of {count} characters reached": "Nachrichtenlimit von {count} Zeichen erreicht", Next: "Weiter", "No emoji found": "Kein Emoji gefunden", "No results": "Keine Ergebnisse", Objects: "Objekte", "Open navigation": "Navigation \xF6ffnen", "Pause slideshow": "Diashow pausieren", "People & Body": "Menschen & K\xF6rper", "Pick an emoji": "Ein Emoji ausw\xE4hlen", "Please select a time zone:": "Bitte eine Zeitzone ausw\xE4hlen:", Previous: "Vorherige", Search: "Suche", "Search results": "Suchergebnisse", "Select a tag": "Schlagwort ausw\xE4hlen", Settings: "Einstellungen", "Settings navigation": "Einstellungen f\xFCr die Navigation", "Smileys & Emotion": "Smileys & Emotionen", "Start slideshow": "Diashow starten", Submit: "Einreichen", Symbols: "Symbole", "Travel & Places": "Reisen & Orte", "Type to search time zone": "Tippen, um eine Zeitzone zu suchen", "Unable to search the group": "Die Gruppe kann nicht durchsucht werden", "Undo changes": "\xC4nderungen r\xFCckg\xE4ngig machen", "Write message, @ to mention someone, : for emoji autocompletion \u2026": "Nachricht schreiben, @, um jemanden zu erw\xE4hnen, : f\xFCr die automatische Vervollst\xE4ndigung von Emojis \u2026" } }, { locale: "el", translations: { "{tag} (invisible)": "{tag} (\u03B1\u03CC\u03C1\u03B1\u03C4\u03BF)", "{tag} (restricted)": "{tag} (\u03C0\u03B5\u03C1\u03B9\u03BF\u03C1\u03B9\u03C3\u03BC\u03AD\u03BD\u03BF)", Actions: "\u0395\u03BD\u03AD\u03C1\u03B3\u03B5\u03B9\u03B5\u03C2", Activities: "\u0394\u03C1\u03B1\u03C3\u03C4\u03B7\u03C1\u03B9\u03CC\u03C4\u03B7\u03C4\u03B5\u03C2", "Animals & Nature": "\u0396\u03CE\u03B1 & \u03A6\u03CD\u03C3\u03B7", "Avatar of {displayName}": "\u0386\u03B2\u03B1\u03C4\u03B1\u03C1 \u03C4\u03BF\u03C5 {displayName}", "Cancel changes": "\u0391\u03BA\u03CD\u03C1\u03C9\u03C3\u03B7 \u03B1\u03BB\u03BB\u03B1\u03B3\u03CE\u03BD", Choose: "\u0395\u03C0\u03B9\u03BB\u03BF\u03B3\u03AE", Close: "\u039A\u03BB\u03B5\u03AF\u03C3\u03B9\u03BC\u03BF", "Close navigation": "\u039A\u03BB\u03B5\u03AF\u03C3\u03B9\u03BC\u03BF \u03C0\u03BB\u03BF\u03AE\u03B3\u03B7\u03C3\u03B7\u03C2", "Confirm changes": "\u0395\u03C0\u03B9\u03B2\u03B5\u03B2\u03B1\u03AF\u03C9\u03C3\u03B7 \u03B1\u03BB\u03BB\u03B1\u03B3\u03CE\u03BD", Custom: "\u03A0\u03C1\u03BF\u03C3\u03B1\u03C1\u03BC\u03BF\u03B3\u03AE", "Edit item": "\u0395\u03C0\u03B5\u03BE\u03B5\u03C1\u03B3\u03B1\u03C3\u03AF\u03B1", "External documentation for {title}": "\u0395\u03BE\u03C9\u03C4\u03B5\u03C1\u03B9\u03BA\u03AE \u03C4\u03B5\u03BA\u03BC\u03B7\u03C1\u03AF\u03C9\u03C3\u03B7 \u03B3\u03B9\u03B1 {title}", Flags: "\u03A3\u03B7\u03BC\u03B1\u03AF\u03B5\u03C2", "Food & Drink": "\u03A6\u03B1\u03B3\u03B7\u03C4\u03CC & \u03A0\u03BF\u03C4\u03CC", "Frequently used": "\u03A3\u03C5\u03C7\u03BD\u03AC \u03C7\u03C1\u03B7\u03C3\u03B9\u03BC\u03BF\u03C0\u03BF\u03B9\u03BF\u03CD\u03BC\u03B5\u03BD\u03BF", Global: "\u039A\u03B1\u03B8\u03BF\u03BB\u03B9\u03BA\u03CC", "Go back to the list": "\u0395\u03C0\u03B9\u03C3\u03C4\u03C1\u03BF\u03C6\u03AE \u03C3\u03C4\u03B7\u03BD \u03B1\u03C1\u03C7\u03B9\u03BA\u03AE \u03BB\u03AF\u03C3\u03C4\u03B1 ", "Message limit of {count} characters reached": "\u03A3\u03C5\u03BC\u03C0\u03BB\u03B7\u03C1\u03CE\u03B8\u03B7\u03BA\u03B5 \u03C4\u03BF \u03CC\u03C1\u03B9\u03BF \u03C4\u03C9\u03BD {count} \u03C7\u03B1\u03C1\u03B1\u03BA\u03C4\u03AE\u03C1\u03C9\u03BD \u03C4\u03BF\u03C5 \u03BC\u03B7\u03BD\u03CD\u03BC\u03B1\u03C4\u03BF\u03C2", Next: "\u0395\u03C0\u03CC\u03BC\u03B5\u03BD\u03BF", "No emoji found": "\u0394\u03B5\u03BD \u03B2\u03C1\u03AD\u03B8\u03B7\u03BA\u03B5 emoji", "No results": "\u039A\u03B1\u03BD\u03AD\u03BD\u03B1 \u03B1\u03C0\u03BF\u03C4\u03AD\u03BB\u03B5\u03C3\u03BC\u03B1", Objects: "\u0391\u03BD\u03C4\u03B9\u03BA\u03B5\u03AF\u03BC\u03B5\u03BD\u03B1", "Open navigation": "\u0386\u03BD\u03BF\u03B9\u03B3\u03BC\u03B1 \u03C0\u03BB\u03BF\u03AE\u03B3\u03B7\u03C3\u03B7\u03C2", "Pause slideshow": "\u03A0\u03B1\u03CD\u03C3\u03B7 \u03C0\u03C1\u03BF\u03B2\u03BF\u03BB\u03AE\u03C2 \u03B4\u03B9\u03B1\u03C6\u03B1\u03BD\u03B5\u03B9\u03CE\u03BD", "People & Body": "\u0386\u03BD\u03B8\u03C1\u03C9\u03C0\u03BF\u03B9 & \u03A3\u03CE\u03BC\u03B1", "Pick an emoji": "\u0395\u03C0\u03B9\u03BB\u03AD\u03BE\u03C4\u03B5 \u03AD\u03BD\u03B1 emoji", "Please select a time zone:": "\u03A0\u03B1\u03C1\u03B1\u03BA\u03B1\u03BB\u03BF\u03CD\u03BC\u03B5 \u03B5\u03C0\u03B9\u03BB\u03AD\u03BE\u03C4\u03B5 \u03BC\u03B9\u03B1 \u03B6\u03CE\u03BD\u03B7 \u03CE\u03C1\u03B1\u03C2:", Previous: "\u03A0\u03C1\u03BF\u03B7\u03B3\u03BF\u03CD\u03BC\u03B5\u03BD\u03BF", Search: "\u0391\u03BD\u03B1\u03B6\u03AE\u03C4\u03B7\u03C3\u03B7", "Search results": "\u0391\u03C0\u03BF\u03C4\u03B5\u03BB\u03AD\u03C3\u03BC\u03B1\u03C4\u03B1 \u03B1\u03BD\u03B1\u03B6\u03AE\u03C4\u03B7\u03C3\u03B7\u03C2", "Select a tag": "\u0395\u03C0\u03B9\u03BB\u03BF\u03B3\u03AE \u03B5\u03C4\u03B9\u03BA\u03AD\u03C4\u03B1\u03C2", Settings: "\u03A1\u03C5\u03B8\u03BC\u03AF\u03C3\u03B5\u03B9\u03C2", "Settings navigation": "\u03A0\u03BB\u03BF\u03AE\u03B3\u03B7\u03C3\u03B7 \u03C1\u03C5\u03B8\u03BC\u03AF\u03C3\u03B5\u03C9\u03BD", "Smileys & Emotion": "\u03A6\u03B1\u03C4\u03C3\u03BF\u03CD\u03BB\u03B5\u03C2 & \u03A3\u03C5\u03BD\u03B1\u03AF\u03C3\u03B8\u03B7\u03BC\u03B1", "Start slideshow": "\u0388\u03BD\u03B1\u03C1\u03BE\u03B7 \u03C0\u03C1\u03BF\u03B2\u03BF\u03BB\u03AE\u03C2 \u03B4\u03B9\u03B1\u03C6\u03B1\u03BD\u03B5\u03B9\u03CE\u03BD", Submit: "\u03A5\u03C0\u03BF\u03B2\u03BF\u03BB\u03AE", Symbols: "\u03A3\u03CD\u03BC\u03B2\u03BF\u03BB\u03B1", "Travel & Places": "\u03A4\u03B1\u03BE\u03AF\u03B4\u03B9\u03B1 & \u03A4\u03BF\u03C0\u03BF\u03B8\u03B5\u03C3\u03AF\u03B5\u03C2", "Type to search time zone": "\u03A0\u03BB\u03B7\u03BA\u03C4\u03C1\u03BF\u03BB\u03BF\u03B3\u03AE\u03C3\u03C4\u03B5 \u03B3\u03B9\u03B1 \u03B1\u03BD\u03B1\u03B6\u03AE\u03C4\u03B7\u03C3\u03B7 \u03B6\u03CE\u03BD\u03B7\u03C2 \u03CE\u03C1\u03B1\u03C2", "Unable to search the group": "\u0394\u03B5\u03BD \u03B5\u03AF\u03BD\u03B1\u03B9 \u03B4\u03C5\u03BD\u03B1\u03C4\u03AE \u03B7 \u03B1\u03BD\u03B1\u03B6\u03AE\u03C4\u03B7\u03C3\u03B7 \u03C4\u03B7\u03C2 \u03BF\u03BC\u03AC\u03B4\u03B1\u03C2", "Undo changes": "\u0391\u03BD\u03B1\u03AF\u03C1\u03B5\u03C3\u03B7 \u0391\u03BB\u03BB\u03B1\u03B3\u03CE\u03BD", "Write message, @ to mention someone \u2026": "\u0393\u03C1\u03AC\u03C8\u03C4\u03B5 \u03AD\u03BD\u03B1 \u03BC\u03AE\u03BD\u03C5\u03BC\u03B1, \u03BA\u03B1\u03B9 \u03BC\u03B5 \u03C4\u03BF \u03C3\u03CD\u03BC\u03B2\u03BF\u03BB\u03BF @, \u03BC\u03BD\u03B7\u03BC\u03BF\u03BD\u03B5\u03CD\u03C3\u03C4\u03B5 \u03BA\u03AC\u03C0\u03BF\u03B9\u03BF\u03BD \u2026" } }, { locale: "eo", translations: { "{tag} (invisible)": "{tag} (ka\u015Dita)", "{tag} (restricted)": "{tag} (limigita)", Actions: "Agoj", Activities: "Aktiveco", "Animals & Nature": "Bestoj & Naturo", Choose: "Elektu", Close: "Fermu", Custom: "Propra", Flags: "Flagoj", "Food & Drink": "Man\u011Da\u0135o & Trinka\u0135o", "Frequently used": "Ofte uzataj", "Message limit of {count} characters reached": "La limo je {count} da literoj atingita", Next: "Sekva", "No emoji found": "La emo\u011Dio forestas", "No results": "La rezulto forestas", Objects: "Objektoj", "Pause slideshow": "Payzi bildprezenton", "People & Body": "Homoj & Korpo", "Pick an emoji": "Elekti emo\u011Dion ", Previous: "Anta\u016Da", Search: "Ser\u0109i", "Search results": "Ser\u0109rezultoj", "Select a tag": "Elektu etikedon", Settings: "Agordo", "Settings navigation": "Agorda navigado", "Smileys & Emotion": "Ridoj kaj Emocioj", "Start slideshow": "Komenci bildprezenton", Symbols: "Signoj", "Travel & Places": "Voja\u0135oj & Lokoj", "Unable to search the group": "Ne eblas ser\u0109i en la grupo", "Write message, @ to mention someone \u2026": "Mesa\u011Di, uzu @ por mencii iun ..." } }, { locale: "es", translations: { "{tag} (invisible)": "{tag} (invisible)", "{tag} (restricted)": "{tag} (restringido)", Actions: "Acciones", Activities: "Actividades", "Animals & Nature": "Animales y naturaleza", "Avatar of {displayName}": "Avatar de {displayName}", "Avatar of {displayName}, {status}": "Avatar de {displayName}, {status}", "Cancel changes": "Cancelar cambios", Choose: "Elegir", Close: "Cerrar", "Close navigation": "Cerrar navegaci\xF3n", "Confirm changes": "Confirmar cambios", Custom: "Personalizado", "Edit item": "Editar elemento", "External documentation for {title}": "Documentacion externa de {title}", Flags: "Banderas", "Food & Drink": "Comida y bebida", "Frequently used": "Usado con frecuenca", Global: "Global", "Go back to the list": "Volver a la lista", "Message limit of {count} characters reached": "El mensaje ha alcanzado el l\xEDmite de {count} caracteres", Next: "Siguiente", "No emoji found": "No hay ning\xFAn emoji", "No results": " Ning\xFAn resultado", Objects: "Objetos", "Open navigation": "Abrir navegaci\xF3n", "Pause slideshow": "Pausar la presentaci\xF3n ", "People & Body": "Personas y cuerpos", "Pick an emoji": "Elegir un emoji", "Please select a time zone:": "Por favor elige un huso de horario:", Previous: "Anterior", Search: "Buscar", "Search results": "Resultados de la b\xFAsqueda", "Select a tag": "Seleccione una etiqueta", Settings: "Ajustes", "Settings navigation": "Navegaci\xF3n por ajustes", "Smileys & Emotion": "Smileys y emoticonos", "Start slideshow": "Iniciar la presentaci\xF3n", Submit: "Enviar", Symbols: "S\xEDmbolos", "Travel & Places": "Viajes y lugares", "Type to search time zone": "Escribe para buscar un huso de horario", "Unable to search the group": "No es posible buscar en el grupo", "Undo changes": "Deshacer cambios", "Write message, @ to mention someone \u2026": "Escriba un mensaje, @ para mencionar a alguien..." } }, { locale: "eu", translations: { "{tag} (invisible)": "{tag} (ikusezina)", "{tag} (restricted)": "{tag} (mugatua)", Actions: "Ekintzak", Activities: "Jarduerak", "Animals & Nature": "Animaliak eta Natura", "Avatar of {displayName}": "{displayName}-(e)n irudia", "Avatar of {displayName}, {status}": "{displayName} -(e)n irudia, {status}", "Cancel changes": "Ezeztatu aldaketak", Choose: "Aukeratu", Close: "Itxi", "Close navigation": "Itxi nabigazioa", "Confirm changes": "Baieztatu aldaketak", Custom: "Pertsonalizatua", "Edit item": "Editatu elementua", "External documentation for {title}": "Kanpoko dokumentazioa {title}(r)entzat", Flags: "Banderak", "Food & Drink": "Janaria eta edariak", "Frequently used": "Askotan erabilia", Global: "Globala", "Go back to the list": "Bueltatu zerrendara", "Message limit of {count} characters reached": "Mezuaren {count} karaketere-limitera heldu zara", Next: "Hurrengoa", "No emoji found": "Ez da emojirik aurkitu", "No results": "Emaitzarik ez", Objects: "Objektuak", "Open navigation": "Ireki nabigazioa", "Pause slideshow": "Pausatu diaporama", "People & Body": "Jendea eta gorputza", "Pick an emoji": "Aukeratu emoji bat", "Please select a time zone:": "Mesedez hautatu ordu-zona bat:", Previous: "Aurrekoa", Search: "Bilatu", "Search results": "Bilaketa emaitzak", "Select a tag": "Hautatu etiketa bat", Settings: "Ezarpenak", "Settings navigation": "Nabigazio ezarpenak", "Smileys & Emotion": "Smileyak eta emozioa", "Start slideshow": "Hasi diaporama", Submit: "Bidali", Symbols: "Sinboloak", "Travel & Places": "Bidaiak eta lekuak", "Type to search time zone": "Idatzi ordu-zona bat bilatzeko", "Unable to search the group": "Ezin izan da taldea bilatu", "Undo changes": "Aldaketak desegin", "Write message, @ to mention someone, : for emoji autocompletion \u2026": "Idatzi mezua, @ norbait aipatzeko, : emojia automatikoki idazteko" } }, { locale: "fi_FI", translations: { "{tag} (invisible)": "{tag} (n\xE4kym\xE4t\xF6n)", "{tag} (restricted)": "{tag} (rajoitettu)", Actions: "Toiminnot", Activities: "Aktiviteetit", "Animals & Nature": "El\xE4imet & luonto", "Avatar of {displayName}": "K\xE4ytt\xE4j\xE4n {displayName} avatar", "Avatar of {displayName}, {status}": "K\xE4ytt\xE4j\xE4n {displayName} avatar, {status}", "Cancel changes": "Peruuta muutokset", Choose: "Valitse", Close: "Sulje", "Close navigation": "Sulje navigaatio", "Confirm changes": "Vahvista muutokset", Custom: "Mukautettu", "Edit item": "Muokkaa kohdetta", "External documentation for {title}": "Ulkoinen dokumentaatio kohteelle {title}", Flags: "Liput", "Food & Drink": "Ruoka & juoma", "Frequently used": "Usein k\xE4ytetyt", Global: "Yleinen", "Go back to the list": "Siirry takaisin listaan", "Message limit of {count} characters reached": "Viestin merkken enimm\xE4isim\xE4\xE4r\xE4 {count} t\xE4ynn\xE4 ", Next: "Seuraava", "No emoji found": "Emojia ei l\xF6ytynyt", "No results": "Ei tuloksia", Objects: "Esineet & asiat", "Open navigation": "Avaa navigaatio", "Pause slideshow": "Keskeyt\xE4 diaesitys", "People & Body": "Ihmiset & keho", "Pick an emoji": "Valitse emoji", "Please select a time zone:": "Valitse aikavy\xF6hyke:", Previous: "Edellinen", Search: "Etsi", "Search results": "Hakutulokset", "Select a tag": "Valitse tagi", Settings: "Asetukset", "Settings navigation": "Asetusnavigaatio", "Smileys & Emotion": "Hymi\xF6t & tunteet", "Start slideshow": "Aloita diaesitys", Submit: "L\xE4het\xE4", Symbols: "Symbolit", "Travel & Places": "Matkustus & kohteet", "Type to search time zone": "Kirjoita etsi\xE4ksesi aikavy\xF6hyke", "Unable to search the group": "Ryhm\xE4\xE4 ei voi hakea", "Undo changes": "Kumoa muutokset", "Write message, @ to mention someone \u2026": "Kirjoita viesti, @ mainitaksesi jonkun..." } }, { locale: "fr", translations: { "{tag} (invisible)": "{tag} (invisible)", "{tag} (restricted)": "{tag} (restreint)", Actions: "Actions", Activities: "Activit\xE9s", "Animals & Nature": "Animaux & Nature", "Avatar of {displayName}": "Avatar de {displayName}", "Avatar of {displayName}, {status}": "Avatar de {displayName}, {status}", "Cancel changes": "Annuler les modifications", Choose: "Choisir", Close: "Fermer", "Close navigation": "Fermer la navigation", "Confirm changes": "Confirmer les modifications", Custom: "Personnalis\xE9", "Edit item": "\xC9diter l'\xE9l\xE9ment", "External documentation for {title}": "Documentation externe pour {title}", Flags: "Drapeaux", "Food & Drink": "Nourriture & Boissons", "Frequently used": "Utilis\xE9s fr\xE9quemment", Global: "Global", "Go back to the list": "Retourner \xE0 la liste", "Message limit of {count} characters reached": "Limite de messages de {count} caract\xE8res atteinte", Next: "Suivant", "No emoji found": "Pas d\u2019\xE9moji trouv\xE9", "No results": "Aucun r\xE9sultat", Objects: "Objets", "Open navigation": "Ouvrir la navigation", "Pause slideshow": "Mettre le diaporama en pause", "People & Body": "Personnes & Corps", "Pick an emoji": "Choisissez un \xE9moji", "Please select a time zone:": "S\xE9lectionnez un fuseau horaire : ", Previous: "Pr\xE9c\xE9dent", Search: "Chercher", "Search results": "R\xE9sultats de recherche", "Select a tag": "S\xE9lectionnez une balise", Settings: "Param\xE8tres", "Settings navigation": "Navigation dans les param\xE8tres", "Smileys & Emotion": "Smileys & \xC9motions", "Start slideshow": "D\xE9marrer le diaporama", Submit: "Valider", Symbols: "Symboles", "Travel & Places": "Voyage & Lieux", "Type to search time zone": "Saisissez les premiers lettres pour rechercher un fuseau horaire", "Unable to search the group": "Impossible de chercher le groupe", "Undo changes": "Annuler les changements", "Write message, @ to mention someone, : for emoji autocompletion \u2026": "Ecrire un message, @ pour mentionner quelqu'un, : pour l'auto-compl\xE9tion des \xE9motic\xF4nes" } }, { locale: "gl", translations: { "{tag} (invisible)": "{tag} (invis\xEDbel)", "{tag} (restricted)": "{tag} (restrinxido)", Actions: "Acci\xF3ns", Activities: "Actividades", "Animals & Nature": "Animais e natureza", "Cancel changes": "Cancelar os cambios", Choose: "Escoller", Close: "Pechar", "Confirm changes": "Confirma os cambios", Custom: "Personalizado", "External documentation for {title}": "Documentaci\xF3n externa para {title}", Flags: "Bandeiras", "Food & Drink": "Comida e bebida", "Frequently used": "Usado con frecuencia", "Message limit of {count} characters reached": "Acadouse o l\xEDmite de {count} caracteres por mensaxe", Next: "Seguinte", "No emoji found": "Non se atopou ning\xFAn \xABemoji\xBB", "No results": "Sen resultados", Objects: "Obxectos", "Pause slideshow": "Pausar o diaporama", "People & Body": "Persoas e corpo", "Pick an emoji": "Escolla un \xABemoji\xBB", Previous: "Anterir", Search: "Buscar", "Search results": "Resultados da busca", "Select a tag": "Seleccione unha etiqueta", Settings: "Axustes", "Settings navigation": "Navegaci\xF3n polos axustes", "Smileys & Emotion": "Sorrisos e emoci\xF3ns", "Start slideshow": "Iniciar o diaporama", Submit: "Enviar", Symbols: "S\xEDmbolos", "Travel & Places": "Viaxes e lugares", "Unable to search the group": "Non foi pos\xEDbel buscar o grupo", "Write message, @ to mention someone \u2026": "Escriba a mensaxe, @ para mencionar a algu\xE9n\u2026" } }, { locale: "he", translations: { "{tag} (invisible)": "{tag} (\u05E0\u05E1\u05EA\u05E8)", "{tag} (restricted)": "{tag} (\u05DE\u05D5\u05D2\u05D1\u05DC)", Actions: "\u05E4\u05E2\u05D5\u05DC\u05D5\u05EA", Activities: "\u05E4\u05E2\u05D9\u05DC\u05D5\u05D9\u05D5\u05EA", "Animals & Nature": "\u05D7\u05D9\u05D5\u05EA \u05D5\u05D8\u05D1\u05E2", Choose: "\u05D1\u05D7\u05D9\u05E8\u05D4", Close: "\u05E1\u05D2\u05D9\u05E8\u05D4", Custom: "\u05D1\u05D4\u05EA\u05D0\u05DE\u05D4 \u05D0\u05D9\u05E9\u05D9\u05EA", Flags: "\u05D3\u05D2\u05DC\u05D9\u05DD", "Food & Drink": "\u05DE\u05D6\u05D5\u05DF \u05D5\u05DE\u05E9\u05E7\u05D0\u05D5\u05EA", "Frequently used": "\u05D1\u05E9\u05D9\u05DE\u05D5\u05E9 \u05EA\u05D3\u05D9\u05E8", Next: "\u05D4\u05D1\u05D0", "No emoji found": "\u05DC\u05D0 \u05E0\u05DE\u05E6\u05D0 \u05D0\u05DE\u05D5\u05D2\u05F3\u05D9", "No results": "\u05D0\u05D9\u05DF \u05EA\u05D5\u05E6\u05D0\u05D5\u05EA", Objects: "\u05D7\u05E4\u05E6\u05D9\u05DD", "Pause slideshow": "\u05D4\u05E9\u05D4\u05D9\u05D9\u05EA \u05DE\u05E6\u05D2\u05EA", "People & Body": "\u05D0\u05E0\u05E9\u05D9\u05DD \u05D5\u05D2\u05D5\u05E3", "Pick an emoji": "\u05E0\u05D0 \u05DC\u05D1\u05D7\u05D5\u05E8 \u05D0\u05DE\u05D5\u05D2\u05F3\u05D9", Previous: "\u05D4\u05E7\u05D5\u05D3\u05DD", Search: "\u05D7\u05D9\u05E4\u05D5\u05E9", "Search results": "\u05EA\u05D5\u05E6\u05D0\u05D5\u05EA \u05D7\u05D9\u05E4\u05D5\u05E9", "Select a tag": "\u05D1\u05D7\u05D9\u05E8\u05EA \u05EA\u05D2\u05D9\u05EA", Settings: "\u05D4\u05D2\u05D3\u05E8\u05D5\u05EA", "Smileys & Emotion": "\u05D7\u05D9\u05D9\u05DB\u05E0\u05D9\u05DD \u05D5\u05E8\u05D2\u05E9\u05D5\u05E0\u05D9\u05DD", "Start slideshow": "\u05D4\u05EA\u05D7\u05DC\u05EA \u05D4\u05DE\u05E6\u05D2\u05EA", Symbols: "\u05E1\u05DE\u05DC\u05D9\u05DD", "Travel & Places": "\u05D8\u05D9\u05D5\u05DC\u05D9\u05DD \u05D5\u05DE\u05E7\u05D5\u05DE\u05D5\u05EA", "Unable to search the group": "\u05DC\u05D0 \u05E0\u05D9\u05EA\u05DF \u05DC\u05D7\u05E4\u05E9 \u05D1\u05E7\u05D1\u05D5\u05E6\u05D4" } }, { locale: "hu_HU", translations: { "{tag} (invisible)": "{tag} (l\xE1thatatlan)", "{tag} (restricted)": "{tag} (korl\xE1tozott)", Actions: "M\u0171veletek", Activities: "Tev\xE9kenys\xE9gek", "Animals & Nature": "\xC1llatok \xE9s term\xE9szet", "Avatar of {displayName}": "{displayName} profilk\xE9pe", "Cancel changes": "V\xE1ltoztat\xE1sok elvet\xE9se", Choose: "V\xE1lassszon", Close: "Bez\xE1r\xE1s", "Confirm changes": "V\xE1ltoztat\xE1sok meger\u0151s\xEDt\xE9se", Custom: "Egy\xE9ni", "External documentation for {title}": "K\xFCls\u0151 dokument\xE1ci\xF3 ehhez: {title}", Flags: "Z\xE1szl\xF3", "Food & Drink": "\xC9tel \xE9s ital", "Frequently used": "Gyakran haszn\xE1lt", Global: "Glob\xE1lis", "Message limit of {count} characters reached": "{count} karakteres \xFCzenetkorl\xE1t el\xE9rve", Next: "K\xF6vetkez\u0151", "No emoji found": "Nem tal\xE1lhat\xF3 emodzsi", "No results": "Nincs tal\xE1lat", Objects: "T\xE1rgyak", "Pause slideshow": "Diavet\xEDt\xE9s sz\xFCneteltet\xE9se", "People & Body": "Emberek \xE9s test", "Pick an emoji": "V\xE1lasszon egy emodzsit", "Please select a time zone:": "V\xE1lasszon id\u0151z\xF3n\xE1t:", Previous: "El\u0151z\u0151", Search: "Keres\xE9s", "Search results": "Tal\xE1latok", "Select a tag": "V\xE1lasszon c\xEDmk\xE9t", Settings: "Be\xE1ll\xEDt\xE1sok", "Settings navigation": "Navig\xE1ci\xF3 a be\xE1ll\xEDt\xE1sokban", "Smileys & Emotion": "Mosolyok \xE9s \xE9rzelmek", "Start slideshow": "Diavet\xEDt\xE9s ind\xEDt\xE1sa", Submit: "Bek\xFCld\xE9s", Symbols: "Szimb\xF3lumok", "Travel & Places": "Utaz\xE1s \xE9s helyek", "Type to search time zone": "G\xE9peljen az id\u0151z\xF3na keres\xE9s\xE9hez", "Unable to search the group": "A csoport nem kereshet\u0151", "Write message, @ to mention someone \u2026": "\xCDrjon \xFCzenetet, @ valaki megeml\xEDt\xE9s\xE9hez\u2026" } }, { locale: "is", translations: { "{tag} (invisible)": "{tag} (\xF3s\xFDnilegt)", "{tag} (restricted)": "{tag} (takmarka\xF0)", Actions: "A\xF0ger\xF0ir", Activities: "A\xF0ger\xF0ir", "Animals & Nature": "D\xFDr og n\xE1tt\xFAra", Choose: "Velja", Close: "Loka", Custom: "S\xE9rsni\xF0i\xF0", Flags: "Fl\xF6gg", "Food & Drink": "Matur og drykkur", "Frequently used": "Oftast nota\xF0", Next: "N\xE6sta", "No emoji found": "Ekkert tj\xE1ningart\xE1kn fannst", "No results": "Engar ni\xF0urst\xF6\xF0ur", Objects: "Hlutir", "Pause slideshow": "Gera hl\xE9 \xE1 skyggnus\xFDningu", "People & Body": "F\xF3lk og l\xEDkami", "Pick an emoji": "Veldu tj\xE1ningart\xE1kn", Previous: "Fyrri", Search: "Leita", "Search results": "Leitarni\xF0urst\xF6\xF0ur", "Select a tag": "Veldu merki", Settings: "Stillingar", "Smileys & Emotion": "Broskallar og tilfinningar", "Start slideshow": "Byrja skyggnus\xFDningu", Symbols: "T\xE1kn", "Travel & Places": "Sta\xF0ir og fer\xF0al\xF6g", "Unable to search the group": "Get ekki leita\xF0 \xED h\xF3pnum" } }, { locale: "it", translations: { "{tag} (invisible)": "{tag} (invisibile)", "{tag} (restricted)": "{tag} (limitato)", Actions: "Azioni", Activities: "Attivit\xE0", "Animals & Nature": "Animali e natura", "Avatar of {displayName}": "Avatar di {displayName}", "Avatar of {displayName}, {status}": "Avatar di {displayName}, {status}", "Cancel changes": "Annulla modifiche", Choose: "Scegli", Close: "Chiudi", "Close navigation": "Chiudi la navigazione", "Confirm changes": "Conferma modifiche", Custom: "Personalizzato", "Edit item": "Modifica l'elemento", "External documentation for {title}": "Documentazione esterna per {title}", Flags: "Bandiere", "Food & Drink": "Cibo e bevande", "Frequently used": "Usati di frequente", Global: "Globale", "Go back to the list": "Torna all'elenco", "Message limit of {count} characters reached": "Limite dei messaggi di {count} caratteri raggiunto", Next: "Successivo", "No emoji found": "Nessun emoji trovato", "No results": "Nessun risultato", Objects: "Oggetti", "Open navigation": "Apri la navigazione", "Pause slideshow": "Presentazione in pausa", "People & Body": "Persone e corpo", "Pick an emoji": "Scegli un emoji", "Please select a time zone:": "Si prega di selezionare un fuso orario:", Previous: "Precedente", Search: "Cerca", "Search results": "Risultati di ricerca", "Select a tag": "Seleziona un'etichetta", Settings: "Impostazioni", "Settings navigation": "Navigazione delle impostazioni", "Smileys & Emotion": "Faccine ed emozioni", "Start slideshow": "Avvia presentazione", Submit: "Invia", Symbols: "Simboli", "Travel & Places": "Viaggi e luoghi", "Type to search time zone": "Digita per cercare un fuso orario", "Unable to search the group": "Impossibile cercare il gruppo", "Undo changes": "Cancella i cambiamenti", "Write message, @ to mention someone, : for emoji autocompletion \u2026": "Scrivi un messaggio, @ per menzionare qualcuno, : per il completamento automatico delle emoji ..." } }, { locale: "ja_JP", translations: { "{tag} (invisible)": "{\u30BF\u30B0} (\u4E0D\u53EF\u8996)", "{tag} (restricted)": "{\u30BF\u30B0} (\u5236\u9650\u4ED8)", Actions: "\u64CD\u4F5C", Activities: "\u30A2\u30AF\u30C6\u30A3\u30D3\u30C6\u30A3", "Animals & Nature": "\u52D5\u7269\u3068\u81EA\u7136", "Avatar of {displayName}": "{displayName} \u306E\u30A2\u30D0\u30BF\u30FC", "Cancel changes": "\u5909\u66F4\u3092\u30AD\u30E3\u30F3\u30BB\u30EB", Choose: "\u9078\u629E", Close: "\u9589\u3058\u308B", "Confirm changes": "\u5909\u66F4\u3092\u627F\u8A8D", Custom: "\u30AB\u30B9\u30BF\u30E0", "External documentation for {title}": "{title} \u306E\u305F\u3081\u306E\u6DFB\u4ED8\u6587\u66F8", Flags: "\u56FD\u65D7", "Food & Drink": "\u98DF\u3079\u7269\u3068\u98F2\u307F\u7269", "Frequently used": "\u3088\u304F\u4F7F\u3046\u3082\u306E", Global: "\u5168\u4F53", "Message limit of {count} characters reached": "{count} \u6587\u5B57\u306E\u30E1\u30C3\u30BB\u30FC\u30B8\u4E0A\u9650\u306B\u9054\u3057\u3066\u3044\u307E\u3059", Next: "\u6B21", "No emoji found": "\u7D75\u6587\u5B57\u304C\u898B\u3064\u304B\u308A\u307E\u305B\u3093", "No results": "\u306A\u3057", Objects: "\u7269", "Pause slideshow": "\u30B9\u30E9\u30A4\u30C9\u30B7\u30E7\u30FC\u3092\u4E00\u6642\u505C\u6B62", "People & Body": "\u69D8\u3005\u306A\u4EBA\u3068\u4F53\u306E\u90E8\u4F4D", "Pick an emoji": "\u7D75\u6587\u5B57\u3092\u9078\u629E", "Please select a time zone:": "\u30BF\u30A4\u30E0\u30BE\u30FC\u30F3\u3092\u9078\u3093\u3067\u4E0B\u3055\u3044\uFF1A", Previous: "\u524D", Search: "\u691C\u7D22", "Search results": "\u691C\u7D22\u7D50\u679C", "Select a tag": "\u30BF\u30B0\u3092\u9078\u629E", Settings: "\u8A2D\u5B9A", "Settings navigation": "\u30CA\u30D3\u30B2\u30FC\u30B7\u30E7\u30F3\u8A2D\u5B9A", "Smileys & Emotion": "\u611F\u60C5\u8868\u73FE", "Start slideshow": "\u30B9\u30E9\u30A4\u30C9\u30B7\u30E7\u30FC\u3092\u958B\u59CB", Submit: "\u63D0\u51FA", Symbols: "\u8A18\u53F7", "Travel & Places": "\u65C5\u884C\u3068\u5834\u6240", "Type to search time zone": "\u30BF\u30A4\u30E0\u30BE\u30FC\u30F3\u691C\u7D22\u306E\u305F\u3081\u5165\u529B\u3057\u3066\u304F\u3060\u3055\u3044", "Unable to search the group": "\u30B0\u30EB\u30FC\u30D7\u3092\u691C\u7D22\u3067\u304D\u307E\u305B\u3093", "Write message, @ to mention someone \u2026": "\u30E1\u30C3\u30BB\u30FC\u30B8\u3092\u8A18\u5165\u3000@\u3092\u3064\u3051\u308B\u3068\u305D\u306E\u4EBA\u306B\u901A\u77E5\u304C\u884C\u304D\u307E\u3059" } }, { locale: "lt_LT", translations: { "{tag} (invisible)": "{tag} (nematoma)", "{tag} (restricted)": "{tag} (apribota)", Actions: "Veiksmai", Activities: "Veiklos", "Animals & Nature": "Gyv\u016Bnai ir gamta", Choose: "Pasirinkti", Close: "U\u017Everti", Custom: "Tinkinti", "External documentation for {title}": "I\u0161orin\u0117 {title} dokumentacija", Flags: "V\u0117liavos", "Food & Drink": "Maistas ir g\u0117rimai", "Frequently used": "Da\u017Eniausiai naudoti", "Message limit of {count} characters reached": "Pasiekta {count} simboli\u0173 \u017Einut\u0117s riba", Next: "Kitas", "No emoji found": "Nerasta jaustuk\u0173", "No results": "N\u0117ra rezultat\u0173", Objects: "Objektai", "Pause slideshow": "Pristabdyti skaidri\u0173 rodym\u0105", "People & Body": "\u017Dmon\u0117s ir k\u016Bnas", "Pick an emoji": "Pasirinkti jaustuk\u0105", Previous: "Ankstesnis", Search: "Ie\u0161koti", "Search results": "Paie\u0161kos rezultatai", "Select a tag": "Pasirinkti \u017Eym\u0119", Settings: "Nustatymai", "Settings navigation": "Nar\u0161ymas nustatymuose", "Smileys & Emotion": "\u0160ypsenos ir emocijos", "Start slideshow": "Prad\u0117ti skaidri\u0173 rodym\u0105", Submit: "Pateikti", Symbols: "Simboliai", "Travel & Places": "Kelion\u0117s ir vietos", "Unable to search the group": "Nepavyko atlikti paie\u0161k\u0105 grup\u0117je", "Write message, @ to mention someone \u2026": "Ra\u0161ykite \u017Einut\u0119, naudokite @ nor\u0117dami ka\u017Ek\u0105 pamin\u0117ti\u2026" } }, { locale: "lv", translations: { "{tag} (invisible)": "{tag} (neredzams)", "{tag} (restricted)": "{tag} (ierobe\u017Eots)", Choose: "Izv\u0113l\u0113ties", Close: "Aizv\u0113rt", Next: "N\u0101kamais", "No results": "Nav rezult\u0101tu", "Pause slideshow": "Pauz\u0113t slaidr\u0101di", Previous: "Iepriek\u0161\u0113jais", "Select a tag": "Izv\u0113l\u0113ties birku", Settings: "Iestat\u012Bjumi", "Start slideshow": "S\u0101kt slaidr\u0101di" } }, { locale: "mk", translations: { "{tag} (invisible)": "{tag} (\u043D\u0435\u0432\u0438\u0434\u043B\u0438\u0432\u043E)", "{tag} (restricted)": "{tag} (\u043E\u0433\u0440\u0430\u043D\u0438\u0447\u0435\u043D\u043E)", Actions: "\u0410\u043A\u0446\u0438\u0438", Activities: "\u0410\u043A\u0442\u0438\u0432\u043D\u043E\u0441\u0442\u0438", "Animals & Nature": "\u0416\u0438\u0432\u043E\u0442\u043D\u0438 & \u041F\u0440\u0438\u0440\u043E\u0434\u0430", Choose: "\u0418\u0437\u0431\u0435\u0440\u0438", Close: "\u0417\u0430\u0442\u0432\u043E\u0440\u0438", Custom: "\u041F\u0440\u0438\u043B\u0430\u0433\u043E\u0434\u0435\u043D\u0438", Flags: "\u0417\u043D\u0430\u043C\u0438\u045A\u0430", "Food & Drink": "\u0425\u0440\u0430\u043D\u0430 & \u041F\u0438\u0458\u0430\u043B\u043E\u0446\u0438", "Frequently used": "\u041D\u0430\u0458\u0447\u0435\u0441\u0442\u043E \u043A\u043E\u0440\u0438\u0441\u0442\u0435\u043D\u0438", "Message limit of {count} characters reached": "\u041E\u0433\u0440\u0430\u043D\u0438\u0447\u0443\u0432\u0430\u045A\u0435\u0442\u043E \u043D\u0430 \u0434\u043E\u043B\u0436\u0438\u043D\u0430\u0442\u0430 \u043D\u0430 \u043F\u043E\u0440\u0430\u043A\u0430\u0442\u0430 \u043E\u0434 {count} \u043A\u0430\u0440\u0430\u043A\u0442\u0435\u0440\u0438 \u0435 \u043D\u0430\u0434\u043C\u0438\u043D\u0430\u0442\u043E", Next: "\u0421\u043B\u0435\u0434\u043D\u043E", "No emoji found": "\u041D\u0435 \u0441\u0435 \u043F\u0440\u043E\u043D\u0430\u0458\u0434\u0435\u043D\u0438 \u0435\u043C\u043E\u0442\u0438\u043A\u043E\u043D\u0438", "No results": "\u041D\u0435\u043C\u0430 \u0440\u0435\u0437\u0443\u043B\u0442\u0430\u0442\u0438", Objects: "\u041E\u0431\u0458\u0435\u043A\u0442\u0438", "Pause slideshow": "\u041F\u0443\u0437\u0438\u0440\u0430\u0458 \u0441\u043B\u0430\u0458\u0434\u0448\u043E\u0443", "People & Body": "\u041B\u0443\u0453\u0435 & \u0422\u0435\u043B\u043E", "Pick an emoji": "\u0418\u0437\u0431\u0435\u0440\u0438 \u0435\u043C\u043E\u0442\u0438\u043A\u043E\u043D", Previous: "\u041F\u0440\u0435\u0434\u0445\u043E\u0434\u043D\u043E", Search: "\u0411\u0430\u0440\u0430\u0458", "Search results": "\u0420\u0435\u0437\u0443\u043B\u0442\u0430\u0442\u0438 \u043E\u0434 \u0431\u0430\u0440\u0443\u0432\u0430\u045A\u0435\u0442\u043E", "Select a tag": "\u0418\u0437\u0431\u0435\u0440\u0438 \u043E\u0437\u043D\u0430\u043A\u0430", Settings: "\u041F\u0430\u0440\u0430\u043C\u0435\u0442\u0440\u0438", "Settings navigation": "\u041F\u0430\u0440\u0430\u043C\u0435\u0442\u0440\u0438 \u0437\u0430 \u043D\u0430\u0432\u0438\u0433\u0430\u0446\u0438\u0458\u0430", "Smileys & Emotion": "\u0421\u043C\u0435\u0448\u043A\u043E\u0432\u0446\u0438 & \u0415\u043C\u043E\u0442\u0438\u043A\u043E\u043D\u0438", "Start slideshow": "\u0421\u0442\u0430\u0440\u0442\u0443\u0432\u0430\u0458 \u0441\u043B\u0430\u0458\u0434\u0448\u043E\u0443", Symbols: "\u0421\u0438\u043C\u0431\u043E\u043B\u0438", "Travel & Places": "\u041F\u0430\u0442\u0443\u0432\u0430\u045A\u0430 & \u041C\u0435\u0441\u0442\u0430", "Unable to search the group": "\u041D\u0435\u043C\u043E\u0436\u0435 \u0434\u0430 \u0441\u0435 \u043F\u0440\u0438\u043D\u0430\u0458\u0434\u0435 \u0433\u0440\u0443\u043F\u0430\u0442\u0430", "Write message, @ to mention someone \u2026": "\u041D\u0430\u043F\u0438\u0448\u0438 \u043F\u043E\u0440\u0430\u043A\u0430, @ \u0437\u0430 \u0434\u0430 \u0441\u043F\u043E\u043C\u043D\u0435\u0448 \u043D\u0435\u043A\u043E\u0458 \u2026" } }, { locale: "my", translations: { "{tag} (invisible)": "{tag} (\u1000\u103D\u101A\u103A\u101D\u103E\u1000\u103A\u1011\u102C\u1038)", "{tag} (restricted)": "{tag} (\u1000\u1014\u103A\u1037\u101E\u1010\u103A)", Actions: "\u101C\u102F\u1015\u103A\u1006\u1031\u102C\u1004\u103A\u1001\u103B\u1000\u103A\u1019\u103B\u102C\u1038", Activities: "\u1015\u103C\u102F\u101C\u102F\u1015\u103A\u1006\u1031\u102C\u1004\u103A\u1010\u102C\u1019\u103B\u102C\u1038", "Animals & Nature": "\u1010\u102D\u101B\u1005\u1039\u1006\u102C\u1014\u103A\u1019\u103B\u102C\u1038\u1014\u103E\u1004\u103A\u1037 \u101E\u1018\u102C\u101D", "Avatar of {displayName}": "{displayName} \u104F \u1000\u102D\u102F\u101A\u103A\u1015\u103D\u102C\u1038", "Cancel changes": "\u1015\u103C\u1031\u102C\u1004\u103A\u1038\u101C\u1032\u1019\u103E\u102F\u1019\u103B\u102C\u1038 \u1015\u101A\u103A\u1016\u103B\u1000\u103A\u101B\u1014\u103A", Choose: "\u101B\u103D\u1031\u1038\u1001\u103B\u101A\u103A\u101B\u1014\u103A", Close: "\u1015\u102D\u1010\u103A\u101B\u1014\u103A", "Confirm changes": "\u1015\u103C\u1031\u102C\u1004\u103A\u1038\u101C\u1032\u1019\u103E\u102F\u1019\u103B\u102C\u1038 \u1021\u1010\u100A\u103A\u1015\u103C\u102F\u101B\u1014\u103A", Custom: "\u1021\u101C\u102D\u102F\u1000\u103B\u1001\u103B\u102D\u1014\u103A\u100A\u103E\u102D\u1019\u103E\u102F", "External documentation for {title}": "{title} \u1021\u1010\u103D\u1000\u103A \u1015\u103C\u1004\u103A\u1015 \u1005\u102C\u101B\u103D\u1000\u103A\u1005\u102C\u1010\u1019\u103A\u1038", Flags: "\u1021\u101C\u1036\u1019\u103B\u102C\u1038", "Food & Drink": "\u1021\u1005\u102C\u1038\u1021\u101E\u1031\u102C\u1000\u103A", "Frequently used": "\u1019\u1000\u103C\u102C\u1001\u100F\u1021\u101E\u102F\u1036\u1038\u1015\u103C\u102F\u101E\u1031\u102C", Global: "\u1000\u1019\u1039\u1018\u102C\u101C\u102F\u1036\u1038\u1006\u102D\u102F\u1004\u103A\u101B\u102C", "Message limit of {count} characters reached": "\u1000\u1014\u103A\u1037\u101E\u1010\u103A \u1005\u102C\u101C\u102F\u1036\u1038\u101B\u1031 {count} \u101C\u102F\u1036\u1038 \u1015\u103C\u100A\u103A\u1037\u1015\u102B\u1015\u103C\u102E", Next: "\u1014\u1031\u102C\u1000\u103A\u101E\u102D\u102F\u1037\u1006\u1000\u103A\u101B\u1014\u103A", "No emoji found": "\u1021\u102E\u1019\u102D\u102F\u1002\u103B\u102E \u101B\u103E\u102C\u1016\u103D\u1031\u1019\u1010\u103D\u1031\u1037\u1014\u102D\u102F\u1004\u103A\u1015\u102B", "No results": "\u101B\u101C\u1012\u103A\u1019\u101B\u103E\u102D\u1015\u102B", Objects: "\u1021\u101B\u102C\u101D\u1010\u1039\u1011\u102F\u1019\u103B\u102C\u1038", "Pause slideshow": "\u1005\u101C\u102D\u102F\u1000\u103A\u101B\u103E\u102D\u102F\u1038 \u1001\u1031\u1010\u1039\u1010\u101B\u1015\u103A\u101B\u1014\u103A", "People & Body": "\u101C\u1030\u1015\u102F\u1002\u1039\u1002\u102D\u102F\u101C\u103A\u1019\u103B\u102C\u1038\u1014\u103E\u1004\u103A\u1037 \u1001\u1014\u1039\u1013\u102C\u1000\u102D\u102F\u101A\u103A", "Pick an emoji": "\u1021\u102E\u1019\u102D\u102F\u1002\u103B\u102E\u101B\u103D\u1031\u1038\u101B\u1014\u103A", "Please select a time zone:": "\u1012\u1031\u101E\u1005\u1036\u1010\u1031\u102C\u103A\u1001\u103B\u102D\u1014\u103A \u101B\u103D\u1031\u1038\u1001\u103B\u101A\u103A\u1015\u1031\u1038\u1015\u102B", Previous: "\u101A\u1001\u1004\u103A", Search: "\u101B\u103E\u102C\u1016\u103D\u1031\u101B\u1014\u103A", "Search results": "\u101B\u103E\u102C\u1016\u103D\u1031\u1019\u103E\u102F \u101B\u101C\u1012\u103A\u1019\u103B\u102C\u1038", "Select a tag": "tag \u101B\u103D\u1031\u1038\u1001\u103B\u101A\u103A\u101B\u1014\u103A", Settings: "\u1001\u103B\u102D\u1014\u103A\u100A\u103E\u102D\u1001\u103B\u1000\u103A\u1019\u103B\u102C\u1038", "Settings navigation": "\u1001\u103B\u102D\u1014\u103A\u100A\u103E\u102D\u1001\u103B\u1000\u103A\u1021\u100A\u103D\u103E\u1014\u103A\u1038", "Smileys & Emotion": "\u1005\u1019\u102D\u102F\u1004\u103A\u101C\u102E\u1019\u103B\u102C\u1038\u1014\u103E\u1004\u103A\u1037 \u1021\u102E\u1019\u102D\u102F\u101B\u103E\u1004\u103A\u1038", "Start slideshow": "\u1005\u101C\u102D\u102F\u1000\u103A\u101B\u103E\u102D\u102F\u1038\u1021\u102C\u1038 \u1005\u1010\u1004\u103A\u101B\u1014\u103A", Submit: "\u1010\u1004\u103A\u101E\u103D\u1004\u103A\u1038\u101B\u1014\u103A", Symbols: "\u101E\u1004\u103A\u1039\u1000\u1031\u1010\u1019\u103B\u102C\u1038", "Travel & Places": "\u1001\u101B\u102E\u1038\u101E\u103D\u102C\u1038\u101C\u102C\u1001\u103C\u1004\u103A\u1038\u1014\u103E\u1004\u103A\u1037 \u1014\u1031\u101B\u102C\u1019\u103B\u102C\u1038", "Type to search time zone": "\u1012\u1031\u101E\u1005\u1036\u1010\u1031\u102C\u103A\u1001\u103B\u102D\u1014\u103A\u1019\u103B\u102C\u1038 \u101B\u103E\u102C\u1016\u103D\u1031\u101B\u1014\u103A \u1005\u102C\u101B\u102D\u102F\u1000\u103A\u1015\u102B", "Unable to search the group": "\u1021\u1016\u103D\u1032\u1037\u1021\u102C\u1038 \u101B\u103E\u102C\u1016\u103D\u1031\u104D \u1019\u101B\u1014\u102D\u102F\u1004\u103A\u1015\u102B", "Write message, @ to mention someone \u2026": "\u1005\u102C\u101B\u1031\u1038\u101E\u102C\u1038\u101B\u1014\u103A\u104A \u1010\u1005\u103A\u1005\u102F\u1036\u1010\u1005\u103A\u1025\u102E\u1038\u1021\u102C\u1038 @ \u1021\u101E\u102F\u1036\u1038\u1015\u103C\u102F \u101B\u100A\u103A\u100A\u103D\u103E\u1014\u103A\u1038\u101B\u1014\u103A..." } }, { locale: "nb_NO", translations: { "{tag} (invisible)": "{tag} (usynlig)", "{tag} (restricted)": "{tag} (beskyttet)", Actions: "Handlinger", Activities: "Aktiviteter", "Animals & Nature": "Dyr og natur", "Avatar of {displayName}": "Avataren til {displayName}", "Avatar of {displayName}, {status}": "{displayName}'s avatar, {status}", "Cancel changes": "Avbryt endringer", Choose: "Velg", Close: "Lukk", "Close navigation": "Lukk navigasjon", "Confirm changes": "Bekreft endringer", Custom: "Tilpasset", "Edit item": "Rediger", "External documentation for {title}": "Ekstern dokumentasjon for {title}", Flags: "Flagg", "Food & Drink": "Mat og drikke", "Frequently used": "Ofte brukt", Global: "Global", "Go back to the list": "G\xE5 tilbake til listen", "Message limit of {count} characters reached": "Karakter begrensing {count} n\xE5dd i melding", Next: "Neste", "No emoji found": "Fant ingen emoji", "No results": "Ingen resultater", Objects: "Objekter", "Open navigation": "\xC5pne navigasjon", "Pause slideshow": "Pause lysbildefremvisning", "People & Body": "Mennesker og kropp", "Pick an emoji": "Velg en emoji", "Please select a time zone:": "Vennligst velg tidssone", Previous: "Forrige", Search: "S\xF8k", "Search results": "S\xF8keresultater", "Select a tag": "Velg en merkelapp", Settings: "Innstillinger", "Settings navigation": "Navigasjons instillinger", "Smileys & Emotion": "Smilefjes og f\xF8lelser", "Start slideshow": "Start lysbildefremvisning", Submit: "Send", Symbols: "Symboler", "Travel & Places": "Reise og steder", "Type to search time zone": "Skriv for \xE5 s\xF8ke etter tidssone", "Unable to search the group": "Kunne ikke s\xF8ke i gruppen", "Undo changes": "Tilbakestill endringer", "Write message, @ to mention someone \u2026": "Bruk @ for \xE5 nevne noen i en melding" } }, { locale: "nl", translations: { "{tag} (invisible)": "{tag} (onzichtbaar)", "{tag} (restricted)": "{tag} (beperkt)", Actions: "Acties", Activities: "Activiteiten", "Animals & Nature": "Dieren & Natuur", "Avatar of {displayName}": "Avatar van {displayName}", "Avatar of {displayName}, {status}": "Avatar van {displayName}, {status}", "Cancel changes": "Wijzigingen annuleren", Choose: "Kies", Close: "Sluiten", "Close navigation": "Navigatie sluiten", "Confirm changes": "Wijzigingen bevestigen", Custom: "Aangepast", "Edit item": "Item bewerken", "External documentation for {title}": "Externe documentatie voor {title}", Flags: "Vlaggen", "Food & Drink": "Eten & Drinken", "Frequently used": "Vaak gebruikt", Global: "Globaal", "Go back to the list": "Ga terug naar de lijst", "Message limit of {count} characters reached": "Berichtlimiet van {count} karakters bereikt", Next: "Volgende", "No emoji found": "Geen emoji gevonden", "No results": "Geen resultaten", Objects: "Objecten", "Open navigation": "Navigatie openen", "Pause slideshow": "Pauzeer diavoorstelling", "People & Body": "Mensen & Lichaam", "Pick an emoji": "Kies een emoji", "Please select a time zone:": "Selecteer een tijdzone:", Previous: "Vorige", Search: "Zoeken", "Search results": "Zoekresultaten", "Select a tag": "Selecteer een label", Settings: "Instellingen", "Settings navigation": "Instellingen navigatie", "Smileys & Emotion": "Smileys & Emotie", "Start slideshow": "Start diavoorstelling", Submit: "Verwerken", Symbols: "Symbolen", "Travel & Places": "Reizen & Plaatsen", "Type to search time zone": "Type om de tijdzone te zoeken", "Unable to search the group": "Kan niet in de groep zoeken", "Undo changes": "Wijzigingen ongedaan maken", "Write message, @ to mention someone, : for emoji autocompletion \u2026": "Schrijf bericht, @ om iemand te noemen, : voor emoji auto-aanvullen ..." } }, { locale: "oc", translations: { "{tag} (invisible)": "{tag} (invisible)", "{tag} (restricted)": "{tag} (limit)", Actions: "Accions", Choose: "Causir", Close: "Tampar", Next: "Seguent", "No results": "Cap de resultat", "Pause slideshow": "Metre en pausa lo diaporama", Previous: "Precedent", "Select a tag": "Seleccionar una etiqueta", Settings: "Param\xE8tres", "Start slideshow": "Lan\xE7ar lo diaporama" } }, { locale: "pl", translations: { "{tag} (invisible)": "{tag} (niewidoczna)", "{tag} (restricted)": "{tag} (ograniczona)", Actions: "Dzia\u0142ania", Activities: "Aktywno\u015B\u0107", "Animals & Nature": "Zwierz\u0119ta i natura", "Avatar of {displayName}": "Awatar {displayName}", "Avatar of {displayName}, {status}": "Awatar {displayName}, {status}", "Cancel changes": "Anuluj zmiany", Choose: "Wybierz", Close: "Zamknij", "Close navigation": "Zamknij nawigacj\u0119", "Confirm changes": "Potwierd\u017A zmiany", Custom: "Zwyczajne", "Edit item": "Edytuj element", "External documentation for {title}": "Dokumentacja zewn\u0119trzna dla {title}", Flags: "Flagi", "Food & Drink": "Jedzenie i picie", "Frequently used": "Cz\u0119sto u\u017Cywane", Global: "Globalnie", "Go back to the list": "Powr\xF3t do listy", "Message limit of {count} characters reached": "Przekroczono limit wiadomo\u015Bci wynosz\u0105cy {count} znak\xF3w", Next: "Nast\u0119pny", "No emoji found": "Nie znaleziono emotikon\xF3w", "No results": "Brak wynik\xF3w", Objects: "Obiekty", "Open navigation": "Otw\xF3rz nawigacj\u0119", "Pause slideshow": "Wstrzymaj pokaz slajd\xF3w", "People & Body": "Ludzie i cia\u0142o", "Pick an emoji": "Wybierz emoji", "Please select a time zone:": "Wybierz stref\u0119 czasow\u0105:", Previous: "Poprzedni", Search: "Szukaj", "Search results": "Wyniki wyszukiwania", "Select a tag": "Wybierz etykiet\u0119", Settings: "Ustawienia", "Settings navigation": "Ustawienia nawigacji", "Smileys & Emotion": "Bu\u017Aki i emotikony", "Start slideshow": "Rozpocznij pokaz slajd\xF3w", Submit: "Wy\u015Blij", Symbols: "Symbole", "Travel & Places": "Podr\xF3\u017Ce i miejsca", "Type to search time zone": "Wpisz, aby wyszuka\u0107 stref\u0119 czasow\u0105", "Unable to search the group": "Nie mo\u017Cna przeszuka\u0107 grupy", "Undo changes": "Cofnij zmiany", "Write message, @ to mention someone, : for emoji autocompletion \u2026": "Napisz wiadomo\u015B\u0107, @ aby o kim\u015B wspomnie\u0107, : dla autouzupe\u0142niania emotikon\xF3w\u2026" } }, { locale: "pt_BR", translations: { "{tag} (invisible)": "{tag} (invis\xEDvel)", "{tag} (restricted)": "{tag} (restrito) ", Actions: "A\xE7\xF5es", Activities: "Atividades", "Animals & Nature": "Animais & Natureza", "Avatar of {displayName}": "Avatar de {displayName}", "Avatar of {displayName}, {status}": "Avatar de {displayName}, {status}", "Cancel changes": "Cancelar altera\xE7\xF5es", Choose: "Escolher", Close: "Fechar", "Close navigation": "Fechar navega\xE7\xE3o", "Confirm changes": "Confirmar altera\xE7\xF5es", Custom: "Personalizado", "Edit item": "Editar item", "External documentation for {title}": "Documenta\xE7\xE3o externa para {title}", Flags: "Bandeiras", "Food & Drink": "Comida & Bebida", "Frequently used": "Mais usados", Global: "Global", "Go back to the list": "Volte para a lista", "Message limit of {count} characters reached": "Limite de mensagem de {count} caracteres atingido", Next: "Pr\xF3ximo", "No emoji found": "Nenhum emoji encontrado", "No results": "Sem resultados", Objects: "Objetos", "Open navigation": "Abrir navega\xE7\xE3o", "Pause slideshow": "Pausar apresenta\xE7\xE3o de slides", "People & Body": "Pessoas & Corpo", "Pick an emoji": "Escolha um emoji", "Please select a time zone:": "Selecione um fuso hor\xE1rio: ", Previous: "Anterior", Search: "Pesquisar", "Search results": "Resultados da pesquisa", "Select a tag": "Selecionar uma tag", Settings: "Configura\xE7\xF5es", "Settings navigation": "Navega\xE7\xE3o de configura\xE7\xF5es", "Smileys & Emotion": "Smiles & Emo\xE7\xF5es", "Start slideshow": "Iniciar apresenta\xE7\xE3o de slides", Submit: "Enviar", Symbols: "S\xEDmbolo", "Travel & Places": "Viagem & Lugares", "Type to search time zone": "Digite para pesquisar o fuso hor\xE1rio ", "Unable to search the group": "N\xE3o foi poss\xEDvel pesquisar o grupo", "Undo changes": "Desfazer modifica\xE7\xF5es", "Write message, @ to mention someone, : for emoji autocompletion \u2026": "Escreva mensagem, @ para mencionar algu\xE9m, : para autocomple\xE7\xE3o emoji..." } }, { locale: "pt_PT", translations: { "{tag} (invisible)": "{tag} (invisivel)", "{tag} (restricted)": "{tag} (restrito)", Actions: "A\xE7\xF5es", Choose: "Escolher", Close: "Fechar", Next: "Seguinte", "No results": "Sem resultados", "Pause slideshow": "Pausar diaporama", Previous: "Anterior", "Select a tag": "Selecionar uma etiqueta", Settings: "Defini\xE7\xF5es", "Start slideshow": "Iniciar diaporama", "Unable to search the group": "N\xE3o \xE9 poss\xEDvel pesquisar o grupo" } }, { locale: "ru", translations: { "{tag} (invisible)": "{tag} (\u043D\u0435\u0432\u0438\u0434\u0438\u043C\u043E\u0435)", "{tag} (restricted)": "{tag} (\u043E\u0433\u0440\u0430\u043D\u0438\u0447\u0435\u043D\u043D\u043E\u0435)", Actions: "\u0414\u0435\u0439\u0441\u0442\u0432\u0438\u044F ", Activities: "\u0421\u043E\u0431\u044B\u0442\u0438\u044F", "Animals & Nature": "\u0416\u0438\u0432\u043E\u0442\u043D\u044B\u0435 \u0438 \u043F\u0440\u0438\u0440\u043E\u0434\u0430 ", "Avatar of {displayName}": "\u0410\u0432\u0430\u0442\u0430\u0440 {displayName}", "Cancel changes": "\u041E\u0442\u043C\u0435\u043D\u0438\u0442\u044C \u0438\u0437\u043C\u0435\u043D\u0435\u043D\u0438\u044F", Choose: "\u0412\u044B\u0431\u0435\u0440\u0438\u0442\u0435", Close: "\u0417\u0430\u043A\u0440\u044B\u0442\u044C", "Confirm changes": "\u041F\u043E\u0434\u0442\u0432\u0435\u0440\u0434\u0438\u0442\u044C \u0438\u0437\u043C\u0435\u043D\u0435\u043D\u0438\u044F", Custom: "\u041F\u043E\u043B\u044C\u0437\u043E\u0432\u0430\u0442\u0435\u043B\u044C\u0441\u043A\u043E\u0435", "External documentation for {title}": "\u0412\u043D\u0435\u0448\u043D\u044F\u044F \u0434\u043E\u043A\u0443\u043C\u0435\u043D\u0442\u0430\u0446\u0438\u044F \u0434\u043B\u044F {title}", Flags: "\u0424\u043B\u0430\u0433\u0438", "Food & Drink": "\u0415\u0434\u0430, \u043D\u0430\u043F\u0438\u0442\u043E\u043A", "Frequently used": "\u0427\u0430\u0441\u0442\u043E \u0438\u0441\u043F\u043E\u043B\u044C\u0437\u0443\u0435\u043C\u044B\u0439", Global: "\u0413\u043B\u043E\u0431\u0430\u043B\u044C\u043D\u044B\u0439", "Message limit of {count} characters reached": "\u0414\u043E\u0441\u0442\u0438\u0433\u043D\u0443\u0442\u043E \u043E\u0433\u0440\u0430\u043D\u0438\u0447\u0435\u043D\u0438\u0435 \u043D\u0430 \u043A\u043E\u043B\u0438\u0447\u0435\u0441\u0442\u0432\u043E \u0441\u0438\u043C\u0432\u043E\u043B\u043E\u0432 \u0432 {count}", Next: "\u0421\u043B\u0435\u0434\u0443\u044E\u0449\u0435\u0435", "No emoji found": "\u042D\u043C\u043E\u0434\u0437\u0438 \u043D\u0435 \u043D\u0430\u0439\u0434\u0435\u043D\u043E", "No results": "\u0420\u0435\u0437\u0443\u043B\u044C\u0442\u0430\u0442\u044B \u043E\u0442\u0441\u0443\u0441\u0442\u0432\u0443\u044E\u0442", Objects: "\u041E\u0431\u044A\u0435\u043A\u0442\u044B", "Pause slideshow": "\u041F\u0440\u0438\u043E\u0441\u0442\u0430\u043D\u043E\u0432\u0438\u0442\u044C \u043F\u043E\u043A\u0430\u0437 \u0441\u043B\u0439\u0434\u043E\u0432", "People & Body": "\u041B\u044E\u0434\u0438 \u0438 \u0442\u0435\u043B\u043E", "Pick an emoji": "\u0412\u044B\u0431\u0435\u0440\u0438\u0442\u0435 \u044D\u043C\u043E\u0434\u0437\u0438", "Please select a time zone:": "\u041F\u043E\u0436\u0430\u043B\u0443\u0439\u0441\u0442\u0430, \u0432\u044B\u0431\u0435\u0440\u0438\u0442\u0435 \u0447\u0430\u0441\u043E\u0432\u043E\u0439 \u043F\u043E\u044F\u0441:", Previous: "\u041F\u0440\u0435\u0434\u044B\u0434\u0443\u0449\u0435\u0435", Search: "\u041F\u043E\u0438\u0441\u043A", "Search results": "\u0420\u0435\u0437\u0443\u043B\u044C\u0442\u0430\u0442\u044B \u043F\u043E\u0438\u0441\u043A\u0430", "Select a tag": "\u0412\u044B\u0431\u0435\u0440\u0438\u0442\u0435 \u043C\u0435\u0442\u043A\u0443", Settings: "\u041F\u0430\u0440\u0430\u043C\u0435\u0442\u0440\u044B", "Settings navigation": "\u041D\u0430\u0432\u0438\u0433\u0430\u0446\u0438\u044F \u043F\u043E \u043D\u0430\u0441\u0442\u0440\u043E\u0439\u043A\u0430\u043C", "Smileys & Emotion": "\u0421\u043C\u0430\u0439\u043B\u0438\u043A\u0438 \u0438 \u044D\u043C\u043E\u0446\u0438\u0438", "Start slideshow": "\u041D\u0430\u0447\u0430\u0442\u044C \u043F\u043E\u043A\u0430\u0437 \u0441\u043B\u0430\u0439\u0434\u043E\u0432", Submit: "\u0423\u0442\u0432\u0435\u0440\u0434\u0438\u0442\u044C", Symbols: "\u0421\u0438\u043C\u0432\u043E\u043B\u044B", "Travel & Places": "\u041F\u0443\u0442\u0435\u0448\u0435\u0441\u0442\u0432\u0438\u044F \u0438 \u043C\u0435\u0441\u0442\u0430", "Type to search time zone": "\u0412\u0432\u0435\u0434\u0438\u0442\u0435 \u0434\u043B\u044F \u043F\u043E\u0438\u0441\u043A\u0430 \u0447\u0430\u0441\u043E\u0432\u043E\u0433\u043E \u043F\u043E\u044F\u0441\u0430", "Unable to search the group": "\u041D\u0435\u0432\u043E\u0437\u043C\u043E\u0436\u043D\u043E \u043D\u0430\u0439\u0442\u0438 \u0433\u0440\u0443\u043F\u043F\u0443", "Write message, @ to mention someone \u2026": "\u041D\u0430\u043F\u0438\u0448\u0438\u0442\u0435 \u0441\u043E\u043E\u0431\u0449\u0435\u043D\u0438\u0435, \u0438\u0441\u043F\u043E\u043B\u044C\u0437\u0443\u0439\u0442\u0435 @ \u0447\u0442\u043E\u0431\u044B \u0443\u043F\u043E\u043C\u044F\u043D\u0443\u0442\u044C \u043A\u043E\u0433\u043E-\u0442\u043E\u2026" } }, { locale: "sk_SK", translations: { "{tag} (invisible)": "{tag} (nevidite\u013En\xFD)", "{tag} (restricted)": "{tag} (obmedzen\xFD)", Actions: "Akcie", Activities: "Aktivity", "Animals & Nature": "Zvierat\xE1 a pr\xEDroda", "Avatar of {displayName}": "Avatar {displayName}", "Avatar of {displayName}, {status}": "Avatar {displayName}, {status}", "Cancel changes": "Zru\u0161i\u0165 zmeny", Choose: "Vybra\u0165", Close: "Zatvori\u0165", "Close navigation": "Zavrie\u0165 navig\xE1ciu", "Confirm changes": "Potvrdi\u0165 zmeny", Custom: "Zvyk", "Edit item": "Upravi\u0165 polo\u017Eku", "External documentation for {title}": "Extern\xE1 dokument\xE1cia pre {title}", Flags: "Vlajky", "Food & Drink": "Jedlo a n\xE1poje", "Frequently used": "\u010Casto pou\u017E\xEDvan\xE9", Global: "Glob\xE1lne", "Go back to the list": "Nasp\xE4\u0165 na zoznam", "Message limit of {count} characters reached": "Limit spr\xE1vy na {count} znakov dosiahnut\xFD", Next: "\u010Eal\u0161\xED", "No emoji found": "Nena\u0161li sa \u017Eiadne emod\u017Ei", "No results": "\u017Diadne v\xFDsledky", Objects: "Objekty", "Open navigation": "Otvori\u0165 navig\xE1ciu", "Pause slideshow": "Pozastavi\u0165 prezent\xE1ciu", "People & Body": "\u013Dudia a telo", "Pick an emoji": "Vyberte si emod\u017Ei", "Please select a time zone:": "Pros\xEDm vyberte \u010Dasov\xFA z\xF3nu:", Previous: "Predch\xE1dzaj\xFAci", Search: "H\u013Eada\u0165", "Search results": "V\xFDsledky vyh\u013Ead\xE1vania", "Select a tag": "Vybra\u0165 \u0161t\xEDtok", Settings: "Nastavenia", "Settings navigation": "Navig\xE1cia v nastaveniach", "Smileys & Emotion": "Smajl\xEDky a em\xF3cie", "Start slideshow": "Za\u010Da\u0165 prezent\xE1ciu", Submit: "Odosla\u0165", Symbols: "Symboly", "Travel & Places": "Cestovanie a miesta", "Type to search time zone": "Za\u010Dn\xEDte p\xEDsa\u0165 pre vyh\u013Ead\xE1vanie \u010Dasovej z\xF3ny", "Unable to search the group": "Skupinu sa nepodarilo n\xE1js\u0165", "Undo changes": "Vr\xE1ti\u0165 zmeny", "Write message, @ to mention someone, : for emoji autocompletion \u2026": "Nap\xED\u0161te spr\xE1vu, @ ak chcete niekoho spomen\xFA\u0165, : pre automatick\xE9 dop\u013A\u0148anie emotikonov\u2026" } }, { locale: "sl", translations: { "{tag} (invisible)": "{tag} (nevidno)", "{tag} (restricted)": "{tag} (omejeno)", Actions: "Dejanja", Activities: "Dejavnosti", "Animals & Nature": "\u017Divali in Narava", "Avatar of {displayName}": "Podoba {displayName}", "Cancel changes": "Prekli\u010Di spremembe", Choose: "Izbor", Close: "Zapri", "Confirm changes": "Potrdi spremembe", Custom: "Po meri", "External documentation for {title}": "Zunanja dokumentacija za {title}", Flags: "Zastavice", "Food & Drink": "Hrana in Pija\u010Da", "Frequently used": "Pogostost uporabe", Global: "Splo\u0161no", "Message limit of {count} characters reached": "Dose\u017Eena omejitev {count} znakov na sporo\u010Dilo.", Next: "Naslednji", "No emoji found": "Ni najdenih izraznih ikon", "No results": "Ni zadetkov", Objects: "Predmeti", "Pause slideshow": "Ustavi predstavitev", "People & Body": "Ljudje in Telo", "Pick an emoji": "Izbor izrazne ikone", "Please select a time zone:": "Izbor \u010Dasovnega pasu:", Previous: "Predhodni", Search: "Iskanje", "Search results": "Zadetki iskanja", "Select a tag": "Izbor oznake", Settings: "Nastavitve", "Settings navigation": "Krmarjenje nastavitev", "Smileys & Emotion": "Izrazne ikone", "Start slideshow": "Za\u010Dni predstavitev", Submit: "Po\u0161lji", Symbols: "Simboli", "Travel & Places": "Potovanja in Kraji", "Type to search time zone": "Vpi\u0161ite niz za iskanje \u010Dasovnega pasu", "Unable to search the group": "Ni mogo\u010De iskati po skupini", "Write message, @ to mention someone \u2026": "Napi\u0161ite sporo\u010Dilo, z @ omenite osebo ..." } }, { locale: "sv", translations: { "{tag} (invisible)": "{tag} (osynlig)", "{tag} (restricted)": "{tag} (begr\xE4nsad)", Actions: "\xC5tg\xE4rder", Activities: "Aktiviteter", "Animals & Nature": "Djur & Natur", "Avatar of {displayName}": "{displayName}s avatar", "Avatar of {displayName}, {status}": "{displayName}s avatar, {status}", "Cancel changes": "Avbryt \xE4ndringar", Choose: "V\xE4lj", Close: "St\xE4ng", "Close navigation": "St\xE4ng navigering", "Confirm changes": "Bekr\xE4fta \xE4ndringar", Custom: "Anpassad", "Edit item": "\xC4ndra", "External documentation for {title}": "Extern dokumentation f\xF6r {title}", Flags: "Flaggor", "Food & Drink": "Mat & Dryck", "Frequently used": "Anv\xE4nds ofta", Global: "Global", "Go back to the list": "G\xE5 tillbaka till listan", "Message limit of {count} characters reached": "Meddelandegr\xE4ns {count} tecken anv\xE4nds", Next: "N\xE4sta", "No emoji found": "Hittade inga emojis", "No results": "Inga resultat", Objects: "Objekt", "Open navigation": "\xD6ppna navigering", "Pause slideshow": "Pausa bildspelet", "People & Body": "Kropp & Sj\xE4l", "Pick an emoji": "V\xE4lj en emoji", "Please select a time zone:": "V\xE4lj tidszon:", Previous: "F\xF6reg\xE5ende", Search: "S\xF6k", "Search results": "S\xF6kresultat", "Select a tag": "V\xE4lj en tag", Settings: "Inst\xE4llningar", "Settings navigation": "Inst\xE4llningsmeny", "Smileys & Emotion": "Selfies & K\xE4nslor", "Start slideshow": "Starta bildspelet", Submit: "Skicka", Symbols: "Symboler", "Travel & Places": "Resor & Sev\xE4rdigheter", "Type to search time zone": "Skriv f\xF6r att v\xE4lja tidszon", "Unable to search the group": "Kunde inte s\xF6ka i gruppen", "Undo changes": "\xC5ngra \xE4ndringar", "Write message, @ to mention someone, : for emoji autocompletion \u2026": "Skriv meddelande, @ f\xF6r att n\xE4mna n\xE5gon, : f\xF6r automatiska emojif\xF6rslag ..." } }, { locale: "tr", translations: { "{tag} (invisible)": "{tag} (g\xF6r\xFCnmez)", "{tag} (restricted)": "{tag} (k\u0131s\u0131tl\u0131)", Actions: "\u0130\u015Flemler", Activities: "Etkinlikler", "Animals & Nature": "Hayvanlar ve Do\u011Fa", "Avatar of {displayName}": "{displayName} avatar\u0131", "Avatar of {displayName}, {status}": "{displayName}, {status} avatar\u0131", "Cancel changes": "De\u011Fi\u015Fiklikleri iptal et", Choose: "Se\xE7in", Close: "Kapat", "Close navigation": "Gezinmeyi kapat", "Confirm changes": "De\u011Fi\u015Fiklikleri onayla", Custom: "\xD6zel", "Edit item": "\xD6geyi d\xFCzenle", "External documentation for {title}": "{title} i\xE7in d\u0131\u015F belgeler", Flags: "Bayraklar", "Food & Drink": "Yeme ve \u0130\xE7me", "Frequently used": "S\u0131k kullan\u0131lanlar", Global: "Evrensel", "Go back to the list": "Listeye d\xF6n", "Message limit of {count} characters reached": "{count} karakter ileti s\u0131n\u0131r\u0131na ula\u015F\u0131ld\u0131", Next: "Sonraki", "No emoji found": "Herhangi bir emoji bulunamad\u0131", "No results": "Herhangi bir sonu\xE7 bulunamad\u0131", Objects: "Nesneler", "Open navigation": "Gezinmeyi a\xE7", "Pause slideshow": "Slayt sunumunu duraklat", "People & Body": "\u0130nsanlar ve Beden", "Pick an emoji": "Bir emoji se\xE7in", "Please select a time zone:": "L\xFCtfen bir saat dilimi se\xE7in:", Previous: "\xD6nceki", Search: "Arama", "Search results": "Arama sonu\xE7lar\u0131", "Select a tag": "Bir etiket se\xE7in", Settings: "Ayarlar", "Settings navigation": "Gezinme ayarlar\u0131", "Smileys & Emotion": "\u0130fadeler ve Duygular", "Start slideshow": "Slayt sunumunu ba\u015Flat", Submit: "G\xF6nder", Symbols: "Simgeler", "Travel & Places": "Gezi ve Yerler", "Type to search time zone": "Saat dilimi aramak i\xE7in yazmaya ba\u015Flay\u0131n", "Unable to search the group": "Grupta arama yap\u0131lamad\u0131", "Undo changes": "De\u011Fi\u015Fiklikleri geri al", "Write message, @ to mention someone, : for emoji autocompletion \u2026": "\u0130leti yaz\u0131n, birini anmak i\xE7in @, otomatik emoji tamamlamak i\xE7in : kullan\u0131n\u2026" } }, { locale: "uk", translations: { "{tag} (invisible)": "{tag} (invisible)", "{tag} (restricted)": "{tag} (restricted)", Actions: "\u0414\u0456\u0457", Activities: "\u0414\u0456\u044F\u043B\u044C\u043D\u0456\u0441\u0442\u044C", "Animals & Nature": "\u0422\u0432\u0430\u0440\u0438\u043D\u0438 \u0442\u0430 \u043F\u0440\u0438\u0440\u043E\u0434\u0430", Choose: "\u0412\u0438\u0431\u0435\u0440\u0456\u0442\u044C", Close: "\u0417\u0430\u043A\u0440\u0438\u0442\u0438", Custom: "\u0412\u043B\u0430\u0441\u043D\u0435", Flags: "\u041F\u0440\u0430\u043F\u043E\u0440\u0438", "Food & Drink": "\u0407\u0436\u0430 \u0442\u0430 \u043D\u0430\u043F\u0438\u0442\u043A\u0438", "Frequently used": "\u041D\u0430\u0439\u0447\u0430\u0441\u0442\u0456\u0448\u0456", Next: "\u0412\u043F\u0435\u0440\u0435\u0434", "No emoji found": "\u0415\u043C\u043E\u0446\u0456\u0439\u043A\u0438 \u0432\u0456\u0434\u0441\u0443\u0442\u043D\u0456", "No results": "\u0412\u0456\u0434\u0441\u0443\u0442\u043D\u0456 \u0440\u0435\u0437\u0443\u043B\u044C\u0442\u0430\u0442\u0438", Objects: "\u041E\u0431'\u0454\u043A\u0442\u0438", "Pause slideshow": "\u041F\u0430\u0443\u0437\u0430 \u0443 \u043F\u043E\u043A\u0430\u0437\u0456 \u0441\u043B\u0430\u0439\u0434\u0456\u0432", "People & Body": "\u041B\u044E\u0434\u0438 \u0442\u0430 \u0436\u0435\u0441\u0442\u0438", "Pick an emoji": "\u0412\u0438\u0431\u0435\u0440\u0456\u0442\u044C \u0435\u043C\u043E\u0446\u0456\u0439\u043A\u0443", Previous: "\u041D\u0430\u0437\u0430\u0434", Search: "\u041F\u043E\u0448\u0443\u043A", "Search results": "\u0420\u0435\u0437\u0443\u043B\u044C\u0442\u0430\u0442\u0438 \u043F\u043E\u0448\u0443\u043A\u0443", "Select a tag": "\u0412\u0438\u0431\u0435\u0440\u0456\u0442\u044C \u043F\u043E\u0437\u043D\u0430\u0447\u043A\u0443", Settings: "\u041D\u0430\u043B\u0430\u0448\u0442\u0443\u0432\u0430\u043D\u043D\u044F", "Smileys & Emotion": "\u0423\u0441\u043C\u0456\u0445\u0430\u0439\u043B\u0438\u043A\u0438 \u0442\u0430 \u0435\u043C\u043E\u0446\u0456\u0439\u043A\u0438", "Start slideshow": "\u041F\u043E\u0447\u0430\u0442\u0438 \u043F\u043E\u043A\u0430\u0437 \u0441\u043B\u0430\u0439\u0434\u0456\u0432", Symbols: "\u0421\u0438\u043C\u0432\u043E\u043B\u0438", "Travel & Places": "\u041F\u043E\u0457\u0437\u0434\u043A\u0438 \u0442\u0430 \u043C\u0456\u0441\u0446\u044F", "Unable to search the group": "\u041D\u0435\u043C\u043E\u0436\u043B\u0438\u0432\u043E \u0448\u0443\u043A\u0430\u0442\u0438 \u0432 \u0433\u0440\u0443\u043F\u0456" } }, { locale: "zh_CN", translations: { "{tag} (invisible)": "{tag} \uFF08\u4E0D\u53EF\u89C1\uFF09", "{tag} (restricted)": "{tag} \uFF08\u53D7\u9650\uFF09", Actions: "\u884C\u4E3A", Activities: "\u6D3B\u52A8", "Animals & Nature": "\u52A8\u7269 & \u81EA\u7136", "Avatar of {displayName}": "{displayName}\u7684\u5934\u50CF", "Avatar of {displayName}, {status}": "{displayName}\u7684\u5934\u50CF\uFF0C{status}", "Cancel changes": "\u53D6\u6D88\u66F4\u6539", Choose: "\u9009\u62E9", Close: "\u5173\u95ED", "Close navigation": "\u5173\u95ED\u5BFC\u822A", "Confirm changes": "\u786E\u8BA4\u66F4\u6539", Custom: "\u81EA\u5B9A\u4E49", "Edit item": "\u7F16\u8F91\u9879\u76EE", "External documentation for {title}": "{title}\u7684\u5916\u90E8\u6587\u6863", Flags: "\u65D7\u5E1C", "Food & Drink": "\u98DF\u7269 & \u996E\u54C1", "Frequently used": "\u7ECF\u5E38\u4F7F\u7528", Global: "\u5168\u5C40", "Go back to the list": "\u8FD4\u56DE\u81F3\u5217\u8868", "Message limit of {count} characters reached": "\u5DF2\u8FBE\u5230 {count} \u4E2A\u5B57\u7B26\u7684\u6D88\u606F\u9650\u5236", Next: "\u4E0B\u4E00\u4E2A", "No emoji found": "\u8868\u60C5\u672A\u627E\u5230", "No results": "\u65E0\u7ED3\u679C", Objects: "\u7269\u4F53", "Open navigation": "\u5F00\u542F\u5BFC\u822A", "Pause slideshow": "\u6682\u505C\u5E7B\u706F\u7247", "People & Body": "\u4EBA & \u8EAB\u4F53", "Pick an emoji": "\u9009\u62E9\u4E00\u4E2A\u8868\u60C5", "Please select a time zone:": "\u8BF7\u9009\u62E9\u4E00\u4E2A\u65F6\u533A\uFF1A", Previous: "\u4E0A\u4E00\u4E2A", Search: "\u641C\u7D22", "Search results": "\u641C\u7D22\u7ED3\u679C", "Select a tag": "\u9009\u62E9\u4E00\u4E2A\u6807\u7B7E", Settings: "\u8BBE\u7F6E", "Settings navigation": "\u8BBE\u7F6E\u5411\u5BFC", "Smileys & Emotion": "\u7B11\u8138 & \u60C5\u611F", "Start slideshow": "\u5F00\u59CB\u5E7B\u706F\u7247", Submit: "\u63D0\u4EA4", Symbols: "\u7B26\u53F7", "Travel & Places": "\u65C5\u6E38 & \u5730\u70B9", "Type to search time zone": "\u6253\u5B57\u4EE5\u641C\u7D22\u65F6\u533A", "Unable to search the group": "\u65E0\u6CD5\u641C\u7D22\u5206\u7EC4", "Undo changes": "\u64A4\u9500\u66F4\u6539", "Write message, @ to mention someone, : for emoji autocompletion \u2026": "\u5199\u4FE1\u606F\uFF0C@ \u63D0\u5230\u67D0\u4EBA\uFF0C: \u7528\u4E8E\u8868\u60C5\u7B26\u53F7\u81EA\u52A8\u5B8C\u6210 ..." } }, { locale: "zh_HK", translations: { "{tag} (invisible)": "{tag} (\u96B1\u85CF)", "{tag} (restricted)": "{tag} (\u53D7\u9650)", Actions: "\u52D5\u4F5C", Activities: "\u6D3B\u52D5", "Animals & Nature": "\u52D5\u7269\u8207\u81EA\u7136", "Avatar of {displayName}": "{displayName} \u7684\u982D\u50CF", "Avatar of {displayName}, {status}": "{displayName}\u7684\u982D\u50CF\uFF0C{status}", "Cancel changes": "\u53D6\u6D88\u66F4\u6539", Choose: "\u9078\u64C7", Close: "\u95DC\u9589", "Close navigation": "\u95DC\u9589\u5C0E\u822A", "Confirm changes": "\u78BA\u8A8D\u66F4\u6539", Custom: "\u81EA\u5B9A\u7FA9", "Edit item": "\u7DE8\u8F2F\u9805\u76EE", "External documentation for {title}": "{title} \u7684\u5916\u90E8\u6587\u6A94", Flags: "\u65D7\u5E5F", "Food & Drink": "\u98DF\u7269\u8207\u98F2\u6599", "Frequently used": "\u7D93\u5E38\u4F7F\u7528", Global: "\u5168\u7403\u7684", "Go back to the list": "\u8FD4\u56DE\u6E05\u55AE", "Message limit of {count} characters reached": "\u5DF2\u9054\u5230\u8A0A\u606F\u6700\u591A {count} \u5B57\u5143\u9650\u5236", Next: "\u4E0B\u4E00\u500B", "No emoji found": "\u672A\u627E\u5230\u8868\u60C5\u7B26\u865F", "No results": "\u7121\u7D50\u679C", Objects: "\u7269\u4EF6", "Open navigation": "\u958B\u555F\u5C0E\u822A", "Pause slideshow": "\u66AB\u505C\u5E7B\u71C8\u7247", "People & Body": "\u4EBA\u7269", "Pick an emoji": "\u9078\u64C7\u8868\u60C5\u7B26\u865F", "Please select a time zone:": "\u8ACB\u9078\u64C7\u6642\u5340\uFF1A", Previous: "\u4E0A\u4E00\u500B", Search: "\u641C\u5C0B", "Search results": "\u641C\u5C0B\u7D50\u679C", "Select a tag": "\u9078\u64C7\u6A19\u7C64", Settings: "\u8A2D\u5B9A", "Settings navigation": "\u8A2D\u5B9A\u503C\u5C0E\u89BD", "Smileys & Emotion": "\u8868\u60C5", "Start slideshow": "\u958B\u59CB\u5E7B\u71C8\u7247", Submit: "\u63D0\u4EA4", Symbols: "\u6A19\u8A8C", "Travel & Places": "\u65C5\u904A\u8207\u666F\u9EDE", "Type to search time zone": "\u9375\u5165\u4EE5\u641C\u7D22\u6642\u5340", "Unable to search the group": "\u7121\u6CD5\u641C\u5C0B\u7FA4\u7D44", "Undo changes": "\u53D6\u6D88\u66F4\u6539", "Write message, @ to mention someone \u2026": "\u8F38\u5165\u8A0A\u606F\u6642\u53EF\u4F7F\u7528 @ \u4F86\u6A19\u793A\u67D0\u4EBA..." } }, { locale: "zh_TW", translations: { "{tag} (invisible)": "{tag} (\u96B1\u85CF)", "{tag} (restricted)": "{tag} (\u53D7\u9650)", Actions: "\u52D5\u4F5C", Activities: "\u6D3B\u52D5", "Animals & Nature": "\u52D5\u7269\u8207\u81EA\u7136", Choose: "\u9078\u64C7", Close: "\u95DC\u9589", Custom: "\u81EA\u5B9A\u7FA9", Flags: "\u65D7\u5E5F", "Food & Drink": "\u98DF\u7269\u8207\u98F2\u6599", "Frequently used": "\u6700\u8FD1\u4F7F\u7528", "Message limit of {count} characters reached": "\u5DF2\u9054\u5230\u8A0A\u606F\u6700\u591A {count} \u5B57\u5143\u9650\u5236", Next: "\u4E0B\u4E00\u500B", "No emoji found": "\u672A\u627E\u5230\u8868\u60C5\u7B26\u865F", "No results": "\u7121\u7D50\u679C", Objects: "\u7269\u4EF6", "Pause slideshow": "\u66AB\u505C\u5E7B\u71C8\u7247", "People & Body": "\u4EBA\u7269", "Pick an emoji": "\u9078\u64C7\u8868\u60C5\u7B26\u865F", Previous: "\u4E0A\u4E00\u500B", Search: "\u641C\u5C0B", "Search results": "\u641C\u5C0B\u7D50\u679C", "Select a tag": "\u9078\u64C7\u6A19\u7C64", Settings: "\u8A2D\u5B9A", "Settings navigation": "\u8A2D\u5B9A\u503C\u5C0E\u89BD", "Smileys & Emotion": "\u8868\u60C5", "Start slideshow": "\u958B\u59CB\u5E7B\u71C8\u7247", Symbols: "\u6A19\u8A8C", "Travel & Places": "\u65C5\u904A\u8207\u666F\u9EDE", "Unable to search the group": "\u7121\u6CD5\u641C\u5C0B\u7FA4\u7D44", "Write message, @ to mention someone \u2026": "\u8F38\u5165\u8A0A\u606F\u6642\u53EF\u4F7F\u7528 @ \u4F86\u6A19\u793A\u67D0\u4EBA..." } }].forEach(function(e3) {
          var t3 = {};
          for (var n3 in e3.translations)
            e3.translations[n3].pluralId ? t3[n3] = { msgid: n3, msgid_plural: e3.translations[n3].pluralId, msgstr: e3.translations[n3].msgstr } : t3[n3] = { msgid: n3, msgstr: [e3.translations[n3]] };
          a2.addTranslation(e3.locale, { translations: { "": t3 } });
        });
        var i = a2.build(), o = (i.ngettext.bind(i), i.gettext.bind(i));
      }, 1205: function(e2, t2) {
        t2.Z = function(e3) {
          return Math.random().toString(36).replace(/[^a-z]+/g, "").slice(0, e3 || 5);
        };
      }, 6051: function(e2, t2, n2) {
        var a2 = n2(4015), i = n2.n(a2), o = n2(3645), r = n2.n(o)()(i());
        r.push([e2.id, ".material-design-icon{display:flex;align-self:center;justify-self:center;align-items:center;justify-content:center}.vue-tooltip[data-v-17fd6e1]{position:absolute;z-index:100000;right:auto;left:auto;display:block;margin:0;margin-top:-3px;padding:10px 0;text-align:left;text-align:start;opacity:0;line-height:1.6;line-break:auto;filter:drop-shadow(0 1px 10px var(--color-box-shadow))}.vue-tooltip[data-v-17fd6e1][x-placement^='top'] .tooltip-arrow{bottom:0;border-bottom-width:0;border-top-color:var(--color-main-background)}.vue-tooltip[data-v-17fd6e1][x-placement^='bottom'] .tooltip-arrow{top:0;border-top-width:0;border-bottom-color:var(--color-main-background)}.vue-tooltip[data-v-17fd6e1][x-placement^='right'] .tooltip-arrow{right:100%;border-left-width:0;border-right-color:var(--color-main-background)}.vue-tooltip[data-v-17fd6e1][x-placement^='left'] .tooltip-arrow{left:100%;border-right-width:0;border-left-color:var(--color-main-background)}.vue-tooltip[data-v-17fd6e1][aria-hidden='true']{visibility:hidden;transition:opacity .15s, visibility .15s;opacity:0}.vue-tooltip[data-v-17fd6e1][aria-hidden='false']{visibility:visible;transition:opacity .15s;opacity:1}.vue-tooltip[data-v-17fd6e1] .tooltip-inner{max-width:350px;padding:5px 8px;text-align:center;color:var(--color-main-text);border-radius:var(--border-radius);background-color:var(--color-main-background)}.vue-tooltip[data-v-17fd6e1] .tooltip-arrow{position:absolute;z-index:1;width:0;height:0;margin:0;border-style:solid;border-color:transparent;border-width:10px}\n", "", { version: 3, sources: ["webpack://./src/assets/material-icons.css", "webpack://./src/directives/Tooltip/index.scss"], names: [], mappings: "AAGA,sBACC,YAAa,CACb,iBAAkB,CAClB,mBAAoB,CACpB,kBAAmB,CACnB,sBAAuB,CCOxB,6BACC,iBAAkB,CAClB,cAAe,CACf,UAAW,CACX,SAAU,CACV,aAAc,CACd,QAAS,CAET,eAAgB,CAChB,cAAe,CACf,eAAgB,CAChB,gBAAiB,CACjB,SAAU,CACV,eAAgB,CAEhB,eAAgB,CAChB,sDAAuD,CAhBxD,gEAoBE,QAAS,CACT,qBAAsB,CACtB,6CAA8C,CAtBhD,mEA2BE,KAAM,CACN,kBAAmB,CACnB,gDAAiD,CA7BnD,kEAkCE,UAAW,CACX,mBAAoB,CACpB,+CAAgD,CApClD,iEAyCE,SAAU,CACV,oBAAqB,CACrB,8CAA+C,CA3CjD,iDAgDE,iBAAkB,CAClB,wCAAyC,CACzC,SAAU,CAlDZ,kDAqDE,kBAAmB,CACnB,uBAAwB,CACxB,SAAU,CAvDZ,4CA4DE,eAAgB,CAChB,eAAgB,CAChB,iBAAkB,CAClB,4BAA6B,CAC7B,kCAAmC,CACnC,6CAA8C,CAjEhD,4CAsEE,iBAAkB,CAClB,SAAU,CACV,OAAQ,CACR,QAAS,CACT,QAAS,CACT,kBAAmB,CACnB,wBAAyB,CACzB,iBA/EgB", sourcesContent: ["/*\n* Ensure proper alignment of the vue material icons\n*/\n.material-design-icon {\n	display: flex;\n	align-self: center;\n	justify-self: center;\n	align-items: center;\n	justify-content: center;\n}\n", `$scope_version:"17fd6e1"; @import 'variables'; @import 'material-icons';
/**
* @copyright Copyright (c) 2016, John Molakvo\xE6 <skjnldsv@protonmail.com>
* @copyright Copyright (c) 2016, Robin Appelman <robin@icewind.nl>
* @copyright Copyright (c) 2016, Jan-Christoph Borchardt <hey@jancborchardt.net>
* @copyright Copyright (c) 2016, Erik Pellikka <erik@pellikka.org>
* @copyright Copyright (c) 2015, Vincent Petry <pvince81@owncloud.com>
*
* Bootstrap v3.3.5 (http://getbootstrap.com)
* Copyright 2011-2015 Twitter, Inc.
* Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
*/

$arrow-width: 10px;

.vue-tooltip[data-v-#{$scope_version}] {
	position: absolute;
	z-index: 100000;
	right: auto;
	left: auto;
	display: block;
	margin: 0;
	/* default to top */
	margin-top: -3px;
	padding: 10px 0;
	text-align: left;
	text-align: start;
	opacity: 0;
	line-height: 1.6;

	line-break: auto;
	filter: drop-shadow(0 1px 10px var(--color-box-shadow));

	// TOP
	&[x-placement^='top'] .tooltip-arrow {
		bottom: 0;
		border-bottom-width: 0;
		border-top-color: var(--color-main-background);
	}

	// BOTTOM
	&[x-placement^='bottom'] .tooltip-arrow {
		top: 0;
		border-top-width: 0;
		border-bottom-color: var(--color-main-background);
	}

	// RIGHT
	&[x-placement^='right'] .tooltip-arrow {
		right: 100%;
		border-left-width: 0;
		border-right-color: var(--color-main-background);
	}

	// LEFT
	&[x-placement^='left'] .tooltip-arrow {
		left: 100%;
		border-right-width: 0;
		border-left-color: var(--color-main-background);
	}

	// HIDDEN / SHOWN
	&[aria-hidden='true'] {
		visibility: hidden;
		transition: opacity .15s, visibility .15s;
		opacity: 0;
	}
	&[aria-hidden='false'] {
		visibility: visible;
		transition: opacity .15s;
		opacity: 1;
	}

	// CONTENT
	.tooltip-inner {
		max-width: 350px;
		padding: 5px 8px;
		text-align: center;
		color: var(--color-main-text);
		border-radius: var(--border-radius);
		background-color: var(--color-main-background);
	}

	// ARROW
	.tooltip-arrow {
		position: absolute;
		z-index: 1;
		width: 0;
		height: 0;
		margin: 0;
		border-style: solid;
		border-color: transparent;
		border-width: $arrow-width;
	}
}
`], sourceRoot: "" }]), t2.Z = r;
      }, 9224: function(e2, t2, n2) {
        var a2 = n2(4015), i = n2.n(a2), o = n2(3645), r = n2.n(o)()(i());
        r.push([e2.id, ".material-design-icon[data-v-2a98ba3b]{display:flex;align-self:center;justify-self:center;align-items:center;justify-content:center}.action-item[data-v-2a98ba3b]{position:relative;display:inline-block}.action-item--single[data-v-2a98ba3b]:hover,.action-item--single[data-v-2a98ba3b]:focus,.action-item--single[data-v-2a98ba3b]:active,.action-item__menutoggle[data-v-2a98ba3b]:hover,.action-item__menutoggle[data-v-2a98ba3b]:focus,.action-item__menutoggle[data-v-2a98ba3b]:active{opacity:1;background-color:rgba(127,127,127,0.25) !important}.action-item__menutoggle[data-v-2a98ba3b]:disabled,.action-item--single[data-v-2a98ba3b]:disabled{opacity:.3 !important}.action-item.action-item--open .action-item__menutoggle[data-v-2a98ba3b]{opacity:1;background-color:rgba(127,127,127,0.25)}.action-item--single[data-v-2a98ba3b],.action-item__menutoggle[data-v-2a98ba3b]{box-sizing:border-box;width:auto;min-width:44px;height:44px;margin:0;padding:0;cursor:pointer;border:none;border-radius:22px;background-color:transparent}.action-item--single--with-title[data-v-2a98ba3b],.action-item__menutoggle--with-title[data-v-2a98ba3b]{position:relative;padding:0 14px;padding-left:44px;white-space:nowrap;opacity:1;border:1px solid var(--color-border-dark);background-color:var(--color-background-dark);background-position:14px center;font-size:inherit}.action-item--single--with-title[data-v-2a98ba3b]  span,.action-item__menutoggle--with-title[data-v-2a98ba3b]  span{width:24px;height:24px;line-height:16px;position:absolute;top:0;left:0}.action-item[data-v-2a98ba3b] .material-design-icon{width:44px;height:44px;opacity:1}.action-item[data-v-2a98ba3b] .material-design-icon .material-design-icon__svg{vertical-align:middle}.action-item__menutoggle[data-v-2a98ba3b]{display:flex;align-items:center;justify-content:center;opacity:.7;font-weight:bold;line-height:16px}.action-item__menutoggle--primary[data-v-2a98ba3b]{opacity:1;color:var(--color-primary-text);border:none;background-color:var(--color-primary-element)}.action-item--open .action-item__menutoggle--primary[data-v-2a98ba3b],.action-item__menutoggle--primary[data-v-2a98ba3b]:hover,.action-item__menutoggle--primary[data-v-2a98ba3b]:focus,.action-item__menutoggle--primary[data-v-2a98ba3b]:active{color:var(--color-primary-text) !important;background-color:var(--color-primary-element-light) !important}.action-item--single[data-v-2a98ba3b]{opacity:.7}.action-item--single[data-v-2a98ba3b]:hover,.action-item--single[data-v-2a98ba3b]:focus,.action-item--single[data-v-2a98ba3b]:active{opacity:1}.action-item--single>[hidden][data-v-2a98ba3b]{display:none}.ie .action-item__menu[data-v-2a98ba3b],.ie .action-item__menu .action-item__menu_arrow[data-v-2a98ba3b],.edge .action-item__menu[data-v-2a98ba3b],.edge .action-item__menu .action-item__menu_arrow[data-v-2a98ba3b]{border:1px solid var(--color-border)}\n", "", { version: 3, sources: ["webpack://./src/assets/material-icons.css", "webpack://./src/components/Actions/Actions.vue", "webpack://./src/assets/variables.scss"], names: [], mappings: "AAGA,uCACC,YAAa,CACb,iBAAkB,CAClB,mBAAoB,CACpB,kBAAmB,CACnB,sBAAuB,CCopBxB,8BACC,iBAAkB,CAClB,oBAAqB,CAIrB,sRAMC,SC5nBc,CD8nBd,kDAA2C,CAC3C,kGAKA,qBAAsB,CApBxB,yEAwBE,SCxoBc,CDyoBd,uCCroBgD,CDsoBhD,gFAKA,qBAAsB,CACtB,UAAW,CACX,cCpqBmB,CDqqBnB,WCrqBmB,CDsqBnB,QAAS,CACT,SAAU,CACV,cAAe,CACf,WAAY,CACZ,kBAAkC,CAClC,4BAA6B,CAE7B,wGACC,iBAAkB,CAClB,cCvqB6C,CDwqB7C,iBChrBkB,CDirBlB,kBAAmB,CACnB,SC/pBa,CDgqBb,yCAA0C,CAE1C,6CAA8C,CAC9C,+BAAwC,CACxC,iBAAkB,CAVlB,oHAeC,UAAW,CACX,WAAY,CACZ,gBC1rBY,CD2rBZ,iBAAkB,CAClB,KAAM,CACN,MAAO,CA9DX,oDAoEE,UCvsBmB,CDwsBnB,WCxsBmB,CDysBnB,SCtrBc,CDgnBhB,+EAyEG,qBAAsB,CACtB,0CAMD,YAAa,CACb,kBAAmB,CACnB,sBAAuB,CACvB,UCpsBiB,CDqsBjB,gBAAiB,CACjB,gBCptBc,CDstBd,mDACC,SCxsBa,CDysBb,+BAAgC,CAChC,WAAY,CACZ,6CAA8C,CAC9C,kPAIC,0CAA2C,CAC3C,8DAA+D,CAC/D,sCAKF,UCxtBiB,CDutBjB,qIAKC,SC3tBa,CDstBd,+CASC,YAAa,CACb,sNAQD,oCAAqC", sourcesContent: ["/*\n* Ensure proper alignment of the vue material icons\n*/\n.material-design-icon {\n	display: flex;\n	align-self: center;\n	justify-self: center;\n	align-items: center;\n	justify-content: center;\n}\n", `$scope_version:"17fd6e1"; @import 'variables'; @import 'material-icons';



























































































































































































































































































































































































































































































































































































































































































.action-item {
	position: relative;
	display: inline-block;

	// put a grey round background when menu is opened
	// or hover-focused
	&--single:hover,
	&--single:focus,
	&--single:active,
	&__menutoggle:hover,
	&__menutoggle:focus,
	&__menutoggle:active {
		opacity: $opacity_full;
		// good looking on dark AND white bg, override server styling
		background-color: $icon-focus-bg !important;
	}

	// TODO: handle this in the future button component
	&__menutoggle:disabled,
	&--single:disabled {
		opacity: .3 !important;
	}

	&.action-item--open .action-item__menutoggle {
		opacity: $opacity_full;
		background-color: $action-background-hover;
	}

	// icons
	&--single,
	&__menutoggle {
		box-sizing: border-box;
		width: auto;
		min-width: $clickable-area;
		height: $clickable-area;
		margin: 0;
		padding: 0;
		cursor: pointer;
		border: none;
		border-radius: $clickable-area / 2;
		background-color: transparent;

		&--with-title {
			position: relative;
			padding: 0 $icon-margin;
			padding-left: $clickable-area;
			white-space: nowrap;
			opacity: $opacity_full;
			border: 1px solid var(--color-border-dark);
			// with a title, we need to display this as a real button
			background-color: var(--color-background-dark);
			background-position: $icon-margin center;
			font-size: inherit;

			// non-background icon class
			// image slot
			::v-deep span {
				width: 24px;
				height: 24px;
				line-height: $icon-size;
				position: absolute;
				top: 0;
				left: 0;
			}
		}
	}

	&::v-deep .material-design-icon {
		width: $clickable-area;
		height: $clickable-area;
		opacity: $opacity_full;

		.material-design-icon__svg {
			vertical-align: middle;
		}
	}

	// icon-more
	&__menutoggle {
		// align menu icon in center
		display: flex;
		align-items: center;
		justify-content: center;
		opacity: $opacity_normal;
		font-weight: bold;
		line-height: $icon-size;

		&--primary {
			opacity: $opacity_full;
			color: var(--color-primary-text);
			border: none;
			background-color: var(--color-primary-element);
			.action-item--open &,
			&:hover,
			&:focus,
			&:active {
				color: var(--color-primary-text) !important;
				background-color: var(--color-primary-element-light) !important;
			}
		}
	}

	&--single {
		opacity: $opacity_normal;
		&:hover,
		&:focus,
		&:active {
			opacity: $opacity_full;
		}
		// hide anything the slot is displaying
		& > [hidden] {
			display: none;
		}
	}
}

.ie,
.edge {
	.action-item__menu,
	.action-item__menu .action-item__menu_arrow {
		border: 1px solid var(--color-border);
	}
}

`, "/**\n * @copyright Copyright (c) 2019 John Molakvo\xE6 <skjnldsv@protonmail.com>\n *\n * @author John Molakvo\xE6 <skjnldsv@protonmail.com>\n *\n * @license GNU AGPL version 3 or any later version\n *\n * This program is free software: you can redistribute it and/or modify\n * it under the terms of the GNU Affero General Public License as\n * published by the Free Software Foundation, either version 3 of the\n * License, or (at your option) any later version.\n *\n * This program is distributed in the hope that it will be useful,\n * but WITHOUT ANY WARRANTY; without even the implied warranty of\n * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n * GNU Affero General Public License for more details.\n *\n * You should have received a copy of the GNU Affero General Public License\n * along with this program. If not, see <http://www.gnu.org/licenses/>.\n *\n */\n\n// https://uxplanet.org/7-rules-for-mobile-ui-button-design-e9cf2ea54556\n// recommended is 48px\n// 44px is what we choose and have very good visual-to-usability ratio\n$clickable-area: 44px;\n\n// background icon size\n// also used for the scss icon font\n$icon-size: 16px;\n\n// icon padding for a $clickable-area width and a $icon-size icon\n// ( 44px - 16px ) / 2\n$icon-margin: ($clickable-area - $icon-size) / 2;\n\n// transparency background for icons\n$icon-focus-bg: rgba(127, 127, 127, .25);\n\n// popovermenu arrow width from the triangle center\n$arrow-width: 9px;\n\n// opacities\n$opacity_disabled: .5;\n$opacity_normal: .7;\n$opacity_full: 1;\n\n// menu round background hover feedback\n// good looking on dark AND white bg\n$action-background-hover: rgba(127, 127, 127, .25);\n\n// various structure data used in the \n// `AppNavigation` component\n$header-height: 50px;\n$navigation-width: 300px;\n\n// mobile breakpoint\n$breakpoint-mobile: 1024px;\n"], sourceRoot: "" }]), t2.Z = r;
      }, 5878: function(e2, t2, n2) {
        var a2 = n2(4015), i = n2.n(a2), o = n2(3645), r = n2.n(o)()(i());
        r.push([e2.id, ".material-design-icon{display:flex;align-self:center;justify-self:center;align-items:center;justify-content:center}.popover{z-index:100000;display:block !important;filter:drop-shadow(0 1px 10px var(--color-box-shadow))}.popover__inner{padding:0;color:var(--color-main-text);border-radius:var(--border-radius);background:var(--color-main-background)}.popover__arrow{position:absolute;z-index:1;width:0;height:0;margin:10px;border-style:solid;border-color:transparent;border-width:10px}.popover[x-placement^='top']{margin-bottom:10px}.popover[x-placement^='top'] .popover__arrow{bottom:-10px;left:calc(50% - $arrow-width);margin-top:0;margin-bottom:0;border-bottom-width:0;border-top-color:var(--color-main-background)}.popover[x-placement^='bottom']{margin-top:10px}.popover[x-placement^='bottom'] .popover__arrow{top:-10px;left:calc(50% - $arrow-width);margin-top:0;margin-bottom:0;border-top-width:0;border-bottom-color:var(--color-main-background)}.popover[x-placement^='right']{margin-left:10px}.popover[x-placement^='right'] .popover__arrow{top:calc(50% - $arrow-width);left:-10px;margin-right:0;margin-left:0;border-left-width:0;border-right-color:var(--color-main-background)}.popover[x-placement^='left']{margin-right:10px}.popover[x-placement^='left'] .popover__arrow{top:calc(50% - $arrow-width);right:-10px;margin-right:0;margin-left:0;border-right-width:0;border-left-color:var(--color-main-background)}.popover[aria-hidden='true']{visibility:hidden;transition:opacity var(--animation-quick),visibility var(--animation-quick);opacity:0}.popover[aria-hidden='false']{visibility:visible;transition:opacity var(--animation-quick);opacity:1}\n", "", { version: 3, sources: ["webpack://./src/assets/material-icons.css", "webpack://./src/components/Popover/Popover.vue"], names: [], mappings: "AAGA,sBACC,YAAa,CACb,iBAAkB,CAClB,mBAAoB,CACpB,kBAAmB,CACnB,sBAAuB,CCyGxB,SACC,cAAe,CACf,wBAAyB,CAEzB,sDAAuD,CAEvD,gBACC,SAAU,CACV,4BAA6B,CAC7B,kCAAmC,CACnC,uCAAwC,CACxC,gBAGA,iBAAkB,CAClB,SAAU,CACV,OAAQ,CACR,QAAS,CACT,WApBgB,CAqBhB,kBAAmB,CACnB,wBAAyB,CACzB,iBAvBgB,CAElB,6BAyBE,kBA3BgB,CAElB,6CA4BG,YA9Be,CA+Bf,6BAA8B,CAC9B,YAAa,CACb,eAAgB,CAChB,qBAAsB,CACtB,6CAA8C,CAjCjD,gCAsCE,eAxCgB,CAElB,gDAyCG,SA3Ce,CA4Cf,6BAA8B,CAC9B,YAAa,CACb,eAAgB,CAChB,kBAAmB,CACnB,gDAAiD,CA9CpD,+BAmDE,gBArDgB,CAElB,+CAsDG,4BAA6B,CAC7B,UAzDe,CA0Df,cAAe,CACf,aAAc,CACd,mBAAoB,CACpB,+CAAgD,CA3DnD,8BAgEE,iBAlEgB,CAElB,8CAmEG,4BAA6B,CAC7B,WAtEe,CAuEf,cAAe,CACf,aAAc,CACd,oBAAqB,CACrB,8CAA+C,CAxElD,6BA6EE,iBAAkB,CAClB,2EAA6E,CAC7E,SAAU,CA/EZ,8BAmFE,kBAAmB,CACnB,yCAA0C,CAC1C,SAAU", sourcesContent: ["/*\n* Ensure proper alignment of the vue material icons\n*/\n.material-design-icon {\n	display: flex;\n	align-self: center;\n	justify-self: center;\n	align-items: center;\n	justify-content: center;\n}\n", `$scope_version:"17fd6e1"; @import 'variables'; @import 'material-icons';














































































































$arrow-width: 10px;

.popover {
	z-index: 100000;
	display: block !important;

	filter: drop-shadow(0 1px 10px var(--color-box-shadow));

	&__inner {
		padding: 0;
		color: var(--color-main-text);
		border-radius: var(--border-radius);
		background: var(--color-main-background);
	}

	&__arrow {
		position: absolute;
		z-index: 1;
		width: 0;
		height: 0;
		margin: $arrow-width;
		border-style: solid;
		border-color: transparent;
		border-width: $arrow-width;
	}

	&[x-placement^='top'] {
		margin-bottom: $arrow-width;

		.popover__arrow {
			bottom: -$arrow-width;
			left: calc(50% - $arrow-width);
			margin-top: 0;
			margin-bottom: 0;
			border-bottom-width: 0;
			border-top-color: var(--color-main-background);
		}
	}

	&[x-placement^='bottom'] {
		margin-top: $arrow-width;

		.popover__arrow {
			top: -$arrow-width;
			left: calc(50% - $arrow-width);
			margin-top: 0;
			margin-bottom: 0;
			border-top-width: 0;
			border-bottom-color: var(--color-main-background);
		}
	}

	&[x-placement^='right'] {
		margin-left: $arrow-width;

		.popover__arrow {
			top: calc(50% - $arrow-width);
			left: -$arrow-width;
			margin-right: 0;
			margin-left: 0;
			border-left-width: 0;
			border-right-color: var(--color-main-background);
		}
	}

	&[x-placement^='left'] {
		margin-right: $arrow-width;

		.popover__arrow {
			top: calc(50% - $arrow-width);
			right: -$arrow-width;
			margin-right: 0;
			margin-left: 0;
			border-right-width: 0;
			border-left-color: var(--color-main-background);
		}
	}

	&[aria-hidden='true'] {
		visibility: hidden;
		transition: opacity var(--animation-quick), visibility var(--animation-quick);
		opacity: 0;
	}

	&[aria-hidden='false'] {
		visibility: visible;
		transition: opacity var(--animation-quick);
		opacity: 1;
	}
}

`], sourceRoot: "" }]), t2.Z = r;
      }, 3645: function(e2) {
        e2.exports = function(e3) {
          var t2 = [];
          return t2.toString = function() {
            return this.map(function(t3) {
              var n2 = e3(t3);
              return t3[2] ? "@media ".concat(t3[2], " {").concat(n2, "}") : n2;
            }).join("");
          }, t2.i = function(e4, n2, a2) {
            typeof e4 == "string" && (e4 = [[null, e4, ""]]);
            var i = {};
            if (a2)
              for (var o = 0; o < this.length; o++) {
                var r = this[o][0];
                r != null && (i[r] = true);
              }
            for (var s = 0; s < e4.length; s++) {
              var l = [].concat(e4[s]);
              a2 && i[l[0]] || (n2 && (l[2] ? l[2] = "".concat(n2, " and ").concat(l[2]) : l[2] = n2), t2.push(l));
            }
          }, t2;
        };
      }, 4015: function(e2) {
        function t2(e3, t3) {
          (t3 == null || t3 > e3.length) && (t3 = e3.length);
          for (var n2 = 0, a2 = new Array(t3); n2 < t3; n2++)
            a2[n2] = e3[n2];
          return a2;
        }
        e2.exports = function(e3) {
          var n2, a2, i = (a2 = 4, function(e4) {
            if (Array.isArray(e4))
              return e4;
          }(n2 = e3) || function(e4, t3) {
            var n3 = e4 && (typeof Symbol != "undefined" && e4[Symbol.iterator] || e4["@@iterator"]);
            if (n3 != null) {
              var a3, i2, o2 = [], r2 = true, s2 = false;
              try {
                for (n3 = n3.call(e4); !(r2 = (a3 = n3.next()).done) && (o2.push(a3.value), !t3 || o2.length !== t3); r2 = true)
                  ;
              } catch (e5) {
                s2 = true, i2 = e5;
              } finally {
                try {
                  r2 || n3.return == null || n3.return();
                } finally {
                  if (s2)
                    throw i2;
                }
              }
              return o2;
            }
          }(n2, a2) || function(e4, n3) {
            if (e4) {
              if (typeof e4 == "string")
                return t2(e4, n3);
              var a3 = Object.prototype.toString.call(e4).slice(8, -1);
              return a3 === "Object" && e4.constructor && (a3 = e4.constructor.name), a3 === "Map" || a3 === "Set" ? Array.from(e4) : a3 === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(a3) ? t2(e4, n3) : void 0;
            }
          }(n2, a2) || function() {
            throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
          }()), o = i[1], r = i[3];
          if (!r)
            return o;
          if (typeof btoa == "function") {
            var s = btoa(unescape(encodeURIComponent(JSON.stringify(r)))), l = "sourceMappingURL=data:application/json;charset=utf-8;base64,".concat(s), c = "/*# ".concat(l, " */"), u = r.sources.map(function(e4) {
              return "/*# sourceURL=".concat(r.sourceRoot || "").concat(e4, " */");
            });
            return [o].concat(u).concat([c]).join("\n");
          }
          return [o].join("\n");
        };
      }, 2694: function(e2, t2, n2) {
        var a2 = n2(3379), i = n2.n(a2), o = n2(7795), r = n2.n(o), s = n2(569), l = n2.n(s), c = n2(3565), u = n2.n(c), d = n2(9216), m = n2.n(d), g = n2(4589), p = n2.n(g), h = n2(9224), v = {};
        v.styleTagTransform = p(), v.setAttributes = u(), v.insert = l().bind(null, "head"), v.domAPI = r(), v.insertStyleElement = m(), i()(h.Z, v), h.Z && h.Z.locals && h.Z.locals;
      }, 3379: function(e2) {
        var t2 = [];
        function n2(e3) {
          for (var n3 = -1, a3 = 0; a3 < t2.length; a3++)
            if (t2[a3].identifier === e3) {
              n3 = a3;
              break;
            }
          return n3;
        }
        function a2(e3, a3) {
          for (var o = {}, r = [], s = 0; s < e3.length; s++) {
            var l = e3[s], c = a3.base ? l[0] + a3.base : l[0], u = o[c] || 0, d = "".concat(c, " ").concat(u);
            o[c] = u + 1;
            var m = n2(d), g = { css: l[1], media: l[2], sourceMap: l[3], supports: l[4], layer: l[5] };
            if (m !== -1)
              t2[m].references++, t2[m].updater(g);
            else {
              var p = i(g, a3);
              a3.byIndex = s, t2.splice(s, 0, { identifier: d, updater: p, references: 1 });
            }
            r.push(d);
          }
          return r;
        }
        function i(e3, t3) {
          var n3 = t3.domAPI(t3);
          return n3.update(e3), function(t4) {
            if (t4) {
              if (t4.css === e3.css && t4.media === e3.media && t4.sourceMap === e3.sourceMap && t4.supports === e3.supports && t4.layer === e3.layer)
                return;
              n3.update(e3 = t4);
            } else
              n3.remove();
          };
        }
        e2.exports = function(e3, i2) {
          var o = a2(e3 = e3 || [], i2 = i2 || {});
          return function(e4) {
            e4 = e4 || [];
            for (var r = 0; r < o.length; r++) {
              var s = n2(o[r]);
              t2[s].references--;
            }
            for (var l = a2(e4, i2), c = 0; c < o.length; c++) {
              var u = n2(o[c]);
              t2[u].references === 0 && (t2[u].updater(), t2.splice(u, 1));
            }
            o = l;
          };
        };
      }, 569: function(e2) {
        var t2 = {};
        e2.exports = function(e3, n2) {
          var a2 = function(e4) {
            if (t2[e4] === void 0) {
              var n3 = document.querySelector(e4);
              if (window.HTMLIFrameElement && n3 instanceof window.HTMLIFrameElement)
                try {
                  n3 = n3.contentDocument.head;
                } catch (e5) {
                  n3 = null;
                }
              t2[e4] = n3;
            }
            return t2[e4];
          }(e3);
          if (!a2)
            throw new Error("Couldn't find a style target. This probably means that the value for the 'insert' parameter is invalid.");
          a2.appendChild(n2);
        };
      }, 9216: function(e2) {
        e2.exports = function(e3) {
          var t2 = document.createElement("style");
          return e3.setAttributes(t2, e3.attributes), e3.insert(t2, e3.options), t2;
        };
      }, 3565: function(e2, t2, n2) {
        e2.exports = function(e3) {
          var t3 = n2.nc;
          t3 && e3.setAttribute("nonce", t3);
        };
      }, 7795: function(e2) {
        e2.exports = function(e3) {
          var t2 = e3.insertStyleElement(e3);
          return { update: function(n2) {
            !function(e4, t3, n3) {
              var a2 = "";
              n3.supports && (a2 += "@supports (".concat(n3.supports, ") {")), n3.media && (a2 += "@media ".concat(n3.media, " {"));
              var i = n3.layer !== void 0;
              i && (a2 += "@layer".concat(n3.layer.length > 0 ? " ".concat(n3.layer) : "", " {")), a2 += n3.css, i && (a2 += "}"), n3.media && (a2 += "}"), n3.supports && (a2 += "}");
              var o = n3.sourceMap;
              o && typeof btoa != "undefined" && (a2 += "\n/*# sourceMappingURL=data:application/json;base64,".concat(btoa(unescape(encodeURIComponent(JSON.stringify(o)))), " */")), t3.styleTagTransform(a2, e4, t3.options);
            }(t2, e3, n2);
          }, remove: function() {
            !function(e4) {
              if (e4.parentNode === null)
                return false;
              e4.parentNode.removeChild(e4);
            }(t2);
          } };
        };
      }, 4589: function(e2) {
        e2.exports = function(e3, t2) {
          if (t2.styleSheet)
            t2.styleSheet.cssText = e3;
          else {
            for (; t2.firstChild; )
              t2.removeChild(t2.firstChild);
            t2.appendChild(document.createTextNode(e3));
          }
        };
      }, 3083: function(e2, t2, n2) {
        var a2 = n2(9125), i = n2(613), o = (n2(3822), n2(1900)), r = n2(2192), s = n2.n(r), l = (0, o.Z)(i.Z, a2.s, a2.x, false, null, "2a98ba3b", null);
        typeof s() == "function" && s()(l), t2.Z = l.exports;
      }, 7020: function(e2, t2, n2) {
        n2.d(t2, { Z: function() {
          return k;
        } });
        var a2 = { name: "Popover", components: { VPopover: n2(2965).VPopover }, mounted: function() {
          var e3 = this;
          this.$watch(function() {
            return e3.$refs.popover.isOpen;
          }, function(t3) {
            t3 ? e3.$emit("after-show") : e3.$emit("after-hide");
          });
        } }, i = n2(3379), o = n2.n(i), r = n2(7795), s = n2.n(r), l = n2(569), c = n2.n(l), u = n2(3565), d = n2.n(u), m = n2(9216), g = n2.n(m), p = n2(4589), h = n2.n(p), v = n2(5878), A = {};
        A.styleTagTransform = h(), A.setAttributes = d(), A.insert = c().bind(null, "head"), A.domAPI = s(), A.insertStyleElement = g(), o()(v.Z, A), v.Z && v.Z.locals && v.Z.locals;
        var b = n2(1900), f = n2(8733), y = n2.n(f), C = (0, b.Z)(a2, function() {
          var e3 = this, t3 = e3.$createElement;
          return (e3._self._c || t3)("VPopover", e3._g(e3._b({ ref: "popover", attrs: { "popover-base-class": "popover", "popover-wrapper-class": "popover__wrapper", "popover-arrow-class": "popover__arrow", "popover-inner-class": "popover__inner" }, scopedSlots: e3._u([{ key: "popover", fn: function() {
            return [e3._t("default")];
          }, proxy: true }], null, true) }, "VPopover", e3.$attrs, false), e3.$listeners), [e3._t("trigger")], 2);
        }, [], false, null, null, null);
        typeof y() == "function" && y()(C);
        var k = C.exports;
      }, 8104: function(e2, t2, n2) {
        var a2 = n2(5494), i = (0, n2(1900).Z)(a2.Z, void 0, void 0, false, null, null, null);
        t2.Z = i.exports;
      }, 613: function(e2, t2, n2) {
        var a2 = n2(858);
        t2.Z = a2.Z;
      }, 5494: function(e2, t2, n2) {
        var a2 = n2(5041);
        t2.Z = a2.Z;
      }, 3822: function(e2, t2, n2) {
        n2(2694);
      }, 2192: function() {
      }, 8733: function() {
      }, 9125: function(e2, t2, n2) {
        n2.d(t2, { s: function() {
          return a2;
        }, x: function() {
          return i;
        } });
        var a2 = function() {
          var e3, t3 = this, n3 = t3.$createElement, a3 = t3._self._c || n3;
          return t3.isValidSingleAction && !t3.forceMenu ? a3("element", t3._b({ directives: [{ name: "tooltip", rawName: "v-tooltip.auto", value: t3.firstAction.text, expression: "firstAction.text", modifiers: { auto: true } }], staticClass: "action-item action-item--single", class: (e3 = {}, e3[t3.firstAction.icon] = t3.firstAction.icon, e3[t3.firstActionClass] = t3.firstActionClass, e3["action-item--single--with-title"] = t3.singleActionTitle, e3), attrs: { rel: "nofollow noreferrer noopener", disabled: t3.isDisabled }, on: t3._d({ focus: t3.onFocus, blur: t3.onBlur }, [t3.firstActionEventBinding, t3.execFirstAction]) }, "element", t3.firstActionBinding, false), [a3("VNodes", { attrs: { vnodes: t3.firstActionIconSlot } }), t3._v("\n\n	" + t3._s(t3.singleActionTitle) + "\n\n	"), t3._v(" "), a3("span", { attrs: { "aria-hidden": true, hidden: "" } }, [t3._t("default")], 2)], 1) : a3("div", { directives: [{ name: "show", rawName: "v-show", value: t3.hasMultipleActions || t3.forceMenu, expression: "hasMultipleActions || forceMenu" }], staticClass: "action-item", class: { "action-item--open": t3.opened } }, [a3("Popover", { attrs: { delay: 0, "handle-resize": true, open: t3.opened, placement: t3.placement, "boundaries-element": t3.boundariesElement, container: t3.container }, on: { "update:open": function(e4) {
            t3.opened = e4;
          }, show: t3.openMenu, "after-show": t3.onOpen, hide: t3.closeMenu }, scopedSlots: t3._u([{ key: "trigger", fn: function() {
            var e4;
            return [a3("button", { ref: "menuButton", staticClass: "icon vue-button action-item__menutoggle", class: (e4 = {}, e4[t3.defaultIcon] = !t3.iconSlotIsPopulated, e4["action-item__menutoggle--with-title"] = t3.menuTitle, e4["action-item__menutoggle--with-icon-slot"] = t3.iconSlotIsPopulated, e4["action-item__menutoggle--default-icon"] = !t3.iconSlotIsPopulated && t3.defaultIcon === "", e4["action-item__menutoggle--primary"] = t3.primary, e4), attrs: { disabled: t3.disabled, "aria-haspopup": "true", "aria-label": t3.ariaLabel, "aria-controls": t3.randomId, "aria-expanded": t3.opened ? "true" : "false", "test-attr": "1", type: "button" }, on: { focus: t3.onFocus, blur: t3.onBlur } }, [t3.iconSlotIsPopulated ? t3._t("icon") : t3.defaultIcon === "" ? a3("DotsHorizontal", { attrs: { size: 20, decorative: "" } }) : t3._e(), t3._v("\n				" + t3._s(t3.menuTitle) + "\n			")], 2)];
          }, proxy: true }], null, true) }, [t3._v(" "), a3("div", { directives: [{ name: "show", rawName: "v-show", value: t3.opened, expression: "opened" }], ref: "menu", class: { open: t3.opened }, attrs: { tabindex: "-1" }, on: { keydown: [function(e4) {
            return !e4.type.indexOf("key") && t3._k(e4.keyCode, "up", 38, e4.key, ["Up", "ArrowUp"]) || e4.ctrlKey || e4.shiftKey || e4.altKey || e4.metaKey ? null : t3.focusPreviousAction.apply(null, arguments);
          }, function(e4) {
            return !e4.type.indexOf("key") && t3._k(e4.keyCode, "down", 40, e4.key, ["Down", "ArrowDown"]) || e4.ctrlKey || e4.shiftKey || e4.altKey || e4.metaKey ? null : t3.focusNextAction.apply(null, arguments);
          }, function(e4) {
            return !e4.type.indexOf("key") && t3._k(e4.keyCode, "tab", 9, e4.key, "Tab") || e4.ctrlKey || e4.shiftKey || e4.altKey || e4.metaKey ? null : t3.focusNextAction.apply(null, arguments);
          }, function(e4) {
            return !e4.type.indexOf("key") && t3._k(e4.keyCode, "tab", 9, e4.key, "Tab") ? null : e4.shiftKey ? e4.ctrlKey || e4.altKey || e4.metaKey ? null : t3.focusPreviousAction.apply(null, arguments) : null;
          }, function(e4) {
            return !e4.type.indexOf("key") && t3._k(e4.keyCode, "page-up", void 0, e4.key, void 0) || e4.ctrlKey || e4.shiftKey || e4.altKey || e4.metaKey ? null : t3.focusFirstAction.apply(null, arguments);
          }, function(e4) {
            return !e4.type.indexOf("key") && t3._k(e4.keyCode, "page-down", void 0, e4.key, void 0) || e4.ctrlKey || e4.shiftKey || e4.altKey || e4.metaKey ? null : t3.focusLastAction.apply(null, arguments);
          }, function(e4) {
            return !e4.type.indexOf("key") && t3._k(e4.keyCode, "esc", 27, e4.key, ["Esc", "Escape"]) || e4.ctrlKey || e4.shiftKey || e4.altKey || e4.metaKey ? null : (e4.preventDefault(), t3.closeMenu.apply(null, arguments));
          }], mousemove: t3.onMouseFocusAction } }, [a3("ul", { attrs: { id: t3.randomId, tabindex: "-1" } }, [t3.opened ? [t3._t("default")] : t3._e()], 2)])])], 1);
        }, i = [];
      }, 1900: function(e2, t2, n2) {
        function a2(e3, t3, n3, a3, i, o, r, s) {
          var l, c = typeof e3 == "function" ? e3.options : e3;
          if (t3 && (c.render = t3, c.staticRenderFns = n3, c._compiled = true), a3 && (c.functional = true), o && (c._scopeId = "data-v-" + o), r ? (l = function(e4) {
            (e4 = e4 || this.$vnode && this.$vnode.ssrContext || this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext) || typeof __VUE_SSR_CONTEXT__ == "undefined" || (e4 = __VUE_SSR_CONTEXT__), i && i.call(this, e4), e4 && e4._registeredComponents && e4._registeredComponents.add(r);
          }, c._ssrRegister = l) : i && (l = s ? function() {
            i.call(this, (c.functional ? this.parent : this).$root.$options.shadowRoot);
          } : i), l)
            if (c.functional) {
              c._injectStyles = l;
              var u = c.render;
              c.render = function(e4, t4) {
                return l.call(t4), u(e4, t4);
              };
            } else {
              var d = c.beforeCreate;
              c.beforeCreate = d ? [].concat(d, l) : [l];
            }
          return { exports: e3, options: c };
        }
        n2.d(t2, { Z: function() {
          return a2;
        } });
      }, 6036: function(e2) {
        e2.exports = gettext$1;
      }, 2965: function(e2) {
        e2.exports = require$$1;
      }, 3251: function(e2) {
        e2.exports = require$$2;
      } }, t = {};
      function n(a2) {
        var i = t[a2];
        if (i !== void 0)
          return i.exports;
        var o = t[a2] = { id: a2, exports: {} };
        return e[a2](o, o.exports, n), o.exports;
      }
      n.n = function(e2) {
        var t2 = e2 && e2.__esModule ? function() {
          return e2.default;
        } : function() {
          return e2;
        };
        return n.d(t2, { a: t2 }), t2;
      }, n.d = function(e2, t2) {
        for (var a2 in t2)
          n.o(t2, a2) && !n.o(e2, a2) && Object.defineProperty(e2, a2, { enumerable: true, get: t2[a2] });
      }, n.o = function(e2, t2) {
        return Object.prototype.hasOwnProperty.call(e2, t2);
      }, n.r = function(e2) {
        typeof Symbol != "undefined" && Symbol.toStringTag && Object.defineProperty(e2, Symbol.toStringTag, { value: "Module" }), Object.defineProperty(e2, "__esModule", { value: true });
      };
      var a = {};
      return function() {
        n.r(a);
        var e2 = n(3083);
        a.default = e2.Z;
      }(), a;
    }();
  });
})(Actions$1);
var Actions = /* @__PURE__ */ getDefaultExportFromCjs(Actions$1.exports);
var ActionButton$1 = { exports: {} };
/*! For license information please see ActionButton.js.LICENSE.txt */
(function(module, exports) {
  !function(t, n) {
    module.exports = n();
  }(self, function() {
    return function() {
      var t = { 5938: function(t2, n2, e2) {
        var o2 = e2(9156);
        n2.Z = { name: "ActionButton", mixins: [o2.Z], props: { disabled: { type: Boolean, default: false } }, computed: { isFocusable: function() {
          return !this.disabled;
        } } };
      }, 723: function(t2, n2, e2) {
        var o2 = e2(2734), i = e2.n(o2);
        n2.Z = { before: function() {
          this.$slots.default && this.text.trim() !== "" || (i().util.warn("".concat(this.$options.name, " cannot be empty and requires a meaningful text content"), this), this.$destroy(), this.$el.remove());
        }, beforeUpdate: function() {
          this.text = this.getText();
        }, data: function() {
          return { text: this.getText() };
        }, computed: { isLongText: function() {
          return this.text && this.text.trim().length > 20;
        } }, methods: { getText: function() {
          return this.$slots.default ? this.$slots.default[0].text.trim() : "";
        } } };
      }, 9156: function(t2, n2, e2) {
        var o2 = e2(723), i = e2(6021);
        n2.Z = { mixins: [o2.Z], props: { icon: { type: String, default: "" }, title: { type: String, default: "" }, closeAfterClick: { type: Boolean, default: false }, ariaLabel: { type: String, default: "" } }, computed: { isIconUrl: function() {
          try {
            return new URL(this.icon);
          } catch (t3) {
            return false;
          }
        } }, methods: { onClick: function(t3) {
          if (this.$emit("click", t3), this.closeAfterClick) {
            var n3 = (0, i.Z)(this, "Actions");
            n3 && n3.closeMenu && n3.closeMenu();
          }
        } } };
      }, 6021: function(t2, n2) {
        n2.Z = function(t3, n3) {
          for (var e2 = t3.$parent; e2; ) {
            if (e2.$options.name === n3)
              return e2;
            e2 = e2.$parent;
          }
        };
      }, 7087: function(t2, n2, e2) {
        var o2 = e2(4015), i = e2.n(o2), r = e2(3645), a = e2.n(r)()(i());
        a.push([t2.id, ".material-design-icon[data-v-ef50c406]{display:flex;align-self:center;justify-self:center;align-items:center;justify-content:center}li.active[data-v-ef50c406]{background-color:var(--color-background-hover)}.action--disabled[data-v-ef50c406]{pointer-events:none;opacity:.5}.action--disabled[data-v-ef50c406]:hover,.action--disabled[data-v-ef50c406]:focus{cursor:default;opacity:.5}.action--disabled *[data-v-ef50c406]{opacity:1 !important}.action-button[data-v-ef50c406]{display:flex;align-items:flex-start;width:100%;height:auto;margin:0;padding:0;padding-right:14px;box-sizing:border-box;cursor:pointer;white-space:nowrap;opacity:.7;color:var(--color-main-text);border:0;border-radius:0;background-color:transparent;box-shadow:none;font-weight:normal;font-size:var(--default-font-size);line-height:44px}.action-button[data-v-ef50c406]:hover,.action-button[data-v-ef50c406]:focus{opacity:1}.action-button>span[data-v-ef50c406]{cursor:pointer;white-space:nowrap}.action-button__icon[data-v-ef50c406]{width:44px;height:44px;opacity:1;background-position:14px center;background-size:16px;background-repeat:no-repeat}.action-button[data-v-ef50c406] .material-design-icon{width:44px;height:44px;opacity:1}.action-button[data-v-ef50c406] .material-design-icon .material-design-icon__svg{vertical-align:middle}.action-button p[data-v-ef50c406]{max-width:220px;line-height:1.6em;padding:10.8px 0;cursor:pointer;text-align:left;overflow:hidden;text-overflow:ellipsis}.action-button__longtext[data-v-ef50c406]{cursor:pointer;white-space:pre-wrap}.action-button__title[data-v-ef50c406]{font-weight:bold;text-overflow:ellipsis;overflow:hidden;white-space:nowrap;max-width:100%;display:inline-block}\n", "", { version: 3, sources: ["webpack://./src/assets/material-icons.css", "webpack://./src/assets/action.scss", "webpack://./src/assets/variables.scss"], names: [], mappings: "AAGA,uCACC,YAAa,CACb,iBAAkB,CAClB,mBAAoB,CACpB,kBAAmB,CACnB,sBAAuB,CACvB,2BCiBE,8CAA+C,CAC/C,mCAMD,mBAAoB,CACpB,UCQmB,CDVpB,kFAIE,cAAe,CACf,UCKkB,CDVpB,qCAQE,oBAAqB,CACrB,gCAOD,YAAa,CACb,sBAAuB,CAEvB,UAAW,CACX,WAAY,CACZ,QAAS,CACT,SAAU,CACV,kBCtB8C,CDuB9C,qBAAsB,CAEtB,cAAe,CACf,kBAAmB,CAEnB,UClBiB,CDmBjB,4BAA6B,CAC7B,QAAS,CACT,eAAgB,CAChB,4BAA6B,CAC7B,eAAgB,CAEhB,kBAAmB,CACnB,kCAAmC,CACnC,gBC7CmB,CDsBpB,4EA2BE,SC9Ba,CDGf,qCA+BE,cAAe,CACf,kBAAmB,CACnB,sCAGA,UC1DkB,CD2DlB,WC3DkB,CD4DlB,SCzCa,CD0Cb,+BAAwC,CACxC,oBC1Da,CD2Db,2BAA4B,CAzC9B,sDA6CE,UCnEkB,CDoElB,WCpEkB,CDqElB,SClDa,CDGf,iFAkDG,qBAAsB,CAlDzB,kCAwDE,eAAgB,CAChB,iBAAkB,CAGlB,gBAAgD,CAEhD,cAAe,CACf,eAAgB,CAGhB,eAAgB,CAChB,sBAAuB,CACvB,0CAGA,cAAe,CAEf,oBAAqB,CACrB,uCAGA,gBAAiB,CACjB,sBAAuB,CACvB,eAAgB,CAChB,kBAAmB,CACnB,cAAe,CACf,oBAAqB", sourcesContent: ["/*\n* Ensure proper alignment of the vue material icons\n*/\n.material-design-icon {\n	display: flex;\n	align-self: center;\n	justify-self: center;\n	align-items: center;\n	justify-content: center;\n}\n", "/**\n * @copyright Copyright (c) 2019 John Molakvo\xE6 <skjnldsv@protonmail.com>\n *\n * @author John Molakvo\xE6 <skjnldsv@protonmail.com>\n * @author Marco Ambrosini <marcoambrosini@pm.me>\n *\n * @license GNU AGPL version 3 or any later version\n *\n * This program is free software: you can redistribute it and/or modify\n * it under the terms of the GNU Affero General Public License as\n * published by the Free Software Foundation, either version 3 of the\n * License, or (at your option) any later version.\n *\n * This program is distributed in the hope that it will be useful,\n * but WITHOUT ANY WARRANTY; without even the implied warranty of\n * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n * GNU Affero General Public License for more details.\n *\n * You should have received a copy of the GNU Affero General Public License\n * along with this program. If not, see <http://www.gnu.org/licenses/>.\n *\n */\n\n@mixin action-active {\n	li {\n		&.active {\n			background-color: var(--color-background-hover);\n		}\n	}\n}\n\n@mixin action--disabled {\n	.action--disabled {\n		pointer-events: none;\n		opacity: $opacity_disabled;\n		&:hover, &:focus {\n			cursor: default;\n			opacity: $opacity_disabled;\n		}\n		& * {\n			opacity: 1 !important;\n		}\n	}\n}\n\n\n@mixin action-item($name) {\n	.action-#{$name} {\n		display: flex;\n		align-items: flex-start;\n\n		width: 100%;\n		height: auto;\n		margin: 0;\n		padding: 0;\n		padding-right: $icon-margin;\n		box-sizing: border-box; // otherwise router-link overflows in Firefox\n\n		cursor: pointer;\n		white-space: nowrap;\n\n		opacity: $opacity_normal;\n		color: var(--color-main-text);\n		border: 0;\n		border-radius: 0; // otherwise Safari will cut the border-radius area\n		background-color: transparent;\n		box-shadow: none;\n\n		font-weight: normal;\n		font-size: var(--default-font-size);\n		line-height: $clickable-area;\n\n		&:hover,\n		&:focus {\n			opacity: $opacity_full;\n		}\n\n		& > span {\n			cursor: pointer;\n			white-space: nowrap;\n		}\n\n		&__icon {\n			width: $clickable-area;\n			height: $clickable-area;\n			opacity: $opacity_full;\n			background-position: $icon-margin center;\n			background-size: $icon-size;\n			background-repeat: no-repeat;\n		}\n\n		&::v-deep .material-design-icon {\n			width: $clickable-area;\n			height: $clickable-area;\n			opacity: $opacity_full;\n\n			.material-design-icon__svg {\n				vertical-align: middle;\n			}\n		}\n\n		// long text area\n		p {\n			max-width: 220px;\n			line-height: 1.6em;\n\n			// 14px are currently 1em line-height. Mixing units as '44px - 1.6em' does not work.\n			padding: #{($clickable-area - 1.6 * 14px) / 2} 0;\n\n			cursor: pointer;\n			text-align: left;\n\n			// in case there are no spaces like long email addresses\n			overflow: hidden;\n			text-overflow: ellipsis;\n		}\n\n		&__longtext {\n			cursor: pointer;\n			// allow the use of `\\n`\n			white-space: pre-wrap;\n		}\n\n		&__title {\n			font-weight: bold;\n			text-overflow: ellipsis;\n			overflow: hidden;\n			white-space: nowrap;\n			max-width: 100%;\n			display: inline-block;\n		}\n	}\n}\n", "/**\n * @copyright Copyright (c) 2019 John Molakvo\xE6 <skjnldsv@protonmail.com>\n *\n * @author John Molakvo\xE6 <skjnldsv@protonmail.com>\n *\n * @license GNU AGPL version 3 or any later version\n *\n * This program is free software: you can redistribute it and/or modify\n * it under the terms of the GNU Affero General Public License as\n * published by the Free Software Foundation, either version 3 of the\n * License, or (at your option) any later version.\n *\n * This program is distributed in the hope that it will be useful,\n * but WITHOUT ANY WARRANTY; without even the implied warranty of\n * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n * GNU Affero General Public License for more details.\n *\n * You should have received a copy of the GNU Affero General Public License\n * along with this program. If not, see <http://www.gnu.org/licenses/>.\n *\n */\n\n// https://uxplanet.org/7-rules-for-mobile-ui-button-design-e9cf2ea54556\n// recommended is 48px\n// 44px is what we choose and have very good visual-to-usability ratio\n$clickable-area: 44px;\n\n// background icon size\n// also used for the scss icon font\n$icon-size: 16px;\n\n// icon padding for a $clickable-area width and a $icon-size icon\n// ( 44px - 16px ) / 2\n$icon-margin: ($clickable-area - $icon-size) / 2;\n\n// transparency background for icons\n$icon-focus-bg: rgba(127, 127, 127, .25);\n\n// popovermenu arrow width from the triangle center\n$arrow-width: 9px;\n\n// opacities\n$opacity_disabled: .5;\n$opacity_normal: .7;\n$opacity_full: 1;\n\n// menu round background hover feedback\n// good looking on dark AND white bg\n$action-background-hover: rgba(127, 127, 127, .25);\n\n// various structure data used in the \n// `AppNavigation` component\n$header-height: 50px;\n$navigation-width: 300px;\n\n// mobile breakpoint\n$breakpoint-mobile: 1024px;\n"], sourceRoot: "" }]), n2.Z = a;
      }, 3645: function(t2) {
        t2.exports = function(t3) {
          var n2 = [];
          return n2.toString = function() {
            return this.map(function(n3) {
              var e2 = t3(n3);
              return n3[2] ? "@media ".concat(n3[2], " {").concat(e2, "}") : e2;
            }).join("");
          }, n2.i = function(t4, e2, o2) {
            typeof t4 == "string" && (t4 = [[null, t4, ""]]);
            var i = {};
            if (o2)
              for (var r = 0; r < this.length; r++) {
                var a = this[r][0];
                a != null && (i[a] = true);
              }
            for (var s = 0; s < t4.length; s++) {
              var c = [].concat(t4[s]);
              o2 && i[c[0]] || (e2 && (c[2] ? c[2] = "".concat(e2, " and ").concat(c[2]) : c[2] = e2), n2.push(c));
            }
          }, n2;
        };
      }, 4015: function(t2) {
        function n2(t3, n3) {
          (n3 == null || n3 > t3.length) && (n3 = t3.length);
          for (var e2 = 0, o2 = new Array(n3); e2 < n3; e2++)
            o2[e2] = t3[e2];
          return o2;
        }
        t2.exports = function(t3) {
          var e2, o2, i = (o2 = 4, function(t4) {
            if (Array.isArray(t4))
              return t4;
          }(e2 = t3) || function(t4, n3) {
            var e3 = t4 && (typeof Symbol != "undefined" && t4[Symbol.iterator] || t4["@@iterator"]);
            if (e3 != null) {
              var o3, i2, r2 = [], a2 = true, s2 = false;
              try {
                for (e3 = e3.call(t4); !(a2 = (o3 = e3.next()).done) && (r2.push(o3.value), !n3 || r2.length !== n3); a2 = true)
                  ;
              } catch (t5) {
                s2 = true, i2 = t5;
              } finally {
                try {
                  a2 || e3.return == null || e3.return();
                } finally {
                  if (s2)
                    throw i2;
                }
              }
              return r2;
            }
          }(e2, o2) || function(t4, e3) {
            if (t4) {
              if (typeof t4 == "string")
                return n2(t4, e3);
              var o3 = Object.prototype.toString.call(t4).slice(8, -1);
              return o3 === "Object" && t4.constructor && (o3 = t4.constructor.name), o3 === "Map" || o3 === "Set" ? Array.from(t4) : o3 === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(o3) ? n2(t4, e3) : void 0;
            }
          }(e2, o2) || function() {
            throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
          }()), r = i[1], a = i[3];
          if (!a)
            return r;
          if (typeof btoa == "function") {
            var s = btoa(unescape(encodeURIComponent(JSON.stringify(a)))), c = "sourceMappingURL=data:application/json;charset=utf-8;base64,".concat(s), l = "/*# ".concat(c, " */"), u = a.sources.map(function(t4) {
              return "/*# sourceURL=".concat(a.sourceRoot || "").concat(t4, " */");
            });
            return [r].concat(u).concat([l]).join("\n");
          }
          return [r].join("\n");
        };
      }, 1756: function(t2, n2, e2) {
        var o2 = e2(3379), i = e2.n(o2), r = e2(7795), a = e2.n(r), s = e2(569), c = e2.n(s), l = e2(3565), u = e2.n(l), d = e2(9216), f = e2.n(d), p = e2(4589), h = e2.n(p), A = e2(7087), C = {};
        C.styleTagTransform = h(), C.setAttributes = u(), C.insert = c().bind(null, "head"), C.domAPI = a(), C.insertStyleElement = f(), i()(A.Z, C), A.Z && A.Z.locals && A.Z.locals;
      }, 3379: function(t2) {
        var n2 = [];
        function e2(t3) {
          for (var e3 = -1, o3 = 0; o3 < n2.length; o3++)
            if (n2[o3].identifier === t3) {
              e3 = o3;
              break;
            }
          return e3;
        }
        function o2(t3, o3) {
          for (var r = {}, a = [], s = 0; s < t3.length; s++) {
            var c = t3[s], l = o3.base ? c[0] + o3.base : c[0], u = r[l] || 0, d = "".concat(l, " ").concat(u);
            r[l] = u + 1;
            var f = e2(d), p = { css: c[1], media: c[2], sourceMap: c[3], supports: c[4], layer: c[5] };
            if (f !== -1)
              n2[f].references++, n2[f].updater(p);
            else {
              var h = i(p, o3);
              o3.byIndex = s, n2.splice(s, 0, { identifier: d, updater: h, references: 1 });
            }
            a.push(d);
          }
          return a;
        }
        function i(t3, n3) {
          var e3 = n3.domAPI(n3);
          return e3.update(t3), function(n4) {
            if (n4) {
              if (n4.css === t3.css && n4.media === t3.media && n4.sourceMap === t3.sourceMap && n4.supports === t3.supports && n4.layer === t3.layer)
                return;
              e3.update(t3 = n4);
            } else
              e3.remove();
          };
        }
        t2.exports = function(t3, i2) {
          var r = o2(t3 = t3 || [], i2 = i2 || {});
          return function(t4) {
            t4 = t4 || [];
            for (var a = 0; a < r.length; a++) {
              var s = e2(r[a]);
              n2[s].references--;
            }
            for (var c = o2(t4, i2), l = 0; l < r.length; l++) {
              var u = e2(r[l]);
              n2[u].references === 0 && (n2[u].updater(), n2.splice(u, 1));
            }
            r = c;
          };
        };
      }, 569: function(t2) {
        var n2 = {};
        t2.exports = function(t3, e2) {
          var o2 = function(t4) {
            if (n2[t4] === void 0) {
              var e3 = document.querySelector(t4);
              if (window.HTMLIFrameElement && e3 instanceof window.HTMLIFrameElement)
                try {
                  e3 = e3.contentDocument.head;
                } catch (t5) {
                  e3 = null;
                }
              n2[t4] = e3;
            }
            return n2[t4];
          }(t3);
          if (!o2)
            throw new Error("Couldn't find a style target. This probably means that the value for the 'insert' parameter is invalid.");
          o2.appendChild(e2);
        };
      }, 9216: function(t2) {
        t2.exports = function(t3) {
          var n2 = document.createElement("style");
          return t3.setAttributes(n2, t3.attributes), t3.insert(n2, t3.options), n2;
        };
      }, 3565: function(t2, n2, e2) {
        t2.exports = function(t3) {
          var n3 = e2.nc;
          n3 && t3.setAttribute("nonce", n3);
        };
      }, 7795: function(t2) {
        t2.exports = function(t3) {
          var n2 = t3.insertStyleElement(t3);
          return { update: function(e2) {
            !function(t4, n3, e3) {
              var o2 = "";
              e3.supports && (o2 += "@supports (".concat(e3.supports, ") {")), e3.media && (o2 += "@media ".concat(e3.media, " {"));
              var i = e3.layer !== void 0;
              i && (o2 += "@layer".concat(e3.layer.length > 0 ? " ".concat(e3.layer) : "", " {")), o2 += e3.css, i && (o2 += "}"), e3.media && (o2 += "}"), e3.supports && (o2 += "}");
              var r = e3.sourceMap;
              r && typeof btoa != "undefined" && (o2 += "\n/*# sourceMappingURL=data:application/json;base64,".concat(btoa(unescape(encodeURIComponent(JSON.stringify(r)))), " */")), n3.styleTagTransform(o2, t4, n3.options);
            }(n2, t3, e2);
          }, remove: function() {
            !function(t4) {
              if (t4.parentNode === null)
                return false;
              t4.parentNode.removeChild(t4);
            }(n2);
          } };
        };
      }, 4589: function(t2) {
        t2.exports = function(t3, n2) {
          if (n2.styleSheet)
            n2.styleSheet.cssText = t3;
          else {
            for (; n2.firstChild; )
              n2.removeChild(n2.firstChild);
            n2.appendChild(document.createTextNode(t3));
          }
        };
      }, 491: function(t2, n2, e2) {
        var o2 = e2(8940), i = e2(4403), r = (e2(7911), e2(1900)), a = e2(3184), s = e2.n(a), c = (0, r.Z)(i.Z, o2.s, o2.x, false, null, "ef50c406", null);
        typeof s() == "function" && s()(c), n2.Z = c.exports;
      }, 4403: function(t2, n2, e2) {
        var o2 = e2(5938);
        n2.Z = o2.Z;
      }, 7911: function(t2, n2, e2) {
        e2(1756);
      }, 3184: function() {
      }, 8940: function(t2, n2, e2) {
        e2.d(n2, { s: function() {
          return o2;
        }, x: function() {
          return i;
        } });
        var o2 = function() {
          var t3 = this, n3 = t3.$createElement, e3 = t3._self._c || n3;
          return e3("li", { staticClass: "action", class: { "action--disabled": t3.disabled } }, [e3("button", { staticClass: "action-button", class: { focusable: t3.isFocusable }, attrs: { "aria-label": t3.ariaLabel, type: "button" }, on: { click: t3.onClick } }, [t3._t("icon", function() {
            return [e3("span", { staticClass: "action-button__icon", class: [t3.isIconUrl ? "action-button__icon--url" : t3.icon], style: { backgroundImage: t3.isIconUrl ? "url(" + t3.icon + ")" : null } })];
          }), t3._v(" "), t3.title ? e3("p", [e3("strong", { staticClass: "action-button__title" }, [t3._v("\n				" + t3._s(t3.title) + "\n			")]), t3._v(" "), e3("br"), t3._v(" "), e3("span", { staticClass: "action-button__longtext", domProps: { textContent: t3._s(t3.text) } })]) : t3.isLongText ? e3("p", { staticClass: "action-button__longtext", domProps: { textContent: t3._s(t3.text) } }) : e3("span", { staticClass: "action-button__text" }, [t3._v(t3._s(t3.text))]), t3._v(" "), t3._e()], 2)]);
        }, i = [];
      }, 1900: function(t2, n2, e2) {
        function o2(t3, n3, e3, o3, i, r, a, s) {
          var c, l = typeof t3 == "function" ? t3.options : t3;
          if (n3 && (l.render = n3, l.staticRenderFns = e3, l._compiled = true), o3 && (l.functional = true), r && (l._scopeId = "data-v-" + r), a ? (c = function(t4) {
            (t4 = t4 || this.$vnode && this.$vnode.ssrContext || this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext) || typeof __VUE_SSR_CONTEXT__ == "undefined" || (t4 = __VUE_SSR_CONTEXT__), i && i.call(this, t4), t4 && t4._registeredComponents && t4._registeredComponents.add(a);
          }, l._ssrRegister = c) : i && (c = s ? function() {
            i.call(this, (l.functional ? this.parent : this).$root.$options.shadowRoot);
          } : i), c)
            if (l.functional) {
              l._injectStyles = c;
              var u = l.render;
              l.render = function(t4, n4) {
                return c.call(n4), u(t4, n4);
              };
            } else {
              var d = l.beforeCreate;
              l.beforeCreate = d ? [].concat(d, c) : [c];
            }
          return { exports: t3, options: l };
        }
        e2.d(n2, { Z: function() {
          return o2;
        } });
      }, 2734: function(t2) {
        t2.exports = Vue;
      } }, n = {};
      function e(o2) {
        var i = n[o2];
        if (i !== void 0)
          return i.exports;
        var r = n[o2] = { id: o2, exports: {} };
        return t[o2](r, r.exports, e), r.exports;
      }
      e.n = function(t2) {
        var n2 = t2 && t2.__esModule ? function() {
          return t2.default;
        } : function() {
          return t2;
        };
        return e.d(n2, { a: n2 }), n2;
      }, e.d = function(t2, n2) {
        for (var o2 in n2)
          e.o(n2, o2) && !e.o(t2, o2) && Object.defineProperty(t2, o2, { enumerable: true, get: n2[o2] });
      }, e.o = function(t2, n2) {
        return Object.prototype.hasOwnProperty.call(t2, n2);
      }, e.r = function(t2) {
        typeof Symbol != "undefined" && Symbol.toStringTag && Object.defineProperty(t2, Symbol.toStringTag, { value: "Module" }), Object.defineProperty(t2, "__esModule", { value: true });
      };
      var o = {};
      return function() {
        e.r(o);
        var t2 = e(491);
        o.default = t2.Z;
      }(), o;
    }();
  });
})(ActionButton$1);
var ActionButton = /* @__PURE__ */ getDefaultExportFromCjs(ActionButton$1.exports);
var render$3 = function __render__3() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("NodeViewWrapper", {
    staticClass: "table-wrapper"
  }, [_c("NodeViewContent", {
    staticClass: "content",
    attrs: {
      "as": "table"
    }
  }), _vm.editor.isEditable ? _c("Actions", {
    staticClass: "table-settings",
    attrs: {
      "force-menu": true,
      "default-icon": "icon-table_settings"
    }
  }, [_c("ActionButton", {
    attrs: {
      "icon": "icon-delete",
      "close-after-click": true
    },
    on: {
      "click": _vm.deleteNode
    }
  }, [_vm._v(" " + _vm._s(_vm.t("text", "Delete this table")) + " ")])], 1) : _vm._e(), _c("div", {
    staticClass: "clearfix"
  })], 1);
};
var staticRenderFns$3 = [];
var TableView_vue_vue_type_style_index_0_scoped_true_lang = "";
const __vue2_script$3 = {
  name: "TableView",
  components: {
    ActionButton,
    Actions,
    NodeViewWrapper,
    NodeViewContent
  },
  props: {
    editor: {
      type: Object,
      required: true
    },
    deleteNode: {
      type: Function,
      required: true
    }
  },
  computed: {
    t: () => window.t
  }
};
const __cssModules$3 = {};
var __component__$3 = /* @__PURE__ */ normalizeComponent$2(__vue2_script$3, render$3, staticRenderFns$3, false, __vue2_injectStyles$3, "3d9e5cd9", null, null);
function __vue2_injectStyles$3(context) {
  for (let o in __cssModules$3) {
    this[o] = __cssModules$3[o];
  }
}
var TableView = /* @__PURE__ */ function() {
  return __component__$3.exports;
}();
var render$2 = function __render__4() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("NodeViewWrapper", {
    attrs: {
      "as": "td"
    }
  }, [_c("div", {
    staticClass: "container"
  }, [_c("NodeViewContent", {
    staticClass: "content"
  }), _vm.editor.isEditable ? _c("Actions", [_c("ActionButton", {
    attrs: {
      "icon": "icon-add_row_before",
      "close-after-click": true
    },
    on: {
      "click": _vm.addRowBefore
    }
  }, [_vm._v(" " + _vm._s(_vm.t("text", "Add row before")) + " ")]), _c("ActionButton", {
    attrs: {
      "icon": "icon-add_row_after",
      "close-after-click": true
    },
    on: {
      "click": _vm.addRowAfter
    }
  }, [_vm._v(" " + _vm._s(_vm.t("text", "Add row after")) + " ")]), _c("ActionButton", {
    attrs: {
      "icon": "icon-delete",
      "close-after-click": true
    },
    on: {
      "click": _vm.deleteRow
    }
  }, [_vm._v(" " + _vm._s(_vm.t("text", "Delete this row")) + " ")])], 1) : _vm._e()], 1)]);
};
var staticRenderFns$2 = [];
var TableCellView_vue_vue_type_style_index_0_scoped_true_lang = "";
const __vue2_script$2 = {
  name: "TableCellView",
  components: {
    ActionButton,
    Actions,
    NodeViewWrapper,
    NodeViewContent
  },
  props: {
    editor: {
      type: Object,
      required: true
    },
    getPos: {
      type: Function,
      required: true
    }
  },
  computed: {
    t: () => window.t
  },
  methods: {
    deleteRow() {
      this.editor.chain().focus().setTextSelection(this.getPos()).deleteRow().run();
    },
    addRowBefore() {
      this.editor.chain().focus().setTextSelection(this.getPos()).addRowBefore().run();
    },
    addRowAfter() {
      this.editor.chain().focus().setTextSelection(this.getPos()).addRowAfter().run();
    }
  }
};
const __cssModules$2 = {};
var __component__$2 = /* @__PURE__ */ normalizeComponent$2(__vue2_script$2, render$2, staticRenderFns$2, false, __vue2_injectStyles$2, "ebb3e394", null, null);
function __vue2_injectStyles$2(context) {
  for (let o in __cssModules$2) {
    this[o] = __cssModules$2[o];
  }
}
var TableCellView = /* @__PURE__ */ function() {
  return __component__$2.exports;
}();
var render$1 = function __render__5() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("NodeViewWrapper", {
    attrs: {
      "as": "th"
    }
  }, [_c("div", [_c("NodeViewContent", {
    staticClass: "content"
  }), _vm.editor.isEditable ? _c("Actions", [_c("ActionButton", {
    attrs: {
      "icon": "icon-add_col_before",
      "close-after-click": true
    },
    on: {
      "click": _vm.addColumnBefore
    }
  }, [_vm._v(" " + _vm._s(_vm.t("text", "Add column before")) + " ")]), _c("ActionButton", {
    attrs: {
      "icon": "icon-add_col_after",
      "close-after-click": true
    },
    on: {
      "click": _vm.addColumnAfter
    }
  }, [_vm._v(" " + _vm._s(_vm.t("text", "Add column after")) + " ")]), _c("ActionButton", {
    attrs: {
      "icon": "icon-delete",
      "close-after-click": true
    },
    on: {
      "click": _vm.deleteColumn
    }
  }, [_vm._v(" " + _vm._s(_vm.t("text", "Delete this column")) + " ")])], 1) : _vm._e()], 1)]);
};
var staticRenderFns$1 = [];
var TableHeaderView_vue_vue_type_style_index_0_scoped_true_lang = "";
const __vue2_script$1 = {
  name: "TableHeaderView",
  components: {
    ActionButton,
    Actions,
    NodeViewWrapper,
    NodeViewContent
  },
  props: {
    editor: {
      type: Object,
      required: true
    },
    getPos: {
      type: Function,
      required: true
    }
  },
  computed: {
    t: () => window.t
  },
  methods: {
    deleteColumn() {
      this.editor.chain().focus().setTextSelection(this.getPos()).deleteColumn().run();
    },
    addColumnBefore() {
      this.editor.chain().focus().setTextSelection(this.getPos()).addColumnBefore().run();
    },
    addColumnAfter() {
      this.editor.chain().focus().setTextSelection(this.getPos()).addColumnAfter().run();
    }
  }
};
const __cssModules$1 = {};
var __component__$1 = /* @__PURE__ */ normalizeComponent$2(__vue2_script$1, render$1, staticRenderFns$1, false, __vue2_injectStyles$1, "4ac11d9e", null, null);
function __vue2_injectStyles$1(context) {
  for (let o in __cssModules$1) {
    this[o] = __cssModules$1[o];
  }
}
var TableHeaderView = /* @__PURE__ */ function() {
  return __component__$1.exports;
}();
function extendNodeWithView(node, view) {
  return node.extend({
    addNodeView() {
      return VueNodeViewRenderer(view);
    }
  });
}
Table.extend({
  addNodeView() {
    return VueNodeViewRenderer(TableView);
  },
  addExtensions() {
    return [
      TableCaption,
      extendNodeWithView(TableCell, TableCellView),
      extendNodeWithView(TableHeader, TableHeaderView),
      TableHeadRow,
      TableRow
    ];
  }
});
/*
 * @copyright Copyright (c) 2022 Max <max@nextcloud.com>
 *
 * @author Max <max@nextcloud.com>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
*/
Extension.create({
  name: "PlainText",
  addExtensions() {
    return [
      PlainTextDocument,
      Text,
      CodeBlockLowlight
    ];
  }
});
/*
 * @copyright Copyright (c) 2022 Max <max@nextcloud.com>
 *
 * @author Max <max@nextcloud.com>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
function markdownUnderlines(md) {
  md.inline.ruler2.after("emphasis", "underline", (state2) => {
    const tokens = state2.tokens;
    for (let i = tokens.length - 1; i > 0; i--) {
      const token = tokens[i];
      if (token.markup === "__") {
        if (token.type === "strong_open") {
          tokens[i].tag = "u";
          tokens[i].type = "u_open";
        }
        if (token.type === "strong_close") {
          tokens[i].tag = "u";
          tokens[i].type = "u_close";
        }
      }
    }
    return false;
  });
}
/*
 * @copyright Copyright (c) 2022 Max <max@nextcloud.com>
 *
 * @author Max <max@nextcloud.com>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
function splitMixedLists(md) {
  md.core.ruler.after("github-task-lists", "split-mixed-task-lists", (state2) => {
    const tokens = state2.tokens;
    for (let i = 0; i < tokens.length; i++) {
      const token = tokens[i];
      if (token.attrGet("class") !== "contains-task-list") {
        continue;
      }
      const firstChild = tokens[i + 1];
      const startsWithTask = firstChild.attrGet("class") === "task-list-item";
      if (!startsWithTask) {
        token.attrs.splice(token.attrIndex("class"));
        if (token.attrs.length === 0) {
          token.attrs = null;
        }
      }
      const splitBefore = findChildOf(tokens, i, (child) => {
        return child.nesting === 1 && child.attrGet("class") !== firstChild.attrGet("class");
      });
      if (splitBefore > i) {
        splitListAt(tokens, splitBefore, state2.Token);
      }
    }
    return false;
  });
}
function splitListAt(tokens, index, TokenConstructor) {
  const closeList = new TokenConstructor("bullet_list_close", "ul", -1);
  closeList.block = true;
  const openList = new TokenConstructor("bullet_list_open", "ul", 1);
  openList.attrSet("class", "contains-task-list");
  openList.block = true;
  tokens.splice(index, 0, closeList, openList);
}
function findChildOf(tokens, parentIndex, predicate) {
  const searchLevel = tokens[parentIndex].level + 1;
  for (let i = parentIndex + 1; i < tokens.length; i++) {
    const token = tokens[i];
    if (token.level < searchLevel) {
      return -1;
    }
    if (token.level === searchLevel && predicate(tokens[i])) {
      return i;
    }
  }
  return -1;
}
const markdownit = MarkdownIt("commonmark", { html: false, breaks: false }).enable("strikethrough").enable("table").use(taskLists, { enable: true, labelAfter: true }).use(splitMixedLists).use(markdownUnderlines).use(callouts);
/*
 * @copyright Copyright (c) 2020 Azul <azul@riseup.net>
 *
 * @author Azul <azul@riseup.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
const absolutePath = function(base, rel) {
  if (!rel) {
    return base;
  }
  if (rel[0] === "/") {
    return rel;
  }
  base = base.split("/");
  rel = rel.split("/");
  while (rel[0] === ".." || rel[0] === ".") {
    if (rel[0] === "..") {
      base.pop();
    }
    rel.shift();
  }
  return base.concat(rel).join("/");
};
const basedir = function(file) {
  const end = file.lastIndexOf("/");
  return end > 0 ? file.slice(0, end) : file.slice(0, end + 1);
};
const domHref = function(node) {
  const ref = node.attrs.href;
  if (!ref) {
    return ref;
  }
  if (ref.match(/^[a-zA-Z]*:/)) {
    return ref;
  }
  const match2 = ref.match(/^([^?]*)\?fileId=(\d+)/);
  if (match2) {
    const [, relPath, id2] = match2;
    const currentDir = basedir(OCA.Viewer.file);
    const dir = absolutePath(currentDir, basedir(relPath));
    return generateUrl(`/apps/files/?dir=${dir}&openfile=${id2}#relPath=${relPath}`);
  }
};
const parseHref = function(dom) {
  const ref = dom.getAttribute("href");
  if (!ref) {
    return ref;
  }
  const match2 = ref.match(/\?dir=([^&]*)&openfile=([^&]*)#relPath=([^&]*)/);
  if (match2) {
    const [, , id2, path2] = match2;
    return `${path2}?fileId=${id2}`;
  }
  return ref;
};
const openLink = function(event, _attrs) {
  const linkElement = event.target.closest("a");
  event.stopPropagation();
  const htmlHref = linkElement.href;
  if (event.button === 0 && !event.ctrlKey && htmlHref.startsWith(window.location.origin)) {
    const query = OC.parseQueryString(htmlHref);
    const fragment = OC.parseQueryString(htmlHref.split("#").pop());
    if (query.dir && fragment.relPath) {
      const filename = fragment.relPath.split("/").pop();
      const path2 = `${query.dir}/${filename}`;
      document.title = `${filename} - ${OC.theme.title}`;
      if (window.location.pathname.match(/apps\/files\/$/))
        ;
      OCA.Viewer.open({ path: path2 });
      return;
    }
    if (query.fileId) {
      window.open(generateUrl(`/f/${query.fileId}`));
      return;
    }
  }
  if (!markdownit.validateLink(htmlHref)) {
    console.error("Invalid link", htmlHref);
    return false;
  }
  window.open(htmlHref);
  return true;
};
const clickHandler = ({ editor, type, onClick: onClick2 }) => {
  return new Plugin({
    props: {
      key: new PluginKey("textLink"),
      handleClick: (view, pos, event) => {
        const $clicked = view.state.doc.resolve(pos);
        const link = $clicked.marks().find((m) => m.type.name === type.name);
        if (!link) {
          return false;
        }
        if (!link.attrs.href) {
          console.warn("Could not determine href of link.");
          console.debug(link);
          return false;
        }
        return onClick2 == null ? void 0 : onClick2(event, link.attrs);
      }
    }
  });
};
/*
 * @copyright Copyright (c) 2019 Azul <azul@riseup.net>
 *
 * @author Azul <azul@riseup.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
const Link = TipTapLink.extend({
  addOptions() {
    var _a;
    return __spreadProps(__spreadValues({}, (_a = this.parent) == null ? void 0 : _a.call(this)), {
      onClick: openLink
    });
  },
  addAttributes() {
    return {
      href: {
        default: null
      }
    };
  },
  inclusive: false,
  parseHTML: [
    {
      tag: "a[href]",
      getAttrs: (dom) => ({
        href: parseHref(dom)
      })
    }
  ],
  renderHTML: ({ mark, HTMLAttributes }) => ["a", __spreadProps(__spreadValues({}, mark.attrs), {
    href: domHref(mark),
    title: mark.attrs.href,
    rel: "noopener noreferrer nofollow"
  }), 0],
  addProseMirrorPlugins() {
    const plugins = this.parent().filter(({ key }) => {
      return !key.startsWith("handleClickLink");
    });
    if (!this.options.openOnClick) {
      return plugins;
    }
    return [
      ...plugins,
      clickHandler({
        editor: this.editor,
        type: this.type,
        onClick: this.options.onClick
      })
    ];
  }
});
/*
 * @copyright Copyright (c) 2019 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
var Strike = TipTapStrike.extend({
  parseHTML() {
    return [
      {
        tag: "s"
      },
      {
        tag: "del"
      },
      {
        tag: "strike"
      },
      {
        style: "text-decoration",
        getAttrs: (value) => value === "line-through"
      }
    ];
  },
  renderHTML() {
    return ["s", 0];
  },
  toMarkdown: {
    open: "~~",
    close: "~~",
    mixable: true,
    expelEnclosingWhitespace: true
  }
});
/*
 * @copyright Copyright (c) 2019 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
const Strong = Bold.extend({
  name: "strong",
  addInputRules() {
    return [
      markInputRule({
        find: starInputRegex,
        type: this.type
      })
    ];
  },
  addPasteRules() {
    return [
      markPasteRule({
        find: starPasteRegex,
        type: this.type
      })
    ];
  }
});
/*
 * @copyright Copyright (c) 2022 Max <max@nextcloud.com>
 *
 * @author Max <max@nextcloud.com>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
const Underline = TipTapUnderline.extend({
  parseHTML() {
    return [
      {
        tag: "u"
      },
      {
        style: "text-decoration",
        getAttrs: (value) => value === "underline"
      }
    ];
  },
  renderHTML() {
    return ["u", 0];
  },
  toMarkdown: {
    open: "__",
    close: "__",
    mixable: true,
    expelEnclosingWhitespace: true
  },
  addInputRules() {
    return [
      markInputRule({
        find: underscoreInputRegex,
        type: this.type
      })
    ];
  },
  addPasteRules() {
    return [
      markPasteRule({
        find: underscorePasteRegex,
        type: this.type
      })
    ];
  }
});
/*
 * @copyright Copyright (c) 2019 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
const Italic = TipTapItalic.extend({
  name: "em"
});
/*
 * @copyright Copyright (c) 2022 Max <max@nextcloud.com>
 *
 * @author Max <max@nextcloud.com>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
*/
var RichText = Extension.create({
  name: "RichText",
  addOptions() {
    return {
      currentDirectory: void 0,
      link: {},
      extensions: []
    };
  },
  addExtensions() {
    const defaultExtensions = [
      Document,
      Text,
      Paragraph,
      Heading,
      Strong,
      Italic,
      Strike,
      Blockquote,
      CodeBlock,
      BulletList,
      HorizontalRule,
      OrderedList,
      ListItem,
      Table,
      TaskList,
      TaskItem,
      Callout,
      Underline,
      Image$1.configure({
        currentDirectory: this.options.currentDirectory,
        inline: true
      }),
      Dropcursor
    ];
    if (this.options.link !== false) {
      defaultExtensions.push(Link.configure(__spreadProps(__spreadValues({}, this.options.link), {
        openOnClick: true
      })));
    }
    const additionalExtensionNames = this.options.extensions.map((e) => e.name);
    return [
      ...this.options.extensions,
      ...defaultExtensions.filter((e) => !additionalExtensionNames.includes(e.name))
    ];
  }
});
var render = function __render__6() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _vm.editor ? _c("EditorContent", {
    attrs: {
      "id": "read-only-editor",
      "editor": _vm.editor
    }
  }) : _vm._e();
};
var staticRenderFns = [];
var RichtextReader_vue_vue_type_style_index_0_lang = "";
const __vue2_script = {
  name: "RichtextReader",
  components: { EditorContent },
  inject: ["currentDirectory"],
  props: {
    content: {
      type: String,
      required: true
    }
  },
  data: () => {
    return {
      editor: null
    };
  },
  computed: {
    htmlContent() {
      return markdownit.render(this.content);
    }
  },
  watch: {
    content() {
      this.updateContent();
    }
  },
  mounted() {
    this.editor = this.createEditor();
    this.editor.setOptions({ editable: false });
  },
  beforeDestroy() {
    this.editor.destroy();
  },
  methods: {
    createEditor() {
      return new Editor({
        content: this.htmlContent,
        extensions: [
          RichText.configure({
            currentDirectory: this.currentDirectory,
            link: {
              onClick: (event, attrs) => this.$emit("click-link", event, attrs)
            }
          })
        ]
      });
    },
    updateContent() {
      this.editor.commands.setContent(this.htmlContent);
    }
  }
};
const __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent$2(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (let o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var RichtextReader = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export { RichtextReader };
